OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Používateľská relácia sa neočakávane prerušila",
    "Provided email-address is not valid" : "Zadaná adresa e-mailu nie je platná",
    "%s has published the calendar »%s«" : "Používateľ %s zverejnil kalendár %s",
    "Unexpected error sending email. Please contact your administrator." : "Neočakávaná chyba počas odosielania e-mailu. Obráťte sa na správcu",
    "Successfully sent email to %1$s" : "E-mail bol úspešne odoslaný pre %1$s",
    "Hello," : "Ahoj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás upozorniť, že používateľ %s zverejnil kalendár %s",
    "Open »%s«" : "Otvoriť »%s«",
    "Cheers!" : "Pekný deň!",
    "Upcoming events" : "Nadchádzajúce udalosti",
    "Appointments" : "Stretnutia",
    "Schedule appointment \"%s\"" : "Naplánovať stretnutie \"%s\"",
    "Schedule an appointment" : "Naplánovať stretnutie",
    "Prepare for %s" : "Pripraviť na %s",
    "Follow up for %s" : "Sledovať pre %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Vaše stretnutie „%s“ s %s vyžaduje potvrdenie",
    "Dear %s, please confirm your booking" : "Vážený %s, potvrďte svoju rezerváciu",
    "Confirm" : "Potvrdiť",
    "This confirmation link expires in %s hours." : "Platnosť tohto potvrdzovacieho odkazu vyprší o %s hodín.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ak predsa len chcete stretnutie zrušiť, kontaktujte organizátora odpoveďou na tento e-mail alebo návštevou jeho profilovej stránky.",
    "Your appointment \"%s\" with %s has been accepted" : "Vaše stretnutie „%s“ s %s bolo potvrdené",
    "Dear %s, your booking has been accepted." : "Vážený/á %s, vaša rezervácia bola prijatá.",
    "Appointment for:" : "Termín pre:",
    "Date:" : "Dátum:",
    "Where:" : "Kde:",
    "Your Comment:" : "Vaša poznámka:",
    "Calendar" : "Kalendár",
    "A Calendar app for Nextcloud" : "Aplikácia Kalendár pre Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aplikácia Kalendár je užívateľské rozhranie pre server CalDAV spoločnosti Nextcloud. Jednoducho synchronizujte udalosti z rôznych zariadení s Nextcloud a upravujte ich online.\n\n* 🚀 **Integrácia s ďalšími aplikáciami Nextcloud! ** V súčasnosti Kontakty - prídu ďalšie.\n* 🌐 ** Podpora WebCal! ** Chcete vidieť zápasy svojho obľúbeného tímu v kalendári? Žiadny problém!\n* 🙋 ** Účastníci! ** Pozvite ľudí na vaše udalosti\n* ⌚️ ** Voľný/Zaneprázdený** Pozrite sa, kedy sa môžu vaši účastníci stretnúť\n* ⏰ ** Pripomienky! ** Získajte upozornenia na udalosti vo vašom prehliadači a prostredníctvom e-mailu.\n* 🙈 ** Nebudeme znovu objavovať koleso! ** Na základe vyborných knižníc [c-dav] (https://github.com/nextcloud/cdav-library), [ical.js] (https: // github. com / mozilla-comm / ical.js) a [fullcalendar] (https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Predchádzajúci deň",
    "Previous week" : "Predchádzajúci týždeň",
    "Previous month" : "Predchádzajúci mesiac",
    "Next day" : "Nasledujúci deň",
    "Next week" : "Nasledujúci týždeň",
    "Next month" : "Nasledujúci mesiac",
    "New event" : "Nová udalosť",
    "Today" : "Dnes",
    "Day" : "Deň",
    "Week" : "Týždeň",
    "Month" : "Mesiac",
    "List" : "Zoznam",
    "Preview" : "Náhľad",
    "Copy link" : "Kopírovať odkaz",
    "Edit" : "Upraviť",
    "Delete" : "Zmazať",
    "Appointment link was copied to clipboard" : "Odkaz na stretnutie bol skopírovaný do schránky",
    "Appointment link could not be copied to clipboard" : "Odkaz na stretnutie nemohol byť skopírovaný do schránky",
    "Add new" : "Pridať nový",
    "Untitled calendar" : "Kalendár bez názvu",
    "Edit name" : "Upraviť názov",
    "Saving name …" : "Ukladanie názvu …",
    "Edit color" : "Upraviť farbu",
    "Saving color …" : "Ukladanie farby …",
    "Copy private link" : "Kopírovať privátny odkaz",
    "Export" : "Export",
    "Unshare from me" : "Zrušiť zdieľanie so mnou",
    "Disable calendar \"{calendar}\"" : "Zakázať kalendár „{calendar}“",
    "Disable untitled calendar" : "Zakázať nepomenovaný kalendár",
    "Enable calendar \"{calendar}\"" : "Povoliť kalendár „{calendar}“",
    "Enable untitled calendar" : "Povoliť nepomenovaný kalendár",
    "An error occurred, unable to change visibility of the calendar." : "Vyskytla sa chyba, nie je možné zmeniť viditeľnosť kalendára.",
    "An error occurred, unable to delete the calendar." : "Vyskytla sa chyba, nie je možné zmazať kalendár.",
    "Calendar link copied to clipboard." : "Odkaz na kalendár skopírovaný do schránky.",
    "Calendar link could not be copied to clipboard." : "Odkaz na kalendár nebolo možné  skopírovať do schránky.",
    "An error occurred, unable to rename the calendar." : "Vyskytla sa chyba, nie je možné premenovať kalendár.",
    "An error occurred, unable to change the calendar's color." : "Vyskytla sa chyba, nie je možné zmeniť farbu kalendára.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Zdieľanie kalendára bude zmazané za {countdown} sekundu","Zdieľanie kalendára bude zmazané za {countdown} sekundy","Zdieľanie kalendára bude zmazané za {countdown} sekúnd","Zdieľanie kalendára bude zmazané za {countdown} sekúnd"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendár bude zmazaný za {countdown} sekundu","Kalendár bude zmazaný za {countdown} sekundy","Kalendár bude zmazaný za {countdown} sekúnd","Kalendár bude zmazaný za {countdown} sekúnd"],
    "Share link" : "Sprístupniť odkaz",
    "Publish calendar" : "Zverejniť kalendár",
    "Publishing calendar" : "Zverejňovať kalendár",
    "Copy public link" : "Kopírovať verejný odkaz",
    "Send link to calendar via email" : "Odoslať odkaz na kalendár emailom",
    "Enter one address" : "Zadajte jednu adresu",
    "Sending email …" : "Odosielanie e-mailu …",
    "Copy subscription link" : "Kopírovať odkaz na odber",
    "Copying link …" : "Kopírovanie odkazu …",
    "Copied link" : "Kopírovaný odkaz",
    "Could not copy link" : "Nie je možné skopírovať odkaz",
    "Copy embedding code" : "Kopírovať vložený kód",
    "Copying code …" : "Kopírovanie kódu …",
    "Copied code" : "Skopírovaný kód",
    "Could not copy code" : "Nie je možné skopírovať kód",
    "Delete share link" : "Zmazať sprístupnený odkaz",
    "Deleting share link …" : "Mazanie odkazu pre sprístupnenie …",
    "An error occurred, unable to publish calendar." : "Vyskytla sa chyba, nie je možné zverejniť kalendár.",
    "An error occurred, unable to send email." : "Vyskytla sa chyba, nepodarilo sa odoslať e-mail.",
    "Embed code copied to clipboard." : "Vložený kód skopírovaný do schránky",
    "Embed code could not be copied to clipboard." : "Vložený kód nebolo možné  skopírovať do schránky.",
    "Unpublishing calendar failed" : "Zrušenie zverejnenia kalendára zlyhalo",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "No users or groups" : "Žiadni používatelia alebo skupiny",
    "can edit" : "môže upraviť",
    "Unshare with {displayName}" : "Zrušiť zdieľanie s {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Vyskytla sa chyba, nie je možné zmeniť zdieľanie kalendára.",
    "An error occurred, unable to change the permission of the share." : "Vyskytla sa chyba, nie je možné zmeniť práva na zdieľanie kalendára.",
    "New calendar" : "Nový kalendár",
    "Name for new calendar" : "Názov nového kalendára",
    "Creating calendar …" : "Vytváranie kalendára …",
    "New calendar with task list" : "Nový kalendár so zoznamom úloh",
    "New subscription from link (read-only)" : "Nový odber z odkazu (iba na čítanie)",
    "Creating subscription …" : "Vytvára sa odber …",
    "An error occurred, unable to create the calendar." : "Vyskytla sa chyba, nie je možné vytvoriť kalendár.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vkladajte platné odkazy (musia sa začínať http://, https://, webcal:// alebo webcals://)",
    "Trash bin" : "Kôš",
    "Loading deleted items." : "Nahrávam zmazané položky.",
    "You do not have any deleted items." : "Nemáte žiadne zmazané položky.",
    "Name" : "Názov",
    "Deleted" : "Zmazané",
    "Restore" : "Obnoviť",
    "Delete permanently" : "Zmazať  natrvalo",
    "Empty trash bin" : "Vyprázdniť kôš",
    "Untitled item" : "Položka bez názvu",
    "Unknown calendar" : "Neznámy kalendár",
    "Could not load deleted calendars and objects" : "Nie je možné načítať zmazané kalendáre a objekty",
    "Could not restore calendar or event" : "Nie je možné obnoviť kalendár alebo udalosť",
    "Do you really want to empty the trash bin?" : "Naozaj chcete vyprázdniť kôš?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Položky v odpadkovom koši budú odstránené po {numDays} dni","Položky v odpadkovom koši budú odstránené po {numDays} dňoch","Položky v odpadkovom koši budú odstránené po {numDays} dňoch","Položky v odpadkovom koši budú odstránené po {numDays} dňoch"],
    "Could not update calendar order." : "Poradie kalendára sa nepodarilo aktualizovať.",
    "Import calendars" : "Import kalendára",
    "Please select a calendar to import into …" : "Vyberte kalendár do ktorého importovať …",
    "Filename" : "Názov súboru",
    "Calendar to import into" : "Kalendár na import do ...",
    "Cancel" : "Zrušiť",
    "_Import calendar_::_Import calendars_" : ["Import kalendára","Import kalendárov","Import kalendárov","Import kalendárov"],
    "{filename} could not be parsed" : "{filename} nie je možné spracovať",
    "No valid files found, aborting import" : "Nenašli sa žiadne platné súbory, import sa prerušuje",
    "Import partially failed. Imported {accepted} out of {total}." : "Import čiastočne zlyhal. Importované {accepted} z {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Úspešne naimportovaná %n udalosť","Úspešne naimportované %n udalosti","Úspešne naimportovaných %n udalostí","Úspešne naimportovaných %n udalostí"],
    "Automatic" : "Automaticky",
    "Automatic ({detected})" : "Automaticky ({detected})",
    "New setting was not saved successfully." : "Nové nastavenie nebolo možné uložiť.",
    "Shortcut overview" : "Stručný prehľad",
    "or" : "alebo",
    "Navigation" : "Navigácia",
    "Previous period" : "Predchádzajúce obdobie",
    "Next period" : "Nadchádzajúce obdobie",
    "Views" : "Zobrazenia",
    "Day view" : "Denné zobrazenie",
    "Week view" : "Týždenné zobrazenie",
    "Month view" : "Mesačné zobrazenie",
    "List view" : "Zobraziť ako zoznam",
    "Actions" : "Akcie",
    "Create event" : "Vytvoriť udalosť",
    "Show shortcuts" : "Zobraziť skratky",
    "Editor" : "Editor",
    "Close editor" : "Zavrieť editor",
    "Save edited event" : "Uložiť upravenú udalosť",
    "Delete edited event" : "Zmazať upravenú udalosť",
    "Duplicate event" : "Duplicitná udalosť",
    "Enable birthday calendar" : "Povoliť narodeninový kalendár",
    "Show tasks in calendar" : "Zobraziť úlohy v kalendári",
    "Enable simplified editor" : "Povoliť zjednodušený editor",
    "Limit visible events per view" : "Obmedziť viditeľné udalosti v jednotlivých pohľadoch",
    "Show weekends" : "Zobraziť víkendy",
    "Show week numbers" : "Zobraziť čísla týždňov",
    "Time increments" : "Časové prírastky",
    "Default reminder" : "Predvolená pripomienka",
    "Copy primary CalDAV address" : "Kopírovať primárnu CalDAV adresu",
    "Copy iOS/macOS CalDAV address" : "Kopírovať iOS/macOS CalDAV adresu",
    "Personal availability settings" : "Osobné nastavenia dostupnosti",
    "Show keyboard shortcuts" : "Zobraziť klávesové skratky",
    "Calendar settings" : "Nastavenia kalendára",
    "No reminder" : "Žiadna pripomienka",
    "CalDAV link copied to clipboard." : "Odkaz CalDAV skopírovaný do schránky.",
    "CalDAV link could not be copied to clipboard." : "Odkaz CalDAV nebolo možné skopírovať do schránky.",
    "Appointment was created successfully" : "Stretnutie bolo úspešne vytvorené",
    "Appointment was updated successfully" : "Stretnutie bolo úspešne aktualizované",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minúta","{duration} minút","{duration} minút","{duration} minút"],
    "0 minutes" : "0 minút",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hodina","{duration} hodiny","{duration} hodín","{duration} hodín"],
    "_{duration} day_::_{duration} days_" : ["{duration} deň","{duration} dni","{duration} dní","{duration} dní"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} týždeň","{duration} týždne","{duration} týždňov","{duration} týždňov"],
    "_{duration} month_::_{duration} months_" : ["{duration} mesiac","{duration} mesiace","{duration} mesiacov","{duration} mesiacov"],
    "_{duration} year_::_{duration} years_" : ["{duration} rok","{duration} roky","{duration} rokov","{duration} rokov"],
    "To configure appointments, add your email address in personal settings." : "Pre nastavenie stretnutia, pridajte svoju e-mail adresu v osobných nastaveniach.",
    "Public – shown on the profile page" : "Verejné – zobrazí sa na stránke profilu",
    "Private – only accessible via secret link" : "Súkromné ​​– prístupné iba cez tajný odkaz",
    "Location" : "Umiestnenie",
    "Description" : "Popis",
    "Visibility" : "Viditeľnosť",
    "Duration" : "Trvanie",
    "Increments" : "Prírastky",
    "Additional calendars to check for conflicts" : "Ďalšie kalendáre pre kontrolu konfliktov",
    "Pick time ranges where appointments are allowed" : "Vyberte časové rozsahy, v ktorých sú povolené stretnutia",
    "to" : "do",
    "Delete slot" : "Odstrániť slot",
    "No times set" : "Nie sú nastavené žiadne časy",
    "Add" : "Pridať",
    "Monday" : "Pondelok",
    "Tuesday" : "Utorok",
    "Wednesday" : "Streda",
    "Thursday" : "Štvrtok",
    "Friday" : "Piatok",
    "Saturday" : "Sobota",
    "Sunday" : "Nedeľa",
    "Add time before and after the event" : "Pridajte čas pred a po udalosti",
    "Before the event" : "Pred udalosťou",
    "After the event" : "Po udalosti",
    "Planning restrictions" : "Obmedzenia plánovania",
    "Minimum time before next available slot" : "Minimálny čas do ďalšieho dostupného slotu",
    "Max slots per day" : "Max. počet slotov na deň",
    "Limit how far in the future appointments can be booked" : "Obmedzte, ako ďaleko v budúcnosti je možné rezervovať schôdzky",
    "Create appointment" : "Vytvorte stretnutie",
    "Edit appointment" : "Upraviť stretnutie",
    "Save" : "Uložiť",
    "Update" : "Aktualizovať",
    "Please confirm your reservation" : "Prosím, potvrďte vašu rezerváciu",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Poslali sme vám e-mail s podrobnosťami. Potvrďte svoj termín pomocou odkazu v e-maili. Teraz môžete túto stránku zatvoriť.",
    "Your name" : "Vaše meno",
    "Your email address" : "Vaša e-mail adresa",
    "Please share anything that will help prepare for our meeting" : "Zdieľajte čokoľvek, čo vám pomôže pripraviť sa na naše stretnutie",
    "Could not book the appointment. Please try again later or contact the organizer." : "Termín sa nepodarilo zarezervovať. Skúste to znova neskôr alebo kontaktujte organizátora.",
    "Book the appointment" : "Rezervovať stretnutie",
    "Reminder" : "Pripomienka",
    "before at" : "pred o",
    "Notification" : "Hlásenie",
    "Email" : "E-mail",
    "Audio notification" : "Hlasový oznam",
    "Other notification" : "Ostatné hlásenia",
    "Relative to event" : "Prislúchajúci k udalosti",
    "On date" : "Dňa",
    "Edit time" : "Zmeniť čas pripomienky",
    "Save time" : "Uložiť zmenený čas pripomienky",
    "Remove reminder" : "Odstrániť pripomienku",
    "on" : "o",
    "at" : "na",
    "+ Add reminder" : "+ Pridať pripomienku",
    "Add reminder" : "Pridať pripomienku",
    "_second_::_seconds_" : ["sekunda","sekundy","sekúnd","sekúnd"],
    "_minute_::_minutes_" : ["minúta","minúty","minút","minút"],
    "_hour_::_hours_" : ["hodina","hodiny","hodín","hodín"],
    "_day_::_days_" : ["deň","dni","dní","dní"],
    "_week_::_weeks_" : ["týždeň","týždne","týždňov","týždňov"],
    "Invitation accepted" : "Pozvánka prijatá",
    "Available" : "Dostupné",
    "Suggested" : "Navrhované",
    "Participation marked as tentative" : "Účasť označená ako predbežná",
    "Accepted {organizerName}'s invitation" : "Prijaté pozvanie od {organizerName}",
    "Not available" : "Nie je k dispozícií",
    "Invitation declined" : "Pozvánka odmietnutá",
    "Declined {organizerName}'s invitation" : "Pozvánka od {organizerName} bola odmietnutá",
    "Invitation is delegated" : "Pozvánka je delegovaná",
    "Checking availability" : "Kontrolujem dostupnosť",
    "Invitation sent" : "Pozvánka odoslaná",
    "Has not responded to {organizerName}'s invitation yet" : "Zatiaľ neodpovedal na pozvanie od {organizerName}",
    "Availability of attendees, resources and rooms" : "Dostupnosť účastníkov, zdrojov a miestností",
    "{organizer} (organizer)" : "{organizer} (organizátor)",
    "Free" : "Voľný",
    "Busy (tentative)" : "Zaneprázdnený (predbežne)",
    "Busy" : "Zaneprázdnený",
    "Out of office" : "Mimo kancelárie",
    "Unknown" : "Neznámy",
    "Accept" : "Prijať",
    "Decline" : "Odmietnuť",
    "Tentative" : "Neistý",
    "The invitation has been accepted successfully." : "Pozvánka bola úspešne prijatá.",
    "Failed to accept the invitation." : "Prijatie pozvánky zlyhalo.",
    "The invitation has been declined successfully." : "Pozvánka bola odmietnutá.",
    "Failed to decline the invitation." : "Odmietnutie pozvánky zlyhalo.",
    "Your participation has been marked as tentative." : "Vaša účasť bola označená ako predbežná.",
    "Failed to set the participation status to tentative." : "Zlyhalo nastavenie vašej účasti ako predbežnej.",
    "Create Talk room for this event" : "Vytvoriť pre túto udalosť miestnosť v Talk",
    "Show busy times" : "Zobraziť časy zaneprázdnenosti",
    "No attendees yet" : "Zatiaľ žiadni účastníci",
    "Successfully appended link to talk room to description." : "Do popisu bol úspešne pridaný odkaz na miestnosť v Talk",
    "Error creating Talk room" : "Chyba pri vytváraní miestnosti v Talk",
    "Send email" : "Odoslať email",
    "Chairperson" : "Predseda",
    "Required participant" : "Požadovaná účasť",
    "Optional participant" : "Nepovinná účasť",
    "Non-participant" : "Bez účasti",
    "Remove attendee" : "Odstrániť účastníka",
    "Search for emails, users or contacts" : "Vyhľadať emaily, užívateľov alebo kontakty",
    "No match found" : "Nenašla sa žiadna zhoda",
    "(organizer)" : "(organizátor)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Ak chcete posielať pozvánky a vybavovať odpovede, [linkopen] pridajte svoju e-mailovú adresu do osobných nastavení [linkclose].",
    "Remove color" : "Odobrať farbu",
    "Event title" : "Názov udalosti",
    "All day" : "Celý deň",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "U opakovaných udalostí nie je možné u jednotlivého výskytu zvlášť meniť, či je udalosť celodenná alebo ne.",
    "from {startDate}" : "od {startDate}",
    "from {startDate} at {startTime}" : "od {startDate} o {startTime}",
    "to {endDate}" : "do {endDate}",
    "to {endDate} at {endTime}" : "do {endDate} o {endTime}",
    "Repeat" : "Opakovať",
    "End repeat" : "Koniec opakovania",
    "Select to end repeat" : "Vyberte koniec opakovania",
    "never" : "nikdy",
    "on date" : "dňa",
    "after" : "po",
    "_time_::_times_" : ["krát","krát","krát","krát"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Táto udalosť je výnimkou v opakovanej udalosti. Nie je možné k nej pridať opakovanie.",
    "first" : "prvý",
    "third" : "tretie",
    "fourth" : "štvrté",
    "fifth" : "piate",
    "second to last" : "po koľko sekúnd",
    "last" : "posledné",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Zmeny v opakovanej udalosti budú mať vplyv len na túto a budúce udalosti.",
    "Repeat every" : "Opakovať každý",
    "By day of the month" : "Podľa dňa v mesiaci",
    "On the" : "V",
    "_month_::_months_" : ["mesiac","mesiace","mesiacov","mesiacov"],
    "_year_::_years_" : ["rok","roky","rokov","rokov"],
    "weekday" : "deň v týždni",
    "weekend day" : "deň cez víkend",
    "No recurrence" : "Žiadne nové",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Definícia opakovania tejto udalosti nie je Nextcloud plne podporovaná. Ak upravíte možnosti opakovania, niektoré opakovania sa môžu stratiť.",
    "Suggestions" : "Návrhy",
    "No rooms or resources yet" : "Žiadne miestnosti alebo zdroje",
    "Add resource" : "Pridať zdroj",
    "Has a projector" : "Má projektor",
    "Has a whiteboard" : "Má tabuľu",
    "Wheelchair accessible" : "Bezbariérový prístup",
    "Remove resource" : "Odstrániť zdroj",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} miesto","{seatingCapacity} miest","{seatingCapacity} miest","{seatingCapacity} miest"],
    "Projector" : "Projektor",
    "Whiteboard" : "Tabuľa",
    "Search for resources or rooms" : "Hľadať zdroje alebo miestnosti",
    "available" : "dostupné",
    "unavailable" : "nedostupné",
    "Room type" : "Typ miestnosti",
    "Any" : "Akékoľvek",
    "Minimum seating capacity" : "Minimálna kapacita miest na sedenie",
    "More" : "Viac",
    "Update this occurrence" : "Aktualizovať tento výskyt",
    "Update this and all future" : "Aktualizovať tento a všetky budúce",
    "Public calendar does not exist" : "Verejný kalendár neexistuje",
    "Maybe the share was deleted or has expired?" : "Možno bolo zrušené sprístupnenie alebo skončila jeho platnosť?",
    "Please select a time zone:" : "Prosím vyberte časovú zónu:",
    "Pick a time" : "Vyberte čas",
    "Pick a date" : "Vyberte dátum",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} o {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} o {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} o {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} o {formattedTime}",
    "Please enter a valid date" : "Zadajte platný dátum",
    "Please enter a valid date and time" : "Zadajte platný dátum a čas",
    "Type to search time zone" : "Písaním nájdete časovú zónu",
    "Global" : "Globálne",
    "Select date" : "Vybrať dátum",
    "Select slot" : "Vybrať slot",
    "No slots available" : "Žiadny slot nie je k dispozícii",
    "The slot for your appointment has been confirmed" : "Slot pre váš termín bol potvrdený",
    "Appointment Details:" : "Podrobnosti o stretnutí",
    "Time:" : "Čas:",
    "Booked for:" : "Rezervované na:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Ďakujem. Vaša rezervácia od {startDate} do {endDate} bola potvrdená.",
    "Book another appointment:" : "Rezervovať ďalšie stretnutie:",
    "See all available slots" : "Zobraziť všetky dostupné sloty",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Časový úsek pre vaše stretnutie od {startDate} do {endDate} už nie je k dispozícii.",
    "Please book a different slot:" : "Prosím rezervujte si iný slot:",
    "Book an appointment with {name}" : "Rezervovať stretnutie s názvom {name}",
    "No public appointments found for {name}" : "Nenašli sa žiadne verejné stretnutia pre {name}",
    "Personal" : "Osobné",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatická detekcia časového pásma určila, že vaše časové pásmo je UTC.\nJe to pravdepodobne výsledok bezpečnostných opatrení vášho webového prehliadača.\nNastavte časové pásmo manuálne v nastaveniach kalendára.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Vami nastavené časové pásmo ({timezoneId}) sa nenašlo. Nastavené bolo UTC.\nZmeňte v nastaveniach svoje časové pásmo a nahláste tento problém.",
    "No more events today" : "Dnes žiadne ďalšie udalosti",
    "No upcoming events" : "Žiadne nadchádzajúce udalosti",
    "Create a new event" : "Vytvoriť novú udalosť",
    "[Today]" : "[Dnes]",
    "[Tomorrow]" : "[Zajtra]",
    "[Yesterday]" : "[Včera]",
    "[Last] dddd" : "[Posledné] dddd",
    "Event does not exist" : "Udalosť neexistuje",
    "Duplicate" : "Duplikát",
    "Delete this occurrence" : "Vymazať tento výskyt",
    "Delete this and all future" : "Vymazať toto a všetko budúce",
    "Details" : "Podrobnosti",
    "Attendees" : "Účastníci",
    "Resources" : "Zdroje",
    "Close" : "Zavrieť",
    "Show more details" : "Zobraziť ďalšie podrobnosti",
    "Subscribe to {name}" : "Prihlásiť sa na odber {name}",
    "Export {name}" : "Exportovať {name}",
    "Anniversary" : "Výročie",
    "Appointment" : "Stretnutie",
    "Business" : "Služobné",
    "Education" : "Výuka",
    "Holiday" : "Sviatok",
    "Meeting" : "Porada",
    "Miscellaneous" : "Rôzne",
    "Non-working hours" : "Mimopracovné hodiny",
    "Not in office" : "Mimo kancelárie",
    "Phone call" : "Telefonát",
    "Sick day" : "Práceneschopnosť",
    "Special occasion" : "Špeciálna príležitosť",
    "Travel" : "Cestovanie",
    "Vacation" : "Dovolenka",
    "Midnight on the day the event starts" : "Najbližšia polnoc pred začiatkom udalosti",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n deň pred udalosťou o {formattedHourMinute}","%n dni pred udalosťou o {formattedHourMinute}","%n dní pred udalosťou o {formattedHourMinute}","%n dní pred udalosťou o {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n týždeň pred udalosťou o {formattedHourMinute}","%n týždne pred udalosťou o {formattedHourMinute}","%n týždňov pred udalosťou o {formattedHourMinute}","%n týždňov pred udalosťou o {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "v deň udalosti o {formattedHourMinute}",
    "at the event's start" : "na začiatku udalosti",
    "at the event's end" : "na konci udalosti",
    "{time} before the event starts" : "{time} pred začiatkom udalosti",
    "{time} before the event ends" : "{time} pred koncom udalosti",
    "{time} after the event starts" : "{time} po začiatku udalosti",
    "{time} after the event ends" : "{time} po skončení udalosti",
    "on {time}" : "o {time}",
    "on {time} ({timezoneId})" : "o {time} ({timezoneId})",
    "Week {number} of {year}" : "Týždeň {number} roku {year}",
    "Does not repeat" : "Neopakuje sa",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "Monthly" : "Mesačne",
    "Yearly" : "Ročne",
    "_Every %n day_::_Every %n days_" : ["Každý deň","Každé %n dni","Každých %n dní","Každých %n dní"],
    "_Every %n week_::_Every %n weeks_" : ["Každý týždeň","Každé %n týždne","Každých %n týždňov","Každých %n týždňov"],
    "_Every %n month_::_Every %n months_" : ["Každý mesiac","Každé %n mesiace","Každých %n mesiacov","Každých %n mesiacov"],
    "_Every %n year_::_Every %n years_" : ["Každý rok","Každé %n rokov","Každých %n rokov","Každých %n rokov"],
    "_on {weekday}_::_on {weekdays}_" : ["v {weekday}","v {weekday}","v {weekday}","v {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["v dni {dayOfMonthList}","v dňoch {dayOfMonthList}","v dňoch {dayOfMonthList}","v dňoch {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "každý mesiac {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "v {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "v {monthNames} v {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n raz","%n raz","%n raz","%n raz"],
    "Untitled event" : "Udalosť bez názvu",
    "Untitled task" : "Úloha bez názvu",
    "Please ask your administrator to enable the Tasks App." : "Požiadajte svojho správcu, aby povolil aplikáciu Úlohy.",
    "Prev" : "Predch",
    "Next" : "Ďalšie",
    "Prev year" : "Predchodzí rok",
    "Next year" : "Nasledujúci rok",
    "Year" : "Rok",
    "W" : "T",
    "%n more" : "%n ďalších",
    "No events to display" : "Žiadne udalosti k zobrazeniu",
    "_+%n more_::_+%n more_" : ["+%n ďalší","+%n ďalší","+%n ďalší","+%n ďalších"],
    "No events" : "Žiadne udalosti",
    "Create a new event or change the visible time-range" : "Vytvorte novú udalosť alebo zmeňte viditeľný časový rozsah",
    "It might have been deleted, or there was a typo in a link" : "Buď to bolo zmazané, alebo je chyba v odkaze",
    "It might have been deleted, or there was a typo in the link" : "Buď to bolo zmazané, alebo je chyba v odkaze",
    "Meeting room" : "Zasadacia miestnosť",
    "Lecture hall" : "Školiaca miestnosť",
    "Seminar room" : "Seminárna miestnosť",
    "Other" : "Iné",
    "When shared show" : "Pri zdieľaní zobraziť",
    "When shared show full event" : "Pri zdieľaní zobraziť udalosť úplne",
    "When shared show only busy" : "Pri zdieľaní zobraziť len zaneprázdnený",
    "When shared hide this event" : "Pri zdieľaní skryť udalosť",
    "The visibility of this event in shared calendars." : "Viditeľnosť tejto udalosti v zdieľaných kalendároch.",
    "Add a location" : "Zadajte umiestnenie",
    "Add a description" : "Zadajte popis",
    "Status" : "Stav",
    "Confirmed" : "Potvrdené",
    "Canceled" : "Zrušené",
    "Confirmation about the overall status of the event." : "Potvrdenie o celkovom stave udalosti.",
    "Show as" : "Zobrazovať ako",
    "Take this event into account when calculating free-busy information." : "Zohľadniť túto udalosť pri určovaní zaneprázdnených/voľných hodín. ",
    "Categories" : "Kategórie",
    "Categories help you to structure and organize your events." : "Kategórie pomáhajú udržiavať prehľad v udalostiach a štruktúrovať ich.",
    "Search or add categories" : "Hľadať alebo pridať kategórie",
    "Add this as a new category" : "Pridať ako novú kategóriu",
    "Custom color" : "Vlastná farba",
    "Special color of this event. Overrides the calendar-color." : "Špeciálna farba tejto udalosti. Prepíše farbu kalendára.",
    "Chat room for event" : "Chatová miestnosť pre udalosť",
    "Imported {filename}" : "Importované {filename}",
    "Meditation" : "Meditácia",
    "Relaxing" : "Odpočinok",
    "Relax" : "Odpočinok",
    "Break" : "Prestávka",
    "Commute" : "Na ceste",
    "Commuting" : "Na ceste",
    "Shuttle" : "Loď",
    "Invoice" : "Faktúra",
    "Finance" : "Financie",
    "Bank" : "Banka",
    "Money" : "Peniaze",
    "Wedding" : "Svadba",
    "Dog" : "Pes",
    "Concert" : "Koncert",
    "Festival" : "Festival",
    "Theater" : "Divadlo",
    "Theatre" : "Koncertná sála",
    "Presentation" : "Prezentácia",
    "Talk" : "Rozhovor",
    "Speech" : "Prejav",
    "Deadline" : "Konečný termín",
    "Submission" : "Podanie",
    "Reporting" : "Zostavy",
    "Camping" : "Táborenie",
    "Camp" : "Kempovanie",
    "Election" : "Voľby",
    "Voting" : "Hlasovanie",
    "Vote" : "Hlas",
    "Barbecue" : "Grilovanie",
    "Barbeque" : "Grilovanie",
    "Garden" : "Záhrada",
    "Farm" : "Farma",
    "Movie" : "Film",
    "Cinema" : "Kino",
    "Graduation" : "Štátnice",
    "Brainstorm" : "Porada",
    "Review" : "Preskúmať",
    "Audit" : "Audit",
    "Inspection" : "Inšpekcia",
    "Proofreading" : "Korektúra",
    "Baseball" : "Bejzbal",
    "Meet" : "Stretnutie",
    "Planning" : "Plánovanie",
    "Pointing" : "Ukazovanie",
    "Retrospective" : "Retrospektíva",
    "Office" : "Kancelária",
    "Contributor week" : "Týždeň prispievateľov",
    "Mail" : "Pošta",
    "Soccer" : "futbal",
    "Football" : "Futbal",
    "Gaming" : "Hranie",
    "Drive" : "Šoférovať",
    "Driving" : "Šoférovanie",
    "Bicycle" : "Bicykel",
    "Cycle" : "Bicyklovať",
    "Cycling" : "Byciklovanie",
    "Biking" : "Bicyklovanie",
    "Bike" : "Bycikel",
    "Podcast" : "Podcast",
    "Basketball" : "Basketbal",
    "Fishing" : "Rybačka",
    "Hiking" : "Turistika",
    "Hike" : "Túra",
    "Art" : "Umenie",
    "Exhibition" : "Výstava",
    "Museum" : "Múzeum",
    "Pilates" : "Cvičenie",
    "Park" : "Park",
    "Walk" : "Chôdza",
    "Studying" : "Učiť sa",
    "Doctor" : "Doktor",
    "Health" : "Zdravie",
    "Dentist" : "Zubár",
    "Hospital" : "Nemocnica",
    "Interview" : "Pohovor",
    "Training" : "Tréning",
    "Practice" : "Tréning",
    "Sports" : "Šport",
    "Exercise" : "Cvičenie",
    "Work out" : "Posilovňa",
    "Working out" : "Posilovať",
    "Gym" : "Fitko",
    "Barber" : "Holič",
    "Haircut" : "Účes",
    "Hairdresser" : "Kaderník",
    "Exam" : "Skúška",
    "Written test" : "Písomka",
    "Oral test" : "Ústny test",
    "Working" : "Práca",
    "New Years Eve" : "Nový rok",
    "NYE" : "Silvester",
    "Fireworks" : "ohňostroj",
    "Running" : "beh",
    "Go for a run" : "behať",
    "Marathon" : "Maratón",
    "Video-conference" : "Video-konferencia",
    "Conference-call" : "Konferenčný hovor",
    "Video-call" : "Video-hovor",
    "Video-chat" : "Video-čet",
    "Video-meeting" : "Video-stretnutie",
    "Call" : "Telefonát",
    "Calling" : "Zavolať",
    "Christmas" : "Vianoce",
    "Conference" : "Konferencia",
    "Pizza" : "Pizza",
    "Travelling" : "Cestovanie",
    "Trip" : "Výlet",
    "Journey" : "Cestovanie",
    "Collaborate" : "Spolupracovať",
    "Pair" : "Dvojica",
    "Lecture" : "Prednáška",
    "Seminar" : "Seminár",
    "Teaching" : "Školenie",
    "Photograph" : "Fotografovať",
    "Party" : "Párty",
    "Celebration" : "Oslava",
    "Celebrate" : "Oslava",
    "Birthday" : "Narodeniny",
    "Shopping" : "Nakupovanie",
    "Groceries" : "Potraviny",
    "Skate" : "Korčulovanie",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Ochutnávka vína",
    "Golf" : "Golf",
    "Dinner" : "Večera",
    "Lunch" : "Obed",
    "Appointment not found" : "Stretnutie nebolo nájdené",
    "User not found" : "Užívateľ nebol nájdený"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
