OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Korisnička sesija neočekivano je istekla",
    "Provided email-address is not valid" : "Unesena adresa e-pošte nije važeća",
    "%s has published the calendar »%s«" : "%s je objavio kalendar »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Došlo je do pogreške pri slanju poruke e-pošte. Obratite se svom administratoru.",
    "Successfully sent email to %1$s" : "Poruka e-pošte uspješno je poslana na %1$s",
    "Hello," : "Pozdrav,",
    "We wanted to inform you that %s has published the calendar »%s«." : "htjeli bismo vas obavijestiti da je %s objavio kalendar »%s«.",
    "Open »%s«" : "Otvori »%s«",
    "Cheers!" : "Bok!",
    "Upcoming events" : "Nadolazeći događaji",
    "Appointments" : "Dogovori",
    "Confirm" : "Potvrdi",
    "Date:" : "Datum:",
    "Where:" : "Gdje:",
    "Calendar" : "Kalendar",
    "A Calendar app for Nextcloud" : "Aplikacija Kalendar za Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aplikacija Kalendar je korisničko sučelje za Nextcloudov CalDAV poslužitelj. Jednostavno sinkronizirajte događaje s raznih uređaja s Nextcloudom i uređujte ih na mreži.\n\n* 🚀 **Integracija s drugim Nextcloudovim aplikacijama!** Trenutno kontakti – i još puno toga.\n* 🌐 **Podrška za WebCal!** Želite li u kalendaru vidjeti važne dane svojeg omiljenog tima? Nema problema!\n* 🙋 **Sudionici!** Pozovite ljude na svoje događaje.\n* ⌚️ **Slobodni/zauzeti!** Provjerite kada su sudionici slobodni\n* ⏰ **Podsjetnici!** Primite upozorenja o događajima u svojem pregledniku ili putem e-pošte.\n* 🔍 Pretraživanje! S lakoćom pronađite svoje događaje\n* ☑️ Zadaci! Pregledajte zadatke s datumom izvršenja izravno u kalendaru\n* 🙈 **Ne izmišljamo toplu vodu!** Na temelju odličnih [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) i [fullcalendar](https://github.com/fullcalendar/fullcalendar) biblioteka.",
    "Previous day" : "Prethodni dan",
    "Previous week" : "Prethodni tjedan",
    "Previous month" : "Prethodni mjesec",
    "Next day" : "Sljedeći dan",
    "Next week" : "Sljedeći tjedan",
    "Next month" : "Sljedeći mjesec",
    "New event" : "Novi događaj",
    "Today" : "Danas",
    "Day" : "Dan",
    "Week" : "Tjedan",
    "Month" : "Mjesec",
    "List" : "Popis",
    "Preview" : "Pretpregled",
    "Copy link" : "Kopiraj poveznicu",
    "Edit" : "Uredi",
    "Delete" : "Izbriši",
    "Untitled calendar" : "Kalendar bez naslova",
    "Edit name" : "Uredi naziv",
    "Saving name …" : "Spremanje naziva...",
    "Edit color" : "Uredi boju",
    "Saving color …" : "Spremanje boje...",
    "Copy private link" : "Kopiraj privatnu poveznicu",
    "Export" : "Izvoz",
    "Unshare from me" : "Prekid dijeljenja sa mnom",
    "An error occurred, unable to change visibility of the calendar." : "Došlo je do pogreške, nije moguće promijeniti vidljivost kalendara.",
    "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
    "Calendar link copied to clipboard." : "Poveznica kalendara kopirana je u međuspremnik.",
    "Calendar link could not be copied to clipboard." : "Poveznica kalendara nije kopirana u međuspremnik.",
    "An error occurred, unable to rename the calendar." : "Došlo je do pogreške, nije moguće promijeniti naziv kalendara.",
    "An error occurred, unable to change the calendar's color." : "Došlo je do pogreške, nije moguće promijeniti boju kalendara.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Prekid dijeljenja kalendara za {countdown} sekundu","Prekid dijeljenja kalendara za {countdown} sekundi","Prekid dijeljenja kalendara za {countdown} sekundi"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Brisanje kalendara za {countdown} sekundu","Brisanje kalendara za {countdown} sekundi","Brisanje kalendara za {countdown} sekundi"],
    "Share link" : "Dijeli poveznicu",
    "Publish calendar" : "Objavi kalendar",
    "Publishing calendar" : "Objavljivanje kalendara",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "Send link to calendar via email" : "Pošalji poveznicu na kalendar putem e-pošte",
    "Enter one address" : "Unesi jednu adresu",
    "Sending email …" : "Slanje e-pošte u tijeku...",
    "Copy subscription link" : "Kopiraj poveznicu pretplate",
    "Copying link …" : "Kopiranje poveznice...",
    "Copied link" : "Poveznica je kopirana",
    "Could not copy link" : "Kopiranje poveznice nije uspjelo",
    "Copy embedding code" : "Kopiraj šifru za ugradnju",
    "Copying code …" : "Kopiranje šifre...",
    "Copied code" : "Šifra je kopirana",
    "Could not copy code" : "Kopiranje šifre nije uspjelo",
    "Delete share link" : "Izbriši poveznicu dijeljenja",
    "Deleting share link …" : "Brisanje poveznice dijeljenja...",
    "An error occurred, unable to publish calendar." : "Došlo je do pogreške, nije moguće objaviti kalendar.",
    "An error occurred, unable to send email." : "Došlo je do pogreške, nije moguće poslati poruku e-pošte.",
    "Embed code copied to clipboard." : "Šifra za ugradnju kopirana je u međuspremnik.",
    "Embed code could not be copied to clipboard." : "Šifru za ugradnju nije moguće kopirati u međuspremnik.",
    "Unpublishing calendar failed" : "Neuspješan prekid objave kalendara",
    "Share with users or groups" : "Dijelite s korisnicima ili grupama",
    "No users or groups" : "Nema korisnika ili grupa",
    "can edit" : "uređivanje moguće",
    "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Došlo je do pogreške, nije moguće promijeniti status dijeljenja kalendara.",
    "An error occurred, unable to change the permission of the share." : "Došlo je do pogreške, nije moguće promijeniti dopuštenje dijeljenja.",
    "New calendar" : "Novi kalendar",
    "Creating calendar …" : "Stvaranje kalendara...",
    "New calendar with task list" : "Novi kalendar s popisom zadataka",
    "New subscription from link (read-only)" : "Nova pretplata putem poveznice (samo za čitanje)",
    "Creating subscription …" : "Stvaranje pretplate...",
    "An error occurred, unable to create the calendar." : "Došlo je do pogreške, nije moguće stvoriti kalendar.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Unesite valjanu poveznicu (mora početi s http://, https://, webcal:// ili webcals://)",
    "Trash bin" : "Kanta za smeće",
    "Name" : "Naziv",
    "Deleted" : "Izbrisano",
    "Restore" : "Vrati",
    "Delete permanently" : "Trajno izbrišite",
    "Empty trash bin" : "Isprazni kantu za smeće",
    "Untitled item" : "Stavka bez naslova",
    "Could not load deleted calendars and objects" : "Učitavanje izbrisanih kalendara i objekata nije uspjelo",
    "Could not restore calendar or event" : "Vraćanje kalendara ili događaja nije uspjelo",
    "Do you really want to empty the trash bin?" : "Želite li zaista isprazniti kantu za smeće?",
    "Could not update calendar order." : "Ažuriranje redoslijeda kalendara nije uspjelo.",
    "Import calendars" : "Uvezi kalendare",
    "Please select a calendar to import into …" : "Odaberite kalendar za uvoz...",
    "Filename" : "Naziv datoteke",
    "Calendar to import into" : "Kalendar za uvoz",
    "Cancel" : "Odustani",
    "_Import calendar_::_Import calendars_" : ["Uvezi kalendar","Uvezi kalendare","Uvezi kalendare"],
    "{filename} could not be parsed" : "Nije moguće parsirati {filename}",
    "No valid files found, aborting import" : "Nisu pronađene važeće datoteke, uvoz je otkazan",
    "Import partially failed. Imported {accepted} out of {total}." : "Djelomično neuspješan uvoz. Uvezeno {accepted} od {total}.",
    "Automatic" : "Automatsko",
    "Automatic ({detected})" : "Automatsko ({detected})",
    "New setting was not saved successfully." : "Nova postavka nije uspješno spremljena.",
    "Shortcut overview" : "Pregled prečaca",
    "or" : "ili",
    "Navigation" : "Navigacija",
    "Previous period" : "Prethodno razdoblje",
    "Next period" : "Sljedeće razdoblje",
    "Views" : "Prikazi",
    "Day view" : "Dnevni prikaz",
    "Week view" : "Tjedni prikaz",
    "Month view" : "Mjesečni prikaz",
    "List view" : "Prikaz popisa",
    "Actions" : "Radnje",
    "Create event" : "Stvori događaj",
    "Show shortcuts" : "Prikaži prečace",
    "Enable birthday calendar" : "Omogući kalendar rođendana",
    "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
    "Enable simplified editor" : "Omogući jednostavan uređivač",
    "Limit visible events per view" : "Ograniči vidljive događaje po pogledu",
    "Show weekends" : "Prikaži vikende",
    "Show week numbers" : "Prikaži brojeve tjedana",
    "Time increments" : "Vremenski prirasti",
    "Default reminder" : "Zadani podsjetnik",
    "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
    "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
    "No reminder" : "Nema podsjetnika",
    "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
    "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
    "Location" : "Lokacija",
    "Description" : "Opis",
    "Visibility" : "Vidljivost",
    "Duration" : "Trajanje",
    "to" : "do",
    "Delete slot" : "Izbriši mjesto",
    "Add" : "Dodaj",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sunday" : "Nedjelja",
    "Save" : "Spremi",
    "Update" : "Ažuriraj",
    "Your email address" : "Vaša adresa e-pošte",
    "Reminder" : "Podsjetnik",
    "before at" : "prije u",
    "Notification" : "Obavijest",
    "Email" : "E-pošta",
    "Audio notification" : "Zvučna obavijest",
    "Other notification" : "Druga obavijest",
    "Relative to event" : "Povezano s događajem",
    "On date" : "Na datum",
    "Edit time" : "Uredi vrijeme",
    "Save time" : "Spremi vrijeme",
    "Remove reminder" : "Ukloni podsjetnik",
    "on" : "na",
    "at" : "u",
    "+ Add reminder" : "+ Dodaj podsjetnik",
    "Add reminder" : "Dodaj podsjetnik",
    "_second_::_seconds_" : ["sekunda","sekundi","sekundi"],
    "_minute_::_minutes_" : ["minuta","minuta","minuta"],
    "_hour_::_hours_" : ["sat","sati","sati"],
    "_day_::_days_" : ["dan","dana","dana"],
    "_week_::_weeks_" : ["tjedan","tjedana","tjedana"],
    "Available" : "Dostupno",
    "Not available" : "Nije dostupno",
    "Availability of attendees, resources and rooms" : "Raspoloživost sudionika, resursa i soba",
    "{organizer} (organizer)" : "{organizer} (organizator)",
    "Free" : "Dostupno",
    "Busy (tentative)" : "Zauzeto (uvjetno)",
    "Busy" : "Zauzeto",
    "Out of office" : "Izvan ureda",
    "Unknown" : "Nepoznato",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "Tentative" : "Uvjetno",
    "Create Talk room for this event" : "Stvori Talk sobu za ovaj događaj",
    "Show busy times" : "Prikaži vremena zauzetosti",
    "No attendees yet" : "Još nema sudionika",
    "Successfully appended link to talk room to description." : "Uspješno dodana poveznica na Talk sobu u opis.",
    "Error creating Talk room" : "Pogreška pri stvaranju Talk sobe",
    "Send email" : "Pošalji poruku e-pošte",
    "Chairperson" : "Predsjednik",
    "Required participant" : "Obavezan sudionik",
    "Optional participant" : "Neobavezan sudionik",
    "Non-participant" : "Nije sudionik",
    "Remove attendee" : "Ukloni sudionika",
    "Search for emails, users or contacts" : "Potražite poruke e-pošte, korisnike ili kontakte",
    "No match found" : "Nema podudaranja",
    "(organizer)" : "(organizator)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "[linkopen]Dodajte svoju adresu e-pošte u osobne postavke[linkclose] za slanje pozivnica i upravljanje odgovorima.",
    "Remove color" : "Ukloni boju",
    "Event title" : "Naslov događaja",
    "All day" : "Cijeli dan",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nije moguće mijenjati cjelodnevne postavke za događaje koji su dio skupa ponavljanja.",
    "from {startDate}" : "od {startDate}",
    "from {startDate} at {startTime}" : "od {startDate} u {startTime}",
    "to {endDate}" : "do {endDate}",
    "to {endDate} at {endTime}" : "do {endDate} u {endTime}",
    "Repeat" : "Ponovi",
    "End repeat" : "Završi ponavljanje",
    "Select to end repeat" : "Odaberi za završetak ponavljanja",
    "never" : "nikad",
    "on date" : "na datum",
    "after" : "nakon",
    "_time_::_times_" : ["put","puta","puta"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ovaj događaj je iznimka ponavljanja skupa ponavljanja. Ne možete mu dodati pravilo ponavljanja.",
    "first" : "prvi",
    "third" : "treći",
    "fourth" : "četvrti",
    "fifth" : "peti",
    "second to last" : "predzadnji",
    "last" : "zadnji",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Promjene pravila ponavljanja primjenjuju se na ovo i sva buduća ponavljanja.",
    "Repeat every" : "Ponovi svakih",
    "By day of the month" : "Do dana u mjesecu",
    "On the" : "Na",
    "_month_::_months_" : ["mjesec","mjeseci","mjeseci"],
    "_year_::_years_" : ["godinu","godina","godina"],
    "weekday" : "dan u tjednu",
    "weekend day" : "dan vikendom",
    "No recurrence" : "Nema ponavljanja",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud ne podržava u potpunosti definiciju ponavljanja za ovaj događaj. Ako uredite mogućnosti ponavljanja, može doći do gubitka određenih ponavljanja.",
    "Suggestions" : "Prijedlozi",
    "No rooms or resources yet" : "Još nema soba ili resursa",
    "Add resource" : "Dodaj resurs",
    "Has a projector" : "Ima projektor",
    "Has a whiteboard" : "Ima ploču za pisanje",
    "Wheelchair accessible" : "Pristupačno za invalidska kolica",
    "Remove resource" : "Ukloni resurs",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sjedalo","{seatingCapacity} sjedala","{seatingCapacity} sjedala"],
    "Projector" : "Projektor",
    "Whiteboard" : "Ploča za pisanje",
    "Search for resources or rooms" : "Potražite resurse ili sobe",
    "available" : "dostupno",
    "unavailable" : "nedostupno",
    "Room type" : "Vrsta sobe",
    "Any" : "Bilo koji",
    "Minimum seating capacity" : "Minimalni broj sjedala",
    "More" : "Više",
    "Update this occurrence" : "Ažuriraj ovo ponavljanje",
    "Update this and all future" : "Ažuriraj ovo i sva buduća ponavljanja",
    "Public calendar does not exist" : "Javni kalendar ne postoji",
    "Maybe the share was deleted or has expired?" : "Možda je dijeljenje izbrisano ili je isteklo?",
    "Please select a time zone:" : "Odaberite vremensku zonu:",
    "Pick a time" : "Odaberi vrijeme",
    "Pick a date" : "Odaberi datum",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} u {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} u {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "dana {formattedDate} u {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} u {formattedTime}",
    "Please enter a valid date" : "Unesite važeći datum",
    "Please enter a valid date and time" : "Unesite važeći datum i vrijeme",
    "Type to search time zone" : "Upišite za pretraživanje vremenskih zona",
    "Global" : "Globalno",
    "Time:" : "Vrijeme:",
    "Personal" : "Osobno",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Značajka automatskog otkrivanja vremenske zone utvrdila je vašu vremensku zonu kao UTC.\nVjerojatno zbog sigurnosnih mjera vašeg internetskog preglednika.\nRučno postavite vremensku zonu u postavkama kalendara.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nije pronađena vaša konfigurirana vremenska zona ({timezoneId}). Postavka vremenske zone vraćena je na UTC.\nPromijenite vremensku zonu u postavkama i prijavite ovu poteškoću.",
    "No more events today" : "Danas više nema događaja",
    "No upcoming events" : "Nema nadolazećih događaja",
    "Create a new event" : "Stvorite novi događaj",
    "[Today]" : "[Danas]",
    "[Tomorrow]" : "[Sutra]",
    "[Yesterday]" : "[Jučer]",
    "[Last] dddd" : "[Zadnji] dddd",
    "Event does not exist" : "Događaj ne postoji",
    "Delete this occurrence" : "Izbriši ovo ponavljanje",
    "Delete this and all future" : "Izbriši ovo i sva buduća ponavljanja",
    "Details" : "Pojedinosti",
    "Attendees" : "Sudionici",
    "Resources" : "Resursi",
    "Close" : "Zatvori",
    "Show more details" : "Prikaži više pojedinosti",
    "Subscribe to {name}" : "Pretplati se na {name}",
    "Anniversary" : "Godišnjica",
    "Appointment" : "Dogovor",
    "Business" : "Poslovno",
    "Education" : "Obrazovno",
    "Holiday" : "Blagdan/praznik",
    "Meeting" : "Sastanak",
    "Miscellaneous" : "Razno",
    "Non-working hours" : "Neradni sati",
    "Not in office" : "Nije u uredu",
    "Phone call" : "Telefonski poziv",
    "Sick day" : "Bolovanje",
    "Special occasion" : "Poseban događaj",
    "Travel" : "Putovanje",
    "Vacation" : "Odmor",
    "Midnight on the day the event starts" : "Ponoć na dan početka događaja",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dan prije početka događaja u {formattedHourMinute}","%n dana prije početka događaja u {formattedHourMinute}","%n dana prije početka događaja u {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tjedan prije početka događaja u {formattedHourMinute}","%n tjedana prije početka događaja u {formattedHourMinute}","%n tjedana prije početka događaja u {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "na dan događaja u {formattedHourMinute}",
    "at the event's start" : "na početku događaja",
    "at the event's end" : "na završetku događaja",
    "{time} before the event starts" : "{time} prije početka događaja",
    "{time} before the event ends" : "{time} prije završetka događaja",
    "{time} after the event starts" : "{time} nakon početka događaja",
    "{time} after the event ends" : "{time} nakon završetka događaja",
    "on {time}" : "u {time}",
    "on {time} ({timezoneId})" : "u {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} tjedan {year}",
    "Does not repeat" : "Ne ponavlja se",
    "Daily" : "Svaki dan",
    "Weekly" : "Svaki tjedan",
    "Monthly" : "Svaki mjesec",
    "Yearly" : "Svake godine",
    "_Every %n day_::_Every %n days_" : ["Svaki %n dan","Svakih %n dana","Svakih %n dana"],
    "_Every %n week_::_Every %n weeks_" : ["Svaki %n tjedan","Svakih %n tjedana","Svakih %n tjedana"],
    "_Every %n month_::_Every %n months_" : ["Svaki %n mjesec","Svakih %n mjeseci","Svakih %n mjeseci"],
    "_Every %n year_::_Every %n years_" : ["Svake %n godine","Svakih %n godina","Svakih %n godina"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}","{weekdays}","{weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["na dan {dayOfMonthList}","na dane {dayOfMonthList}","na dane {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet}",
    "in {monthNames}" : "u {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "u {monthNames} {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n put","%n puta","%n puta"],
    "Untitled event" : "Događaj bez naslova",
    "Untitled task" : "Zadatak bez naslova",
    "Please ask your administrator to enable the Tasks App." : "Zatražite od administratora da omogući aplikaciju Tasks.",
    "Prev" : "Pret.",
    "Next" : "Sljedeća",
    "Prev year" : "Pret. godina",
    "Next year" : "Sljedeće godine",
    "Year" : "Godina",
    "W" : "W",
    "%n more" : "još %n",
    "No events to display" : "Nema događaja za prikaz",
    "_+%n more_::_+%n more_" : ["+%n više","+%n više","+%n više"],
    "No events" : "Nema događaja",
    "Create a new event or change the visible time-range" : "Stvorite novi događaj ili promijenite vidljivi vremenski raspon",
    "It might have been deleted, or there was a typo in a link" : "Možda je izbrisan ili postoji tipfeler u poveznici",
    "It might have been deleted, or there was a typo in the link" : "Možda je izbrisan ili postoji tipfeler u poveznici",
    "Meeting room" : "Soba za sastanke",
    "Lecture hall" : "Predavaonica",
    "Seminar room" : "Soba za seminare",
    "Other" : "Drugo",
    "When shared show" : "Kada se dijeli, prikaži",
    "When shared show full event" : "Kada se dijeli, prikaži cijeli događaj",
    "When shared show only busy" : "Kada se dijeli, prikaži samo zauzeto",
    "When shared hide this event" : "Kada se dijeli, sakrij događaj",
    "The visibility of this event in shared calendars." : "Vidljivost ovog događaja u dijeljenim kalendarima.",
    "Add a location" : "Dodaj lokaciju",
    "Add a description" : "Dodaj opis",
    "Status" : "Status",
    "Confirmed" : "Potvrđeno",
    "Canceled" : "Otkazano",
    "Confirmation about the overall status of the event." : "Potvrda cjelokupnog statusa događaja.",
    "Show as" : "Prikaži kao",
    "Take this event into account when calculating free-busy information." : "Uzmite ovaj događaj u obzir pri izračunu informacija o dostupnosti i zauzeću.",
    "Categories" : "Kategorije",
    "Categories help you to structure and organize your events." : "Kategorije vam pomažu odrediti strukturu i organizirati događaj.",
    "Search or add categories" : "Pretraži ili dodaj kategorije",
    "Add this as a new category" : "Dodaj kao novu kategoriju",
    "Custom color" : "Prilagođena boja",
    "Special color of this event. Overrides the calendar-color." : "Posebna boja ovog događaja. Primjenjuje se umjesto boje kalendara.",
    "Chat room for event" : "Soba za razmjenu poruka za događaj",
    "Imported {filename}" : "Uvezena datoteka {filename}",
    "Meditation" : "Meditacija",
    "Relaxing" : "Opuštanje",
    "Relax" : "Opustite se",
    "Commuting" : "Na putu",
    "Invoice" : "Faktura",
    "Presentation" : "Prezentacija",
    "Talk" : "Razgovor",
    "Camping" : "Kampiranje",
    "Camp" : "Idi na kampiranje",
    "Movie" : "Film",
    "Cinema" : "Kino",
    "Graduation" : "Diplomiranje",
    "Brainstorm" : "Razmišljanje",
    "Review" : "Pregled",
    "Baseball" : "Bejzbol",
    "Meet" : "Sastanak",
    "Planning" : "Planiranje",
    "Pointing" : "Pokazivanje",
    "Retrospective" : "Retrospektiva",
    "Office" : "Ured",
    "Contributor week" : "Tjedan suradnika",
    "Mail" : "Pošta",
    "Soccer" : "Nogomet",
    "Football" : "Nogomet",
    "Gaming" : "Igranje",
    "Drive" : "Vožnja",
    "Driving" : "Vožnja",
    "Bicycle" : "Bicikl",
    "Cycle" : "Vožnja biciklom",
    "Biking" : "Biciklizam",
    "Bike" : "Bicikl",
    "Podcast" : "Podcast",
    "Basketball" : "Košarka",
    "Fishing" : "Ribolov",
    "Hiking" : "Planinarenje",
    "Hike" : "Izlet",
    "Art" : "Umjetnost",
    "Exhibition" : "Izložba",
    "Museum" : "Muzej",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Studying" : "Učenje",
    "Doctor" : "Liječnik",
    "Health" : "Zdravlje",
    "Dentist" : "Stomatolog",
    "Hospital" : "Bolnica",
    "Interview" : "Razgovor",
    "Training" : "Trening",
    "Practice" : "Vježba",
    "Sports" : "Sport",
    "Exercise" : "Tjelovježba",
    "Work out" : "Vježba",
    "Working out" : "Vježbanje",
    "Gym" : "Teretana",
    "Barber" : "Brijač",
    "Haircut" : "Frizura",
    "Exam" : "Ispit",
    "Written test" : "Pisani ispit",
    "Oral test" : "Usmeni ispit",
    "Working" : "Rad",
    "New Years Eve" : "Stara godina",
    "NYE" : "NYE",
    "Fireworks" : "Vatromet",
    "Running" : "Trčanje",
    "Go for a run" : "Trčati",
    "Marathon" : "Maraton",
    "Video-conference" : "Videokonferencija",
    "Conference-call" : "Konferencijski poziv",
    "Video-call" : "Videopoziv",
    "Video-chat" : "Videorazgovor",
    "Video-meeting" : "Videosastanak",
    "Call" : "Poziv",
    "Calling" : "Pozivanje",
    "Christmas" : "Božić",
    "Conference" : "Konferencija",
    "Pizza" : "Pizza",
    "Travelling" : "Putovanja",
    "Journey" : "Putovanje",
    "Collaborate" : "Suradnja",
    "Pair" : "Par",
    "Lecture" : "Predavanje",
    "Seminar" : "Seminar",
    "Photograph" : "Fotografija",
    "Party" : "Tulum",
    "Celebration" : "Proslava",
    "Celebrate" : "Slavlje",
    "Birthday" : "Rođendan",
    "Shopping" : "Kupnja",
    "Skate" : "Koturanje",
    "Skateboard" : "Daska za koturanje",
    "Wine tasting" : "Degustacija vina",
    "Golf" : "Golf",
    "Dinner" : "Večera",
    "Lunch" : "Ručak",
    "User not found" : "Korisnik nije pronađen"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
