<?php return array(
    'root' => array(
        'name' => '__root__',
        'pretty_version' => 'v4.1.1',
        'version' => '4.1.1.0',
        'reference' => 'b1738ab3d684950cd51e9b60a55947d944cebf26',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => 'v4.1.1',
            'version' => '4.1.1.0',
            'reference' => 'b1738ab3d684950cd51e9b60a55947d944cebf26',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
