OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "শুভেচ্ছা!",
    "Calendar" : "দিনপঞ্জী",
    "Today" : "আজ",
    "Day" : "দিবস",
    "Week" : "সপ্তাহ",
    "Month" : "মাস",
    "Copy link" : "লিঙ্ক কপি করো",
    "Edit" : "সম্পাদনা",
    "Delete" : "মুছে",
    "Export" : "রপ্তানি",
    "Share link" : "লিংক ভাগাভাগি করেন",
    "can edit" : "সম্পাদনা করতে পারবেন",
    "New calendar" : "নতুন দিনপঞ্জী",
    "Name" : "নাম",
    "Deleted" : "মুছে ফেলা",
    "Restore" : "ফিরিয়ে দাও",
    "Cancel" : "বাতিল",
    "Automatic" : "স্বয়ংক্রিয়",
    "Actions" : "পদক্ষেপসমূহ",
    "Location" : "অবস্থান",
    "Description" : "বিবরণ",
    "to" : "প্রতি",
    "Add" : "যোগ করুন",
    "Monday" : "সোমবার",
    "Tuesday" : "মঙ্গলবার",
    "Wednesday" : "বুধবার",
    "Thursday" : "বৃহস্পতিবার",
    "Friday" : "শুক্রবার",
    "Saturday" : "শনিবার",
    "Sunday" : "রবিবার",
    "Save" : "সংরক্ষণ",
    "Update" : "পরিবর্ধন",
    "Your email address" : "আপনার ই-মেইল ঠিকানা",
    "Email" : "ইমেইল",
    "Unknown" : "অজানা",
    "Send email" : "ইমেইল পাঠান ",
    "Repeat" : "পূনঃসংঘটন",
    "never" : "কখনোই নয়",
    "More" : "বেশী",
    "Personal" : "ব্যক্তিগত",
    "Details" : "বিসতারিত",
    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
    "Close" : "বন্ধ",
    "Daily" : "দৈনিক",
    "Weekly" : "সাপ্তাহিক",
    "Next" : "পরবর্তী",
    "Other" : "অন্যান্য",
    "Mail" : "মেইল",
    "Birthday" : "জন্মদিন"
},
"nplurals=2; plural=(n != 1);");
