OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Sessão do usuário expirou inesperadamente",
    "Provided email-address is not valid" : "O e-mail fornecido não é válido",
    "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Erro inesperado ao enviar e-mail. Entre em contato com o administrador.",
    "Successfully sent email to %1$s" : "E-mail enviado com sucesso para %1$s",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Informamos que %s publicou o calendário »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "Saudações!",
    "Upcoming events" : "Próximos eventos",
    "Appointments" : "Agendamentos",
    "Schedule appointment \"%s\"" : "Agendar compromisso \"1%s\"",
    "Schedule an appointment" : "Agende um compromisso",
    "Prepare for %s" : "Prepare para 1%s",
    "Follow up for %s" : "Acompanhamento para 1%s",
    "Your appointment \"%s\" with %s needs confirmation" : "Seu compromisso \"%s\" com %sprecisa de confirmação",
    "Dear %s, please confirm your booking" : "Caro 1%s, por favor confirme a sua reserva",
    "Confirm" : "Confirmar",
    "This confirmation link expires in %s hours." : "Este link de confirmação expira 1%s em horas.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Se você deseja cancelar o compromisso como um todo, por favor contacte o organizador respondendo este email ou visitando sua página de perfil.",
    "Your appointment \"%s\" with %s has been accepted" : "Seu compromisso \"%s\" com %s foi aceito",
    "Dear %s, your booking has been accepted." : "Olá %s. Seu convite foi aceito.",
    "Appointment for:" : "Compromisso para:",
    "Date:" : "Data:",
    "Where:" : "Local:",
    "Your Comment:" : "Seu Comentário:",
    "Calendar" : "Calendário",
    "A Calendar app for Nextcloud" : "Um aplicativo de Calendário para Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "O aplicativo Calendário é uma interface de usuário para o servidor CalDAV do Nextcloud. Sincronize facilmente eventos de vários dispositivos com o Nextcloud e edite-os online.\n\n* 🚀 **Integração com outros aplicativos Nextcloud!** Atualmente Contatos - mais por vir.\n* 🌐 **Suporte WebCal!** Deseja ver as partidas do seu time no calendário? Sem problemas!\n* 🙋 **Participantes!** Convide pessoas para seus eventos\n* ⌚️ **Disponibilidade:** Veja quando seus participantes estarão disponíveis para atender\n* ⏰ **Lembretes!** Receba alarmes para eventos no seu navegador e via e-mail.\n* 🔍 Pesquise! Encontre seus eventos facilmente\n* ☑️ Tarefas! Veja as tarefas com a data de entrega diretamente no calendário\n* 🙈 **Não estamos reinventando a roda!** Baseado nas excelentes bibliotecas [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) e [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Dia anterior",
    "Previous week" : "Semana anterior",
    "Previous month" : "Mês anterior",
    "Next day" : "Próximo dia",
    "Next week" : "Próxima semana",
    "Next month" : "Próximo mês",
    "New event" : "Novo evento",
    "Today" : "Hoje",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "List" : "Lista",
    "Preview" : "Previsão",
    "Copy link" : "Copiar o link",
    "Edit" : "Editar",
    "Delete" : "Excluir",
    "Appointment link was copied to clipboard" : "O link do agendamento foi copiado para a área de transferência",
    "Appointment link could not be copied to clipboard" : "Não foi possível copiar o link do compromisso para a área de transferência",
    "Add new" : "Adicionar novo",
    "Untitled calendar" : "Calendário sem título",
    "Edit name" : "Editar nome",
    "Saving name …" : "Salvando nome...",
    "Edit color" : "Editar cor",
    "Saving color …" : "Salvando cor...",
    "Copy private link" : "Copiar link privado",
    "Export" : "Exportar",
    "Unshare from me" : "Descompartilhar comigo",
    "Disable calendar \"{calendar}\"" : "Desativar calendário \"{calendar}\"",
    "Disable untitled calendar" : "Desativar calendário sem título",
    "Enable calendar \"{calendar}\"" : "Ativar calendário \"{calendar}\"",
    "Enable untitled calendar" : "Ativar calendário sem título",
    "An error occurred, unable to change visibility of the calendar." : "Erro ao alterar a visibilidade do calendário.",
    "An error occurred, unable to delete the calendar." : "Erro ao excluir o calendário.",
    "Calendar link copied to clipboard." : "Link do calendário copiado para a área de transferência.",
    "Calendar link could not be copied to clipboard." : "Não foi possível copiar o link da agenda para a área de transferência.",
    "An error occurred, unable to rename the calendar." : "Erro ao renomear o calendário.",
    "An error occurred, unable to change the calendar's color." : "Erro ao alterar a cor do calendário.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Descompartilhando o calendário em {countdown} segundo","Descompartilhando o calendário em {countdown} segundos","Descompartilhando o calendário em {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Excluindo o calendário em {countdown} segundo","Excluindo o calendário em {countdown} segundos","Excluindo o calendário em {countdown} segundos"],
    "Share link" : "Compartilhar link",
    "Publish calendar" : "Publicar calendário",
    "Publishing calendar" : "Calendário de publicação",
    "Copy public link" : "Copiar link público",
    "Send link to calendar via email" : "Enviar link para o calendário via e-mail",
    "Enter one address" : "Digite um endereço",
    "Sending email …" : "Enviando e-mail...",
    "Copy subscription link" : "Copiar link de inscrição",
    "Copying link …" : "Copiando link...",
    "Copied link" : "Link copiado",
    "Could not copy link" : "Não foi possível copiar o link",
    "Copy embedding code" : "Copiar código de incorporação",
    "Copying code …" : "Copiando código...",
    "Copied code" : "Código copiado",
    "Could not copy code" : "Não foi possível copiar o código",
    "Delete share link" : "Excluir compartilhamento do link",
    "Deleting share link …" : "Excluindo link de compartilhamento...",
    "An error occurred, unable to publish calendar." : "Erro ao publicar calendário.",
    "An error occurred, unable to send email." : "Erro ao tentar enviar o e-mail.",
    "Embed code copied to clipboard." : "Código de incorporação copiado para a área de transferência.",
    "Embed code could not be copied to clipboard." : "O código de incorporação não pôde ser copiado para a área de transferência.",
    "Unpublishing calendar failed" : "Erro ao remover a publicação do calendário",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "No users or groups" : "Nenhum usuário ou grupo",
    "can edit" : "pode editar",
    "Unshare with {displayName}" : "Descompartilhar com {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Erro ao descompartilhar o calendário.",
    "An error occurred, unable to change the permission of the share." : "Erro ao alterar a permissão do compartilhamento.",
    "New calendar" : "Novo calendário",
    "Name for new calendar" : "Nome para o calendário",
    "Creating calendar …" : "Criando calendário...",
    "New calendar with task list" : "Novo calendário com lista de tarefas",
    "New subscription from link (read-only)" : "Nova subscrição do link (somente leitura)",
    "Creating subscription …" : "Criando assinatura...",
    "An error occurred, unable to create the calendar." : "Erro ao criar o calendário.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Digite um link válido (começando com http://, https://, webcal://, ou webcals://)",
    "Trash bin" : "Lixeira",
    "Loading deleted items." : "Carregando itens excluídos.",
    "You do not have any deleted items." : "Você não possui itens excluídos.",
    "Name" : "Nome",
    "Deleted" : "Excluído",
    "Restore" : "Restaurar",
    "Delete permanently" : "Excluir permanentemente",
    "Empty trash bin" : "Esvaziar lixeira",
    "Untitled item" : "Item sem título ",
    "Unknown calendar" : "Calendário desconhecido",
    "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos excluídos",
    "Could not restore calendar or event" : "Não foi possível restaurar o calendário ou evento",
    "Do you really want to empty the trash bin?" : "Tem certeza de que deseja esvaziar a lixeira?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Os itens na lixeira são excluídos após {numDays} dias","Os itens na lixeira são excluídos após {numDays} dias","Os itens na lixeira são excluídos após {numDays} dias"],
    "Could not update calendar order." : "Não foi possível atualizar o pedido da agenda.",
    "Import calendars" : "Importar calendários",
    "Please select a calendar to import into …" : "Selecione o calendário para onde importar...",
    "Filename" : "Nome de arquivo",
    "Calendar to import into" : "Calendário a importar",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendário","Importar calendários","Importar calendários"],
    "{filename} could not be parsed" : "{filename} não pôde ser analisado",
    "No valid files found, aborting import" : "Nenhum arquivo válido encontrado, importação interrompida",
    "Import partially failed. Imported {accepted} out of {total}." : "Erro na importação. Importado {accepted} de {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Importado com sucesso %n evento","Importados com sucesso %n eventos","Importados com sucesso %n eventos"],
    "Automatic" : "Automático",
    "Automatic ({detected})" : "Automático ({detected})",
    "New setting was not saved successfully." : "A nova configuração não foi salva.",
    "Shortcut overview" : "Visão geral de atalhos",
    "or" : "ou",
    "Navigation" : "Navegação",
    "Previous period" : "Período anterior",
    "Next period" : "Próximo período",
    "Views" : "Visualizações",
    "Day view" : "Visão diária",
    "Week view" : "Visão semanal",
    "Month view" : "Visão mensal",
    "List view" : "Exibição de lista",
    "Actions" : "Ações",
    "Create event" : "Criar evento",
    "Show shortcuts" : "Mostrar atalhos",
    "Editor" : "Editor",
    "Close editor" : "Fechar editor",
    "Save edited event" : "Salvar evento editado",
    "Delete edited event" : "Excluir evento editado",
    "Duplicate event" : "Evento duplicado",
    "Enable birthday calendar" : "Ativar calendário de aniversários",
    "Show tasks in calendar" : "Mostrar tarefas no calendário",
    "Enable simplified editor" : "Ativar o editor simplificado",
    "Limit visible events per view" : "Limitar eventos visíveis por visualização",
    "Show weekends" : "Mostrar fins de semana",
    "Show week numbers" : "Exibir o número das semanas",
    "Time increments" : "Incrementos de tempo",
    "Default reminder" : "Lembrete padrão",
    "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
    "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
    "Personal availability settings" : "Configurações de disponibilidade pessoal",
    "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
    "Calendar settings" : "Configurações do calendário",
    "No reminder" : "Nenhum lembrete",
    "CalDAV link copied to clipboard." : "Link CalDAV copiado para a área de transferência.",
    "CalDAV link could not be copied to clipboard." : "Link CalDAV não copiado para a área de transferência.",
    "Appointment was created successfully" : "O compromisso foi criado com sucesso",
    "Appointment was updated successfully" : "Agendamento atualizado com sucesso",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
    "0 minutes" : "0 minutos",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
    "_{duration} day_::_{duration} days_" : ["{duration} dia","{duration} dias","{duration} dias"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semana","{duration} semanas","{duration} semanas"],
    "_{duration} month_::_{duration} months_" : ["{duration} mês","{duration} meses","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} ano","{duration} anos","{duration} anos"],
    "To configure appointments, add your email address in personal settings." : "Para configurar compromissos, adicione seu endereço de e-mail nas configurações pessoais.",
    "Public – shown on the profile page" : "Público - mostrado na página do perfil",
    "Private – only accessible via secret link" : "Privado - acessível apenas por meio de link secreto",
    "Location" : "Localização",
    "Description" : "Descrição",
    "Visibility" : "Visibilidade",
    "Duration" : "Duração:",
    "Increments" : "Incrementos",
    "Additional calendars to check for conflicts" : "Calendários adicionais para verificar conflitos",
    "Pick time ranges where appointments are allowed" : "Escolha os intervalos de tempo onde os compromissos são permitidos",
    "to" : "para",
    "Delete slot" : "Excluir vaga",
    "No times set" : "Nenhum horário definido",
    "Add" : "Adicionar",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Add time before and after the event" : "Adicionar um tempo antes e depois do evento",
    "Before the event" : "Antes do evento",
    "After the event" : "Depois do evento",
    "Planning restrictions" : "Restrições de planejamento",
    "Minimum time before next available slot" : "Tempo mínimo antes do próximo vaga disponível",
    "Max slots per day" : "Máximo de vagas por dia",
    "Limit how far in the future appointments can be booked" : "Limite em quanto tempo os compromissos futuros podem ser reservados",
    "Create appointment" : "Criar compromisso",
    "Edit appointment" : "Editar compromisso",
    "Save" : "Salvar",
    "Update" : "Atualizar",
    "Please confirm your reservation" : "Por favor, confirme sua reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Enviamos a você um e-mail com os detalhes. Por favor, confirme seu agendamento usando o link no e-mail. Você pode fechar esta página agora.",
    "Your name" : "Seu nome",
    "Your email address" : "Seu endereço de e-mail",
    "Please share anything that will help prepare for our meeting" : "Por favor, compartilhe qualquer coisa que ajude a se preparar para nosso encontro",
    "Could not book the appointment. Please try again later or contact the organizer." : "Não foi possível agendar o compromisso. Tente novamente mais tarde ou entre em contato com o organizador.",
    "Book the appointment" : "Agendar o compromisso",
    "Reminder" : "Lembrete",
    "before at" : "antes das",
    "Notification" : "Notificação",
    "Email" : "E-mail",
    "Audio notification" : "Notificação de áudio",
    "Other notification" : "Outras notificações",
    "Relative to event" : "Relativo ao evento",
    "On date" : "Na data",
    "Edit time" : "Editar horário",
    "Save time" : "Salvar horário",
    "Remove reminder" : "Remover lembrete",
    "on" : "ligado",
    "at" : "em",
    "+ Add reminder" : "+ Adicionar lembrete",
    "Add reminder" : "Adicionar lembrete ",
    "_second_::_seconds_" : ["segundo","segundos","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos","minutos"],
    "_hour_::_hours_" : ["hora","horas","horas"],
    "_day_::_days_" : ["dia","dias","dias"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "Invitation accepted" : "Convite aceito",
    "Available" : "Disponível",
    "Suggested" : "Sugerido",
    "Participation marked as tentative" : "Participação marcada como provisória",
    "Accepted {organizerName}'s invitation" : "Aceitou o convite de {organizerName}",
    "Not available" : "Indisponível",
    "Invitation declined" : "Convite recusado",
    "Declined {organizerName}'s invitation" : "Recusou o convite de {organizerName}",
    "Invitation is delegated" : "O convite é delegado",
    "Checking availability" : "Verificando disponibilidade",
    "Invitation sent" : "Convite enviado",
    "Has not responded to {organizerName}'s invitation yet" : "Ainda não respondeu ao convite de {organizerName}",
    "Availability of attendees, resources and rooms" : "Disponibilidade de participantes, recursos e salas",
    "{organizer} (organizer)" : "{organizer} (organizador)",
    "Free" : "Livre",
    "Busy (tentative)" : "Ocupado (talvez)",
    "Busy" : "Ocupado",
    "Out of office" : "Fora do escritório",
    "Unknown" : "Desconhecido",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Tentative" : "Talvez",
    "The invitation has been accepted successfully." : "O convite foi aceito.",
    "Failed to accept the invitation." : "Falha ao aceitar o convite.",
    "The invitation has been declined successfully." : "O convite foi recusado.",
    "Failed to decline the invitation." : "Falha ao recusar o convite.",
    "Your participation has been marked as tentative." : "Sua participação foi marcada como incerta.",
    "Failed to set the participation status to tentative." : "Falha ao marcar sua participação como incerta.",
    "Create Talk room for this event" : "Criar sala no Talk para este evento",
    "Show busy times" : "Mostrar horários ocupados",
    "No attendees yet" : "Nenhum participante ainda",
    "Successfully appended link to talk room to description." : "O link para a sala Talk foi adicionado com sucesso na descrição",
    "Error creating Talk room" : "Erro ao criar a sala Talk",
    "Send email" : "Enviar e-mail",
    "Chairperson" : "Organizador",
    "Required participant" : "Participante obrigatório",
    "Optional participant" : "Participante opcional",
    "Non-participant" : "Não participante",
    "Remove attendee" : "Remover participante",
    "Search for emails, users or contacts" : "Pesquise e-mails, usuários ou contatos",
    "No match found" : "Nenhuma correspondência encontrada",
    "(organizer)" : "(organizador)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar convites e gerenciar respostas, [linkopen]adicione seu endereço de e-mail nas configurações pessoais[linkclose].",
    "Remove color" : "Remover cor",
    "Event title" : "Título do evento",
    "All day" : "Dia inteiro",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Não é possível modificar a configuração de dia inteiro para eventos que fazem parte de um conjunto de recorrência.",
    "from {startDate}" : "de {startDate}",
    "from {startDate} at {startTime}" : "de {startDate} às {startTime}",
    "to {endDate}" : "até {endDate}",
    "to {endDate} at {endTime}" : "até {endDate} às {endTime}",
    "Repeat" : "Repetir",
    "End repeat" : "Terminar repetição",
    "Select to end repeat" : "Selecione para finalizar a repetição",
    "never" : "nunca",
    "on date" : "na data",
    "after" : "após",
    "_time_::_times_" : ["vez","vezes","vezes"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento é a exceção de recorrência de um conjunto de recorrência. Você não pode adicionar uma regra de recorrência a ele.",
    "first" : "primeiro",
    "third" : "terceiro",
    "fourth" : "quarto",
    "fifth" : "quinto",
    "second to last" : "segundos atrás",
    "last" : "último",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Alterações na regra de recorrência serão aplicadas somente a esta e a todas as ocorrências futuras.",
    "Repeat every" : "Repetir a cada",
    "By day of the month" : "Pelo dia do mês",
    "On the" : "Em",
    "_month_::_months_" : ["mês","meses","meses"],
    "_year_::_years_" : ["ano","anos","anos"],
    "weekday" : "Dia da semana",
    "weekend day" : "dia da semana",
    "No recurrence" : "Sem recorrência ",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "A definição de recorrência deste evento não é totalmente suportada pelo Nextcloud. Se você editar as opções de recorrência, determinadas recorrências poderão ser perdidas.",
    "Suggestions" : "Sugestões",
    "No rooms or resources yet" : "Ainda não há salas ou recursos",
    "Add resource" : "Adicionar recurso",
    "Has a projector" : "Tem projetor",
    "Has a whiteboard" : "Tem quadro branco",
    "Wheelchair accessible" : "Acessível a cadeiras de rodas",
    "Remove resource" : "Remover recurso",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} assento","{seatingCapacity} assentos","{seatingCapacity} assentos"],
    "Projector" : "Projetor",
    "Whiteboard" : "Quadro branco",
    "Search for resources or rooms" : "Pesquise recursos ou salas",
    "available" : "disponível",
    "unavailable" : "indisponível",
    "Room type" : "Tipo de sala",
    "Any" : "Qualquer uma",
    "Minimum seating capacity" : "Capacidade mínima de assento",
    "More" : "Mais",
    "Update this occurrence" : "Atualizar esta ocorrência",
    "Update this and all future" : "Atualizar este e todos os futuros",
    "Public calendar does not exist" : "Calendário público não existe",
    "Maybe the share was deleted or has expired?" : "Talvez o compartilhamento esteja excluído ou expirado?",
    "Please select a time zone:" : "Selecione um fuso horário:",
    "Pick a time" : "Escolha um horário",
    "Pick a date" : "Escolha uma data",
    "from {formattedDate}" : "de {formattedDate}",
    "to {formattedDate}" : "até {formattedDate}",
    "on {formattedDate}" : "em {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "de {formattedDate} às {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "até {formattedDate} às {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "em {formattedDate} às {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} às {formattedTime}",
    "Please enter a valid date" : "Digite uma data válida",
    "Please enter a valid date and time" : "Digite uma data e hora válida",
    "Type to search time zone" : "Digite para pesquisar o fuso horário",
    "Global" : "Global",
    "Select date" : "Selecionar data",
    "Select slot" : "Selecionar vaga",
    "No slots available" : "Nenhuma vaga disponível",
    "The slot for your appointment has been confirmed" : "A vaga para o seu agendamento foi confirmada",
    "Appointment Details:" : "Detalhes do Agendamento:",
    "Time:" : "Tempo:",
    "Booked for:" : "Reservado para:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Obrigada. Sua reserva de {startDate} a {endDate} foi confirmada.",
    "Book another appointment:" : "Agendar outro compromisso",
    "See all available slots" : "Ver todas as vagas disponíveis",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "O período para seu compromisso de {startDate} a {endDate} não está mais disponível.",
    "Please book a different slot:" : "Reserve um slot diferente:",
    "Book an appointment with {name}" : "Agende um compromisso com {name}",
    "No public appointments found for {name}" : "Nenhum agendamento público encontrado para {name}",
    "Personal" : "Pessoal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "A detecção automática determinou que seu fuso horário seja UTC.\nProvavelmente, isso é resultado de medidas de segurança do seu navegador.\nDefina seu fuso horário manualmente nas configurações do calendário.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Seu fuso horário configurado ({timezoneId}) não foi encontrado. Retornando ao UTC.\nAltere seu fuso horário nas configurações e informe este problema.",
    "No more events today" : "Sem mais eventos para hoje",
    "No upcoming events" : "Nenhum evento próximo",
    "Create a new event" : "Criar um novo evento",
    "[Today]" : "[Hoje]",
    "[Tomorrow]" : "[Amanhã]",
    "[Yesterday]" : "[Ontem]",
    "[Last] dddd" : "[Último] dddd",
    "Event does not exist" : "O evento não existe",
    "Duplicate" : "Duplicada",
    "Delete this occurrence" : "Excluir esta ocorrência",
    "Delete this and all future" : "Excluir esta e todas as futuras",
    "Details" : "Detalhes",
    "Attendees" : "Participantes",
    "Resources" : "Recursos",
    "Close" : "Fechar",
    "Show more details" : "Mostrar mais detalhes",
    "Subscribe to {name}" : "Inscrever-se em {name}",
    "Export {name}" : "Exportar {name}",
    "Anniversary" : "Aniversário",
    "Appointment" : "Compromisso",
    "Business" : "Negócio",
    "Education" : "Educação",
    "Holiday" : "Feriado",
    "Meeting" : "Reunião",
    "Miscellaneous" : "Diversos",
    "Non-working hours" : "Horas fora do expediente",
    "Not in office" : "Fora do escritório",
    "Phone call" : "Chamada telefônica",
    "Sick day" : "Dia ruim",
    "Special occasion" : "Ocasião especial",
    "Travel" : "Viagem",
    "Vacation" : "Férias",
    "Midnight on the day the event starts" : "Meia-noite do dia em que o evento começa",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dia antes do evento às {formattedHourMinute}","%n dias antes do evento às {formattedHourMinute}","%n dias antes do evento às {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semana antes do evento às {formattedHourMinute}","%n semanas antes do evento às {formattedHourMinute}","%n semanas antes do evento às {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "no dia do evento às {formattedHourMinute}",
    "at the event's start" : "no início do evento",
    "at the event's end" : "no fim do evento",
    "{time} before the event starts" : "{time} antes de iniciar o evento",
    "{time} before the event ends" : "{time} antes do evento terminar",
    "{time} after the event starts" : "{time} após o evento iniciar",
    "{time} after the event ends" : "{time} após o evento terminar",
    "on {time}" : "às {time}",
    "on {time} ({timezoneId})" : "às {time} ({timezoneId})",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Does not repeat" : "Não repetir",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Monthly" : "Mensalmente",
    "Yearly" : "Anualmente",
    "_Every %n day_::_Every %n days_" : ["A cada %n dia","A cada %n dias","A cada %n dias"],
    "_Every %n week_::_Every %n weeks_" : ["A cada %n semana","A cada %n semanas","A cada %n semanas"],
    "_Every %n month_::_Every %n months_" : ["A cada %n mês","A cada %n meses","A cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["A cada %n ano","A cada %n anos","A cada %n anos"],
    "_on {weekday}_::_on {weekdays}_" : ["em {weekday}","em {weekdays}","em {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["no dia {dayOfMonthList}","nos dias {dayOfMonthList}","nos dias {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "no {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "em {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "em {monthNames} no {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "até {untilDate}",
    "_%n time_::_%n times_" : ["%n vez","%n vezes","%n vezes"],
    "Untitled event" : "Evento sem título",
    "Untitled task" : "Tarefa sem título",
    "Please ask your administrator to enable the Tasks App." : "Peça ao administrador para ativar o aplicativo Tarefas.",
    "Prev" : "Anterior",
    "Next" : "Próximo",
    "Prev year" : "Ano anterior",
    "Next year" : "Próximo ano",
    "Year" : "Ano",
    "W" : "S",
    "%n more" : "%n mais",
    "No events to display" : "Não há mais eventos a mostrar",
    "_+%n more_::_+%n more_" : ["mais +%n","mais +%n","mais +%n"],
    "No events" : "Sem eventos",
    "Create a new event or change the visible time-range" : "Crie um novo evento ou altere o intervalo de tempo visível",
    "It might have been deleted, or there was a typo in a link" : "Pode ter sido excluído ou houve um erro de digitação no link",
    "It might have been deleted, or there was a typo in the link" : "Pode ter sido excluído ou houve um erro de digitação no link",
    "Meeting room" : "Sala de reuniões",
    "Lecture hall" : "Auditório",
    "Seminar room" : "Sala de seminários",
    "Other" : "De Outro",
    "When shared show" : "Quando compartilhando mostrar",
    "When shared show full event" : "Quando compartilhado, mostrar evento completo",
    "When shared show only busy" : "Quando compartilhado, mostrar somente ocupado",
    "When shared hide this event" : "Quando compartilhado, ocultar este evento",
    "The visibility of this event in shared calendars." : "A visibilidade deste evento em calendários compartilhados.",
    "Add a location" : "Adicionar uma localização",
    "Add a description" : "Adicionar uma descrição",
    "Status" : "Status",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelado",
    "Confirmation about the overall status of the event." : "Confirmação sobre o status geral do evento.",
    "Show as" : "Mostrar como",
    "Take this event into account when calculating free-busy information." : "Leve esse evento em consideração ao calcular informações de disponibilidade.",
    "Categories" : "Categorias",
    "Categories help you to structure and organize your events." : "As categorias ajudam a estruturar e organizar seus eventos.",
    "Search or add categories" : "Pesquisar ou adicionar categorias",
    "Add this as a new category" : "Adicione isso como uma nova categoria",
    "Custom color" : "Cor personalizada",
    "Special color of this event. Overrides the calendar-color." : "Cor especial deste evento. Substitui a cor do calendário.",
    "Chat room for event" : "Sala de bato-papo para evento",
    "Imported {filename}" : "Importado {filename}",
    "Meditation" : "Meditação",
    "Relaxing" : "Relaxamento",
    "Relax" : "Relaxamento",
    "Break" : "Pausa",
    "Commute" : "Trajeto",
    "Commuting" : "Alternância",
    "Shuttle" : "Transporte",
    "Invoice" : "Fatura",
    "Finance" : "Finança",
    "Bank" : "Banco",
    "Money" : "Dinheiro",
    "Wedding" : "Casamento",
    "Dog" : "Cachorro",
    "Concert" : "Conserto",
    "Festival" : "Festival",
    "Theater" : "Teatro ",
    "Theatre" : "Teatro",
    "Presentation" : "Apresentação",
    "Talk" : "Falar",
    "Speech" : "Discurso",
    "Deadline" : "Prazo final",
    "Submission" : "Submissão",
    "Reporting" : "Relatando",
    "Camping" : "Acampamento",
    "Camp" : "Acampamento",
    "Election" : "Eleição",
    "Voting" : "Votando",
    "Vote" : "Voto",
    "Barbecue" : "Churrasco",
    "Barbeque" : "Churrasco",
    "Garden" : "Jardim",
    "Farm" : "Fazenda",
    "Movie" : "Filme",
    "Cinema" : "Cinema",
    "Graduation" : "Formatura",
    "Brainstorm" : "Brainstorm",
    "Review" : "Revisar",
    "Audit" : "Auditoria",
    "Inspection" : "Inspeção",
    "Proofreading" : "Revisão",
    "Baseball" : "Beisebol",
    "Meet" : "Reunião",
    "Planning" : "Planejamento",
    "Pointing" : "Apontar",
    "Retrospective" : "Retrospectiva",
    "Office" : "Escritório",
    "Contributor week" : "Semana do colaborador",
    "Mail" : "Correspondência",
    "Soccer" : "Futebol",
    "Football" : "Futebol americano",
    "Gaming" : "Jogo",
    "Drive" : "Dirigir",
    "Driving" : "Dirigindo",
    "Bicycle" : "Bicicleta",
    "Cycle" : "Bicicleta",
    "Cycling" : "Ciclismo",
    "Biking" : "Ciclismo",
    "Bike" : "Bicicleta",
    "Podcast" : "Podcast",
    "Basketball" : "Basquete",
    "Fishing" : "Pesca",
    "Hiking" : "Caminhada",
    "Hike" : "Caminhada",
    "Art" : "Arte",
    "Exhibition" : "Exibição",
    "Museum" : "Museu",
    "Pilates" : "Pilates",
    "Park" : "Parque",
    "Walk" : "Andar",
    "Studying" : "Estudo",
    "Doctor" : "Doutor",
    "Health" : "Saúde",
    "Dentist" : "Dentista",
    "Hospital" : "Hospital",
    "Interview" : "Entrevista",
    "Training" : "Treinamento",
    "Practice" : "Prática",
    "Sports" : "Esportes",
    "Exercise" : "Exercício",
    "Work out" : "Ginástica",
    "Working out" : "Ginástica",
    "Gym" : "Academia",
    "Barber" : "Barbeiro",
    "Haircut" : "Cortar cabelo",
    "Hairdresser" : "Cabeleireiro",
    "Exam" : "Exame",
    "Written test" : "Teste escrito",
    "Oral test" : "Teste oral",
    "Working" : "Trabalho",
    "New Years Eve" : "Véspera de Ano Novo",
    "NYE" : "NYE",
    "Fireworks" : "Fogos de artifício",
    "Running" : "Corrida",
    "Go for a run" : "Ir correr",
    "Marathon" : "Maratona",
    "Video-conference" : "Vídeo-conferência",
    "Conference-call" : "Conferência-chamada",
    "Video-call" : "Vídeo-chamada",
    "Video-chat" : "Vídeo-chat",
    "Video-meeting" : "Vídeo-reunião",
    "Call" : "Chamada",
    "Calling" : "Chamada",
    "Christmas" : "Natal",
    "Conference" : "Conferência",
    "Pizza" : "Pizza",
    "Travelling" : "Viagem",
    "Trip" : "Viagem",
    "Journey" : "Jornada",
    "Collaborate" : "Colaborativo",
    "Pair" : "Par",
    "Lecture" : "Leitura",
    "Seminar" : "Seminário",
    "Teaching" : "Ensinando",
    "Photograph" : "Fotografia",
    "Party" : "Festa",
    "Celebration" : "Comemoração",
    "Celebrate" : "Comemorar",
    "Birthday" : "Aniversário",
    "Shopping" : "Compras",
    "Groceries" : "Mercearias",
    "Skate" : "Skate",
    "Skateboard" : "Skate",
    "Wine tasting" : "Degustação de vinho",
    "Golf" : "Golfe",
    "Dinner" : "Jantar",
    "Lunch" : "Rodar",
    "Appointment not found" : "Agendamento não encontrado",
    "User not found" : "Usuário não encontrado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
