OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Bruger-Sessionen udløb uventet",
    "Provided email-address is not valid" : "Leveret e-mailadresse er ikke gyldig ",
    "%s has published the calendar »%s«" : "%s har oprettet en begivenhed i kalenderen »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Uventet fejl ved afsendelse, venligst kontakt din administrator",
    "Successfully sent email to %1$s" : "Sendt e-mail til %1$s",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønkser at informerer dig om at %s har oprettet en begivenhed i kalenderen »%s«.",
    "Open »%s«" : "Åbn »%s«",
    "Cheers!" : "Hav en fortsat god dag.",
    "Upcoming events" : "Kommende begivenheder",
    "Appointments" : "Aftaler",
    "Schedule appointment \"%s\"" : "Planlæg en aftale \"%s\"",
    "Schedule an appointment" : "Planlæg en aftale",
    "Prepare for %s" : "Gør klar til %s",
    "Follow up for %s" : "Følg op til %s",
    "Dear %s, please confirm your booking" : "Kære %s, bekræft venligst din reservation",
    "Confirm" : "Bekræft",
    "This confirmation link expires in %s hours." : "Dette bekræftelseslink udløber om %s timer.",
    "Date:" : "Dato:",
    "Where:" : "Hvor:",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "En kalender-app til Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Kalender-appen er en brugergrænseflade til Nextclouds CalDAV-server. Synkroniser nemt begivenheder fra forskellige enheder med din Nextcloud og rediger dem online.\n\n* 🚀 **Integration med andre Nextcloud-apps!** Kontakter i øjeblikket - mere på vej.\n* 🌐 **WebCal Support!** Vil du se dit yndlingsholds kampdage i din kalender? Intet problem!\n* 🙋 **Deltagere!** Inviter folk til dine begivenheder\n* ⌚️ **Ledig/Optaget!** Se, hvornår dine deltagere er tilgængelige til at mødes\n* ⏰ **Påmindelser!** Få alarmer for begivenheder i din browser og via e-mail\n* 🔍 Søg! Find dine arrangementer med ro\n* ☑️ Opgaver! Se opgaver med forfaldsdato direkte i kalenderen\n* 🙈 **Vi genopfinder ikke hjulet!** Baseret på det fantastiske [c-dav-bibliotek](https://github.com/nextcloud/cdav-library), [ical.js](https://github. com/mozilla-comm/ical.js) og [fullcalendar](https://github.com/fullcalendar/fullcalendar) biblioteker.",
    "Previous day" : "Forrige dag",
    "Previous week" : "Forrige uge",
    "Previous month" : "Forrige måned",
    "Next day" : "Næste dag",
    "Next week" : "Næste uge",
    "Next month" : "Næste måned",
    "New event" : "Opret begivenhed",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Uge",
    "Month" : "Måned",
    "List" : "Liste",
    "Preview" : "Forhåndsvisning",
    "Copy link" : "Kopiér link",
    "Edit" : "Rediger",
    "Delete" : "Slet",
    "Appointment link was copied to clipboard" : "Aftalelink blev kopieret til udklipsholder",
    "Appointment link could not be copied to clipboard" : "Aftalelinket kunne ikke kopieres til udklipsholderen",
    "Add new" : "Tilføj ny",
    "Untitled calendar" : "Unanvngiven kalender",
    "Edit name" : "Rediger navn",
    "Saving name …" : "Gemmer navn…",
    "Edit color" : "Rediger farve",
    "Saving color …" : "Gemmer farve…",
    "Copy private link" : "Kopier privat link",
    "Export" : "Eksportér",
    "Unshare from me" : "Fjern deling fra mig",
    "Disable calendar \"{calendar}\"" : "Slå kalender fra {calendar}",
    "Disable untitled calendar" : "Deaktiver unavngiven kalender",
    "Enable calendar \"{calendar}\"" : "Slå kalender til {calendar}",
    "Enable untitled calendar" : "Aktiver unavngiven kalender",
    "An error occurred, unable to change visibility of the calendar." : "Kalenderens synlighed kunne ikke ændres.",
    "An error occurred, unable to delete the calendar." : "Kalenderen kunne ikke slettes.",
    "Calendar link copied to clipboard." : "Kalender link kopieret.",
    "Calendar link could not be copied to clipboard." : "Kalender link kunne ikke kopieres.",
    "An error occurred, unable to rename the calendar." : "Kalenderen kunne ikke omdøbes.",
    "An error occurred, unable to change the calendar's color." : "Kalenderens farve kunne ikke ændres.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling af kalenderen om {countdown} sekund","Fjerner deling af kalenderen om {countdown} sekunder"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalenderen bliver slettet om {countdown} sekunder","Kalenderen bliver slettet om {countdown} sekunder"],
    "Share link" : "Del link",
    "Publish calendar" : "Udgiv kalender",
    "Publishing calendar" : "Udgiver kalender",
    "Copy public link" : "Kopier offentligt link",
    "Send link to calendar via email" : "Send link til kalender via e-mail",
    "Enter one address" : "Indtast én adresse",
    "Sending email …" : "Sender email…",
    "Copy subscription link" : "Kopier abonnementslink",
    "Copying link …" : "Kopierer link…",
    "Copied link" : "Link kopieret",
    "Could not copy link" : "Link kunne ikke kopieres",
    "Copy embedding code" : "Kopier indlejringskode",
    "Copying code …" : "Kopierer kode…",
    "Copied code" : "Kode kopieret",
    "Could not copy code" : "Kode kunne ikke kopieres",
    "Delete share link" : "Slet delingslink",
    "Deleting share link …" : "Sletter delingslink…",
    "An error occurred, unable to publish calendar." : "Kalenderen kunne ikke udgives",
    "An error occurred, unable to send email." : "Der opstod en fejl, kunne ikke sende e-mail.",
    "Embed code copied to clipboard." : "Indlejringskode kopieret til udklipsholder.",
    "Embed code could not be copied to clipboard." : "Indlejringskoden kunne ikke kopieres til udklipsholderen.",
    "Unpublishing calendar failed" : "Udgivelse af kalender mislykkedes",
    "Share with users or groups" : "Del med brugere eller grupper",
    "No users or groups" : "Ingen brugere eller grupper",
    "can edit" : "kan redigere",
    "Unshare with {displayName}" : "Fjern deling med {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Der opstod en fejl, der kunne ikke ændre ophævelsen af deling af kalenderen.",
    "An error occurred, unable to change the permission of the share." : "Der opstod en fejl, som ikke kunne ændre tilladelsen til delingen.",
    "New calendar" : "Ny kalender",
    "Name for new calendar" : "Navn på ny kalender",
    "Creating calendar …" : "Opretter kalender…",
    "New calendar with task list" : "Ny kalender med opgaveliste",
    "New subscription from link (read-only)" : "Nyt abonnement fra link (skrivebeskyttet)",
    "Creating subscription …" : "Opretter abonnement…",
    "An error occurred, unable to create the calendar." : "Der opstod en fejl, og kalenderen kunne ikke oprettes.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Indtast venligst et gyldigt link (startende med http://, https://, webcal:// eller webcals://)",
    "Trash bin" : "Skraldespand",
    "Loading deleted items." : "Indlæser slettede elementer.",
    "You do not have any deleted items." : "Du har ingen slettede elementer.",
    "Name" : "Navn",
    "Deleted" : "Slettet",
    "Restore" : "Gendan",
    "Delete permanently" : "Slet permanent",
    "Empty trash bin" : "Tom papirkurv",
    "Untitled item" : "Unavngiven element",
    "Unknown calendar" : "Ukendt kalender",
    "Could not load deleted calendars and objects" : "Kunne ikke indlæse slettede kalendere og objekter",
    "Could not restore calendar or event" : "Kunne ikke gendanne kalender eller begivenhed",
    "Do you really want to empty the trash bin?" : "Vil du virkelig tømme skraldespanden?",
    "Could not update calendar order." : "Kunne ikke opdatere kalenderrækkefølgen.",
    "Import calendars" : "Importer kalendere",
    "Please select a calendar to import into …" : "Vælg venligst en kalender, der skal importeres til...",
    "Filename" : "Filnavn",
    "Calendar to import into" : "Kalender at importere til",
    "Cancel" : "Annullér",
    "_Import calendar_::_Import calendars_" : ["Importer kalender","Importer kalendere"],
    "{filename} could not be parsed" : "{filename} kunne ikke tilføjes",
    "No valid files found, aborting import" : "Ingen gyldige filer fundet, importen afbrydes",
    "Import partially failed. Imported {accepted} out of {total}." : "Importen mislykkedes delvist. Importeret {accepted} ud af {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n begivenhed blev importeret","%n begivenheder blev importeret"],
    "Automatic" : "Automatisk",
    "Automatic ({detected})" : "Automatisk ({detected})",
    "New setting was not saved successfully." : "Den nye indstilling blev ikke gemt.",
    "Shortcut overview" : "Genvejsoversigt",
    "or" : "eller",
    "Navigation" : "Navigation",
    "Previous period" : "Tidligere periode",
    "Next period" : "Næste periode",
    "Views" : "Visninger",
    "Day view" : "Dagsvisning",
    "Week view" : "Ugevisning",
    "Month view" : "Månedsvisning",
    "List view" : "Vis som liste",
    "Actions" : "Handlinger",
    "Create event" : "Opret begivenhed",
    "Show shortcuts" : "Vis genveje",
    "Editor" : "Editor",
    "Close editor" : "Luk editor",
    "Save edited event" : "Gem redigeret begivenhed",
    "Delete edited event" : "Slet redigeret begivenhed",
    "Duplicate event" : "Dubleret begivenhed",
    "Enable birthday calendar" : "Slå fødselsdagskalender til",
    "Show tasks in calendar" : "Vis opgaver i kalenderen",
    "Enable simplified editor" : "Slå simpel editor til",
    "Limit visible events per view" : "Begræns synlige hændelser pr. visning",
    "Show weekends" : "Vis weekender",
    "Show week numbers" : "Vis ugenummer ",
    "Time increments" : "Tidsstigninger",
    "Default reminder" : "Standard påmindelse",
    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
    "Copy iOS/macOS CalDAV address" : "Kopiér iOS/macOS CalDAV-adresse",
    "Personal availability settings" : "Personlige tilgængelighedsindstillinger",
    "Show keyboard shortcuts" : "Vis tastaturgenveje",
    "Calendar settings" : "Kalenderindstillinger",
    "No reminder" : "Ingen påmindelse",
    "CalDAV link copied to clipboard." : "CalDAV-linket er kopieret til udklipsholderen.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-linket kunne ikke kopieres til udklipsholderen.",
    "Appointment was created successfully" : "Aftalen blev oprettet",
    "Appointment was updated successfully" : "Aftalen blev opdateret",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minutter"],
    "0 minutes" : "0 minutter",
    "_{duration} hour_::_{duration} hours_" : ["{duration} time","{duration} timer"],
    "_{duration} day_::_{duration} days_" : ["{duration} dag","{duration} dage"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} uge","{duration} uger"],
    "_{duration} month_::_{duration} months_" : ["{duration} måned","{duration} måneder"],
    "_{duration} year_::_{duration} years_" : ["{duration} år","{duration} år"],
    "To configure appointments, add your email address in personal settings." : "For at konfigurere aftaler skal du tilføje din e-mailadresse i personlige indstillinger.",
    "Public – shown on the profile page" : "Offentlig – vist på profilsiden",
    "Private – only accessible via secret link" : "Privat – kun tilgængelig via hemmeligt link",
    "Location" : "Sted",
    "Description" : "Beskrivelse",
    "Visibility" : "Synlighed",
    "Duration" : "Varighed",
    "Increments" : "Inkrementer",
    "Additional calendars to check for conflicts" : "Yderligere kalendere til at tjekke for konflikter",
    "Pick time ranges where appointments are allowed" : "Vælg tidsintervaller, hvor aftaler er tilladt",
    "to" : "til",
    "Delete slot" : "Slet slot",
    "No times set" : "Ingen tider fastsat",
    "Add" : "Tilføj",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sunday" : "Søndag",
    "Add time before and after the event" : "Tilføj tid før og efter begivenheden",
    "Before the event" : "Før arrangementet",
    "After the event" : "Efter arrangementet",
    "Planning restrictions" : "Planlægningsrestriktioner",
    "Minimum time before next available slot" : "Minimum tid før næste ledige plads",
    "Max slots per day" : "Max slots om dagen",
    "Limit how far in the future appointments can be booked" : "Begræns hvor langt ude i fremtiden, der kan bookes tider",
    "Create appointment" : "Opret aftale",
    "Edit appointment" : "Rediger aftale",
    "Save" : "Gem",
    "Update" : "Opdatér",
    "Please confirm your reservation" : "Bekræft venligst din reservation",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Vi har sendt dig en e-mail med detaljer. Bekræft venligst din aftale ved at bruge linket i e-mailen. Du kan lukke denne side nu.",
    "Your name" : "Dit navn",
    "Your email address" : "Din email adresse",
    "Please share anything that will help prepare for our meeting" : "Del venligst alt, der kan hjælpe med at forberede vores møde",
    "Could not book the appointment. Please try again later or contact the organizer." : "Det var ikke muligt at bestille tid. Prøv venligst igen senere eller kontakt arrangøren.",
    "Book the appointment" : "Bestil tid",
    "Reminder" : "Påmindelse",
    "before at" : "før kl",
    "Notification" : "Notifikation",
    "Email" : "E-mail",
    "Audio notification" : "Lydmeddelelse",
    "Other notification" : "Anden meddelelse",
    "Relative to event" : "I forhold til begivenhed",
    "On date" : "På dato",
    "Edit time" : "Rediger tid",
    "Save time" : "Gem tid",
    "Remove reminder" : "Fjern påmindelse",
    "on" : "på",
    "at" : "ved",
    "+ Add reminder" : "+ Tilføj påmindelse",
    "Add reminder" : "Tilføj påmindelse",
    "_second_::_seconds_" : ["sekund","sekunder"],
    "_minute_::_minutes_" : ["minut","minutter"],
    "_hour_::_hours_" : ["time","timer"],
    "_day_::_days_" : ["dag","dage"],
    "_week_::_weeks_" : ["uge","uger"],
    "Invitation accepted" : "Invitation accepteret",
    "Available" : "Tilgængelig",
    "Suggested" : "Foreslået",
    "Participation marked as tentative" : "Deltagelse markeret som foreløbig",
    "Accepted {organizerName}'s invitation" : "Accepterede invitationen fra {organizerName}",
    "Not available" : "Ikke tilgængelig",
    "Invitation declined" : "Invitation afvist",
    "Declined {organizerName}'s invitation" : "Afviste {organizerName}s invitation",
    "Invitation is delegated" : "Invitation er uddelegeret",
    "Checking availability" : "Kontrol af tilgængelighed",
    "Invitation sent" : "Invitation sendt",
    "Has not responded to {organizerName}'s invitation yet" : "Har endnu ikke svaret på {organizerName}s invitation",
    "Availability of attendees, resources and rooms" : "Tilgængelighed af deltagere, ressourcer og lokaler",
    "{organizer} (organizer)" : "{organizer} (arrangør)",
    "Free" : "Ledig",
    "Busy (tentative)" : "Optaget (foreløbig)",
    "Busy" : "Optaget",
    "Out of office" : "Ikke på kontoret",
    "Unknown" : "Ukendt",
    "Accept" : "Accepter",
    "Decline" : "Afvis",
    "Tentative" : "Foreløbig",
    "The invitation has been accepted successfully." : "Invitationen er blevet accepteret.",
    "Failed to accept the invitation." : "Kunne ikke acceptere invitationen.",
    "The invitation has been declined successfully." : "Invitationen er blevet afvist.",
    "Failed to decline the invitation." : "Invitationen kunne ikke afvises.",
    "Your participation has been marked as tentative." : "Din deltagelse er blevet markeret som foreløbig.",
    "Failed to set the participation status to tentative." : "Kunne ikke indstille deltagelsesstatus til foreløbig.",
    "Create Talk room for this event" : "Opret Snak rum for denne begivenhed",
    "Show busy times" : "Vis optaget tider",
    "No attendees yet" : "Ingen deltagere endnu",
    "Successfully appended link to talk room to description." : "Link til samtalerum blev tilføjet til beskrivelsen.",
    "Error creating Talk room" : "Fejl ved oprettelse af talerum",
    "Send email" : "Send e-mail",
    "Chairperson" : "Formand",
    "Required participant" : "Nødvendig deltager",
    "Optional participant" : "Valgfri deltager",
    "Non-participant" : "Deltager ikke",
    "Remove attendee" : "Fjern deltager",
    "Search for emails, users or contacts" : "Søg efter e-mails, brugere eller kontakter",
    "No match found" : "Ingen match fundet",
    "(organizer)" : "(arrangør)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "For at udsende invitationer og håndtere svar, [linkopen]tilføj din e-mailadresse i personlige indstillinger[linkclose].",
    "Remove color" : "Fjern farve",
    "Event title" : "Titel",
    "All day" : "Hele dagen",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan ikke ændre heldagsindstillingen for begivenheder, der er en del af et gentagelsessæt.",
    "from {startDate}" : "fra {startDate}",
    "from {startDate} at {startTime}" : "fra {startDate} kl {startTime}",
    "to {endDate}" : "til {endDate}",
    "to {endDate} at {endTime}" : "til {endDate} kl {endTime}",
    "Repeat" : "Gentag",
    "End repeat" : "Afslut gentagelse",
    "Select to end repeat" : "Vælg for at afslutte gentagelsen",
    "never" : "aldrig",
    "on date" : "på dato",
    "after" : "efter",
    "_time_::_times_" : ["gang","gange"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Denne begivenhed er gentagelses-undtagelsen af et gentagelsessæt. Du kan ikke tilføje en gentagelsesregel til den.",
    "first" : "første",
    "third" : "tredje",
    "fourth" : "fjerde",
    "fifth" : "femte",
    "second to last" : "næstsidste",
    "last" : "sidste",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Ændringer i gentagelsesreglen vil kun gælde for denne og alle fremtidige hændelser.",
    "Repeat every" : "Gentag hver",
    "By day of the month" : "Efter dag i måneden",
    "On the" : "Den",
    "_month_::_months_" : ["måned","måneder"],
    "_year_::_years_" : ["år","år"],
    "weekday" : "hverdag",
    "weekend day" : "weekenddag",
    "No recurrence" : "Ingen gentagelse",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Gentagelsesdefinitionen af denne begivenhed understøttes ikke fuldt ud af Nextcloud. Hvis du redigerer gentagelsesmulighederne, kan visse gentagelser gå tabt.",
    "Suggestions" : "Forslag",
    "No rooms or resources yet" : "Ingen lokaler eller ressourcer endnu",
    "Add resource" : "Tilføj ressource",
    "Has a projector" : "Har en projektor",
    "Has a whiteboard" : "Har en whiteboardtavle",
    "Wheelchair accessible" : "Kørestolsvenligt",
    "Remove resource" : "Fjern ressource",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sæde","{seatingCapacity} sæder"],
    "Projector" : "Projektor",
    "Whiteboard" : "Whiteboard",
    "Search for resources or rooms" : "Søg efter ressourcer eller lokaler",
    "available" : "tilgængelig",
    "unavailable" : "ikke tilgængelig",
    "Room type" : "Værelses type",
    "Any" : "Enhver",
    "Minimum seating capacity" : "Minimum siddekapacitet",
    "More" : "Mere",
    "Update this occurrence" : "Opdater denne forekomst",
    "Update this and all future" : "Opdater denne og alle fremtidige",
    "Public calendar does not exist" : "Offentlig kalender findes ikke",
    "Maybe the share was deleted or has expired?" : "Måske er delingen blevet slettet eller er udløbet?",
    "Please select a time zone:" : "Vælg venligst en tidszone:",
    "Pick a time" : "Vælg et tidspunkt",
    "Pick a date" : "Vælg en dato",
    "from {formattedDate}" : "fra {formattedDate}",
    "to {formattedDate}" : "til {formattedDate}",
    "on {formattedDate}" : "på {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} kl. {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "til {formattedDate} at {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
    "Please enter a valid date" : "Indtast venligst en gyldig dato",
    "Please enter a valid date and time" : "Indtast venligst en gyldig dato og tid",
    "Type to search time zone" : "Indtast for at søge i tidszone",
    "Global" : "Global",
    "Select date" : "Vælg dato",
    "Select slot" : "Vælg tidspunkt",
    "No slots available" : "Ingen ledige tidspunkter",
    "The slot for your appointment has been confirmed" : "Tidspunktet for din aftale er blevet bekræftet",
    "Appointment Details:" : "Detaljer om aftale:",
    "Time:" : "Tid:",
    "Booked for:" : "Booket til:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Tak skal du have. Din reservation fra {startDate} til {endDate} er blevet bekræftet.",
    "Book another appointment:" : "Bestil endnu en tid:",
    "See all available slots" : "Se alle tilgængelige tidspunkter",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Tidsrummet for din aftale fra {startDate} til {endDate} er ikke længere tilgængeligt.",
    "Please book a different slot:" : "Book venligst et andet tidspunkt:",
    "Book an appointment with {name}" : "Book en tid med {name}",
    "No public appointments found for {name}" : "Ingen offentlige aftaler fundet for {name}",
    "Personal" : "Personlig",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiske tidszoneregistrering bestemte, at din tidszone var UTC.\nDette er højst sandsynligt resultatet af sikkerhedsforanstaltninger i din webbrowser.\nIndstil venligst din tidszone manuelt i kalenderindstillingerne.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din konfigurerede tidszone ({timezoneId}) blev ikke fundet. Falder tilbage til UTC.\nSkift venligst din tidszone i indstillingerne og rapporter dette problem.",
    "No more events today" : "Ikke flere begivenheder i dag",
    "No upcoming events" : "Ingen kommende begivenheder",
    "Create a new event" : "Opret en ny begivenhed",
    "[Today]" : "[i dag]",
    "[Tomorrow]" : "[I morgen]",
    "[Yesterday]" : "[Yesterday]",
    "[Last] dddd" : "[Last] dddd",
    "Event does not exist" : "Begivenheden eksisterer ikke",
    "Duplicate" : "dubletter",
    "Delete this occurrence" : "Slet denne forekomst",
    "Delete this and all future" : "Slet denne og alle fremtidige",
    "Details" : "Detaljer",
    "Attendees" : "Deltagere",
    "Resources" : "Resourcer",
    "Close" : "Luk",
    "Show more details" : "Vis flere detaljer",
    "Subscribe to {name}" : "Abonner på {name}",
    "Export {name}" : "Eksportér {name}",
    "Anniversary" : "Årsdag",
    "Appointment" : "Aftale",
    "Business" : "Forretning",
    "Education" : "Uddannelse",
    "Holiday" : "Ferie",
    "Meeting" : "Møde",
    "Miscellaneous" : "Diverse",
    "Non-working hours" : "Ikke-arbejdstid",
    "Not in office" : "Ikke på kontoret",
    "Phone call" : "Telefon opkald",
    "Sick day" : "Sygedag",
    "Special occasion" : "Speciel lejlighed",
    "Travel" : "Rejse",
    "Vacation" : "Ferie",
    "Midnight on the day the event starts" : "Midnat på dagen, hvor arrangementet starter",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dag før begivenheden kl. {formattedHourMinute}","%n dage før begivenheden kl. {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n uge før begivenheden på {formattedHourMinute}","%n uger før begivenheden på {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "på dagen for begivenheden kl. {formattedHourMinute}",
    "at the event's start" : "ved arrangementets start",
    "at the event's end" : "ved arrangementets afslutning",
    "{time} before the event starts" : "{time} før begivenheden starter",
    "{time} before the event ends" : "{time} før begivenheden slutter",
    "{time} after the event starts" : "{time} efter begivenhedens start",
    "{time} after the event ends" : "{time} efter begivenheden slutter",
    "on {time}" : "{time}",
    "on {time} ({timezoneId})" : "den {time} ({timezoneId})",
    "Week {number} of {year}" : "Uge {number} i {year}",
    "Does not repeat" : "Gentager sig ikke",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Monthly" : "Månedligt",
    "Yearly" : "Årligt",
    "_Every %n day_::_Every %n days_" : ["Hver %n dag","Hver %n dage"],
    "_Every %n week_::_Every %n weeks_" : ["Hver %n uge","Hver %n uger"],
    "_Every %n month_::_Every %n months_" : ["Hver %n måned","Hver %n måneder"],
    "_Every %n year_::_Every %n years_" : ["Hver %n år","Hver %n år"],
    "_on {weekday}_::_on {weekdays}_" : ["på {weekday}","på {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["på dagen {dayOfMonthList}","på dagene {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "på {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "i {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "i {monthNames} på {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "indtil {untilDate}",
    "_%n time_::_%n times_" : ["%n gang","%n gange"],
    "Untitled event" : "Unavngiven begivenhed",
    "Untitled task" : "Unavngivet opgave",
    "Please ask your administrator to enable the Tasks App." : "Bed din administrator om at aktivere Opgaver-appen.",
    "Prev" : "Forrige",
    "Next" : "Næste",
    "Prev year" : "Forrige år",
    "Next year" : "Næste år",
    "Year" : "År",
    "W" : "W",
    "%n more" : "%n yderligere",
    "No events to display" : "Ingen begivenheder",
    "_+%n more_::_+%n more_" : ["+%n yderligere","+%n yderligere"],
    "No events" : "Ingen begivenheder",
    "Create a new event or change the visible time-range" : "Opret en ny begivenhed, eller skift det synlige tidsinterval",
    "It might have been deleted, or there was a typo in a link" : "Det kan være blevet slettet, eller der var en tastefejl i et link",
    "It might have been deleted, or there was a typo in the link" : "Det kan være blevet slettet, eller der var en tastefejl i linket",
    "Meeting room" : "Mødelokale",
    "Lecture hall" : "Foredragssal",
    "Seminar room" : "Seminarrum",
    "Other" : "Andet",
    "When shared show" : "Ved delt vis",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "The visibility of this event in shared calendars." : "Synligheden af denne begivenhed i delte kalendere.",
    "Add a location" : "Tilføj en placering",
    "Add a description" : "Tilføj en beskrivelse",
    "Status" : "Status",
    "Confirmed" : "Bekræftet",
    "Canceled" : "Annulleret",
    "Confirmation about the overall status of the event." : "Bekræftelse af arrangementets overordnede status.",
    "Show as" : "Vis som",
    "Take this event into account when calculating free-busy information." : "Tag denne begivenhed i betragtning, når du beregner ledig-optaget-information.",
    "Categories" : "Kategorier",
    "Categories help you to structure and organize your events." : "Kategorier hjælper dig med at strukturere og organisere dine begivenheder.",
    "Search or add categories" : "Søg eller tilføj kategorier",
    "Add this as a new category" : "Tilføj dette som en ny kategori",
    "Custom color" : "Brug brugerdefinerede farver",
    "Special color of this event. Overrides the calendar-color." : "Særlig farve på denne begivenhed. Tilsidesætter kalenderfarven.",
    "Chat room for event" : "Chatrum til begivenhed",
    "Imported {filename}" : "Importerede {filename}",
    "Meditation" : "Meditation",
    "Relaxing" : "Slapper af",
    "Relax" : "Slap af",
    "Break" : "Pause",
    "Commute" : "Pendler",
    "Commuting" : "Pendler",
    "Shuttle" : "Shuttle",
    "Invoice" : "Faktura",
    "Finance" : "Økonomi",
    "Bank" : "Bank",
    "Money" : "Penge",
    "Wedding" : "Bryllup",
    "Dog" : "Hund",
    "Concert" : "Koncert",
    "Festival" : "Festival",
    "Theater" : "Teater",
    "Theatre" : "Teater",
    "Presentation" : "Præsentation",
    "Talk" : "Snak",
    "Speech" : "Tale",
    "Deadline" : "Deadline",
    "Submission" : "Indsendelse",
    "Reporting" : "Indberetning",
    "Camping" : "Camping",
    "Camp" : "Lejr",
    "Election" : "Valg",
    "Voting" : "Afstemning",
    "Vote" : "Stemme",
    "Barbecue" : "Grill",
    "Barbeque" : "Grill",
    "Garden" : "Have",
    "Farm" : "Gård",
    "Movie" : "Film",
    "Cinema" : "Biograf",
    "Graduation" : "Graduering",
    "Brainstorm" : "Brainstorm",
    "Review" : "Gennemse",
    "Audit" : "Audit",
    "Inspection" : "Inspektion",
    "Proofreading" : "Korrekturlæsning",
    "Baseball" : "Baseball",
    "Meet" : "Møde",
    "Planning" : "Planlægning",
    "Pointing" : "Peger",
    "Retrospective" : "Tilbagevirkende kraft",
    "Office" : "Kontor",
    "Contributor week" : "Bidragsyder uge",
    "Mail" : "Mail",
    "Soccer" : "Fodbold",
    "Football" : "Fodbold",
    "Gaming" : "Gaming",
    "Drive" : "Køre",
    "Driving" : "Kørsel",
    "Bicycle" : "Cykel",
    "Cycle" : "Cyklus",
    "Cycling" : "Cykling",
    "Biking" : "Cykling",
    "Bike" : "Cykel",
    "Podcast" : "Podcast",
    "Basketball" : "Basketball",
    "Fishing" : "Fiskeri",
    "Hiking" : "Vandring",
    "Hike" : "Vandring",
    "Art" : "Kunst",
    "Exhibition" : "Udstilling",
    "Museum" : "Museum",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Walk" : "Gåtur",
    "Studying" : "Studere",
    "Doctor" : "Læge",
    "Health" : "Sundhed",
    "Dentist" : "Tandlæge",
    "Hospital" : "Hospital",
    "Interview" : "Interview",
    "Training" : "Træning",
    "Practice" : "Øve",
    "Sports" : "Sport",
    "Exercise" : "Træning",
    "Work out" : "Work out",
    "Working out" : "Træner",
    "Gym" : "Træningscenter",
    "Barber" : "Barbér",
    "Haircut" : "Klipning",
    "Hairdresser" : "Frisør",
    "Exam" : "Eksamen",
    "Written test" : "Skriftlig prøve",
    "Oral test" : "Mundtlig prøve",
    "Working" : "Arbejder",
    "New Years Eve" : "Nytårs aften",
    "NYE" : "NYE",
    "Fireworks" : "Fyrværkeri",
    "Running" : "Løber",
    "Go for a run" : "Tager ud og løber",
    "Marathon" : "Marathon",
    "Video-conference" : "Video konference",
    "Conference-call" : "Konferenceopkald",
    "Video-call" : "Videoopkald",
    "Video-chat" : "Videochat",
    "Video-meeting" : "Video-møde",
    "Call" : "Kald",
    "Calling" : "Kalder",
    "Christmas" : "Jul",
    "Conference" : "Konference",
    "Pizza" : "Pizza",
    "Travelling" : "Rejsende",
    "Trip" : "Rejse",
    "Journey" : "Rejse",
    "Collaborate" : "Samarbejde",
    "Pair" : "Par",
    "Lecture" : "Foredrag",
    "Seminar" : "Seminar",
    "Teaching" : "Undervisning",
    "Photograph" : "Fotografi",
    "Party" : "Fest",
    "Celebration" : "Fejring",
    "Celebrate" : "Fejre",
    "Birthday" : "Fødselsdag",
    "Shopping" : "Shopping",
    "Groceries" : "Dagligvarer",
    "Skate" : "Skøjte",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Vinsmagning",
    "Golf" : "Golf",
    "Dinner" : "Middag",
    "Lunch" : "Frokost",
    "Appointment not found" : "Aftale ikke fundet",
    "User not found" : "Bruger ikke fundet"
},
"nplurals=2; plural=(n != 1);");
