OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s dalijās ar kalendāru »%s«",
    "Hello," : "Sveicināti,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Mēs jūs vēlējāmies informēt, ka %s publicēja kalendāru »%s«.",
    "Open »%s«" : "Atvērt »%s«",
    "Cheers!" : "Priekā!",
    "Confirm" : "Apstiprināt",
    "Calendar" : "Kalendārs",
    "A Calendar app for Nextcloud" : "Kalendāra lietotne priekš Nextcloud",
    "New event" : "Jauns notikums",
    "Today" : "Šodien",
    "Day" : "Diena",
    "Week" : "Nedēļa",
    "Month" : "Mēnesis",
    "List" : "Saraksts",
    "Preview" : "Priekšskatīt",
    "Copy link" : "Kopēt saiti",
    "Edit" : "Rediģēt",
    "Delete" : "Dzēst",
    "Export" : "Eksportēt",
    "Share link" : "Koplietot saiti",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "No users or groups" : "Nav lietotāji vai grupas",
    "can edit" : "var rediģēt",
    "New calendar" : "Jauns kalendārs",
    "New calendar with task list" : "Jauns kalendārs ar uzdevumu sarakstu",
    "Name" : "Vārds",
    "Deleted" : "Dzēstie",
    "Restore" : "Atjaunot",
    "Delete permanently" : "Dzēst pavisam",
    "Filename" : "Datnes nosaukums",
    "Cancel" : "Atcelt",
    "Automatic" : "Automātisks",
    "List view" : "Saraksta izkārtojums",
    "Actions" : "Darbības",
    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
    "Show week numbers" : "Rādīt nedēļu numurus",
    "Location" : "Vieta",
    "Description" : "Apraksts",
    "to" : "kam",
    "Add" : "Pievienot",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Sunday" : "Svētdiena",
    "Save" : "Saglabāt",
    "Update" : "Atjaunināt",
    "Your email address" : "Jūsu e-pasta adrese",
    "Notification" : "Paziņojums",
    "Email" : "E-pasts",
    "Available" : "Pieejams",
    "Busy" : "Aizņemts",
    "Unknown" : "Nezināms",
    "Accept" : "Pieņemt",
    "Decline" : "Noraidīt",
    "Tentative" : "Mēģinājums",
    "Send email" : "Sūtīt e-pastu",
    "All day" : "Visas dienas",
    "Repeat" : "Atkārtot",
    "never" : "nekad",
    "after" : "pēc",
    "available" : "pieejams",
    "More" : "Vairāk",
    "Global" : "Globāls",
    "Personal" : "Personīgs",
    "Create a new event" : "Izveidot jaunu notikumu",
    "Details" : "Detaļas",
    "Attendees" : "Apmeklētāji",
    "Resources" : "Resursi",
    "Close" : "Aizvērt",
    "Anniversary" : "Gadadiena",
    "Week {number} of {year}" : "{number} nedēļa no {year}",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "Next" : "Nākamā",
    "Other" : "Cits",
    "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
    "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
    "Status" : "Status",
    "Confirmed" : "Apstiprināts",
    "Categories" : "Kategorijas",
    "Presentation" : "Prezentācija",
    "Talk" : "Runāt",
    "Mail" : "E-pasts",
    "Birthday" : "Dzimšanas diena",
    "User not found" : "Lietotājs nav atrasts"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
