/*! For license information please see calendar-node_modules_moment_locale_mn_js.js.LICENSE.txt */
(self.webpackChunkcalendar=self.webpackChunkcalendar||[]).push([["node_modules_moment_locale_mn_js"],{5115:function(e,s,a){!function(e){"use strict";function s(e,s,a,_){switch(a){case"s":return s?"хэдхэн секунд":"хэдхэн секундын";case"ss":return e+(s?" секунд":" секундын");case"m":case"mm":return e+(s?" минут":" минутын");case"h":case"hh":return e+(s?" цаг":" цагийн");case"d":case"dd":return e+(s?" өдөр":" өдрийн");case"M":case"MM":return e+(s?" сар":" сарын");case"y":case"yy":return e+(s?" жил":" жилийн");default:return e}}e.defineLocale("mn",{months:"Нэгдүгээр сар_Хоёрдугаар сар_Гуравдугаар сар_Дөрөвдүгээр сар_Тавдугаар сар_Зургадугаар сар_Долдугаар сар_Наймдугаар сар_Есдүгээр сар_Аравдугаар сар_Арван нэгдүгээр сар_Арван хоёрдугаар сар".split("_"),monthsShort:"1 сар_2 сар_3 сар_4 сар_5 сар_6 сар_7 сар_8 сар_9 сар_10 сар_11 сар_12 сар".split("_"),monthsParseExact:!0,weekdays:"Ням_Даваа_Мягмар_Лхагва_Пүрэв_Баасан_Бямба".split("_"),weekdaysShort:"Ням_Дав_Мяг_Лха_Пүр_Баа_Бям".split("_"),weekdaysMin:"Ня_Да_Мя_Лх_Пү_Ба_Бя".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY-MM-DD",LL:"YYYY оны MMMMын D",LLL:"YYYY оны MMMMын D HH:mm",LLLL:"dddd, YYYY оны MMMMын D HH:mm"},meridiemParse:/ҮӨ|ҮХ/i,isPM:function(e){return"ҮХ"===e},meridiem:function(e,s,a){return e<12?"ҮӨ":"ҮХ"},calendar:{sameDay:"[Өнөөдөр] LT",nextDay:"[Маргааш] LT",nextWeek:"[Ирэх] dddd LT",lastDay:"[Өчигдөр] LT",lastWeek:"[Өнгөрсөн] dddd LT",sameElse:"L"},relativeTime:{future:"%s дараа",past:"%s өмнө",s,ss:s,m:s,mm:s,h:s,hh:s,d:s,dd:s,M:s,MM:s,y:s,yy:s},dayOfMonthOrdinalParse:/\d{1,2} өдөр/,ordinal:function(e,s){switch(s){case"d":case"D":case"DDD":return e+" өдөр";default:return e}}})}(a(30381))}}]);
//# sourceMappingURL=calendar-node_modules_moment_locale_mn_js.js.map?v=fa6ea37815658cf6c70b