/*! For license information please see calendar-node_modules_moment_locale_is_js.js.LICENSE.txt */
(self.webpackChunkcalendar=self.webpackChunkcalendar||[]).push([["node_modules_moment_locale_is_js"],{90135:function(r,e,u){!function(r){"use strict";function e(r){return r%100==11||r%10!=1}function u(r,u,a,n){var s=r+" ";switch(a){case"s":return u||n?"nokkrar sekúndur":"nokkrum sekúndum";case"ss":return e(r)?s+(u||n?"sekúndur":"sekúndum"):s+"sekúnda";case"m":return u?"mínúta":"mínútu";case"mm":return e(r)?s+(u||n?"mínútur":"mínútum"):u?s+"mínúta":s+"mínútu";case"hh":return e(r)?s+(u||n?"klukkustundir":"klukkustundum"):s+"klukkustund";case"d":return u?"dagur":n?"dag":"degi";case"dd":return e(r)?u?s+"dagar":s+(n?"daga":"dögum"):u?s+"dagur":s+(n?"dag":"degi");case"M":return u?"mánuður":n?"mánuð":"mánuði";case"MM":return e(r)?u?s+"mánuðir":s+(n?"mánuði":"mánuðum"):u?s+"mánuður":s+(n?"mánuð":"mánuði");case"y":return u||n?"ár":"ári";case"yy":return e(r)?s+(u||n?"ár":"árum"):s+(u||n?"ár":"ári")}}r.defineLocale("is",{months:"janúar_febrúar_mars_apríl_maí_júní_júlí_ágúst_september_október_nóvember_desember".split("_"),monthsShort:"jan_feb_mar_apr_maí_jún_júl_ágú_sep_okt_nóv_des".split("_"),weekdays:"sunnudagur_mánudagur_þriðjudagur_miðvikudagur_fimmtudagur_föstudagur_laugardagur".split("_"),weekdaysShort:"sun_mán_þri_mið_fim_fös_lau".split("_"),weekdaysMin:"Su_Má_Þr_Mi_Fi_Fö_La".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY [kl.] H:mm",LLLL:"dddd, D. MMMM YYYY [kl.] H:mm"},calendar:{sameDay:"[í dag kl.] LT",nextDay:"[á morgun kl.] LT",nextWeek:"dddd [kl.] LT",lastDay:"[í gær kl.] LT",lastWeek:"[síðasta] dddd [kl.] LT",sameElse:"L"},relativeTime:{future:"eftir %s",past:"fyrir %s síðan",s:u,ss:u,m:u,mm:u,h:"klukkustund",hh:u,d:u,dd:u,M:u,MM:u,y:u,yy:u},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(u(30381))}}]);
//# sourceMappingURL=calendar-node_modules_moment_locale_is_js.js.map?v=c6b597d56ac08fbdfb44