OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Brukerøkten utløp uventet",
    "Provided email-address is not valid" : "Oppgitt e-postadresse er ikke gyldig",
    "%s has published the calendar »%s«" : "%s har publisert kalenderen \"%s\"",
    "Unexpected error sending email. Please contact your administrator." : "Det oppstod uventet feil under sending av e-post. Kontakt din administrator.",
    "Successfully sent email to %1$s" : "Epost sendt til %1$s",
    "Hello," : "Hei,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønsker å informere deg om at %s har publisert kalenderen \"%s\".",
    "Open »%s«" : "Åpne \"%s\"",
    "Cheers!" : "Ha det!",
    "Upcoming events" : "Kommende hendelser",
    "Appointments" : "Avtaler",
    "Schedule appointment \"%s\"" : "Registrer avtale \"%s\"",
    "Schedule an appointment" : "Registrer en avtale",
    "Prepare for %s" : "Forbered for %s",
    "Follow up for %s" : "Følg opp for %s",
    "Dear %s, please confirm your booking" : "Kjære %s, vennligst bekreft bestillingen din",
    "Confirm" : "Bekreft",
    "This confirmation link expires in %s hours." : "Denne bekreftelseslinken utgår om %stimer.",
    "Date:" : "Dato:",
    "Where:" : "Hvor:",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "En kalender til Nextcloud",
    "Previous day" : "Forrige dag",
    "Previous week" : "Forrige uke",
    "Previous month" : "Forrige måned",
    "Next day" : "Neste dag",
    "Next week" : "Neste uke",
    "Next month" : "Neste måned",
    "New event" : "Ny hendelse",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Uke",
    "Month" : "Måned",
    "List" : "Liste",
    "Preview" : "Forhåndsvis",
    "Copy link" : "Kopier lenke",
    "Edit" : "Rediger",
    "Delete" : "Slett",
    "Appointment link was copied to clipboard" : "Avtalelenke ble kopiert til utklippstavlen",
    "Appointment link could not be copied to clipboard" : "Avtalelenken ble ikke kopiert til utklippstavlen",
    "Add new" : "Legg til ny",
    "Untitled calendar" : "Kalender uten tittel",
    "Edit name" : "Rediger navn",
    "Saving name …" : "Lagrer navn ...",
    "Edit color" : "Rediger farge",
    "Saving color …" : "Lagrer farge  ...",
    "Copy private link" : "Kopier privat lenke",
    "Export" : "Eksporter",
    "Unshare from me" : "Fjern deling fra meg",
    "Disable calendar \"{calendar}\"" : "Deaktiver kalender \"{calendar}\"",
    "Disable untitled calendar" : "Deaktiver kalender uten tittel",
    "Enable untitled calendar" : "Aktiver kalender uten tittel",
    "An error occurred, unable to change visibility of the calendar." : "En feil oppstod, kan ikke endre synlighet til kalenderen.",
    "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
    "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
    "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
    "An error occurred, unable to rename the calendar." : "Det oppstod en feil, klarte ikke å endre navn på kalenderen.",
    "An error occurred, unable to change the calendar's color." : "En feil oppstod, kunne ikke endre fargen til kalenderen.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling av kalenderen om {countdown} sekund","Fjerner deling av kalenderen om {countdown} sekunder"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Sletter kalenderen om {countdown} sekund","Sletter kalenderen om {countdown} sekunder"],
    "Share link" : "Del lenke",
    "Publish calendar" : "Publiser kalender",
    "Publishing calendar" : "Publiserer kalender",
    "Copy public link" : "Kopier offentlig lenke",
    "Send link to calendar via email" : "Sende lenke til kalenderen via e-post",
    "Enter one address" : "Tast inn en adresse",
    "Sending email …" : "Sender epost ...",
    "Copy subscription link" : "Kopier abonnementslenke",
    "Copying link …" : "Kopierer lenke ...",
    "Copied link" : "Kopier lenke",
    "Could not copy link" : "Klarte ikke å kopiere lenken",
    "Copy embedding code" : "Kopier innbyggingskode",
    "Copying code …" : "Kopierer kode ...",
    "Copied code" : "Kode kopiert",
    "Could not copy code" : "Klarte ikke å kopiere koden",
    "Delete share link" : "Slett delingslenke",
    "Deleting share link …" : "Sletter delingslenke ...",
    "An error occurred, unable to publish calendar." : "Det oppstod en feil, klarte ikke å publisere kalenderen.",
    "An error occurred, unable to send email." : "En feil oppstod, kan ikke sende e-post.",
    "Embed code copied to clipboard." : "Innbyggingskode kopiert til utklippstavle.",
    "Embed code could not be copied to clipboard." : "Innbyggingskode ble ikke kopiert til utklippstavle.",
    "Unpublishing calendar failed" : "Fjerne publiseringen av kalenderen feilet.",
    "Share with users or groups" : "Del med brukere eller grupper",
    "No users or groups" : "Ingen brukere eller grupper",
    "can edit" : "kan endre",
    "Unshare with {displayName}" : "Fjern deling med {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "En feil oppstod, kan ikke endre fjerning av deling av kalenderen.",
    "An error occurred, unable to change the permission of the share." : "En feil oppstod, kan ikke endre rettighetene til delingen.",
    "New calendar" : "Ny kalender",
    "Name for new calendar" : "Navn på ny kalender",
    "Creating calendar …" : "Oppretter kalender ...",
    "New calendar with task list" : "Ny kalender med oppgaveliste",
    "New subscription from link (read-only)" : "Nytt abonnement fra lenke (kun lesing)",
    "Creating subscription …" : "Oppretter abonnement ...",
    "An error occurred, unable to create the calendar." : "En feil oppstod, kunne ikke opprette kalenderen",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vennligst angi gyldig lenke (starte med http://, https://, webcal://, eller webcals://)",
    "Trash bin" : "Papirkurv",
    "Name" : "Navn",
    "Deleted" : "Slettet",
    "Restore" : "Gjenopprett",
    "Delete permanently" : "Slett permanent",
    "Empty trash bin" : "Tøm papirkurv",
    "Unknown calendar" : "Ukjent kalender",
    "Could not load deleted calendars and objects" : "Kunne ikke laste slettede kalendere og objekter",
    "Could not restore calendar or event" : "Kunne ikke gjenopprette kalender eller hendelse",
    "Do you really want to empty the trash bin?" : "Vil du virkelig tømme papirkurven?",
    "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendere.",
    "Import calendars" : "Importer kalendere",
    "Please select a calendar to import into …" : "Vennligst velg en kalender å importere til ...",
    "Filename" : "Filnavn",
    "Calendar to import into" : "Kalenderen det skal importeres til",
    "Cancel" : "Avbryt",
    "_Import calendar_::_Import calendars_" : ["Importer kalender","Importer kalendere"],
    "{filename} could not be parsed" : "{filename} kunne ikke leses",
    "No valid files found, aborting import" : "Ingen gyldig filer funnet, avbryter importering",
    "Import partially failed. Imported {accepted} out of {total}." : "Importen mislyktes delvis. Importerte {accepted} av {total}. ",
    "Automatic" : "Automatisk",
    "Automatic ({detected})" : "Automatisk ({detected})",
    "New setting was not saved successfully." : "Ny innstilling ble ikke lagret.",
    "Shortcut overview" : "Oversikt over snarveier",
    "or" : "eller",
    "Navigation" : "Navigasjon",
    "Previous period" : "Forrige periode",
    "Next period" : "Neste periode",
    "Views" : "Visninger",
    "Day view" : "Dagsvisning",
    "Week view" : "Ukesvisning",
    "Month view" : "Månedsvisning",
    "List view" : "Listevisning",
    "Actions" : "Handlinger",
    "Create event" : "Opprett hendelse",
    "Show shortcuts" : "Vis snarveier",
    "Save edited event" : "Lagre endret hendelse",
    "Delete edited event" : "Slett endret hendelse",
    "Duplicate event" : "Dupliser hendelse",
    "Enable birthday calendar" : "Aktiver fødselsdagkalender",
    "Show tasks in calendar" : "Vis oppgaver i kalender",
    "Enable simplified editor" : "Aktiver forenklet redigering",
    "Limit visible events per view" : "Begrens synlige hendelser i brukerutsnitt",
    "Show weekends" : "Vis helger",
    "Show week numbers" : "Vis ukenummer",
    "Time increments" : "Tidsøkninger",
    "Default reminder" : "Standardpåminnelse",
    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
    "Copy iOS/macOS CalDAV address" : "Kopier CalDAV-lenke for iOS/macOS",
    "Show keyboard shortcuts" : "Vis tastatursnarveier",
    "Calendar settings" : "Kalenderinnstillinger",
    "No reminder" : "Ingen påminnelse",
    "CalDAV link copied to clipboard." : "CalDAV-lenke kopiert til utklippstavlen.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minutt","{duration} minutter"],
    "0 minutes" : "0 minutter",
    "_{duration} hour_::_{duration} hours_" : ["{duration} time","{duration} timer"],
    "_{duration} day_::_{duration} days_" : ["{duration} dag","{duration} dager"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} uke","{duration} uker"],
    "_{duration} month_::_{duration} months_" : ["{duration} måned","{duration} måneder"],
    "_{duration} year_::_{duration} years_" : ["{duration} år","{duration} år"],
    "Location" : "Sted",
    "Description" : "Beskrivelse",
    "Visibility" : "Synlighet",
    "Duration" : "Varighet",
    "Increments" : "Økninger",
    "Additional calendars to check for conflicts" : "Ekstra kalendere for å se etter konflikter",
    "Pick time ranges where appointments are allowed" : "Velg tidsrom der avtaler er tillatt",
    "to" : "til",
    "Delete slot" : "Slett tidsrom",
    "No times set" : "Ingen tidsrom satt",
    "Add" : "Legg til",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sunday" : "Søndag",
    "Before the event" : "Før hendelsen",
    "After the event" : "Etter hendelsen",
    "Minimum time before next available slot" : "Minimumstid før neste tilgjengelige tidsrom",
    "Max slots per day" : "Maks. antall tidsrom per dag",
    "Limit how far in the future appointments can be booked" : "Begrens hvor langt frem i tid avtaler kan bestilles",
    "Create appointment" : "Opprett avtale",
    "Edit appointment" : "Endre avtale",
    "Save" : "Lagre",
    "Update" : "Oppdater",
    "Please confirm your reservation" : "Vennligst bekreft din reservasjon",
    "Your name" : "Ditt navn",
    "Your email address" : "Din e-postadresse",
    "Book the appointment" : "Bestill avtalen",
    "Reminder" : "Påminnelse",
    "before at" : "før ved",
    "Notification" : "Varsel",
    "Email" : "E-post",
    "Audio notification" : "Lydvarsel",
    "Other notification" : "Andre varsel",
    "Relative to event" : "Relativt til hendelse",
    "On date" : "På dato",
    "Edit time" : "Rediger tidspunkt",
    "Save time" : "Lagre tidspunkt",
    "Remove reminder" : "Fjern påminnelse",
    "on" : "på",
    "at" : "ved",
    "+ Add reminder" : "+ Legg til påminnelse",
    "Add reminder" : "Legg til påminnelse",
    "_second_::_seconds_" : ["sekund","sekunder"],
    "_minute_::_minutes_" : ["minutt","minutter"],
    "_hour_::_hours_" : ["time","timer"],
    "_day_::_days_" : ["dag","dager"],
    "_week_::_weeks_" : ["uke","uker"],
    "Available" : "Tilgjengelig",
    "Not available" : "Ikke tilgjengelig",
    "Invitation sent" : "Invitasjon er sendt",
    "Availability of attendees, resources and rooms" : "Tilgjengelighet til deltagere, ressurser og rom",
    "{organizer} (organizer)" : "{organizer} (organisator)",
    "Free" : "Ledig",
    "Busy (tentative)" : "Opptatt (foreløpig)",
    "Busy" : "Opptatt",
    "Out of office" : "Fraværende",
    "Unknown" : "Ukjent",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Tentative" : "Foreløpig",
    "Create Talk room for this event" : "Opprett Talk-rom for denne hendelsen",
    "Show busy times" : "Vis opptatte tider",
    "No attendees yet" : "Ingen deltakere enda",
    "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
    "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
    "Send email" : "Send e-post",
    "Chairperson" : "Ordstyrer",
    "Required participant" : "Påkrevd deltaker",
    "Optional participant" : "Valgfri deltaker",
    "Non-participant" : "Ikke-deltaker",
    "Remove attendee" : "Fjern deltaker",
    "Search for emails, users or contacts" : "Søk blant eposter, brukere eller kontaker",
    "No match found" : "Ingen treff",
    "(organizer)" : "(organisator)",
    "Remove color" : "Fjern farge",
    "Event title" : "Tittel på hendelsen",
    "All day" : "Hele dagen",
    "from {startDate}" : "fra {startDate}",
    "from {startDate} at {startTime}" : "fra {startDate}, {startTime}",
    "to {endDate}" : "til {endDate}",
    "to {endDate} at {endTime}" : "til {endDate}, {endTime}",
    "Repeat" : "Gjenta",
    "End repeat" : "Avslutt gjentakelse",
    "Select to end repeat" : "Velg for å avslutte gjentakelse",
    "never" : "aldri",
    "on date" : "på dato",
    "after" : "etter",
    "_time_::_times_" : ["gang","ganger"],
    "first" : "første",
    "third" : "tredje",
    "fourth" : "fjerde",
    "fifth" : "femte",
    "last" : "siste",
    "Repeat every" : "Gjenta hver",
    "By day of the month" : "På en dag i måneden",
    "On the" : "På den",
    "_month_::_months_" : ["måned","måneder"],
    "_year_::_years_" : ["år","år"],
    "weekday" : "ukedag",
    "weekend day" : "helgedag",
    "No recurrence" : "Ingen gjentakelse",
    "No rooms or resources yet" : "Ingen rom eller ressurser enda",
    "Has a projector" : "Har en projektor",
    "Wheelchair accessible" : "Tilgjengelig for rullestol",
    "Projector" : "Projektor",
    "Search for resources or rooms" : "Søk etter ressurser eller rom",
    "available" : "tilgjengelig",
    "Room type" : "Romtype",
    "Minimum seating capacity" : "Minimum sittekapasitet",
    "More" : "Mer",
    "Update this occurrence" : "Oppdater denne hendelsen",
    "Update this and all future" : "Oppdater denne og fremtidige hendelser",
    "Public calendar does not exist" : "Offentlig kalender finnes ikke",
    "Maybe the share was deleted or has expired?" : "Er deling slettet eller utløpt?",
    "Please select a time zone:" : "Vennligst velg en tidssone:",
    "Pick a time" : "Velg et tidspunkt",
    "Pick a date" : "Velg en dato",
    "from {formattedDate}" : "fra {formattedDate}",
    "to {formattedDate}" : "til {formattedDate}",
    "on {formattedDate}" : "den {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} kl. {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "til {formattedDate} kl. {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "den {formattedDate} kl. {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
    "Please enter a valid date" : "Vennligst tast inn en gyldig dato",
    "Please enter a valid date and time" : "Vennligst tast inn en gyldig dato og et tidspunkt",
    "Type to search time zone" : "Skriv for å søke etter tidssone",
    "Global" : "Global",
    "Select date" : "Velg dato",
    "Select slot" : "Velg tidsrom",
    "No slots available" : "Ingen tidsrom tilgjengelig",
    "The slot for your appointment has been confirmed" : "Tidsrommet for din avtale har blitt bekreftet",
    "Time:" : "Tid:",
    "Booked for:" : "Bestilt for:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Takk skal du ha. Bestillingen din fra {startDate} til {endDate} er bekreftet.",
    "Book another appointment:" : "Bestill en annen avtale:",
    "See all available slots" : "Se tilgjengelige tidsrom",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Tidsrommet for din avtale fra {startDate} toø {endDate} er ikke tilgjengelig lengre.",
    "Please book a different slot:" : "Vennligst bestill et annet tidsrom:",
    "Book an appointment with {name}" : "Bestill en avtale med {name}",
    "Personal" : "Personlig",
    "No more events today" : "Ingen flere hendelser i dag",
    "No upcoming events" : "Ingen kommende hendelser",
    "Event does not exist" : "Hendelsen finnes ikke",
    "Delete this occurrence" : "Slett denne hendelsen",
    "Delete this and all future" : "Slett denne og fremtidige hendelser",
    "Details" : "Detaljer",
    "Attendees" : "Deltakere",
    "Resources" : "Ressurser",
    "Close" : "Lukk",
    "Show more details" : "Vis flere detaljer",
    "Subscribe to {name}" : "Abonner på {name}",
    "Anniversary" : "Jubileum",
    "Appointment" : "Avtale",
    "Business" : "Forretninger",
    "Education" : "Utdanning",
    "Holiday" : "Helligdag",
    "Meeting" : "Møte",
    "Miscellaneous" : "Diverse",
    "Non-working hours" : "Utenfor arbeidstid",
    "Not in office" : "Ikke på kontoret",
    "Phone call" : "Telefonsamtale",
    "Sick day" : "Sykedag",
    "Special occasion" : "Spesiell anledning",
    "Travel" : "Reise",
    "Vacation" : "Ferie",
    "Week {number} of {year}" : "Uke {number} {year}",
    "Does not repeat" : "Gjentas ikke",
    "Daily" : "Daglig",
    "Weekly" : "Ukentlig",
    "Monthly" : "Månedlig",
    "Yearly" : "Årlig",
    "_%n time_::_%n times_" : ["%n gang","%n ganger"],
    "Untitled event" : "Hendelse uten tittel",
    "Untitled task" : "Oppgave uten tittel",
    "Please ask your administrator to enable the Tasks App." : "Ta kontakt med din administrator for å sette opp Oppgaver-appen.",
    "Prev" : "Forrige",
    "Next" : "Neste",
    "Year" : "År",
    "No events to display" : "Ingen hendelser å vise",
    "No events" : "Ingen hendelser",
    "Create a new event or change the visible time-range" : "Opprett en ny hendelse eller endre på valgt tidsrom",
    "Other" : "Annet",
    "When shared show" : "Når delt vis",
    "When shared show full event" : "Vis hele hendelsen om den deles",
    "When shared show only busy" : "Vis kun opptatt om den deles",
    "When shared hide this event" : "Skjul denne hendelsen om den deles",
    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere",
    "Add a location" : "Legg til et sted",
    "Add a description" : "Legg til en beskrivelse",
    "Status" : "Status",
    "Confirmed" : "Bekreftet",
    "Canceled" : "Avbrutt",
    "Confirmation about the overall status of the event." : "Bekreftelse om den generelle statusen til arrangementet.",
    "Show as" : "Vis som",
    "Take this event into account when calculating free-busy information." : "Ta hensyn til denne hendelsen når det beregnes ledig-opptatt-informasjon.",
    "Categories" : "Kategorier",
    "Categories help you to structure and organize your events." : "Kategorier hjelper deg med å strukturere og organisere arrangementene dine.",
    "Search or add categories" : "Søk eller legg til kategorier",
    "Add this as a new category" : "Legg til som ny kategori",
    "Custom color" : "Tilpasset farge",
    "Special color of this event. Overrides the calendar-color." : "Spesial farge for denne hendelsen. Overstyrer kalenderfargen.",
    "Imported {filename}" : "Importerte {filename}",
    "Meditation" : "Meditasjon",
    "Relaxing" : "Avslapping",
    "Commuting" : "Pendler",
    "Money" : "Penger",
    "Presentation" : "Presentasjon",
    "Talk" : "Samtale",
    "Camping" : "Camping",
    "Movie" : "Film",
    "Cinema" : "Kino",
    "Brainstorm" : "Brainstorm",
    "Review" : "Anmeldelse",
    "Meet" : "Møte",
    "Planning" : "Planlegge",
    "Office" : "Kontor",
    "Mail" : "E-post",
    "Soccer" : "Fotball",
    "Gaming" : "Gaming",
    "Drive" : "Kjøre",
    "Bicycle" : "Sykkel",
    "Cycle" : "Sykle",
    "Biking" : "Sykling",
    "Podcast" : "Podkast",
    "Fishing" : "Fisking",
    "Hiking" : "Tur",
    "Art" : "Kunst",
    "Exhibition" : "Utstilling",
    "Museum" : "Museum",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Studying" : "Studere",
    "Doctor" : "Doktor",
    "Health" : "Helse",
    "Dentist" : "Tannlege",
    "Hospital" : "Sykehus",
    "Interview" : "Intervju",
    "Training" : "Trene",
    "Practice" : "Øve",
    "Sports" : "Sport",
    "Gym" : "Gym",
    "Barber" : "Barberer",
    "Haircut" : "Frisør",
    "Exam" : "Eksamen",
    "Working" : "Jobb",
    "New Years Eve" : "Nyttårsaften",
    "Fireworks" : "Fyrverkeri",
    "Running" : "Løpe",
    "Go for a run" : "Løpetur",
    "Marathon" : "Maraton",
    "Video-conference" : "Videokonferanse",
    "Conference-call" : "Telefonkonferanse",
    "Video-call" : "Videosamtale",
    "Video-chat" : "Videochat",
    "Video-meeting" : "Videokonferanse",
    "Call" : "Ringe",
    "Calling" : "Ringer",
    "Christmas" : "Jul",
    "Conference" : "Konferanse",
    "Pizza" : "Pizza",
    "Travelling" : "Reise",
    "Journey" : "Reise",
    "Collaborate" : "Samarbeide",
    "Pair" : "Par",
    "Lecture" : "Forelesning",
    "Seminar" : "Seminar",
    "Photograph" : "Fotografere",
    "Party" : "Fest",
    "Celebration" : "Feiring",
    "Celebrate" : "Feire",
    "Birthday" : "Fødselsdag",
    "Shopping" : "Shoppe",
    "Skate" : "Skate",
    "Skateboard" : "Skatebrett",
    "Wine tasting" : "Vinsmaking",
    "Golf" : "Golf",
    "Dinner" : "Middag",
    "Lunch" : "Lunsj",
    "User not found" : "Fant ikke brukeren"
},
"nplurals=2; plural=(n != 1);");
