/**
 * Calendar App
 *
 * @copyright 2019 Georg Ehrke <oc.list@georgehrke.com>
 *
 * @author Georg Ehrke
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

.modal--scheduler {
	position: relative;

	.fc-bgevent {
		opacity: .8;
	}

	.blocking-event-free-busy {
		border-color: red;
		border-style: solid;
		border-left-width: 2px;
		border-right-width: 2px;
		background-color: transparent !important;
		opacity: 0.7 !important;
		z-index: 2;
	}

	.blocking-event-free-busy.blocking-event-free-busy--first-row {
		border-top-width: 2px;
	}

	.blocking-event-free-busy.blocking-event-free-busy--last-row {
		border-bottom-width: 2px;
	}

	.loading-indicator {
		width: 100%;
		position: absolute;
		top: 0;
		height: 50px;
		margin-top: 75px;
	}
}

.freebusy-caption {
	display: flex;
	margin-top: 10px;

	&__calendar-user-types,
	&__colors {
		width: 50%;
		display: flex;
	}

	&__colors {
		display: flex;
		justify-content: space-between;

		.freebusy-caption-item {
			display: flex;
			align-items: center;

			&__color {
				height: 1em;
				width: 2em;
				display: block;
				border: 1px solid var(--color-border-dark);
				opacity: 0.8;
			}

			&__label {
				margin-left: 5px;
			}
		}
	}
}
