OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Användarsessionen upphörde oväntat",
    "Provided email-address is not valid" : "Den angivna e-postadressen är inte giltig",
    "%s has published the calendar »%s«" : "%s har publicerat kalender »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Oväntat fel vid skickande av e-post. Kontakta din administratör.",
    "Successfully sent email to %1$s" : "E-post skickad till %1$s",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi vill informera dig att %s har publicerat kalendern »%s«.",
    "Open »%s«" : "Öppna »%s«",
    "Cheers!" : "Ha de fint!",
    "Upcoming events" : "Kommande händelser",
    "Appointments" : "Möten",
    "Schedule appointment \"%s\"" : "Schemalägg möte ”%s”",
    "Schedule an appointment" : "Schemalägg ett möte",
    "Prepare for %s" : "Förberedelse inför %s",
    "Follow up for %s" : "Uppföljning av %s",
    "Confirm" : "Bekräfta",
    "Date:" : "Datum:",
    "Where:" : "Plats:",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "En kalender-app för Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Kalendar-appen är ett gränssnitt till Nextclouds CalDAV server. Synkronisera händelser enkelt från diverse enheter till Nextcloud samt redigera dem online.\n\n* 🚀 **Integrerad med andra Nextcloud-appar!** För tillfället Kontakter - fler på väg.\n* 🌐 **WebCal Support!** Vill du se ditt favoritlags matchdagar i din kalender? Inga problem!\n* 🙋 **Deltagare!** Bjud in andra deltagare till dina aktiviteter\n* ⌚️ **Ledig/Upptagen!** Se när andra deltagare har ledig tid\n* ⏰ **Påminnelser!** Få påminnelser för aktiviteter i webbläsaren och på e-mail.\n* 🔍 Sök! Hitta dina event lätt!\n* ☑️ Uppgifter! Se dina uppgifters slutdatum direkt i kalendern\n* 🙈 **Vi uppfinner inte hjulet igen!** Appen är baserad på de fantastiska biblioteken [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) och [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Föregående dag",
    "Previous week" : "Föregående vecka",
    "Previous month" : "Föregående månad",
    "Next day" : "Nästa dag",
    "Next week" : "Nästa vecka",
    "Next month" : "Nästa månad",
    "New event" : "Ny händelse",
    "Today" : "Idag",
    "Day" : "Dag",
    "Week" : "Vecka",
    "Month" : "Månad",
    "List" : "Lista",
    "Preview" : "Förhandsvisning",
    "Copy link" : "Kopiera länk",
    "Edit" : "Redigera",
    "Delete" : "Ta bort",
    "Add new" : "Lägg till ny",
    "Untitled calendar" : "Namnlös kalender",
    "Edit name" : "Ändra namn",
    "Saving name …" : "Sparar namn …",
    "Edit color" : "Ändra färg",
    "Saving color …" : "Sparar färg …",
    "Copy private link" : "Kopiera privat länk",
    "Export" : "Exportera",
    "Unshare from me" : "Sluta dela från mig",
    "An error occurred, unable to change visibility of the calendar." : "Ett fel inträffade, kunde inte ändra synlighet på kalendern.",
    "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
    "Calendar link copied to clipboard." : "Kalenderlänk kopierad till urklipp.",
    "Calendar link could not be copied to clipboard." : "Kalenderlänk kunde inte kopieras till urklipp.",
    "An error occurred, unable to rename the calendar." : "Ett fel inträffade, kunde inte byta namn på kalendern.",
    "An error occurred, unable to change the calendar's color." : "Ett fel inträffade, kunde inte byta färg på kalendern.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Slutar dela kalendern om {countdown} sekund","Slutar dela kalendern om {countdown} sekunder"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Slutar dela kalendern om {countdown} sekund","Raderar kalendern {countdown} sekunder"],
    "Share link" : "Dela länk",
    "Publish calendar" : "Publicera kalender ",
    "Publishing calendar" : "Publicerar kalender",
    "Copy public link" : "Kopiera publik länk",
    "Send link to calendar via email" : "Skicka länk till kalender via e-post",
    "Enter one address" : "Mata in en adress",
    "Sending email …" : "Skickar e-post …",
    "Copy subscription link" : "Kopiera abonnemangslänk",
    "Copying link …" : "Kopierar länk …",
    "Copied link" : "Kopierad länk",
    "Could not copy link" : "Kunde inte kopiera länk",
    "Copy embedding code" : "Kopiera inbäddad kod",
    "Copying code …" : "Kopierar kod …",
    "Copied code" : "Kopierad kod",
    "Could not copy code" : "Kunde inte kopiera kod",
    "Delete share link" : "Ta bort delad länk",
    "Deleting share link …" : "Raderar delad länk …",
    "An error occurred, unable to publish calendar." : "Ett fel inträffade, kunde inte publicera kalendern.",
    "An error occurred, unable to send email." : "Fel uppstod. Mejlet kunde inte skickas.",
    "Embed code copied to clipboard." : "Inbäddad kod kopierad till urklipp.",
    "Embed code could not be copied to clipboard." : "Inbäddad kod kunde inte kopieras till urklipp.",
    "Unpublishing calendar failed" : "Avpublicering av kalendern misslyckades",
    "Share with users or groups" : "Dela med användare eller grupper",
    "No users or groups" : "Inga användare eller grupper",
    "can edit" : "kan redigera",
    "Unshare with {displayName}" : "Sluta dela med {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Fel uppstod. Det gick inte att ta bort kalenderdelningen.",
    "An error occurred, unable to change the permission of the share." : "Ett fel inträffade. Det gick inte att ändra behörighet för delningen.",
    "New calendar" : "Ny kalender",
    "Creating calendar …" : "Skapar kalender …",
    "New calendar with task list" : "Ny kalender med uppgiftslista",
    "New subscription from link (read-only)" : "Ny prenumeration från länk (skrivskyddad)",
    "Creating subscription …" : "Skapar abonnemang …",
    "An error occurred, unable to create the calendar." : "Ett fel inträffade, kunde inte skapa kalender.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Ange en giltig länk (startar med http://, https://, webcal://, eller webcals://)",
    "Trash bin" : "Papperskorg",
    "Name" : "Namn",
    "Deleted" : "Borttagen",
    "Restore" : "Återställ",
    "Delete permanently" : "Ta bort permanent",
    "Empty trash bin" : "Töm papperskorgen",
    "Unknown calendar" : "Okänd kalender",
    "Could not load deleted calendars and objects" : "Kunde inte ladda borttagna kalendrar och objekt",
    "Could not restore calendar or event" : "Kunde inte återställa kalender eller händelse",
    "Do you really want to empty the trash bin?" : "Vill du verkligen tömma papperskorgen?",
    "Could not update calendar order." : "Det gick inte att uppdatera kalenderordningen.",
    "Import calendars" : "Importera kalendrar",
    "Please select a calendar to import into …" : "Vänligen välj en kalender du vill importera till …",
    "Filename" : "Filnamn",
    "Calendar to import into" : "Kalender att importera till",
    "Cancel" : "Avbryt",
    "_Import calendar_::_Import calendars_" : ["Importera kalender","Importera kalendrar"],
    "{filename} could not be parsed" : "{filename} kunde inte läsas",
    "No valid files found, aborting import" : "Inga giltiga filer hittades, avbryter import",
    "Import partially failed. Imported {accepted} out of {total}." : "Importen misslyckades delvis. Importerade {accepted} av {total}.",
    "Automatic" : "Automatisk",
    "Automatic ({detected})" : "Automatisk ({detected})",
    "New setting was not saved successfully." : "Den nya inställningen kunde inte sparas.",
    "Shortcut overview" : "Översikt av genvägar",
    "or" : "eller",
    "Navigation" : "Navigering",
    "Previous period" : "Föregående period",
    "Next period" : "Nästa period",
    "Views" : "Vyer",
    "Day view" : "Översikt dag",
    "Week view" : "Översikt vecka",
    "Month view" : "Översikt månad",
    "List view" : "Listvy",
    "Actions" : "Åtgärder",
    "Create event" : "Skapa händelse",
    "Show shortcuts" : "Visa genvägar",
    "Enable birthday calendar" : "Aktivera födelsedagskalender",
    "Show tasks in calendar" : "Visa uppgifter i kalendern",
    "Enable simplified editor" : "Aktivera förenklad redigerare",
    "Limit visible events per view" : "Begränsa synliga händelser per vy",
    "Show weekends" : "Visa helger",
    "Show week numbers" : "Visa veckonummer",
    "Time increments" : "Tidsintervall",
    "Default reminder" : "Standardpåminnelse",
    "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
    "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar",
    "No reminder" : "Ingen påminnelse",
    "CalDAV link copied to clipboard." : "CalDAV-länk kopierad till urklipp.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-länk kunde inte kopieras till urklipp.",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuter"],
    "0 minutes" : "0 minuter",
    "_{duration} hour_::_{duration} hours_" : ["{duration} timme","{duration} timmar"],
    "_{duration} day_::_{duration} days_" : ["{duration} dag","{duration} dagar"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} vecka","{duration} veckor"],
    "_{duration} month_::_{duration} months_" : ["{duration} månad","{duration} månader"],
    "_{duration} year_::_{duration} years_" : ["{duration} år","{duration} år"],
    "Location" : "Plats",
    "Description" : "Beskrivning",
    "Visibility" : "Synlighet",
    "Duration" : "Varaktighet",
    "Increments" : "Tidsintervall",
    "to" : "till",
    "Add" : "Lägg till",
    "Monday" : "Måndag",
    "Tuesday" : "Tisdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lördag",
    "Sunday" : "Söndag",
    "Create appointment" : "Skapa möte",
    "Edit appointment" : "Redigera möte",
    "Save" : "Spara",
    "Update" : "Uppdatera",
    "Your name" : "Ditt namn",
    "Your email address" : "Din e-postadress",
    "Book the appointment" : "Boka mötet",
    "Reminder" : "Påminnelse",
    "before at" : "innan",
    "Notification" : "Notifiering",
    "Email" : "E-post",
    "Audio notification" : "Ljudmeddelande",
    "Other notification" : "Annan notifiering",
    "Relative to event" : "I förhållande till händelse",
    "On date" : "På datum",
    "Edit time" : "Ändra tid",
    "Save time" : "Lagra tid",
    "Remove reminder" : "Ta bort påminnelse",
    "on" : "på",
    "at" : "kl",
    "+ Add reminder" : "+Lägg till påminnelse",
    "Add reminder" : "Lägg till påminnelse",
    "_second_::_seconds_" : ["sekund","sekunder"],
    "_minute_::_minutes_" : ["minut","minuter"],
    "_hour_::_hours_" : ["timme","timmar"],
    "_day_::_days_" : ["dag","dagar"],
    "_week_::_weeks_" : ["vecka","veckor"],
    "Available" : "Tillgänglig",
    "Not available" : "Inte tillgänglig",
    "Availability of attendees, resources and rooms" : "Deltagares tillgänglighet, resurser och lokaler",
    "{organizer} (organizer)" : "{organizer} (arrangör)",
    "Free" : "Ledig",
    "Busy (tentative)" : "Upptagen (preliminär)",
    "Busy" : "Upptagen",
    "Out of office" : "Ej på plats",
    "Unknown" : "Okänd",
    "Accept" : "Acceptera",
    "Decline" : "Avböj",
    "Tentative" : "Preliminärt",
    "Create Talk room for this event" : "Skapa ett rum i Talk för denna händelse",
    "Show busy times" : "Visa upptagna tider",
    "No attendees yet" : "Inga deltagare ännu",
    "Successfully appended link to talk room to description." : "Länk till rum i Talk tillagd i beskrivningen.",
    "Error creating Talk room" : "Kunde inte skapa rum i Talk",
    "Send email" : "Skicka e-post",
    "Chairperson" : "Ordförande",
    "Required participant" : "Obligatorisk deltagare",
    "Optional participant" : "Valfri deltagare",
    "Non-participant" : "Icke-deltagare",
    "Remove attendee" : "Ta bort deltagaren",
    "Search for emails, users or contacts" : "Sök efter e-postadresser, användare eller kontakter",
    "No match found" : "Ingen träff",
    "(organizer)" : "(arrangör)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "För att kunna skicka inbjudningar och hantera svar måste du [linkopen]lägga till din e-mailadress i inställningarna[linkclose].",
    "Remove color" : "Ta bort färg",
    "Event title" : "Händelsens titel",
    "All day" : "Heldag",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan inte ändra inställning för heldag när händelsen är återkommande.",
    "from {startDate}" : "från {startDate}",
    "from {startDate} at {startTime}" : "från {startDate} kl {startTime}",
    "to {endDate}" : "till {endDate}",
    "to {endDate} at {endTime}" : "till {endDate} kl {endTime}",
    "Repeat" : "Upprepa",
    "End repeat" : "Sluta upprepa",
    "Select to end repeat" : "Välj för att avsluta upprepning",
    "never" : "aldrig",
    "on date" : "på datum",
    "after" : "efter",
    "_time_::_times_" : ["gång","gånger"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Den här händelsen är återkommande undantag för en upprepning. Du kan inte lägga till en regel för den.",
    "first" : "första",
    "third" : "tredje",
    "fourth" : "fjärde",
    "fifth" : "femte",
    "second to last" : "näst sist",
    "last" : "sist",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Ändringar av återkommande regel gäller endast för denna och alla framtida händelser.",
    "Repeat every" : "Upprepa varje",
    "By day of the month" : "Efter dag i månaden",
    "On the" : "På den",
    "_month_::_months_" : ["månad","månader"],
    "_year_::_years_" : ["år","år"],
    "weekday" : "veckodag",
    "weekend day" : "helgdag",
    "No recurrence" : "Ingen upprepning",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Återkommande definition av denna händelse stöds inte helt av Nextcloud. Om du redigerar återfallsalternativen kan vissa återfall försvinna.",
    "Suggestions" : "Rekommendationer",
    "No rooms or resources yet" : "Inga rum eller resurser än",
    "Add resource" : "Lägg till resurs",
    "Has a projector" : "Projektor finns",
    "Has a whiteboard" : "Whiteboard finns",
    "Wheelchair accessible" : "Tillgänglig i rullstol",
    "Remove resource" : "Ta bort resurs",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} plats","{seatingCapacity} platser"],
    "Projector" : "Projektor",
    "Whiteboard" : "Whiteboard",
    "Search for resources or rooms" : "Sök efter resurser eller rum",
    "available" : "tillgänglig",
    "unavailable" : "ej tillgänglig",
    "Room type" : "Rumtyp",
    "Any" : "Alla",
    "Minimum seating capacity" : "Minsta antal platser",
    "More" : "Mer",
    "Update this occurrence" : "Uppdatera denna förekomst",
    "Update this and all future" : "Uppdatera denna och alla kommande",
    "Public calendar does not exist" : "Publik kalender finns inte",
    "Maybe the share was deleted or has expired?" : "Kanske har delningen tagits bort eller har gått ut?",
    "Please select a time zone:" : "Välj en tidszon:",
    "Pick a time" : "Välj en tidpunkt",
    "Pick a date" : "Välj ett datum",
    "from {formattedDate}" : "från {formattedDate}",
    "to {formattedDate}" : "till {formattedDate}",
    "on {formattedDate}" : "på {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "från {formattedDate} kl {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "till {formattedDate} kl {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "på {formattedDate} kl {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} kl {formattedTime}",
    "Please enter a valid date" : "Ange ett giltigt datum",
    "Please enter a valid date and time" : "Ange giltigt datum och tid",
    "Type to search time zone" : "Skriv för att söka tidszon",
    "Global" : "Global",
    "Select date" : "Välj datum",
    "Time:" : "Tid:",
    "Booked for:" : "Bokad för:",
    "Personal" : "Privat",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiska tidszon-detekteringen fastställde din tidszon till UTC.\nDetta är troligtvis resultatet av säkerhetsinställningar i din webbläsare.\nVänligen ställ in din tidszon manuellt i kalenderinställningarna.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din tidszon ({timezoneId}) hittades inte. Återgår till UTC.\nVänligen ändra din tidszon i inställningarna och rapportera detta problem.",
    "No more events today" : "Inga fler händelser idag",
    "No upcoming events" : "Inga kommande händelser",
    "Create a new event" : "Skapa en ny händelse",
    "[Today]" : "[Idag]",
    "[Tomorrow]" : "[Imorgon]",
    "[Yesterday]" : "[Igår]",
    "[Last] dddd" : "[Sista] dddd",
    "Event does not exist" : "Händelsen existerar inte",
    "Delete this occurrence" : "Ta bort denna förekomst",
    "Delete this and all future" : "Ta bort denna och alla kommande",
    "Details" : "Detaljer",
    "Attendees" : "Deltagare",
    "Resources" : "Resurser",
    "Close" : "Stäng",
    "Show more details" : "Visa mer information",
    "Subscribe to {name}" : "Prenumerera på {name}",
    "Anniversary" : "Födelsedag",
    "Appointment" : "Bokning",
    "Business" : "Företag",
    "Education" : "Utbildning",
    "Holiday" : "Ledighet",
    "Meeting" : "Möte",
    "Miscellaneous" : "Diverse",
    "Non-working hours" : "Icke-arbetstid",
    "Not in office" : "Inte på kontoret",
    "Phone call" : "Telefonsamtal",
    "Sick day" : "Sjukdag",
    "Special occasion" : "Speciellt tillfälle",
    "Travel" : "Resa",
    "Vacation" : "Semester",
    "Midnight on the day the event starts" : "Midnatt den dagen evenemanget börjar",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dagar före händelsen klockan {formattedHourMinute}","%n dag före händelsen klockan {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n veckor före händelsen klockan {formattedHourMinute}","%n vecka före händelsen klockan {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "på samma dag som händelsen klockan {formattedHourMinute}",
    "at the event's start" : "när händelsen börjar",
    "at the event's end" : "när händelsen slutar",
    "{time} before the event starts" : "{time} före händelsens början",
    "{time} before the event ends" : "{time} före händelsens slut",
    "{time} after the event starts" : "{time} efter händelsens början",
    "{time} after the event ends" : "{time} efter händelsens slut",
    "on {time}" : "klockan {time}",
    "on {time} ({timezoneId})" : "klockan {time} ({timezoneId})",
    "Week {number} of {year}" : "Vecka {number} år {year}",
    "Does not repeat" : "Upprepar inte",
    "Daily" : "Varje dag",
    "Weekly" : "Varje vecka",
    "Monthly" : "Varje månad",
    "Yearly" : "Årligen",
    "_Every %n day_::_Every %n days_" : ["Varje %n dag","Varje %n dagar"],
    "_Every %n week_::_Every %n weeks_" : ["Varje %n vecka","Varje %n veckor"],
    "_Every %n month_::_Every %n months_" : ["Varje %n månad","Varje %n månader"],
    "_Every %n year_::_Every %n years_" : ["Varje %n år","Varje %n år"],
    "_on {weekday}_::_on {weekdays}_" : ["på {weekday}","på {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["på dag {dayOfMonthList}","på dagar {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "på den {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "i {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "i {monthNames} på den {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "till {untilDate}",
    "_%n time_::_%n times_" : ["%n gång","%n gånger"],
    "Untitled event" : "Namnlös händelse",
    "Untitled task" : "Namnlös uppgift",
    "Please ask your administrator to enable the Tasks App." : "Be din administratör aktivera Tasks-appen.",
    "Prev" : "Föregående",
    "Next" : "Nästa",
    "Prev year" : "Föreg. år",
    "Next year" : "Nästa år",
    "Year" : "År",
    "W" : "v",
    "%n more" : " %n till",
    "No events to display" : "Inga händelser att visa",
    "_+%n more_::_+%n more_" : ["och %n till","och %n till"],
    "No events" : "Inga händelser",
    "Create a new event or change the visible time-range" : "Skapa ny händelse eller ändra det synliga tidspannet",
    "It might have been deleted, or there was a typo in a link" : "Den kan ha raderats eller så var länken felaktig",
    "It might have been deleted, or there was a typo in the link" : "Den kan ha raderats eller så var länken felaktig",
    "Meeting room" : "Mötesrum",
    "Lecture hall" : "Föreläsningssal",
    "Seminar room" : "Seminarierum",
    "Other" : "Annat",
    "When shared show" : "Visa om delad",
    "When shared show full event" : "Om delad, visa hela händelsen",
    "When shared show only busy" : "Om delad, visa endast upptagen",
    "When shared hide this event" : "Om delad, dölj denna händelse",
    "The visibility of this event in shared calendars." : "Synligheten för denna händelse i delade kalendrar.",
    "Add a location" : "Lägg till en plats",
    "Add a description" : "Lägg till en beskrivning",
    "Status" : "Status",
    "Confirmed" : "Bekräftad",
    "Canceled" : "Avbruten",
    "Confirmation about the overall status of the event." : "Bekräftelse av händelsens övergripande status.",
    "Show as" : "Visa som",
    "Take this event into account when calculating free-busy information." : "Ta hänsyn till denna händelse när ledig/upptagen tid beräknas.",
    "Categories" : "Kategorier",
    "Categories help you to structure and organize your events." : "Kategorier hjälper dig strukturera och organisera dina händelser.",
    "Search or add categories" : "Sök eller lägg till kategorier",
    "Add this as a new category" : "Lägg till som en ny kategori",
    "Custom color" : "Anpassad färg",
    "Special color of this event. Overrides the calendar-color." : "Anpassad färg på denna händelse. Åsidosätter kalenderfärgen.",
    "Chat room for event" : "Mötesrum för event",
    "Imported {filename}" : "Importerad {filename}",
    "Meditation" : "Meditation",
    "Relaxing" : "Relaxa",
    "Relax" : "Relax",
    "Break" : "Paus",
    "Commute" : "Pendla",
    "Commuting" : "Pendlar",
    "Shuttle" : "Pendel",
    "Invoice" : "Faktura",
    "Finance" : "Finans",
    "Bank" : "Bank",
    "Money" : "Pengar",
    "Wedding" : "Bröllop",
    "Dog" : "Hund",
    "Concert" : "Konsert",
    "Festival" : "Festival",
    "Theater" : "Teater",
    "Theatre" : "Teater",
    "Presentation" : "Presentation",
    "Talk" : "Samtal",
    "Speech" : "Föredrag",
    "Deadline" : "Deadline",
    "Submission" : "Inlämning",
    "Reporting" : "Rapport",
    "Camping" : "Camping",
    "Camp" : "Camp",
    "Election" : "Val",
    "Voting" : "Röstning",
    "Vote" : "Rösta",
    "Barbecue" : "Grillning",
    "Barbeque" : "Grillning",
    "Garden" : "Trädgård",
    "Farm" : "Gård",
    "Movie" : "Film",
    "Cinema" : "Bio",
    "Graduation" : "Examen",
    "Brainstorm" : "Brainstorm",
    "Review" : "Granska",
    "Audit" : "Granskning",
    "Inspection" : "Inspektion",
    "Proofreading" : "Korrektur",
    "Baseball" : "Baseball",
    "Meet" : "Möte",
    "Planning" : "Planering",
    "Pointing" : "Peka",
    "Retrospective" : "Återkoppling",
    "Office" : "Kontor",
    "Contributor week" : "Bidragarvecka",
    "Mail" : "E-post",
    "Soccer" : "Fotboll",
    "Football" : "Fotboll",
    "Gaming" : "Gaming",
    "Drive" : "Biltur",
    "Driving" : "Körning",
    "Bicycle" : "Cykel",
    "Cycle" : "Cykling",
    "Cycling" : "Cykling",
    "Biking" : "Cykling",
    "Bike" : "Cykel",
    "Podcast" : "Podcast",
    "Basketball" : "Basketboll",
    "Fishing" : "Fiske",
    "Hiking" : "Vandring",
    "Hike" : "Vandra",
    "Art" : "Konst",
    "Exhibition" : "Utställning",
    "Museum" : "Museum",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Walk" : "Promenad",
    "Studying" : "Studerar",
    "Doctor" : "Läkare",
    "Health" : "Hälsa",
    "Dentist" : "Tandläkare",
    "Hospital" : "Sjukhus",
    "Interview" : "Intervju",
    "Training" : "Träning",
    "Practice" : "Träning",
    "Sports" : "Sport",
    "Exercise" : "Träning",
    "Work out" : "Work out",
    "Working out" : "Working out",
    "Gym" : "Gym",
    "Barber" : "Frisör",
    "Haircut" : "Frisyr",
    "Hairdresser" : "Frisör",
    "Exam" : "Prov",
    "Written test" : "Skriftligt prov",
    "Oral test" : "Muntligt prov",
    "Working" : "Arbete",
    "New Years Eve" : "Nyårsafton",
    "NYE" : "Nyårsafton",
    "Fireworks" : "Fyrverkerier",
    "Running" : "Löpning",
    "Go for a run" : "Löprunda",
    "Marathon" : "Marathon",
    "Video-conference" : "Videokonferens",
    "Conference-call" : "Konferenssamtal",
    "Video-call" : "Video-samtal",
    "Video-chat" : "Video-chat",
    "Video-meeting" : "Video-möte",
    "Call" : "Samtal",
    "Calling" : "Ringer",
    "Christmas" : "Jul",
    "Conference" : "Konferens",
    "Pizza" : "Pizza",
    "Travelling" : "Reser",
    "Trip" : "Resa",
    "Journey" : "Resa",
    "Collaborate" : "Samarbete",
    "Pair" : "Par",
    "Lecture" : "Föreläsning",
    "Seminar" : "Seminarium",
    "Teaching" : "Undervisa",
    "Photograph" : "Fotograf",
    "Party" : "Fest",
    "Celebration" : "Firande",
    "Celebrate" : "Fira",
    "Birthday" : "Födelsedag",
    "Shopping" : "Shopping",
    "Groceries" : "Mat",
    "Skate" : "Skate",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Vinprovning",
    "Golf" : "Golf",
    "Dinner" : "Middag",
    "Lunch" : "Lunch",
    "Appointment not found" : "Mötet hittades inte",
    "User not found" : "Användaren hittades inte"
},
"nplurals=2; plural=(n != 1);");
