OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Sessione utente scaduta in modo inatteso",
    "Provided email-address is not valid" : "L'indirizzo email fornito non è valido",
    "%s has published the calendar »%s«" : "%s ha pubblicato il calendario «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Errore inatteso nell'invio dell'email. Contatta l'amministratore.",
    "Successfully sent email to %1$s" : "Email inviata a %1$s correttamente",
    "Hello," : "Ciao,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Ti vogliamo informare che %s ha pubblicato il calendario «%s». ",
    "Open »%s«" : "Apri «%s»",
    "Cheers!" : "Evviva!",
    "Upcoming events" : "Prossimi eventi",
    "Appointments" : "Appuntamenti",
    "Schedule appointment \"%s\"" : "Fissa appuntamento \"%s\"",
    "Schedule an appointment" : "Fissa un appuntamento",
    "Prepare for %s" : "Prepara per %s",
    "Follow up for %s" : "Azione supplementare per %s",
    "Dear %s, please confirm your booking" : "Gentile %s, conferma la tua prenotazione",
    "Confirm" : "Conferma",
    "This confirmation link expires in %s hours." : "Il collegamento di conferma scade in %s ore.",
    "Date:" : "Data:",
    "Where:" : "Luogo:",
    "Calendar" : "Calendario",
    "A Calendar app for Nextcloud" : "Un'applicazione di calendario per Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "L'applicazione Calendario è un'interfaccia grafica per il server CalDAV di Nextcloud. Sincronizza facilmente gli eventi tra vari dispositivi con il tuo Nextcloud e modificali in linea.\n\n* 🚀 **Integrazione con le altre applicazioni di Nextcloud!** Attualmente Contatti - altre in arrivo.\n* 🌐 **Supporto WebCal!** Vuoi vedere le date delle partite della tua squadra preferita sul tuo calendario? Nessun problema!\n* 🙋 **Partecipanti!** Invita le persone ai tuoi eventi\n* ⌚️ **Libero/occupato:** Guarda quando i partecipanti sono disponibili per incontrarti\n* ⏰ **Promemoria!** Imposta avvisi per gli eventi nel tuo browser e via email.\n* 🔍 Ricerca! Trova facilmente i tuoi eventi\n* ☑️ Attività! Vedi le attività con una data di scadenza direttamente nel tuo calendario\n* 🙈 **Non stiamo reinventando la ruota!** Basato sulle ottime librerie [c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) e [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Giorno precedente",
    "Previous week" : "Settimana precedente",
    "Previous month" : "Mese precedente",
    "Next day" : "Giorno successivo",
    "Next week" : "Settimana successiva",
    "Next month" : "Mese successivo",
    "New event" : "Nuovo evento",
    "Today" : "Oggi",
    "Day" : "Giorno",
    "Week" : "Settimana",
    "Month" : "Mese",
    "List" : "Elenco",
    "Preview" : "Anteprima",
    "Copy link" : "Copia link",
    "Edit" : "Modifica",
    "Delete" : "Elimina",
    "Appointment link was copied to clipboard" : "Il collegamento dell'appuntamento è stato copiato negli appunti",
    "Appointment link could not be copied to clipboard" : "Impossibile copiare il collegamento dell'appuntamento negli appunti",
    "Add new" : "Aggiungi nuovo",
    "Untitled calendar" : "Calendario senza titolo",
    "Edit name" : "Modifica nome",
    "Saving name …" : "Salvataggio nome...",
    "Edit color" : "Modifica colore",
    "Saving color …" : "Salvataggio colore...",
    "Copy private link" : "Copia collegamento privato",
    "Export" : "Esporta",
    "Unshare from me" : "Rimuovi condivisione da me",
    "An error occurred, unable to change visibility of the calendar." : "Si è verificato un errore, impossibile cambiare la visibilità del calendario.",
    "An error occurred, unable to delete the calendar." : "Si è verificato un errore, impossibile eliminare il calendario.",
    "Calendar link copied to clipboard." : "Collegamento del calendario copiato negli appunti.",
    "Calendar link could not be copied to clipboard." : "Il collegamento del calendario non può essere copiato negli appunti.",
    "An error occurred, unable to rename the calendar." : "Si è verificato un errore, impossibile rinominare il calendario.",
    "An error occurred, unable to change the calendar's color." : "Si è verificato un errore, impossibile cambiare il colore del calendario.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Rimozione condivisione del calendario in {countdown} secondo","Rimozione condivisione del calendario in {countdown} secondi","Rimozione condivisione del calendario in {countdown} secondi"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminazione del calendario in {countdown} secondo","Eliminazione del calendario in {countdown} secondi","Eliminazione del calendario in {countdown} secondi"],
    "Share link" : "Condividi il collegamento",
    "Publish calendar" : "Pubblica calendario",
    "Publishing calendar" : "Pubblicazione calendario",
    "Copy public link" : "Copia collegamento pubblico",
    "Send link to calendar via email" : "Invia collegamento al calendario tramite email",
    "Enter one address" : "Digita un indirizzo",
    "Sending email …" : "Invio email...",
    "Copy subscription link" : "Copia collegamento di sottoscrizione",
    "Copying link …" : "Copia collegamento...",
    "Copied link" : "Collegamento copiato",
    "Could not copy link" : "Impossibile copiare il collegamento",
    "Copy embedding code" : "Copia codice di incorporazione",
    "Copying code …" : "Copia codice...",
    "Copied code" : "Codice copiato",
    "Could not copy code" : "Impossibile copiare il codice",
    "Delete share link" : "Elimina collegamento di condivisione",
    "Deleting share link …" : "Eliminazione collegamento di condivisione...",
    "An error occurred, unable to publish calendar." : "Si è verificato un errore, impossibile pubblicare il calendario.",
    "An error occurred, unable to send email." : "Si è verificato un errore, impossibile inviare il messaggio.",
    "Embed code copied to clipboard." : "Codice di incorporazione copiato negli appunti.",
    "Embed code could not be copied to clipboard." : "Impossibile copiare codice di incorporazione negli appunti.",
    "Unpublishing calendar failed" : "Rimozione calendario non riuscita",
    "Share with users or groups" : "Condividi con utenti o gruppi",
    "No users or groups" : "Nessun utente o gruppo",
    "can edit" : "può modificare",
    "Unshare with {displayName}" : "Rimuovi condivisione con {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Si è verificato un errore, impossibile cambiare la condivisione del calendario.",
    "An error occurred, unable to change the permission of the share." : "Si è verificato un errore, impossibile cambiare i permessi della condivisione.",
    "New calendar" : "Nuovo calendario",
    "Name for new calendar" : "Nome del nuovo calendario",
    "Creating calendar …" : "Creazione calendario...",
    "New calendar with task list" : "Nuovo calendario con elenco delle attività",
    "New subscription from link (read-only)" : "Nuova sottoscrizione da collegamento (sola lettura)",
    "Creating subscription …" : "Crea sottoscrizione...",
    "An error occurred, unable to create the calendar." : "Si è verificato un errore, impossibile creare il calendario.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Inserisci un collegamento valido (inizia con http://, https://, webcal://, o webcals://)",
    "Trash bin" : "Cestino",
    "Name" : "Nome",
    "Deleted" : "Eliminati",
    "Restore" : "Ripristina",
    "Delete permanently" : "Elimina definitivamente",
    "Empty trash bin" : "Svuota cestino",
    "Untitled item" : "Elemento senza titolo",
    "Unknown calendar" : "Calendario sconosciuto",
    "Could not load deleted calendars and objects" : "Impossibile caricare i calendari e gli oggetti eliminati",
    "Could not restore calendar or event" : "Impossibile ripristinare il calendario o l'evento",
    "Do you really want to empty the trash bin?" : "Vuoi davvero svuotare il cestino?",
    "Could not update calendar order." : "Impossibile aggiornare l'ordine del calendario.",
    "Import calendars" : "Importa calendari",
    "Please select a calendar to import into …" : "Seleziona un calendario in cui importare...",
    "Filename" : "Nome file",
    "Calendar to import into" : "Calendario in cui importare",
    "Cancel" : "Annulla",
    "_Import calendar_::_Import calendars_" : ["Importa calendario","Importa calendari","Importa calendari"],
    "{filename} could not be parsed" : "{filename} non può essere analizzato",
    "No valid files found, aborting import" : "Nessun file valido trovato, importazione interrotta",
    "Import partially failed. Imported {accepted} out of {total}." : "Importazione parzialmente non riuscita. Importati {accepted} di {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n evento importato con successo","%n evento importato con successo","%n evento importato con successo"],
    "Automatic" : "Automatico",
    "Automatic ({detected})" : "Automatico ({detected})",
    "New setting was not saved successfully." : "La nuova impostazione non è stata salvata correttamente.",
    "Shortcut overview" : "Riepilogo delle scorciatoie",
    "or" : "o",
    "Navigation" : "Navigazione",
    "Previous period" : "Periodo precedente",
    "Next period" : "Periodo successivo",
    "Views" : "Viste",
    "Day view" : "Vista del giorno",
    "Week view" : "Vista della settimana",
    "Month view" : "Vista del mese",
    "List view" : "Vista Elenco",
    "Actions" : "Azioni",
    "Create event" : "Crea evento",
    "Show shortcuts" : "Mostra scorciatoie",
    "Editor" : "Editor",
    "Enable birthday calendar" : "Attiva calendario dei compleanni",
    "Show tasks in calendar" : "Mostra le attività in calendario",
    "Enable simplified editor" : "Attiva editor semplificato",
    "Limit visible events per view" : "Limita gli eventi visibili per vista",
    "Show weekends" : "Mostra i fine settimana",
    "Show week numbers" : "Mostra i numeri delle settimane",
    "Time increments" : "Incrementi di tempo",
    "Default reminder" : "Promemoria predefinito",
    "Copy primary CalDAV address" : "Copia indirizzo CalDAV principale",
    "Copy iOS/macOS CalDAV address" : "Copia indirizzo CalDAV iOS/macOS",
    "Personal availability settings" : "Impostazioni di disponibilità personale",
    "Show keyboard shortcuts" : "Mostra scorciatoie da tastiera",
    "No reminder" : "Nessun promemoria",
    "CalDAV link copied to clipboard." : "Collegamento CalDAV copiato negli appunti.",
    "CalDAV link could not be copied to clipboard." : "Impossibile copiare collegamento CalDAV negli appunti.",
    "Appointment was created successfully" : "L'appuntamento è stato creato correttamente",
    "Appointment was updated successfully" : "L'appuntamento è stato aggiornato correttamente",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minuti","{duration} minuti"],
    "0 minutes" : "0 minuti",
    "_{duration} hour_::_{duration} hours_" : ["{duration} ora","{duration} ore","{duration} ore"],
    "_{duration} day_::_{duration} days_" : ["{duration} giorno","{duration} giorni","{duration} giorni"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} settimana","{duration} settimane","{duration} settimane"],
    "_{duration} month_::_{duration} months_" : ["{duration} mese","{duration} mesi","{duration} mesi"],
    "_{duration} year_::_{duration} years_" : ["{duration} anno","{duration} anni","{duration} anni"],
    "To configure appointments, add your email address in personal settings." : "Per configurare gli appuntamenti, aggiungi il tuo indirizzo email nelle impostazioni personali.",
    "Public – shown on the profile page" : "Pubblica – mostrata nella pagina del profilo",
    "Private – only accessible via secret link" : "Privata – accessibile solo da collegamento segreto",
    "Location" : "Luogo",
    "Description" : "Descrizione",
    "Visibility" : "Visibilità",
    "Duration" : "Durata",
    "Increments" : "Incrementi",
    "Additional calendars to check for conflicts" : "Calendari aggiuntivi per controllare conflitti",
    "Pick time ranges where appointments are allowed" : "Scegli gli intervalli di ore in cui sono permessi appuntamenti",
    "to" : "a",
    "Delete slot" : "Elimina slot",
    "No times set" : "Nessuna ora impostata",
    "Add" : "Aggiungi",
    "Monday" : "Lunedì",
    "Tuesday" : "Martedì",
    "Wednesday" : "Mercoledì",
    "Thursday" : "Giovedì",
    "Friday" : "Venerdì",
    "Saturday" : "Sabato",
    "Sunday" : "Domenica",
    "Add time before and after the event" : "Aggiungi tempo prima e dopo l'evento",
    "Before the event" : "Prima dell'evento",
    "After the event" : "Dopo l'evento",
    "Planning restrictions" : "Restrizioni sulla pianificazione",
    "Minimum time before next available slot" : "Tempo minimo prima del successivo slot disponibile",
    "Max slots per day" : "Slot massimi al giorno",
    "Limit how far in the future appointments can be booked" : "Limita fino a quando è possibile prenotare appuntamenti futuri",
    "Create appointment" : "Crea appuntamento",
    "Edit appointment" : "Modifica appuntamento",
    "Save" : "Salva",
    "Update" : "Aggiorna",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ti abbiamo inviato un'email con i dettagli. Conferma il tuo appuntamento usando il collegamento nell'email. Ora puoi chiudere questa pagina.",
    "Your name" : "Il tuo nome",
    "Your email address" : "Il tuo indirizzo email",
    "Please share anything that will help prepare for our meeting" : "Condividi tutto ciò che possa aiutarci a preparare il nostro incontro",
    "Could not book the appointment. Please try again later or contact the organizer." : "Impossibile prenotare l'appuntamento. Riprova più tardi o contatta l'organizzatore.",
    "Book the appointment" : "Prenota l'appuntamento",
    "Reminder" : "Promemoria",
    "before at" : "prima di",
    "Notification" : "Notifica",
    "Email" : "Email",
    "Audio notification" : "Notifica audio",
    "Other notification" : "Altra notifica",
    "Relative to event" : "Relativo all'evento",
    "On date" : "In data",
    "Edit time" : "Ora di modifica",
    "Save time" : "Ora di salvataggio",
    "Remove reminder" : "Rimuovi promemoria",
    "on" : "il",
    "at" : "alle",
    "+ Add reminder" : "+ Aggiungi promemoria",
    "Add reminder" : "Aggiungi promemoria",
    "_second_::_seconds_" : ["secondo","secondi","secondi"],
    "_minute_::_minutes_" : ["minuto","minuti","minuti"],
    "_hour_::_hours_" : ["ora","ore","ore"],
    "_day_::_days_" : ["giorno","giorni","giorni"],
    "_week_::_weeks_" : ["settimana","settimane","settimane"],
    "Invitation accepted" : "Invito accettato",
    "Available" : "Disponibile",
    "Suggested" : "Suggerito",
    "Participation marked as tentative" : "Partecipazione contrassegnata come provvisoria",
    "Accepted {organizerName}'s invitation" : "Invito di {organizerName} accettato",
    "Not available" : "Non disponibile",
    "Invitation declined" : "Invito rifiutato",
    "Declined {organizerName}'s invitation" : "Invito di {organizerName} rifiutato",
    "Invitation is delegated" : "Invito delegato",
    "Checking availability" : "Verifica disponibilità",
    "Invitation sent" : "Invito spedito",
    "Has not responded to {organizerName}'s invitation yet" : "Non ha ancora risposto all'invito di {organizerName}",
    "Availability of attendees, resources and rooms" : "Disponibilità di partecipanti, risorse e stanze",
    "{organizer} (organizer)" : "{organizer} (organizzatore)",
    "Free" : "Libero",
    "Busy (tentative)" : "Occupato (provvisorio)",
    "Busy" : "Occupato",
    "Out of office" : "Fuori sede",
    "Unknown" : "Sconosciuto",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "Tentative" : "Provvisorio",
    "The invitation has been accepted successfully." : "L'invito è stato accettato con successo.",
    "Failed to accept the invitation." : "Impossibile accettare l'invito.",
    "The invitation has been declined successfully." : "L'invito è stato rifiutato con successo.",
    "Failed to decline the invitation." : "Impossibile rifiutare l'invito.",
    "Your participation has been marked as tentative." : "La tua partecipazione è stata contrassegnata come \"provvisoria\".",
    "Failed to set the participation status to tentative." : "Impossibile impostare lo stato di partecipazione su \"provvisorio\".",
    "Create Talk room for this event" : "Crea stanza di Talk per questo evento",
    "Show busy times" : "Mostra orari in cui si è occupati",
    "No attendees yet" : "Ancora nessun partecipante",
    "Successfully appended link to talk room to description." : "Collegamento aggiunto correttamente alla stanza di Talk come descrizione.",
    "Error creating Talk room" : "Errore durante la creazione della stanza di Talk",
    "Send email" : "Invia email",
    "Chairperson" : "Presidente",
    "Required participant" : "Partecipante necessario",
    "Optional participant" : "Partecipante facoltativo",
    "Non-participant" : "Non partecipante",
    "Remove attendee" : "Rimuovi partecipante",
    "Search for emails, users or contacts" : "Cerca email, utenti o contatti",
    "No match found" : "Nessuna corrispondenza trovata",
    "(organizer)" : "(organizzatore)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Per inviare inviti e gestire risposte, [linkopen]aggiungi il tuo indirizzo email nelle impostazioni personali[linkclose].",
    "Remove color" : "Rimuovi colore",
    "Event title" : "Titolo dell'evento",
    "All day" : "Tutto il giorno",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Impossibile modificare le impostazioni di un giorno intero per gli eventi che sono parte di un insieme di ricorrenze.",
    "from {startDate}" : "da {startDate}",
    "from {startDate} at {startTime}" : "dal {startDate} alle {startTime}",
    "to {endDate}" : "a {endDate}",
    "to {endDate} at {endTime}" : "a {endDate} alle {endTime}",
    "Repeat" : "Ripeti",
    "End repeat" : "Termina ripetizione",
    "Select to end repeat" : "Seleziona per terminare la ripetizione",
    "never" : "mai",
    "on date" : "in data",
    "after" : "dopo",
    "_time_::_times_" : ["volta","volte","volte"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Questo evento è l'eccezione di un insieme di ricorrenze. Non puoi aggiungergli una regola di ricorrenza.",
    "first" : "primo",
    "third" : "terzo",
    "fourth" : "quarto",
    "fifth" : "quinto",
    "second to last" : "penultimo",
    "last" : "ultimo",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Le modifiche alla regola di ricorrenza saranno applicate a questa e a tutte le future occorrenze.",
    "Repeat every" : "Ripeti ogni",
    "By day of the month" : "Per giorno del mese",
    "On the" : "Il",
    "_month_::_months_" : ["mese","mesi","mesi"],
    "_year_::_years_" : ["anno","anni","anni"],
    "weekday" : "giorno feriale",
    "weekend day" : "giorno del fine settimana",
    "No recurrence" : "Nessuna ricorrenza",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definizione di ricorrenza di questo evento non è supportata completamente da Nextcloud. Se modifichi le opzioni di ricorrenza, alcune ricorrenze potrebbero essere perse.",
    "Suggestions" : "Consigli",
    "No rooms or resources yet" : "Ancora nessuna stanza o risorsa",
    "Add resource" : "Aggiungi risorsa",
    "Has a projector" : "Ha un proiettore",
    "Has a whiteboard" : "Ha una lavagna",
    "Wheelchair accessible" : "Accessibile alle carrozzine",
    "Remove resource" : "Rimuovi risorsa",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sedia","{seatingCapacity} sedie","{seatingCapacity} sedie"],
    "Projector" : "Proiettore",
    "Whiteboard" : "Lavagna",
    "Search for resources or rooms" : "Cerca risorse o stanze",
    "available" : "disponibile",
    "unavailable" : "non disponibile",
    "Room type" : "Tipo stanza",
    "Any" : "Qualsiasi",
    "Minimum seating capacity" : "Numero minimo di sedie",
    "More" : "Altro",
    "Update this occurrence" : "Aggiorna questa occorrenza",
    "Update this and all future" : "Aggiorna questa e tutte le future",
    "Public calendar does not exist" : "Il calendario pubblico non esiste",
    "Maybe the share was deleted or has expired?" : "Forse la condivisione è stata eliminata o è scaduta?",
    "Please select a time zone:" : "Seleziona un fuso orario:",
    "Pick a time" : "Scegli un orario",
    "Pick a date" : "Scegli una data",
    "from {formattedDate}" : "dal {formattedDate}",
    "to {formattedDate}" : "al {formattedDate}",
    "on {formattedDate}" : "il {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "dal {formattedDate} alle {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "al {formattedDate} alle {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "il {formattedDate} alle {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} alle {formattedTime}",
    "Please enter a valid date" : "Digita una data valida",
    "Please enter a valid date and time" : "Digita una data e un orario validi",
    "Type to search time zone" : "Digita per cercare il fuso orario",
    "Global" : "Globale",
    "Select date" : "Seleziona data",
    "Select slot" : "Seleziona slot",
    "No slots available" : "Nessuno slot disponibile",
    "The slot for your appointment has been confirmed" : "Lo slot per il tuo appuntamento è stato confermato",
    "Appointment Details:" : "Dettagli appuntamento:",
    "Time:" : "Ora:",
    "Booked for:" : "Prenotato per:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Grazie. La tua prenotazione dal {startDate} al {endDate} è stata confermata.",
    "Book another appointment:" : "Prenota un altro appuntamento:",
    "See all available slots" : "Mostra tutti gli slot disponibili",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Lo slot per il tuo appuntamento dal {startDate} al {endDate} non è più disponibile.",
    "Please book a different slot:" : "Prenota uno slot diverso:",
    "Book an appointment with {name}" : "Prenota un appuntamento con {name}",
    "No public appointments found for {name}" : "Nessun appuntamento pubblico trovato per {name}",
    "Personal" : "Personale",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Il rilevamento automatico del fuso orario ha determinato che il tuo è UTC.\nProbabilmente è il risultato di alcune misure di sicurezza del tuo browser web.\nImposta il tuo fuso orario a mano nelle impostazioni del calendario.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Il fuso orario configurato ({timezoneId}) non è stato trovato. Ripiego su UTC.\nCambia il tuo fuso orario nelle impostazioni e segnala questo problema.",
    "No more events today" : "Non ci sono altri eventi oggi",
    "No upcoming events" : "Nessun prossimo evento",
    "Create a new event" : "Crea un nuovo evento",
    "[Today]" : "[Oggi]",
    "[Tomorrow]" : "[Domani]",
    "[Yesterday]" : "[Ieri]",
    "[Last] dddd" : "[Ultimo] dddd",
    "Event does not exist" : "L'evento non esiste",
    "Delete this occurrence" : "Elimina questa occorrenza",
    "Delete this and all future" : "Elimina questa e tutte le future",
    "Details" : "Dettagli",
    "Attendees" : "Partecipanti",
    "Resources" : "Risorse",
    "Close" : "Chiudi",
    "Show more details" : "Mostra altri dettagli",
    "Subscribe to {name}" : "Sottoscrivi {name}",
    "Export {name}" : "Esporta {name}",
    "Anniversary" : "Anniversario",
    "Appointment" : "Appuntamento",
    "Business" : "Lavoro",
    "Education" : "Formazione",
    "Holiday" : "Vacanza",
    "Meeting" : "Riunione",
    "Miscellaneous" : "Varie",
    "Non-working hours" : "Ore non lavorative",
    "Not in office" : "Non in ufficio",
    "Phone call" : "Telefonata",
    "Sick day" : "Giorno di malattia",
    "Special occasion" : "Occasione speciale",
    "Travel" : "Viaggio",
    "Vacation" : "Assenza",
    "Midnight on the day the event starts" : "Mezzanotte del giorno in cui inizia l'evento",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n giorno prima dell'evento alle {formattedHourMinute}","%n giorni prima dell'evento alle {formattedHourMinute}","%n giorni prima dell'evento alle {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n settimana prima dell'evento alle {formattedHourMinute}","%n settimane prima dell'evento alle {formattedHourMinute}","%n settimane prima dell'evento alle {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "il giorno dell'evento alle {formattedHourMinute}",
    "at the event's start" : "all'inizio dell'evento",
    "at the event's end" : "alla fine dell'evento",
    "{time} before the event starts" : "{time} prima che l'evento inizi",
    "{time} before the event ends" : "{time} prima che l'evento finisca",
    "{time} after the event starts" : "{time} dopo l'inizio dell'evento",
    "{time} after the event ends" : "{time} dopo la fine dell'evento",
    "on {time}" : "il {time}",
    "on {time} ({timezoneId})" : "il {time} {timezoneId}",
    "Week {number} of {year}" : "Settimana {number} del {year}",
    "Does not repeat" : "Non ripete",
    "Daily" : "Quotidianamente",
    "Weekly" : "Settimanalmente",
    "Monthly" : "Mensilmente",
    "Yearly" : "Annualmente",
    "_Every %n day_::_Every %n days_" : ["Ogni %n giorno","Ogni %n giorni","Ogni %n giorni"],
    "_Every %n week_::_Every %n weeks_" : ["Ogni %n settimana","Ogni %n settimane","Ogni %n settimane"],
    "_Every %n month_::_Every %n months_" : ["Ogni %n mese","Ogni %n mesi","Ogni %n mesi"],
    "_Every %n year_::_Every %n years_" : ["Ogni %n anno","Ogni %n anni","Ogni %n anni"],
    "_on {weekday}_::_on {weekdays}_" : ["il {weekday}","i {weekdays}","i {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["il giorno {dayOfMonthList}","nei giorni {dayOfMonthList}","nei giorni {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "il {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "in {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "in {monthNames} il {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "fino al {untilDate}",
    "_%n time_::_%n times_" : ["%n volta","%n volte","%n volte"],
    "Untitled event" : "Evento senza titolo",
    "Untitled task" : "Attività senza titolo",
    "Please ask your administrator to enable the Tasks App." : "Chiedi al tuo amministratore di abilitare l'applicazione Attività.",
    "Prev" : "Prec.",
    "Next" : "Succ.",
    "Prev year" : "Anno prec.",
    "Next year" : "Anno succ.",
    "Year" : "Anno",
    "W" : "S",
    "%n more" : "%n altri",
    "No events to display" : "Nessun evento da visualizzare",
    "_+%n more_::_+%n more_" : ["+%n altro","+%n altri","+%n altri"],
    "No events" : "Nessun evento",
    "Create a new event or change the visible time-range" : "Crea un nuovo evento o cambia l'intervallo di tempo visibile",
    "It might have been deleted, or there was a typo in a link" : "Potrebbe essere stato eliminato o c'era un errore di digitazione in un collegamento",
    "It might have been deleted, or there was a typo in the link" : "Potrebbe essere stato eliminato o c'era un errore di digitazione nel collegamento",
    "Meeting room" : "Sala riunioni",
    "Lecture hall" : "Sala conferenze",
    "Seminar room" : "Sala seminari",
    "Other" : "Altro",
    "When shared show" : "Se condiviso, mostra",
    "When shared show full event" : "Se condiviso, mostra evento completo",
    "When shared show only busy" : "Se condiviso, mostra solo occupato",
    "When shared hide this event" : "Se condiviso, nascondi questo evento",
    "The visibility of this event in shared calendars." : "La visibilità di questo evento nei calendari condivisi.",
    "Add a location" : "Aggiungi un luogo",
    "Add a description" : "Aggiungi una descrizione",
    "Status" : "Stato",
    "Confirmed" : "Confermato",
    "Canceled" : "Annullato",
    "Confirmation about the overall status of the event." : "Conferma sullo stato complessivo dell'evento.",
    "Show as" : "Mostra come",
    "Take this event into account when calculating free-busy information." : "Considera questo evento nel calcolo delle informazioni libero-occupato.",
    "Categories" : "Categorie",
    "Categories help you to structure and organize your events." : "Le categorie ti aiutano a strutturare e organizzare i tuoi eventi.",
    "Search or add categories" : "Cerca o aggiungi categorie",
    "Add this as a new category" : "Aggiungi come una nuova categoria",
    "Custom color" : "Colore personalizzato",
    "Special color of this event. Overrides the calendar-color." : "Colore speciale di questo evento. Ignora il colore del calendario.",
    "Chat room for event" : "Stanza di chat per evento",
    "Imported {filename}" : "Importato {filename}",
    "Meditation" : "Meditazione",
    "Relaxing" : "Rilassamento",
    "Relax" : "Riposo",
    "Break" : "Pausa",
    "Commute" : "Fare il pendolare",
    "Commuting" : "Pendolare",
    "Shuttle" : "Navetta",
    "Invoice" : "Fattura",
    "Finance" : "Finanza",
    "Bank" : "Banca",
    "Money" : "Soldi",
    "Wedding" : "Matrimonio",
    "Dog" : "Cane",
    "Concert" : "Concerto",
    "Festival" : "Festival",
    "Theater" : "Teatro",
    "Theatre" : "Teatro",
    "Presentation" : "Presentazione",
    "Talk" : "Parlare",
    "Speech" : "Discorso",
    "Deadline" : "Scadenza",
    "Submission" : "Sottomissione",
    "Reporting" : "Segnalazione",
    "Camping" : "Campeggio",
    "Camp" : "Accamparsi",
    "Election" : "Elezione",
    "Voting" : "Votazione",
    "Vote" : "Votare",
    "Barbecue" : "Grigliata",
    "Barbeque" : "Grigliata",
    "Garden" : "Giardino",
    "Farm" : "Fattoria",
    "Movie" : "Film",
    "Cinema" : "Cinema",
    "Graduation" : "Laurea",
    "Brainstorm" : "Brainstorm",
    "Review" : "Recensione",
    "Audit" : "Controllo",
    "Inspection" : "Ispezione",
    "Proofreading" : "Correzione",
    "Baseball" : "Baseball",
    "Meet" : "Incontrare",
    "Planning" : "Pianificazione",
    "Pointing" : "Indicazione",
    "Retrospective" : "Retrospettiva",
    "Office" : "Ufficio",
    "Contributor week" : "Settimana del collaboratore",
    "Mail" : "Posta",
    "Soccer" : "Calcio",
    "Football" : "Football",
    "Gaming" : "Gioco",
    "Drive" : "Guidare",
    "Driving" : "Guidare",
    "Bicycle" : "Bicicletta",
    "Cycle" : "Pedalare",
    "Cycling" : "Andare in bicicletta",
    "Biking" : "Pedalata",
    "Bike" : "Bicicletta",
    "Podcast" : "Podcast",
    "Basketball" : "Pallacanestro",
    "Fishing" : "Pesca",
    "Hiking" : "Escursionismo",
    "Hike" : "Escursione",
    "Art" : "Arte",
    "Exhibition" : "Mostra",
    "Museum" : "Museo",
    "Pilates" : "Pilates",
    "Park" : "Parco",
    "Walk" : "Camminare",
    "Studying" : "Studiare",
    "Doctor" : "Medico",
    "Health" : "Salute",
    "Dentist" : "Dentista",
    "Hospital" : "Ospedale",
    "Interview" : "Intervista",
    "Training" : "Allenamento",
    "Practice" : "Esercitazione",
    "Sports" : "Sport",
    "Exercise" : "Esercizio",
    "Work out" : "Allenarsi",
    "Working out" : "Allenamento",
    "Gym" : "Palestra",
    "Barber" : "Barbiere",
    "Haircut" : "Taglio di capelli",
    "Hairdresser" : "Parrucchiere",
    "Exam" : "Esame",
    "Written test" : "Prova scritta",
    "Oral test" : "Prova orale",
    "Working" : "Lavorare",
    "New Years Eve" : "Capodanno",
    "NYE" : "Capodanno",
    "Fireworks" : "Fuochi d'artificio",
    "Running" : "Correre",
    "Go for a run" : "Andare a correre",
    "Marathon" : "Maratona",
    "Video-conference" : "Videoconferenza",
    "Conference-call" : "Conferenza",
    "Video-call" : "Chiamata video",
    "Video-chat" : "Chat video",
    "Video-meeting" : "Riunione video",
    "Call" : "Chiamare",
    "Calling" : "Chiamata",
    "Christmas" : "Natale",
    "Conference" : "Conferenza",
    "Pizza" : "Pizza",
    "Travelling" : "Viaggiare",
    "Trip" : "Viaggio",
    "Journey" : "Viaggio",
    "Collaborate" : "Collaborare",
    "Pair" : "Coppia",
    "Lecture" : "Lezione",
    "Seminar" : "Seminario",
    "Teaching" : "Insegnare",
    "Photograph" : "Fotografia",
    "Party" : "Festa",
    "Celebration" : "Celebrazione",
    "Celebrate" : "Celebrare",
    "Birthday" : "Compleanno",
    "Shopping" : "Acquisti",
    "Groceries" : "Drogheria",
    "Skate" : "Pattinare",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Degustazione di vini",
    "Golf" : "Golf",
    "Dinner" : "Cena",
    "Lunch" : "Pranzo",
    "Appointment not found" : "Appuntamento non trovato",
    "User not found" : "Utente non trovato"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
