/*! For license information please see calendar-node_modules_moment_locale_sk_js.js.LICENSE.txt */
(self.webpackChunkcalendar=self.webpackChunkcalendar||[]).push([["node_modules_moment_locale_sk_js"],{64249:function(e,s,n){!function(e){"use strict";var s="január_február_marec_apríl_máj_jún_júl_august_september_október_november_december".split("_"),n="jan_feb_mar_apr_máj_jún_júl_aug_sep_okt_nov_dec".split("_");function a(e){return e>1&&e<5}function r(e,s,n,r){var t=e+" ";switch(n){case"s":return s||r?"pár sekúnd":"pár sekundami";case"ss":return s||r?t+(a(e)?"sekundy":"sekúnd"):t+"sekundami";case"m":return s?"minúta":r?"minútu":"minútou";case"mm":return s||r?t+(a(e)?"minúty":"minút"):t+"minútami";case"h":return s?"hodina":r?"hodinu":"hodinou";case"hh":return s||r?t+(a(e)?"hodiny":"hodín"):t+"hodinami";case"d":return s||r?"deň":"dňom";case"dd":return s||r?t+(a(e)?"dni":"dní"):t+"dňami";case"M":return s||r?"mesiac":"mesiacom";case"MM":return s||r?t+(a(e)?"mesiace":"mesiacov"):t+"mesiacmi";case"y":return s||r?"rok":"rokom";case"yy":return s||r?t+(a(e)?"roky":"rokov"):t+"rokmi"}}e.defineLocale("sk",{months:s,monthsShort:n,weekdays:"nedeľa_pondelok_utorok_streda_štvrtok_piatok_sobota".split("_"),weekdaysShort:"ne_po_ut_st_št_pi_so".split("_"),weekdaysMin:"ne_po_ut_st_št_pi_so".split("_"),longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY H:mm",LLLL:"dddd D. MMMM YYYY H:mm"},calendar:{sameDay:"[dnes o] LT",nextDay:"[zajtra o] LT",nextWeek:function(){switch(this.day()){case 0:return"[v nedeľu o] LT";case 1:case 2:return"[v] dddd [o] LT";case 3:return"[v stredu o] LT";case 4:return"[vo štvrtok o] LT";case 5:return"[v piatok o] LT";case 6:return"[v sobotu o] LT"}},lastDay:"[včera o] LT",lastWeek:function(){switch(this.day()){case 0:return"[minulú nedeľu o] LT";case 1:case 2:case 4:case 5:return"[minulý] dddd [o] LT";case 3:return"[minulú stredu o] LT";case 6:return"[minulú sobotu o] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"pred %s",s:r,ss:r,m:r,mm:r,h:r,hh:r,d:r,dd:r,M:r,MM:r,y:r,yy:r},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(n(30381))}}]);
//# sourceMappingURL=calendar-node_modules_moment_locale_sk_js.js.map?v=ee0c4dbe5fe87f007a63