OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "A sesión de usuario caducou inesperadamente",
    "Provided email-address is not valid" : "O enderezo de correo-e indicado non é válido",
    "%s has published the calendar »%s«" : "%s publicou o calendario «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Produciuse un erro inesperado ao enviar correo. Póñase en contacto co seu administrador.",
    "Hello," : "Ola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte de que %s publicou o calendario «%s»",
    "Open »%s«" : "Abrir «%s»",
    "Cheers!" : "Saúdos!",
    "Upcoming events" : "Próximos eventos",
    "Appointments" : "Cita",
    "Confirm" : "Confirmar",
    "Date:" : "Data:",
    "Where:" : "Onde:",
    "Calendar" : "Calendario",
    "A Calendar app for Nextcloud" : "Unha aplicación de calendario para o Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "A aplicación de Calendario é unha interface de usuario para o servidor CalDAV do Nextcloud. Sincronice doadamente eventos en varios dispositivos co seu Nextcloud e edíteos en líña.\n\n* 🚀 **Integración con outras aplicación do Nextcloud!** Actualmente Contactos – outras por chegar.\n* 🌐 **Compatibilidade con WebCal!** Quere ver os partidos do seu equipo favorito no seu calendario? Non hai problema!\n* 🙋 **Asistentes** Convide á xente aos seus eventos.\n* ⌚️ **Libre/Ocupado:** Verá cando os asistentes están dispoñíbeis\n* ⏰ **Lembretes!** Obteña alarmas para eventos no navegador e por correo-e.\n* 🔍 Busca! Atopa os teus eventos ao teu gusto\n* ☑️ Tarefas! Vexa as tarefas con data de vencemento directamente no calendario\n* 🙈 **Non reinventamos a roda!** Baseada nas grandes bibliotecas [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) e [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Día anterior",
    "Previous week" : "Semana anterior",
    "Previous month" : "Mes anterior",
    "Next day" : "Día seguinte",
    "Next week" : "Semana seguinte",
    "Next month" : "Mes seguinte",
    "New event" : "Novo evento",
    "Today" : "Hoxe",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Preview" : "Vista previa",
    "Copy link" : "Copiar a ligazón",
    "Edit" : "Editar",
    "Delete" : "Eliminar",
    "Add new" : "Engadir novo",
    "Untitled calendar" : "Calendario sen título",
    "Edit name" : "Editar o nome",
    "Saving name …" : "Gardando o nome …",
    "Edit color" : "Editar a cor",
    "Saving color …" : "Gardando a cor …",
    "Copy private link" : "Copiar a ligazón privada",
    "Export" : "Exportar",
    "Unshare from me" : "Deixar de compartir",
    "An error occurred, unable to change visibility of the calendar." : "Produciuse un erro, non é posíbel cambiar a visibilidade do calendario.",
    "An error occurred, unable to delete the calendar." : "Produciuse un erro, non é posíbel eliminar o calendario.",
    "Calendar link copied to clipboard." : "A ligazón do calendario foi copiada no portapapeis.",
    "Calendar link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón do calendario no portapapeis.",
    "An error occurred, unable to rename the calendar." : "Produciuse un erro, non é posíbel renomear o calendario.",
    "An error occurred, unable to change the calendar's color." : "Produciuse un erro, non é posíbel cambiar a cor do calendario.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixar de compartir o calendario en {countdown} segundo","Deixar de compartir o calendario en {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminar o calendario en {countdown} segundo","Eliminar o calendario en {countdown} segundos"],
    "Share link" : "Compartir ligazón",
    "Publish calendar" : "Publicar o calendario",
    "Publishing calendar" : "Publicando o calendario",
    "Copy public link" : "Copiar a ligazón pública",
    "Send link to calendar via email" : "Enviar a ligazón ao calendario por correo",
    "Enter one address" : "Introduza un enderezo",
    "Sending email …" : "Enviando correo …",
    "Copy subscription link" : "Copiar a ligazón de subscrición",
    "Copying link …" : "Copiando a ligazón …",
    "Copied link" : "Ligazón copiada",
    "Could not copy link" : "Non foi posíbel copiar a ligazón",
    "Copy embedding code" : "Copia o código incrustado",
    "Copying code …" : "Copiando o código …",
    "Copied code" : "Código copiado",
    "Could not copy code" : "Non foi posíbel copiar o código",
    "Delete share link" : "Eliminar a ligazón compartida",
    "Deleting share link …" : "Eliminando a ligazón compartida …",
    "An error occurred, unable to publish calendar." : "Produciuse un erro, non é posíbel publicar o calendario.",
    "An error occurred, unable to send email." : "Produciuse un erro, non é posíbel enviar o correo",
    "Embed code copied to clipboard." : "Código incrustado copiado ao portapapeis.",
    "Embed code could not be copied to clipboard." : "Non foi posíbel copiar o código incrustado no portapapeis.",
    "Unpublishing calendar failed" : "Produciuse un fallo ao deixar de publicar o calendario",
    "Share with users or groups" : "Compartir con usuarios ou grupos",
    "No users or groups" : "Non hai usuarios nin grupos",
    "can edit" : "pode editar",
    "Unshare with {displayName}" : "Deixar de compartir con {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Produciuse un erro, non é posíbel cambiar a non compartición do calendario.",
    "An error occurred, unable to change the permission of the share." : "Produciuse un erro, non é posíbel cambiar o permiso da compartición.",
    "New calendar" : "Novo calendario",
    "Creating calendar …" : "Creando o calendario …",
    "New calendar with task list" : "Novo calendario con lista de tarefas",
    "New subscription from link (read-only)" : "Nova subscrición dende ligazón (só lectura)",
    "Creating subscription …" : "Creando subscrición …",
    "An error occurred, unable to create the calendar." : "Produciuse un erro, non é posíbel crear o calendario.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Introduza unha ligazón correcta (comezando con http://, https://, webcal://, or webcals://)",
    "Name" : "Nome",
    "Deleted" : "Eliminada",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar de xeito permanente",
    "Could not update calendar order." : "Non foi posíbel actualizar a orde do calendario.",
    "Import calendars" : "Importar calendarios",
    "Please select a calendar to import into …" : "Seleccione un calendario para importalo a …",
    "Filename" : "Nome de ficheiro",
    "Calendar to import into" : "Calendario ao que importar",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendario","Importar calendarios"],
    "{filename} could not be parsed" : "Non foi posíbel analizar {filename}",
    "No valid files found, aborting import" : "Non se atoparon ficheiros válidos, cancelando a importación.",
    "Import partially failed. Imported {accepted} out of {total}." : "Fallou parcialmente a importación. Importáronse {accepted} de {total}.",
    "Automatic" : "Automatico",
    "Automatic ({detected})" : "Automático ({detected})",
    "New setting was not saved successfully." : "O novo axuste non foi fardado correctamente.",
    "Shortcut overview" : "Vista xeral dos atallos",
    "or" : "ou",
    "Navigation" : "Navegación",
    "Previous period" : "Período anterior",
    "Next period" : "Período seguinte",
    "Views" : "Vistas",
    "Day view" : "Vista do día",
    "Week view" : "Vista da semana",
    "Month view" : "Vista do mes",
    "List view" : "Ver como lista",
    "Actions" : "Accións",
    "Create event" : "Crear evento",
    "Show shortcuts" : "Amosar atallos",
    "Editor" : "Editor",
    "Enable birthday calendar" : "Activar o calendario de aniversarios",
    "Show tasks in calendar" : "Amosar as tarefas no calendario",
    "Enable simplified editor" : "Activar o editor simplificado",
    "Limit visible events per view" : "Limitar os eventos visíbeis por vista",
    "Show weekends" : "Amosar os fins de semana",
    "Show week numbers" : "Amosar o número de semana",
    "Copy primary CalDAV address" : "Copiar o enderezo principal do CalDAV",
    "Copy iOS/macOS CalDAV address" : "Copiar o enderezo CalDAV de iOS/macOS",
    "Show keyboard shortcuts" : "Amosar os atallos de teclado",
    "No reminder" : "Non hai lembretes",
    "CalDAV link copied to clipboard." : "Copiada a ligazón CalDAV ao portapapeis.",
    "CalDAV link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón CalDAV ao portapapeis.",
    "Location" : "Localización",
    "Description" : "Descrición",
    "Duration" : "Duración",
    "to" : "para",
    "Add" : "Engadir",
    "Monday" : "luns",
    "Tuesday" : "martes",
    "Wednesday" : "mércores",
    "Thursday" : "xoves",
    "Friday" : "venres",
    "Saturday" : "sábado",
    "Sunday" : "domingo",
    "Save" : "Gardar",
    "Update" : "Actualizar",
    "Your email address" : "O seu enderezo de correo",
    "before at" : "antes dás",
    "Notification" : "Notificación",
    "Email" : "Correo-e",
    "Audio notification" : "Notificación de son",
    "Other notification" : "Outra notificación",
    "Relative to event" : "Relativo ao evento",
    "On date" : "Na data",
    "Edit time" : "Editar a hora",
    "Save time" : "Gardar a hora",
    "Remove reminder" : "Retirar o lembrete",
    "on" : "o",
    "at" : "ás",
    "+ Add reminder" : "+ Engadir lembrete",
    "Add reminder" : "Engadir recordatorio",
    "_second_::_seconds_" : ["segundo","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos"],
    "_hour_::_hours_" : ["hora","horas"],
    "_day_::_days_" : ["día","días"],
    "_week_::_weeks_" : ["semana","semanas"],
    "Available" : "Dispoñíbel",
    "Not available" : "Non dispoñíbel",
    "Availability of attendees, resources and rooms" : "Dispoñibilidade de asistentes, recursos e salas",
    "Free" : "Libre",
    "Busy (tentative)" : "Ocupado (tentativa)",
    "Busy" : "Ocupado",
    "Out of office" : "Fóra da oficina",
    "Unknown" : "Descoñecido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativa",
    "Create Talk room for this event" : "Crear sala de conversas para este evento",
    "Show busy times" : "Amosar as horas ocupadas",
    "No attendees yet" : "Aínda non hai participantes",
    "Successfully appended link to talk room to description." : "Engadiuse satisfactoriamente unha ligazón á descrición da  sala de conversas.",
    "Error creating Talk room" : "Produciuse un erro ao crear a sala de conversas",
    "Send email" : "Enviar o correo",
    "Chairperson" : "Presidente",
    "Required participant" : "Participante obrigatorio",
    "Optional participant" : "Participante opcional",
    "Non-participant" : "Non participantes",
    "Remove attendee" : "Eliminar o asistente",
    "No match found" : "Non se atopou ningunha coincidencia",
    "(organizer)" : "(organizador)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar convites e xestionar respostas, [linkopen]engada o seu enderezo de correo electrónico na configuración persoal[linkclose].",
    "Remove color" : "Retirar a cor",
    "Event title" : "Título do evento",
    "All day" : "Todo o día",
    "from {startDate}" : "dende {startDate}",
    "from {startDate} at {startTime}" : "dende {startDate} ás {startTime}",
    "to {endDate}" : "ata {endDate}",
    "to {endDate} at {endTime}" : "ata {endDate} ás {endTime}",
    "Repeat" : "Repetir",
    "End repeat" : "Fin da repetición",
    "Select to end repeat" : "Seleccionar para finalizar a repetición",
    "never" : "nunca",
    "on date" : "na data",
    "after" : "após",
    "_time_::_times_" : ["vez","veces"],
    "first" : "primeiro",
    "third" : "terceiro",
    "fourth" : "cuarto",
    "fifth" : "quinto",
    "second to last" : "penúltimo",
    "last" : "último",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Os cambios na regra de recorrencia só se aplicarán a esta e a todas as futuras recorrencias.",
    "Repeat every" : "Repetir cada",
    "By day of the month" : "Por día do mes",
    "On the" : "Durante o",
    "_month_::_months_" : ["mes","meses"],
    "_year_::_years_" : ["ano","anos"],
    "weekday" : "día da semana",
    "weekend day" : "día da fin de semana",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud non é totalmente compatíbel coa definición de recorrencia deste evento. Se edita as opcións de recorrencia, pódense perder certas recorrencias.",
    "Add resource" : "Engadir recurso",
    "Has a projector" : "Ten un proxector",
    "Has a whiteboard" : "Ten un encerado dixital",
    "Wheelchair accessible" : "Accesíbel para cadeiras de rodas",
    "Remove resource" : "Retirar recurso",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asento","{seatingCapacity} asentos"],
    "Projector" : "Proxector",
    "Whiteboard" : "Encerado dixital",
    "Search for resources or rooms" : "Buscar por recursos ou aulas",
    "available" : "dispoñíbel",
    "More" : "Máis",
    "Update this occurrence" : "Actualizar esta recorrencia",
    "Update this and all future" : "Actualizar esta e todas as futuras",
    "Public calendar does not exist" : "O calendario público non existe",
    "Maybe the share was deleted or has expired?" : "Quizais a acción foi eliminada ou caducou.",
    "Pick a time" : "Escolla un momento",
    "Pick a date" : "Escolla unha data",
    "from {formattedDate}" : "dende {formattedDate}",
    "to {formattedDate}" : "ata {formattedDate}",
    "on {formattedDate}" : "o {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "dende {formattedDate} ás {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "ata {formattedDate} ás {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "o {formattedDate} ás {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} ás {formattedTime}",
    "Please enter a valid date" : "Introduza unha data válida",
    "Please enter a valid date and time" : "Introduza unha data e hora válidas",
    "Global" : "Global",
    "Time:" : "Hora:",
    "Personal" : "Persoal",
    "No more events today" : "Hoxe non hai máis eventos",
    "No upcoming events" : "Non hai eventos próximos",
    "Create a new event" : "Crear un novo evento",
    "[Today]" : "[Hoxe]",
    "[Tomorrow]" : "[Mañá]",
    "[Yesterday]" : "[Onte]",
    "[Last] dddd" : "[Último] dddd",
    "Event does not exist" : "O evento non existe",
    "Delete this occurrence" : "Eliminar esta recorrencia",
    "Delete this and all future" : "Eliminar esta e todas as futuras",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Resources" : "Recursos",
    "Close" : "Pechar",
    "Show more details" : "Amosar máis detalles",
    "Subscribe to {name}" : "Subscribirse a {name}",
    "Anniversary" : "Aniversario",
    "Appointment" : "Cita",
    "Business" : "Negocios",
    "Education" : "Educación",
    "Holiday" : "Festivo",
    "Meeting" : "Xuntanza",
    "Miscellaneous" : "Miscelánea",
    "Non-working hours" : "Horas non laborábeis",
    "Not in office" : "Fóra da oficina",
    "Phone call" : "Chamada telefónica",
    "Sick day" : "Día de enfermidade",
    "Special occasion" : "Ocasión especial",
    "Travel" : "Viaxe",
    "Vacation" : "Vacacións",
    "Midnight on the day the event starts" : "Media noite do día que comeza o evento",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n día antes do evento ás {formattedHourMinute}","%n días antes do evento ás {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semana antes do evento ás {formattedHourMinute}","%n semanas antes do evento ás {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "o día do evento ás {formattedHourMinute}",
    "at the event's start" : "no inicio do evento",
    "at the event's end" : "no remate do evento",
    "{time} before the event starts" : "{time} antes do inicio do evento",
    "{time} before the event ends" : "{time} antes do remate do evento",
    "{time} after the event starts" : "{time} após o inicio do evento",
    "{time} after the event ends" : "{time} após que remate o evento",
    "on {time}" : "ás {time}",
    "on {time} ({timezoneId})" : "ás {time} ({timezoneId})",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Does not repeat" : "Non repetir",
    "Daily" : "Cada día",
    "Weekly" : "Cada semana",
    "Monthly" : "Cada mes",
    "Yearly" : "Cada ano",
    "_Every %n day_::_Every %n days_" : ["Cada día","Cada %n días"],
    "_Every %n week_::_Every %n weeks_" : ["Cada semana","Cada %n semanas"],
    "_Every %n month_::_Every %n months_" : ["Cada mes","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada ano","Cada %n anos"],
    "_on {weekday}_::_on {weekdays}_" : ["o {weekday}","os {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["o día {dayOfMonthList}","os días {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "o {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "en {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "en {monthNames} no {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "ata {untilDate}",
    "_%n time_::_%n times_" : ["%n vez","%n veces"],
    "Untitled event" : "Evento sen título",
    "Untitled task" : "Tarefa sen título",
    "Please ask your administrator to enable the Tasks App." : "Pregúntelle ao seu administrador pola activación da aplicación de tarefas.",
    "Prev" : "Previo",
    "Next" : "Seguinte",
    "Year" : "Ano",
    "W" : "S",
    "%n more" : "%n máis",
    "No events to display" : "Non hai eventos para amosar",
    "_+%n more_::_+%n more_" : ["+%n máis","+%n máis"],
    "No events" : "Non hai eventos",
    "Create a new event or change the visible time-range" : "Crear un novo evento ou cambiar o intervalo de tempo visíbel",
    "It might have been deleted, or there was a typo in a link" : "Pode que fose eliminado ou houbese un erro de dixitación nunha ligazón",
    "It might have been deleted, or there was a typo in the link" : "Pode que fose eliminado ou houbese un erro de dixitación na ligazón",
    "Other" : "Outro",
    "When shared show" : "Amosar ao compartir",
    "When shared show full event" : "Amosar o evento completo ao compartir",
    "When shared show only busy" : "Amosar só o ocupado ao compartir",
    "When shared hide this event" : "Agochar este evento ao compartir",
    "The visibility of this event in shared calendars." : "A visibilidade deste evento nos calendarios compartidos.",
    "Add a location" : "Engadir unha localización",
    "Add a description" : "Engadir unha descrición",
    "Status" : "Estado",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelada",
    "Confirmation about the overall status of the event." : "Confirmación sobre o estado xeral do evento.",
    "Show as" : "Amosar como",
    "Take this event into account when calculating free-busy information." : "Teña en conta este evento ao calcular a información da ocupación.",
    "Categories" : "Categorías",
    "Categories help you to structure and organize your events." : "As categorías axudan a estruturar e organizar os seus eventos.",
    "Search or add categories" : "Buscar ou engadir categorías",
    "Add this as a new category" : "Engadir isto como unha nova categoría",
    "Custom color" : "Cor personalizada",
    "Special color of this event. Overrides the calendar-color." : "Cor especial deste evento. Anula a cor do calendario.",
    "Chat room for event" : "Sala de conversas para o evento",
    "Imported {filename}" : "{filename} foi importado",
    "Meditation" : "Meditación",
    "Relaxing" : "Relaxante",
    "Relax" : "Relaxamento",
    "Commuting" : "De casa ao traballo ou ao revés",
    "Invoice" : "Factura",
    "Presentation" : "Presentación",
    "Talk" : "Talk",
    "Camping" : "Campismo",
    "Camp" : "Campo",
    "Movie" : "Filme",
    "Cinema" : "Cinema",
    "Graduation" : "Graduación",
    "Brainstorm" : "Tormenta de ideas",
    "Review" : "Revisar",
    "Baseball" : "Béisbol",
    "Meet" : "Xuntanza",
    "Planning" : "Planificación",
    "Pointing" : "Sinalar",
    "Retrospective" : "Retrospectiva",
    "Office" : "Oficina",
    "Contributor week" : "Semana de colaboradores",
    "Mail" : "Correo",
    "Soccer" : "Futbol",
    "Football" : "Rugby",
    "Gaming" : "Xogos",
    "Drive" : "Conducir",
    "Bicycle" : "Bicicleta",
    "Cycle" : "Bici",
    "Biking" : "Ciclismo",
    "Bike" : "Bicicleta",
    "Podcast" : "Podcast",
    "Basketball" : "Baloncesto",
    "Fishing" : "Pesca",
    "Hiking" : "Excursionismo",
    "Hike" : "Camiñada",
    "Art" : "Arte",
    "Exhibition" : "Exhibición",
    "Museum" : "Museo",
    "Pilates" : "Pilates",
    "Park" : "Parque",
    "Studying" : "Estudando",
    "Doctor" : "Médico",
    "Health" : "Saúde",
    "Dentist" : "Dentista",
    "Hospital" : "Hospital",
    "Interview" : "Entrevista",
    "Training" : "Adestramento",
    "Practice" : "Práctica",
    "Sports" : "Deportes",
    "Exercise" : "Exercicio",
    "Work out" : " Rutina de exercicio",
    "Working out" : "Facendo exercicio",
    "Gym" : "Ximnasio",
    "Barber" : "Perruqueiro",
    "Haircut" : "Corte de pelo",
    "Exam" : "Exame",
    "Working" : "Traballando",
    "New Years Eve" : "Serán de fin de ano",
    "NYE" : "Noitevella",
    "Fireworks" : "Fogos artificiais",
    "Running" : "Correndo",
    "Go for a run" : "Ir correr",
    "Marathon" : "Maratón",
    "Video-conference" : "Vídeoconferencia",
    "Conference-call" : "Chamada de conferencia",
    "Video-call" : "Vídeochamada",
    "Video-chat" : "Vídeoconversa",
    "Video-meeting" : "Vídeoxuntanza",
    "Call" : "Chamada",
    "Calling" : "Chamando",
    "Christmas" : "Nadal",
    "Conference" : "Conferencia",
    "Pizza" : "Pizza",
    "Travelling" : "Viaxando",
    "Journey" : "Traxecto",
    "Collaborate" : "Colaborar",
    "Pair" : "Parella",
    "Lecture" : "Lectura",
    "Seminar" : "Seminario",
    "Photograph" : "Fotografo",
    "Party" : "Festa",
    "Celebration" : "Celebración",
    "Celebrate" : "Celebrar",
    "Birthday" : "Aniversario (nacemento)",
    "Shopping" : "Compras",
    "Skate" : "Patinar",
    "Skateboard" : "Monopatín",
    "Wine tasting" : "Cata de viños",
    "Golf" : "Golf",
    "Dinner" : "Cea",
    "Lunch" : "Xantar",
    "User not found" : "Non se atopou o usuario"
},
"nplurals=2; plural=(n != 1);");
