OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Термін дії сесії користувача несподівано завершився",
    "Provided email-address is not valid" : "Надано некоректну адресу електронної пошти ",
    "%s has published the calendar »%s«" : "%s опублікував календар »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Виникла несподівана помилка під час надсилання електронного повідомлення. Будь ласка повідомте адміністратора.",
    "Successfully sent email to %1$s" : "Успішно надіслано лист на адресу %1$s",
    "Hello," : "Вітаємо,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Дозвольте повідомити вас, що%s опублікував календар \"%s\".",
    "Open »%s«" : "Відкрити \"%s\"",
    "Cheers!" : "Щасти!",
    "Upcoming events" : "Майбутні події",
    "Appointments" : "Зустрічі",
    "Schedule appointment \"%s\"" : "Запланувати зустріч \"%s\"",
    "Schedule an appointment" : "Запланувати зустріч",
    "Prepare for %s" : "Підготуватися до %s",
    "Follow up for %s" : "Слідкувати за %s",
    "Dear %s, please confirm your booking" : "Шановний(а) %s, будь ласка, підтвердіть ваше резервування",
    "Confirm" : "Підтвердити",
    "This confirmation link expires in %s hours." : "Термін дії посилання для підтвердженння спливає за %sгодин.",
    "Date:" : "Дата:",
    "Where:" : "Місце:",
    "Calendar" : "Календар",
    "A Calendar app for Nextcloud" : "Застосунок \"Календар\" для Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Застосунок \"Календар\" надає зручний доступ до календарних даних у хмарному сервері Nextcloud за допомогою протоколу CalDAV. З легкістю редагуйте та синхронізуйте події між вашими пристроями та Nextcloud в онлайні.\n\n* 🚀 **Інтеграція з іншими застосунками Nextcloud!**: на разі - це \"Контакти\", невдовзі додаватимуться інші застосунки.\n* 🌐 **Надає підтримку за протоколом WebCal!** Бажаєте бачити у своєму календарі дати матчів вашої улюбленої команди? Без проблем!\n* 🙋 **Учасники!** Запросіть інших людей до участі у вашіх подіях\n* ⌚️ **Доступність учасників** Побачте коли ваші друзі чи колеги доступні для запрошення на зустріч, яку ви плануєте організувати.\n* ⏰ **Нагадування!** Отримуйте сповіщення та нагадування про подію у вашому браузері та за допомогою електронної пошти.\n* 🔍 Пошук! Знаходьте легко події.\n* ☑️ Завдання! Переглядайте завдання, які мають терміни виконання, безпосередньо в календарі\n* 🙈 **Ми не винаходимо наново колесо!** Сервіс створено на відомій бібліотеці [c-dav](https://github.com/nextcloud/cdav-library), а також бібліотеках [ical.js](https://github.com/mozilla-comm/ical.js) і [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Вчора",
    "Previous week" : "Попередній тиждень",
    "Previous month" : "Попередній місяць",
    "Next day" : "Завтра",
    "Next week" : "Наступний тиждень",
    "Next month" : "Наступний місяць",
    "New event" : "Нова подія",
    "Today" : "Сьогодні",
    "Day" : "День",
    "Week" : "Тиждень",
    "Month" : "Місяць",
    "List" : "Список",
    "Preview" : "Перегляд",
    "Copy link" : "Скопіювати посилання",
    "Edit" : "Редагувати",
    "Delete" : "Вилучити",
    "Appointment link was copied to clipboard" : "Посилання на зустріч скопійовано до буферу обміну",
    "Appointment link could not be copied to clipboard" : "Неможливо скопіювати посилання до буферу обміну",
    "Add new" : "Додати новий",
    "Untitled calendar" : "Календар без назви",
    "Edit name" : "Редагувати назву",
    "Saving name …" : "Збереження назви...",
    "Edit color" : "Редагувати колір",
    "Saving color …" : "Збереження кольору...",
    "Copy private link" : "Копіювати приватне посилання",
    "Export" : "Експорт",
    "Unshare from me" : "Вилучити доступ для мене",
    "Disable calendar \"{calendar}\"" : "Вимкнути календар \"{calendar}\"",
    "Disable untitled calendar" : "Вимкнути календар без назви",
    "Enable calendar \"{calendar}\"" : "Увімкнути календар \"{calendar}\"",
    "Enable untitled calendar" : "Увімкнути календар без назви",
    "An error occurred, unable to change visibility of the calendar." : "Помилка: неможливо змінити відображення календаря.",
    "An error occurred, unable to delete the calendar." : "Помилка: неможливо вилучити календар.",
    "Calendar link copied to clipboard." : "Посилання на календар скопійовано.",
    "Calendar link could not be copied to clipboard." : "Неможливо копіювати посилання на календар.",
    "An error occurred, unable to rename the calendar." : "Помилка: неможливо перейменувати календар.",
    "An error occurred, unable to change the calendar's color." : "Помилка: неможливо змінити колір календаря.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Поширення календаря буде відмінено через {countdown} секунду","Поширення календаря буде відмінено через {countdown} секунд","Поширення календаря буде відмінено через {countdown} секунд","Календар буде від'єднано за {countdown} секунд"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календар буде видалено через {countdown} секунду","Календар буде видалено через {countdown} секунд","Календар буде видалено через {countdown} секунд","Календар буде вилучено через {countdown} секунд"],
    "Share link" : "Посилання спільного доступу",
    "Publish calendar" : "Опублікувати календар",
    "Publishing calendar" : "Публікую календар",
    "Copy public link" : "Копіювати публічне посилання",
    "Send link to calendar via email" : "Відправити посилання на календар за допомогою електронної пошти",
    "Enter one address" : "Зазначте одну адресу",
    "Sending email …" : "Надсилаю повідомлення...",
    "Copy subscription link" : "Копіювати посилання на підписку",
    "Copying link …" : "Копіюю посилання...",
    "Copied link" : "Скопійоване посилання",
    "Could not copy link" : "Не вдалося cкопіювати посилання",
    "Copy embedding code" : "Копіювати код вбудування",
    "Copying code …" : "Копіюю код...",
    "Copied code" : "Скопійований код",
    "Could not copy code" : "Не вдалося скопіювати код",
    "Delete share link" : "Вилучити посилання спільного доступу",
    "Deleting share link …" : "Вилучення посилання спільного доступу...",
    "An error occurred, unable to publish calendar." : "Помилка: неможливо опублікувати календар.",
    "An error occurred, unable to send email." : "Помилка: неможливо надіслати повідомлення.",
    "Embed code copied to clipboard." : "Код вбудування cкопійовано.",
    "Embed code could not be copied to clipboard." : "Неможливо скопіювати код вбудування.",
    "Unpublishing calendar failed" : "Не вдалося скасувати публікацію календаря",
    "Share with users or groups" : "Поділитися з користувачем або групою",
    "No users or groups" : "Відсутні користувачі або групи",
    "can edit" : "може редагувати",
    "Unshare with {displayName}" : "Забрати спільний доступ з {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Помилка: неможливо змінити скасування доступу до календаря.",
    "An error occurred, unable to change the permission of the share." : "Помилка: неможливо змінити права доступу до спільного ресурсу.",
    "New calendar" : "Новий календар",
    "Name for new calendar" : "Назва нового календаря",
    "Creating calendar …" : "Створення календаря...",
    "New calendar with task list" : "Новий календар зі списком завдань",
    "New subscription from link (read-only)" : "Нова підписка з посилання (лише для читання)",
    "Creating subscription …" : "Створення підписки...",
    "An error occurred, unable to create the calendar." : "Помилка: неможливо створити календар.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Будь ласка, зазначте правильне посилання (має починатися з http://, https://, webcal:// або webcals://)",
    "Trash bin" : "Кошик",
    "Loading deleted items." : "Завантажую вилучені елементи.",
    "You do not have any deleted items." : "У вас відсутні елементи, які було вилучено.",
    "Name" : "Назва",
    "Deleted" : "Вилучено",
    "Restore" : "Відновити",
    "Delete permanently" : "Вилучити безповоротно",
    "Empty trash bin" : "Очистити кошик",
    "Untitled item" : "Елемент без назви",
    "Unknown calendar" : "Невідомий календар",
    "Could not load deleted calendars and objects" : "Не вдалося завантажити календарі та об’єкти, які було раніше вилучено",
    "Could not restore calendar or event" : "Не вдалося відновити календар або подію",
    "Do you really want to empty the trash bin?" : "Ви дійсно хочете очистити кошик?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Вміст кошику буде очищено через {numDays} день","Вміст кошику буде очищено через {numDays} дні","Вміст кошику буде очищено через {numDays} днів","Вміст кошику буде очищено через {numDays} днів"],
    "Could not update calendar order." : "Не вдалося оновити порядок відображення календарів.",
    "Import calendars" : "Імпортувати календарі",
    "Please select a calendar to import into …" : "Будь ласка, оберіть до якого календаря імпортувати дані...",
    "Filename" : "Ім'я файлу",
    "Calendar to import into" : "Імпортувати до цього календаря",
    "Cancel" : "Скасувати",
    "_Import calendar_::_Import calendars_" : ["Імпортувати календар","Імпортувати календарі","Імпортувати календарі","Імпортувати календарі"],
    "{filename} could not be parsed" : "Неможливо обробити {filename}",
    "No valid files found, aborting import" : "Відсутні дійсні файли, імпорт даних скасовано",
    "Import partially failed. Imported {accepted} out of {total}." : "Імпорт частково не вдався. Імпортовано {accepted} із {total}",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успішно вставлено %n подію","Успішно вставлено %n події","Успішно вставлено %n подій","Успішно вставлено %n подій"],
    "Automatic" : "Автоматично",
    "Automatic ({detected})" : "Автоматично ({detected})",
    "New setting was not saved successfully." : "Нові налаштування не було збережено.",
    "Shortcut overview" : "Перегляд скорочень",
    "or" : "або",
    "Navigation" : "Навігація",
    "Previous period" : "Попередній період",
    "Next period" : "Наступний період",
    "Views" : "Перегляди",
    "Day view" : "День",
    "Week view" : "Тиждень",
    "Month view" : "Місяць",
    "List view" : "Перелік",
    "Actions" : "Дії",
    "Create event" : "Додати подію",
    "Show shortcuts" : "Показати скорочення",
    "Editor" : "Редактор",
    "Close editor" : "Закрити редактор",
    "Save edited event" : "Закрити відредаговану подію",
    "Delete edited event" : "Вилучити відредаговану подію",
    "Duplicate event" : "Створити копію події",
    "Enable birthday calendar" : "Увімкнути календар дат народження",
    "Show tasks in calendar" : "Показувати завдання у календарі",
    "Enable simplified editor" : "Увімкнути спрощений редактор",
    "Limit visible events per view" : "Обмежити подання подій",
    "Show weekends" : "Показувати вихідні дні",
    "Show week numbers" : "Показувати номери тижнів",
    "Time increments" : "Крок приросту часу",
    "Default reminder" : "Типове нагадування",
    "Copy primary CalDAV address" : "Копіювати основну адресу CalDAV",
    "Copy iOS/macOS CalDAV address" : "Копіювати адресу CalDAV для iOS/macOS ",
    "Personal availability settings" : "Налаштування приватної доступності",
    "Show keyboard shortcuts" : "Показувати клавіатурні скорочення",
    "Calendar settings" : "Налаштування",
    "No reminder" : "Відсутні нагадування",
    "CalDAV link copied to clipboard." : "Посилання CalDAV скопійовано.",
    "CalDAV link could not be copied to clipboard." : "Неможливо копіювати посилання CalDAV.",
    "Appointment was created successfully" : "Успішно створено зустріч",
    "Appointment was updated successfully" : "Успішно оновлено зустріч",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} хвилина","{duration} хвилини","{duration} хвилин","{duration} хвилин"],
    "0 minutes" : "0 хвилин",
    "_{duration} hour_::_{duration} hours_" : ["{duration} година","{duration} години","{duration} годин","{duration} годин"],
    "_{duration} day_::_{duration} days_" : ["{duration} день","{duration} дні","{duration} днів","{duration} днів"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} тиждень","{duration} тижні","{duration} тижнів","{duration} тижнів"],
    "_{duration} month_::_{duration} months_" : ["{duration} місяць","{duration} місяці","{duration} місяців","{duration} місяців"],
    "_{duration} year_::_{duration} years_" : ["{duration} рік","{duration} роки","{duration} років","{duration} років"],
    "To configure appointments, add your email address in personal settings." : "Для налаштування зустрічей потрібно додати вашу електронну адресу у особистих налаштуваннях.",
    "Public – shown on the profile page" : "Публічне - буде показано на сторінці профілю",
    "Private – only accessible via secret link" : "Приватне - доступне тільки через таємне посилання",
    "Location" : "Місце",
    "Description" : "Опис",
    "Visibility" : "Видимість",
    "Duration" : "Тривалість",
    "Increments" : "Крок",
    "Additional calendars to check for conflicts" : "Додаткові клаендарі, які потрібно перевірити на конфлікти",
    "Pick time ranges where appointments are allowed" : "Виберіть часові діапазони, доступні для запрошення на зустріч",
    "to" : "до",
    "Delete slot" : "Видалити проміжок часу",
    "No times set" : "Не вибрано час",
    "Add" : "Додати",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Sunday" : "Неділя",
    "Add time before and after the event" : "Додайте часовий проміжок до та після події",
    "Before the event" : "До події",
    "After the event" : "Після події",
    "Planning restrictions" : "Заплановані обмеження",
    "Minimum time before next available slot" : "Найменший час перед наступним можливим часовим проміжком",
    "Max slots per day" : "Максимальна кількість проміжків часу на день",
    "Limit how far in the future appointments can be booked" : "Обмеження щодо тривалості майбутніх зустрічй, які можна зарезервувати",
    "Create appointment" : "Створити зустріч",
    "Edit appointment" : "Редагувати зустріч",
    "Save" : "Зберегти",
    "Update" : "Оновити",
    "Please confirm your reservation" : "Будь ласка, підтвердіть резервування",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ми надіслали вам лист з докладною інформацією щодо зустрічі. Просимо підтвердити вашу участь - для цього перейдіть за наведеним у листі посиланням. Ви можете просто закрити цю сторінку.",
    "Your name" : "Ваше ім'я",
    "Your email address" : "Ваша адреса електронної пошти",
    "Please share anything that will help prepare for our meeting" : "Будь ласка, поділіться корисними матер'ялами, які допоможуть підготоуватися до нашої зустрічі",
    "Could not book the appointment. Please try again later or contact the organizer." : "Не вдалося зарезервувати зустріч. Спробуйте пізніше або сконтактуйте з організатором.",
    "Book the appointment" : "Зарезервувати зустріч",
    "Reminder" : "Нагадування",
    "before at" : "до о",
    "Notification" : "Сповіщення",
    "Email" : "Ел.пошта",
    "Audio notification" : "Звукове сповіщення",
    "Other notification" : "Інше сповіщення",
    "Relative to event" : "Щодо події",
    "On date" : "Дата",
    "Edit time" : "Редагувати час",
    "Save time" : "Зберегти час",
    "Remove reminder" : "Прибрати нагадування",
    "on" : "у",
    "at" : "о",
    "+ Add reminder" : "+ Додати нагадування",
    "Add reminder" : "Додати нагадування",
    "_second_::_seconds_" : ["секунда","секунд","секунд","секунди"],
    "_minute_::_minutes_" : ["хвилина","хвилин","хвилин","хвилини"],
    "_hour_::_hours_" : ["година","годин","годин","години"],
    "_day_::_days_" : ["день","днів","днів","дні"],
    "_week_::_weeks_" : ["тиждень","тижнів","тижнів","тижні"],
    "Invitation accepted" : "Запрошення прийнято",
    "Available" : "Доступно",
    "Suggested" : "Запропоновано",
    "Participation marked as tentative" : "Участь можлива",
    "Accepted {organizerName}'s invitation" : "Прийнято запрошення від {organizerName}",
    "Not available" : "Не доступно",
    "Invitation declined" : "Запрошення відхилено",
    "Declined {organizerName}'s invitation" : "Відхилене від {organizerName} запрошення ",
    "Invitation is delegated" : "Запрошення делеговано",
    "Checking availability" : "Перевірка доступності",
    "Invitation sent" : "Запрошення надіслано",
    "Has not responded to {organizerName}'s invitation yet" : "Ще не відповів на запрошення від {organizerName}",
    "Availability of attendees, resources and rooms" : "Доступність учасників, ресурсів і приміщень",
    "{organizer} (organizer)" : "{organizer} (організатор)",
    "Free" : "Вільно",
    "Busy (tentative)" : "Зайнято (попередньо)",
    "Busy" : "Зайнято",
    "Out of office" : "Недоступно",
    "Unknown" : "Невідомо",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Tentative" : "Можливо так",
    "The invitation has been accepted successfully." : "Запрошення успішно прийнято.",
    "Failed to accept the invitation." : "Не вдалося прийняти запрошення.",
    "The invitation has been declined successfully." : "Запрошення відхилено.",
    "Failed to decline the invitation." : "Не вадлося відхилити запрошення.",
    "Your participation has been marked as tentative." : "Вашу участь позначено як можливу.",
    "Failed to set the participation status to tentative." : "Не вдалося встановити статус \"можливо\".",
    "Create Talk room for this event" : "Створити віртуальну кімнату Talk для цієї події",
    "Show busy times" : "Показати час, коли зайнято",
    "No attendees yet" : "Поки жодного учасника",
    "Successfully appended link to talk room to description." : "Успішно додано посилання на віртуальну кімнату Talk до опису події.",
    "Error creating Talk room" : "Помилка при створенні віртуальної кімнати Talk",
    "Send email" : "Надіслати лист",
    "Chairperson" : "Модератор",
    "Required participant" : "Обов'язковий учасник",
    "Optional participant" : "Необов'язковий учасник",
    "Non-participant" : "Неучасник",
    "Remove attendee" : "Вилучити учасника",
    "Search for emails, users or contacts" : "Пошук листів, користувачів або контактів",
    "No match found" : "Збігів не знайдено",
    "(organizer)" : "(організатор)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Для надсилання запрошень та отримання відповіді, [linkopen]додайте ел.адресу в особистих налаштуваннях[linkclose].",
    "Remove color" : "Вилучити колір",
    "Event title" : "Назва події",
    "All day" : "Цілий день",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не вдалося змінити цілодобове налаштування для подій, які є повторювальними подіями.",
    "from {startDate}" : "з {startDate}",
    "from {startDate} at {startTime}" : "до {startDate} о {startTime}",
    "to {endDate}" : "до {endDate}",
    "to {endDate} at {endTime}" : "до {endDate} о {endTime}",
    "Repeat" : "Повторювати",
    "End repeat" : "Повторювати до",
    "Select to end repeat" : "Вибрати, щоби завершити повторення",
    "never" : "ніколи",
    "on date" : "дата",
    "after" : "опісля",
    "_time_::_times_" : ["раз","разів","разів","разів"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ця подія є винятком з набору повторювальних подій. Ви не можете застосувати до нього правило повторення.",
    "first" : "перший",
    "third" : "третій",
    "fourth" : "четвертий",
    "fifth" : "п'ятий",
    "second to last" : "з другого до останнього",
    "last" : "останній",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Зміни до правила повторення стосуватимуться лише поточної та подальших подій.",
    "Repeat every" : "Повторювати кожні",
    "By day of the month" : "За днем місяця",
    "On the" : "У",
    "_month_::_months_" : ["місяць","місяців","місяців","місяці"],
    "_year_::_years_" : ["рік","років","років","роки"],
    "weekday" : "робочі дні",
    "weekend day" : "вихідні дні",
    "No recurrence" : "Відсутнє повторення",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Правила повторювання ціє події не повністю підтримуються у Nextcloud. Після зміни налаштувань деякі повторення можуть зникнути.",
    "Suggestions" : "Пропозиції",
    "No rooms or resources yet" : "Ще немає кімнат або ресурсів",
    "Add resource" : "Додати ресурс",
    "Has a projector" : "Має проєктор",
    "Has a whiteboard" : "Має білу дошку",
    "Wheelchair accessible" : "Доступ для інвалідних візків",
    "Remove resource" : "Вилучити ресурс",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} місце","{seatingCapacity} місця","{seatingCapacity} місць","{seatingCapacity} місць"],
    "Projector" : "Проєктор",
    "Whiteboard" : "Біла дошка",
    "Search for resources or rooms" : "Пошук ресурсів або кімнат",
    "available" : "доступне",
    "unavailable" : "недоступне",
    "Room type" : "Вид кімнати",
    "Any" : "Будь-яка",
    "Minimum seating capacity" : "Мінімальна кількість місць",
    "More" : "Більше",
    "Update this occurrence" : "Оновити це повторення",
    "Update this and all future" : "Оновити цю подію та всі наступні",
    "Public calendar does not exist" : "Публічний календар не існує",
    "Maybe the share was deleted or has expired?" : "Можливо спільний доступ було скасовано або він більше не дійсний?",
    "Please select a time zone:" : "Виберіть часову зону:",
    "Pick a time" : "Виберіть час",
    "Pick a date" : "Виберіть дату",
    "from {formattedDate}" : "з {formattedDate}",
    "to {formattedDate}" : "до {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "з {formattedDate} о {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} о {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} о {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} о {formattedTime}",
    "Please enter a valid date" : "Будь ласка, зазначте правильну дату",
    "Please enter a valid date and time" : "Будь ласка, зазначте правильну дату та час",
    "Type to search time zone" : "Зазначте часову зону для пошуку",
    "Global" : "Загальний",
    "Select date" : "Виберіть дату",
    "Select slot" : "Виберіть проміжок",
    "No slots available" : "Відсутні доступні часові проміжки",
    "The slot for your appointment has been confirmed" : "Часовий проміжок вашої зустрічі підтверджено",
    "Appointment Details:" : "Деталі зустрічі:",
    "Time:" : "Час:",
    "Booked for:" : "Зарезервовано для:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Дякуємо вам. Ваше резервування від {startDate} до {endDate} підтверджено.",
    "Book another appointment:" : "Зарезервувати іншу зустріч:",
    "See all available slots" : "Дивитися усі доступні дати",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Проміжок для вашого запрошення від {startDate} до {endDate} більше не доступний.",
    "Please book a different slot:" : "Зарезервуйте інший часовий проміжок:",
    "Book an appointment with {name}" : "Зарезервуйте зустріч з {name}",
    "No public appointments found for {name}" : "Не знайдено публічних зустрічей для {name}",
    "Personal" : "Особисте",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Вашу часову зону автоматично встановлено як UTC.\nСкоріш за все це зумовлено безпековими обмеженнями вашого веббравзера.\nБудь ласка, встановіть вашу часову зону вручну у наолаштуваннях календаря.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Не знайдено налаштування вашої часової зони ({timezoneId}). Не вдалося встановити типову часову зону UTC.\nБудь ласка, змініть вашу часову зону у налаштуваннях та надішліть звіт про помилку.",
    "No more events today" : "Подій на сьогодні не заплановано",
    "No upcoming events" : "Відсутні майбутні події",
    "Create a new event" : "Створити нову подію",
    "[Today]" : "[Today]",
    "[Tomorrow]" : "[Tomorrow]",
    "[Yesterday]" : "[Yesterday]",
    "Event does not exist" : "Подія відсутня",
    "Duplicate" : "Копіювати",
    "Delete this occurrence" : "Вилучити повторення",
    "Delete this and all future" : "Вилучити це та всі подальші повторення",
    "Details" : "Деталі",
    "Attendees" : "Учасники",
    "Resources" : "Ресурси",
    "Close" : "Закрити",
    "Show more details" : "Докладніше",
    "Subscribe to {name}" : "Підписатися на {name}",
    "Export {name}" : "Експортувати {name}",
    "Anniversary" : "Річниця",
    "Appointment" : "Запрошення на зустріч",
    "Business" : "Робота",
    "Education" : "Освіта",
    "Holiday" : "Вихідний",
    "Meeting" : "Зустріч",
    "Miscellaneous" : "Різне",
    "Non-working hours" : "Неробочий час",
    "Not in office" : "Поза офісом",
    "Phone call" : "Телефонний дзвінок",
    "Sick day" : "Хворію",
    "Special occasion" : "Особлива подія",
    "Travel" : "Подорожую",
    "Vacation" : "Відпустка",
    "Midnight on the day the event starts" : "Опівночі в день початку події",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n день до початку події о {formattedHourMinute}","%n днів до початку події о {formattedHourMinute}","%n днів до початку події о {formattedHourMinute}","%n дні до початку події о {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n тиждень до початку події о {formattedHourMinute}","%n тижнів до початку події о {formattedHourMinute}","%n тижнів до початку події о {formattedHourMinute}","%n тижні до початку події о {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "у день події о {formattedHourMinute}",
    "at the event's start" : "на початку події",
    "at the event's end" : "наприкінці події",
    "{time} before the event starts" : "{time} до початку події",
    "{time} before the event ends" : "{time} до завершення події",
    "{time} after the event starts" : "{time} після початку події",
    "{time} after the event ends" : "{time} після завершення події",
    "on {time}" : "о {time}",
    "on {time} ({timezoneId})" : "о {time} ({timezoneId})",
    "Week {number} of {year}" : "Тиждень {number} з {year} року",
    "Does not repeat" : "Не повторюється",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Monthly" : "Щомісяця",
    "Yearly" : "Щороку",
    "_Every %n day_::_Every %n days_" : ["Кожен %n день","Кожні %n днів","Кожні %n днів","Кожні %n дні"],
    "_Every %n week_::_Every %n weeks_" : ["Кожен %n тиждень","Кожні %n тижнів","Кожні %n тижнів","Кожні %n тижні"],
    "_Every %n month_::_Every %n months_" : ["Кожен %n місяць","Кожні %n місяців","Кожні %n місяців","Кожні %n місяці"],
    "_Every %n year_::_Every %n years_" : ["Кожен %n рік","Кожні %n років","Кожні %n років","Кожні %n роки"],
    "_on {weekday}_::_on {weekdays}_" : ["у {weekdays}","у {weekdays}","у {weekdays}","у {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["у наступний день {dayOfMonthList}","у наступні дні {dayOfMonthList}","у наступні дні {dayOfMonthList}","у наступні дні {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "у {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "у {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "у {monthNames} у {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n раз","%n разів","%n разів","%n рази"],
    "Untitled event" : "Подія без назви",
    "Untitled task" : "Завдання без назви",
    "Please ask your administrator to enable the Tasks App." : "Зверніться до вашого адміністратора щодо увімкнення застосунку \"Завдання\".",
    "Prev" : "Назад",
    "Next" : "Далі",
    "Prev year" : "Попередній рік",
    "Next year" : "Наступний рік",
    "Year" : "рік",
    "W" : "Тиж.",
    "%n more" : "%n більше",
    "No events to display" : "Відсутні події для показу",
    "_+%n more_::_+%n more_" : ["+%n раз ще","+%n разів ще","+%n разів ще","+%n рази ще"],
    "No events" : "Відсутні події",
    "Create a new event or change the visible time-range" : "Створити нову подію або змінити часовий проміжок до відображення",
    "It might have been deleted, or there was a typo in a link" : "Можливо, що його було вилучено або міститься помилка у посиланні",
    "It might have been deleted, or there was a typo in the link" : "Можливо, що його було вилучено або міститься помилка у посиланні",
    "Meeting room" : "Кімната для зустрічей",
    "Lecture hall" : "Лекційна зала",
    "Seminar room" : "Кімната для занять",
    "Other" : "Інші",
    "When shared show" : "Показувати, якщо у спільному доступі",
    "When shared show full event" : "Показувати повний зміст, якщо у спільному доступі",
    "When shared show only busy" : "Показувати тільки зайнятість, якщо у спільному доступі",
    "When shared hide this event" : "Приховати подію, якщо у спільному доступі",
    "The visibility of this event in shared calendars." : "Видимість цієї події у спільних календарях.",
    "Add a location" : "Додати розташування",
    "Add a description" : "Додати опис",
    "Status" : "Статус",
    "Confirmed" : "Підтверджено",
    "Canceled" : "Скасовано",
    "Confirmation about the overall status of the event." : "Підтвердження загального статусу події.",
    "Show as" : "Показати як",
    "Take this event into account when calculating free-busy information." : "Брати до уваги цю подію при розрахунку вільного/зайнятого часу.",
    "Categories" : "Категорії",
    "Categories help you to structure and organize your events." : "Категорії допомагають впорядковувати ваші події.",
    "Search or add categories" : "Шукати чи додати категорії",
    "Add this as a new category" : "Додати як нову категорію",
    "Custom color" : "Власний колір",
    "Special color of this event. Overrides the calendar-color." : "Власний колір для цієї події. Перезаписати колір календаря.",
    "Chat room for event" : "Кімната чату для події",
    "Imported {filename}" : "Імпортовано {filename}",
    "Meditation" : "Медитація",
    "Relaxing" : "Відпочинок",
    "Relax" : "Відпочити",
    "Break" : "Перерва",
    "Commute" : "Поїздка",
    "Commuting" : "В дорозі",
    "Shuttle" : "Автобус",
    "Invoice" : "Рахунок",
    "Finance" : "Гроші",
    "Bank" : "Банк",
    "Money" : "Гроші",
    "Wedding" : "Весілля",
    "Dog" : "Пес",
    "Concert" : "Концерт",
    "Festival" : "Фестиваль",
    "Theater" : "Театр",
    "Theatre" : "Театр",
    "Presentation" : "Презентація",
    "Talk" : "Розмова",
    "Speech" : "Промова",
    "Deadline" : "Реченець",
    "Submission" : "Подання",
    "Reporting" : "Звітування",
    "Camping" : "За містом",
    "Camp" : "На природі",
    "Election" : "Вибори",
    "Voting" : "Голосування",
    "Vote" : "Голосувати",
    "Barbecue" : "Барбекю",
    "Barbeque" : "Барбекю",
    "Garden" : "Сад",
    "Farm" : "Ферма",
    "Movie" : "Фільм",
    "Cinema" : "Кіно",
    "Graduation" : "Випускний",
    "Brainstorm" : "Обговорення",
    "Review" : "Перегляд",
    "Audit" : "Аудит",
    "Inspection" : "Перевірка",
    "Proofreading" : "Вичитка",
    "Baseball" : "Бейсбол",
    "Meet" : "Зустріч",
    "Planning" : "Планування",
    "Pointing" : "Призначено",
    "Retrospective" : "Ретроспектива",
    "Office" : "Робота",
    "Contributor week" : "Тиждень постачальника",
    "Mail" : "Пошта",
    "Soccer" : "Футбол",
    "Football" : "Американський футбол",
    "Gaming" : "Ігри",
    "Drive" : "Автівка",
    "Driving" : "Водіння",
    "Bicycle" : "Велосипед",
    "Cycle" : "Колісний транспорт",
    "Cycling" : "Велосипед",
    "Biking" : "Мотоцикл",
    "Bike" : "Велосипед",
    "Podcast" : "Подкаст",
    "Basketball" : "Баскетбол",
    "Fishing" : "Рибалка",
    "Hiking" : "Ходьба",
    "Hike" : "Похід",
    "Art" : "Мистецтво",
    "Exhibition" : "Виставка",
    "Museum" : "Музей",
    "Pilates" : "Пілатес",
    "Park" : "Парк",
    "Walk" : "Прогулянка",
    "Studying" : "Навчання",
    "Doctor" : "Лікар",
    "Health" : "Здоров'я",
    "Dentist" : "Стоматолог",
    "Hospital" : "Лікарня",
    "Interview" : "Співбесіда",
    "Training" : "Тренування",
    "Practice" : "Практика",
    "Sports" : "Спорт",
    "Exercise" : "Вправи",
    "Work out" : "Тренажери",
    "Working out" : "У тренажерному залі",
    "Gym" : "Тренажерний зал",
    "Barber" : "Перукар",
    "Haircut" : "Зачіска",
    "Hairdresser" : "Перукар",
    "Exam" : "Іспит",
    "Written test" : "Письмовий тест",
    "Oral test" : "Усний тест",
    "Working" : "Працюю",
    "New Years Eve" : "Новий рік",
    "NYE" : "Новий рік",
    "Fireworks" : "Феєрверки",
    "Running" : "Бігаю",
    "Go for a run" : "Пробіжка",
    "Marathon" : "Марафон",
    "Video-conference" : "Відеоконференція",
    "Conference-call" : "Конференц-виклик",
    "Video-call" : "Відеовиклик",
    "Video-chat" : "Відеочат",
    "Video-meeting" : "Відеозустріч",
    "Call" : "Дзвінок",
    "Calling" : "Телефоную",
    "Christmas" : "Різдво",
    "Conference" : "Конференція",
    "Pizza" : "Піцца",
    "Travelling" : "Подорожую",
    "Trip" : "Поїздка",
    "Journey" : "Подорож",
    "Collaborate" : "Співпраця",
    "Pair" : "Пара",
    "Lecture" : "Лекція",
    "Seminar" : "Семінар",
    "Teaching" : "Викладання",
    "Photograph" : "Фотограф",
    "Party" : "Вечірка",
    "Celebration" : "Святкування",
    "Celebrate" : "Святкування",
    "Birthday" : "День народження",
    "Shopping" : "Шопінг",
    "Groceries" : "Бакалія",
    "Skate" : "Ковзани",
    "Skateboard" : "Скейт",
    "Wine tasting" : "Дегустація",
    "Golf" : "Гольф",
    "Dinner" : "Вечеря",
    "Lunch" : "Обід",
    "Appointment not found" : "Запрошення на зустріч не знайдено",
    "User not found" : "Користувача не знайдено"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
