OC.L10N.register(
    "calendar",
    {
    "Calendar" : "ប្រតិទិន",
    "Today" : "ថ្ងៃ​នេះ",
    "Day" : "ថ្ងៃ",
    "Week" : "សប្ដាហ៍",
    "Month" : "ខែ",
    "Copy link" : "ចម្លងតំណ",
    "Edit" : "កែប្រែ",
    "Delete" : "លុប",
    "Export" : "នាំចេញ",
    "Share link" : "Share link",
    "can edit" : "អាច​កែប្រែ",
    "New calendar" : "ប្រតិទិន​ថ្មី",
    "Name" : "ឈ្មោះ",
    "Deleted" : "បាន​លុប",
    "Restore" : "ស្ដារ​មក​វិញ",
    "Delete permanently" : "លុប​ជា​អចិន្ត្រៃយ៍",
    "Cancel" : "បោះបង់",
    "Location" : "ទីតាំង",
    "Description" : "ការ​អធិប្បាយ",
    "to" : "ទៅ",
    "Add" : "បញ្ចូល",
    "Monday" : "ថ្ងៃចន្ទ",
    "Tuesday" : "ថ្ងៃអង្គារ",
    "Wednesday" : "ថ្ងៃពុធ",
    "Thursday" : "ថ្ងៃព្រហស្បតិ៍",
    "Friday" : "ថ្ងៃសុក្រ",
    "Saturday" : "ថ្ងៃសៅរ៍",
    "Sunday" : "ថ្ងៃអាទិត្យ",
    "Save" : "រក្សាទុក",
    "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
    "Your email address" : "អ៊ីម៉ែល​របស់​អ្នក",
    "Email" : "អ៊ីមែល",
    "Send email" : "ផ្ញើ​អ៊ីមែល",
    "Repeat" : "ធ្វើម្ដងទៀត",
    "never" : "មិនដែរ",
    "first" : "ទីមួយ",
    "last" : "ចុងក្រោយ",
    "More" : "ច្រើន​ទៀត",
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "Details" : "ព័ត៌មាន​លម្អិត",
    "Attendees" : "អ្នក​ចូលរួម",
    "Close" : "បិទ",
    "Daily" : "រាល់ថ្ងៃ",
    "Weekly" : "រាល់​សប្ដាហ៍",
    "Next" : "បន្ទាប់",
    "Year" : "ឆ្នាំ",
    "Other" : "ផ្សេងៗ",
    "Mail" : "សំបុត្រ",
    "Birthday" : "ថ្ងៃ​កំណើត"
},
"nplurals=1; plural=0;");
