OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "Şərəfə!",
    "Calendar" : "Təqvim",
    "Today" : "Bu gün",
    "Day" : "Gün",
    "Week" : "Həftə",
    "Month" : "Ay",
    "Copy link" : "linki nüsxələ",
    "Edit" : "Dəyişiklik et",
    "Delete" : "Sil",
    "Export" : "Çıxarış",
    "Share link" : "Linki yayımla",
    "can edit" : "dəyişmək olar",
    "New calendar" : "Yeni təqvim",
    "Name" : "Ad",
    "Deleted" : "Silinib",
    "Restore" : "Geri qaytar",
    "Delete permanently" : "Həmişəlik sil",
    "Cancel" : "Dayandır",
    "Automatic" : "Avtomatik",
    "Actions" : "İşlər",
    "Location" : "Yerləşdiyiniz ünvan",
    "Description" : "Açıqlanma",
    "to" : "doğru",
    "Add" : "Əlavə etmək",
    "Monday" : "Bazar ertəsi",
    "Tuesday" : "Çərşənbə axşamı",
    "Wednesday" : "Çərşənbə",
    "Thursday" : "Cümə axşamı",
    "Friday" : "Cümə",
    "Saturday" : "Şənbə",
    "Sunday" : "Bazar",
    "Save" : "Saxla",
    "Update" : "Yenilənmə",
    "Your email address" : "Sizin email ünvanı",
    "Email" : "Email",
    "Send email" : "Email yolla",
    "Repeat" : "Təkrar",
    "never" : "heç vaxt",
    "More" : "Daha da",
    "Personal" : "Şəxsi",
    "Details" : "Detallar",
    "Attendees" : "İştirakçılar",
    "Close" : "Bağla",
    "Daily" : "Günlük",
    "Weekly" : "Həftəlik",
    "Next" : "Növbəti",
    "Other" : "Digər",
    "Mail" : "Məktub",
    "Birthday" : "Ad günü"
},
"nplurals=2; plural=(n != 1);");
