OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s је објавио календар »%s«",
    "Hello," : "Здраво, ",
    "We wanted to inform you that %s has published the calendar »%s«." : "Желимо да Вас обавестимо да је %s објавио календар »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Здраво!",
    "Confirm" : "Потврди",
    "Date:" : "Датум:",
    "Where:" : "Место:",
    "Calendar" : "Календар",
    "A Calendar app for Nextcloud" : "Календар апликација за Некстклауд",
    "New event" : "Нови догађај",
    "Today" : "Данас",
    "Day" : "Дан",
    "Week" : "Недеља",
    "Month" : "Месец",
    "List" : "Излистај",
    "Preview" : "Претпреглед",
    "Copy link" : "Копирај везу",
    "Edit" : "Измени",
    "Delete" : "Обриши",
    "Edit name" : "Измени име",
    "Copy private link" : "Копирај приватну везу",
    "Export" : "Извези",
    "An error occurred, unable to delete the calendar." : "Догодила се грешка, не могу да обришем календар.",
    "Calendar link copied to clipboard." : "Веза календара копирана у оставу.",
    "Calendar link could not be copied to clipboard." : "Веза календара није могла да се копира у оставу.",
    "Share link" : "Дели везу",
    "Delete share link" : "Обриши везу дељења",
    "Share with users or groups" : "Дели са корисницима или групама",
    "No users or groups" : "Нема корисника или група",
    "can edit" : "може да мења",
    "Unshare with {displayName}" : "Уклони дељење са {displayName}",
    "New calendar" : "Нови календар",
    "Name" : "Име",
    "Deleted" : "Обрисано",
    "Restore" : "Врати",
    "Delete permanently" : "Обриши заувек",
    "Filename" : "Име фајла",
    "Cancel" : "Одустани",
    "Automatic" : "Аутоматски",
    "or" : "или",
    "List view" : "Приказ листе",
    "Actions" : "Радње",
    "Show week numbers" : "Прикажи број седмице",
    "Show keyboard shortcuts" : "Прикажи пречице тастатуре",
    "Location" : "Локација",
    "Description" : "Опис",
    "Duration" : "Трајање",
    "to" : "за",
    "Add" : "Додај",
    "Monday" : "Понедељак",
    "Tuesday" : "Уторак",
    "Wednesday" : "Среда",
    "Thursday" : "Четвртак",
    "Friday" : "Петак",
    "Saturday" : "Субота",
    "Sunday" : "Недеља",
    "Save" : "Сачувај",
    "Update" : "Ажурирај",
    "Your email address" : "Адреса Ваше е-поште",
    "Notification" : "Обавештење",
    "Email" : "Е-пошта",
    "Available" : "Доступно",
    "Busy" : "Заузет",
    "Unknown" : "Непознато",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "Tentative" : "Условна потврда",
    "Send email" : "Пошаљи е-пошту",
    "All day" : "Цео дан",
    "Repeat" : "Понављај",
    "never" : "никада",
    "after" : "након",
    "available" : "доступно",
    "More" : "Остало",
    "Global" : "Цео свет",
    "Time:" : "Време:",
    "Personal" : "Лично",
    "[Today]" : "[Данас]",
    "[Tomorrow]" : "[Сутра]",
    "[Yesterday]" : "[Јуче]",
    "Details" : "Детаљи",
    "Attendees" : "Присутни",
    "Resources" : "Ресурси",
    "Close" : "Затвори",
    "Anniversary" : "Годишњица",
    "Week {number} of {year}" : "Недеља {number} у {year}",
    "Daily" : "дневно",
    "Weekly" : "недељно",
    "Untitled event" : "Неименовани догађај",
    "Untitled task" : "Неименовани задатак",
    "Prev" : "Претходни",
    "Next" : "Следећа",
    "Year" : "Година",
    "Other" : "Остало",
    "When shared show full event" : "Прикажи цео догађај када је догађај дељен",
    "When shared show only busy" : "Прикажи само да сте заузети када је догађај дељен",
    "When shared hide this event" : "Сакриј догађај када је догађај дељен",
    "Status" : "Статус",
    "Confirmed" : "Потврђен",
    "Canceled" : "Отказано",
    "Categories" : "Категорије",
    "Add this as a new category" : "Додај ово као нову категорију",
    "Talk" : "Разговор",
    "Movie" : "Филм",
    "Cinema" : "Биоскоп",
    "Review" : "Претпреглед",
    "Mail" : "поштом",
    "Dentist" : "Стоматолог",
    "Hospital" : "Болница",
    "Birthday" : "Рођендан",
    "User not found" : "Корисник није нађен"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
