OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "La sessió ha caducat inesperadament",
    "Provided email-address is not valid" : "L'adreça electrònica proporcionada no és vàlida",
    "%s has published the calendar »%s«" : "%s ha publicat el calendari «%s»",
    "Unexpected error sending email. Please contact your administrator." : "S'ha produït un error inesperat en enviar el correu electrònic. Contacteu amb l'administrador.",
    "Successfully sent email to %1$s" : "Correu enviat correctament a %1$s",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Us volem informar que %s ha publicat el calendari «%s».",
    "Open »%s«" : "Obre «%s»",
    "Cheers!" : "A reveure!",
    "Upcoming events" : "Pròxims esdeveniments",
    "Appointments" : "Cites",
    "Schedule appointment \"%s\"" : "Planifica cita \"%s\"",
    "Schedule an appointment" : "Planifica una cita",
    "Prepare for %s" : "Preparar-se per a %s",
    "Follow up for %s" : "Seguiment de %s",
    "Dear %s, please confirm your booking" : "Benvolgut %s, confirmeu la vostra reserva",
    "Confirm" : "Confirma",
    "This confirmation link expires in %s hours." : "Aquest enllaç de confirmació caduca d'aquí a %s hores.",
    "Date:" : "Data:",
    "Where:" : "Ubicació:",
    "Calendar" : "Calendari",
    "A Calendar app for Nextcloud" : "Una aplicació de calendari per al Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "L'aplicació Calendar és una interfície d'usuari per al servidor CalDAV de Nextcloud. Sincronitza fàcilment els esdeveniments de diversos dispositius amb el teu Nextcloud i permet editar-los directament.\n\n* 🚀 **Integració amb altres aplicacions de Nextcloud!** Amb Contactes actualment: més per venir.\n* 🌐 **Suport WebCal!** Vols veure els dies de partit del teu equip favorit al teu calendari? Cap problema!\n* 🙋 **Assistents!** Convida persones als teus esdeveniments\n* ⌚️ **Lliure/Ocupat!** Consulta quan els teus assistents estan disponibles per reunir-se\n* ⏰ **Recordatoris!** Obté alarmes d'esdeveniments al vostre navegador i per correu electrònic\n* 🔍 Cerca! Troba els teus esdeveniments amb facilitat\n* ☑️ Tasques! Consulta les tasques amb data de venciment directament al calendari\n* 🙈 **No estem reinventant la roda!** Basat en la gran llibreries [biblioteca c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https:// github.com/mozilla-comm/ical.js) i [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Dia anterior",
    "Previous week" : "Setmana anterior",
    "Previous month" : "Mes anterior",
    "Next day" : "Dia següent",
    "Next week" : "Setmana següent",
    "Next month" : "Mes següent",
    "New event" : "Esdeveniment nou",
    "Today" : "Avui",
    "Day" : "Dia",
    "Week" : "Setmana",
    "Month" : "Mes",
    "List" : "Llista",
    "Preview" : "Previsualitza",
    "Copy link" : "Copia l'enllaç",
    "Edit" : "Edita",
    "Delete" : "Suprimeix",
    "Appointment link was copied to clipboard" : "L'enllaç de la cita s'ha copiat al porta-retalls",
    "Appointment link could not be copied to clipboard" : "No s'ha pogut copiar l'enllaç de la cita al porta-retalls",
    "Add new" : "Afegeix nou/nova",
    "Untitled calendar" : "Calendari sense títol",
    "Edit name" : "Edita el nom",
    "Saving name …" : "Desant el nom …",
    "Edit color" : "Edita el color",
    "Saving color …" : "Desant el color …",
    "Copy private link" : "Copia l'enllaç privat",
    "Export" : "Exporta",
    "Unshare from me" : "Deixa de compartir",
    "Disable calendar \"{calendar}\"" : "Desactiva el calendari \"{calendar}\"",
    "Disable untitled calendar" : "Desactiva el calendari sense títol",
    "Enable calendar \"{calendar}\"" : "Activa el calendari \"{calendar}\"",
    "Enable untitled calendar" : "Activa el calendari sense títol",
    "An error occurred, unable to change visibility of the calendar." : "S'ha produït un error. No s'ha canviat la visibilitat del calendari.",
    "An error occurred, unable to delete the calendar." : "S'ha produït un error. No s'ha suprimit el calendari.",
    "Calendar link copied to clipboard." : "S'ha copiat l'enllaç del calendari al porta-retalls.",
    "Calendar link could not be copied to clipboard." : "No s'ha pogut copiar l'enllaç del calendari al porta-retalls.",
    "An error occurred, unable to rename the calendar." : "S'ha produït un error. No s'ha canviat el nom del calendari.",
    "An error occurred, unable to change the calendar's color." : "S'ha produït un error. No s'ha canviat el color del calendari.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixant de compartir el calendari en {countdown} segons","S'està deixant de compartir el calendari en {countdown} segons"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminant el calendari en {countdown} segons","S'està suprimint el calendari en {countdown} segons"],
    "Share link" : "Enllaç de compartició",
    "Publish calendar" : "Publica el calendari",
    "Publishing calendar" : "S'està publicant el calendari",
    "Copy public link" : "Copia l'enllaç públic",
    "Send link to calendar via email" : "Enviar per correu l'enllaç al calendari",
    "Enter one address" : "Escriviu una adreça",
    "Sending email …" : "Envian correu …",
    "Copy subscription link" : "Copiar l'enllaç de subscripció",
    "Copying link …" : "Copiant l'enllaç …",
    "Copied link" : "S'ha copiat l'enllaç",
    "Could not copy link" : "No s'ha pogut copiar l'enllaç",
    "Copy embedding code" : "Copiar el codi per inserir",
    "Copying code …" : "Copiant el codi …",
    "Copied code" : "Codi copiat",
    "Could not copy code" : "No s'ha pogut copiar el codi",
    "Delete share link" : "Suprimeix l'enllaç de compartició",
    "Deleting share link …" : "S'està suprimint l'enllaç de compartició …",
    "An error occurred, unable to publish calendar." : "Ha succeït un error i no ha estat possible publicar el calendari.",
    "An error occurred, unable to send email." : "Ha succeït un error i no ha estat possible enviar el correu.",
    "Embed code copied to clipboard." : "S'ha copiat el codi al porta-retalls.",
    "Embed code could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls el codi d'inserció.",
    "Unpublishing calendar failed" : "Ha fallat la des-publicació del calendari",
    "Share with users or groups" : "Comparteix amb usuaris o grups",
    "No users or groups" : "No hi ha usuaris ni grups",
    "can edit" : "pot editar-lo",
    "Unshare with {displayName}" : "S'ha deixat de compartir amb {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Ha succeït un error i no s'ha pogut canviar la no-compartició del calendari.",
    "An error occurred, unable to change the permission of the share." : "Ha succeït un error i no s'ha pogut canviar els permisos de compartició.",
    "New calendar" : "Calendari nou",
    "Name for new calendar" : "Nom per al nou calendari",
    "Creating calendar …" : "Creant el calendari …",
    "New calendar with task list" : "Calendari nou amb llista de tasques",
    "New subscription from link (read-only)" : "Nova subscripció des d'enllaç (només lectura)",
    "Creating subscription …" : "Creant la subscripció …",
    "An error occurred, unable to create the calendar." : "Ha succeït un error i no s'ha pogut crear el calendari.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Escriviu un enllaç vàlid (que comenci amb http://, https://, webcal://, o webcals://)",
    "Trash bin" : "Paperera",
    "Loading deleted items." : "S'estan carregant els elements suprimits.",
    "You do not have any deleted items." : "No teniu cap element suprimit.",
    "Name" : "Nom",
    "Deleted" : "Suprimit",
    "Restore" : "Restaura",
    "Delete permanently" : "Suprimeix de manera permanent",
    "Empty trash bin" : "Buida la paperera",
    "Untitled item" : "Element sense títol",
    "Unknown calendar" : "Calendari desconegut",
    "Could not load deleted calendars and objects" : "No s'han pogut carregar els calendaris i els objectes suprimits",
    "Could not restore calendar or event" : "No s'ha pogut restaurar el calendari o l'esdeveniment",
    "Do you really want to empty the trash bin?" : "Realment voleu buidar la paperera?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Els elements de la paperera se suprimeixen al cap de {numDays} dia","Els elements de la paperera se suprimeixen al cap de {numDays} dies"],
    "Could not update calendar order." : "No s'ha pogut actualitzar l'ordre del calendari.",
    "Import calendars" : "Importar calendaris",
    "Please select a calendar to import into …" : "Escolliu un calendari per ser importat …",
    "Filename" : "Nom del fitxer",
    "Calendar to import into" : "Calendari a importar",
    "Cancel" : "Cancel·la",
    "_Import calendar_::_Import calendars_" : ["Importar calendari","Importa calendaris"],
    "{filename} could not be parsed" : "No s'ha pogut entendre el contingut del fitxer {filename}",
    "No valid files found, aborting import" : "No s'han trobat fitxers que siguin vàlids i s'ha avortat la importació",
    "Import partially failed. Imported {accepted} out of {total}." : "La importació ha fallat parcialment. S'han importat {accepted} d'un total de {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["S'ha importat correctament %n esdeveniment","S'ha importat correctament %n esdeveniments"],
    "Automatic" : "Automàtic",
    "Automatic ({detected})" : "Automàtic ({detected})",
    "New setting was not saved successfully." : "No s'ha desat correctament la nova configuració.",
    "Shortcut overview" : "Descripció general de la drecera",
    "or" : "o",
    "Navigation" : "Navegació",
    "Previous period" : "Període anterior",
    "Next period" : "Període següent",
    "Views" : "Vistes",
    "Day view" : "Vista de dia",
    "Week view" : "Vista de setmana",
    "Month view" : "Vista de mes",
    "List view" : "Vista de llista",
    "Actions" : "Accions",
    "Create event" : "Crea un esdeveniment",
    "Show shortcuts" : "Mostra les dreceres",
    "Editor" : "Editor",
    "Close editor" : "Tanca l'editor",
    "Save edited event" : "Desa l'esdeveniment editat",
    "Delete edited event" : "Suprimeix l'esdeveniment editat",
    "Duplicate event" : "Esdeveniment duplicat",
    "Enable birthday calendar" : "Activa el calendari d'aniversaris",
    "Show tasks in calendar" : "Mostra les tasques en el calendari",
    "Enable simplified editor" : "Habilita l'editor simplificat",
    "Limit visible events per view" : "Limita el esdeveniments visibles per visualització",
    "Show weekends" : "Mostra els caps de setmana",
    "Show week numbers" : "Mostra el número de la setmana",
    "Time increments" : "Increments de temps",
    "Default reminder" : "Recordatori per defecte",
    "Copy primary CalDAV address" : "Copia l'adreça CalDEV primària",
    "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
    "Personal availability settings" : "Configuració de disponibilitat personal",
    "Show keyboard shortcuts" : "Mostra les dreceres del teclat",
    "Calendar settings" : "Configuració del calendari",
    "No reminder" : "Sense recordatoris",
    "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
    "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
    "Appointment was created successfully" : "La cita s'ha creat correctament",
    "Appointment was updated successfully" : "La cita s'ha actualitzat correctament",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuts"],
    "0 minutes" : "0 minuts",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} hores"],
    "_{duration} day_::_{duration} days_" : ["{duration} dia","{duration} dies"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} setmana","{duration} setmanes"],
    "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} mesos"],
    "_{duration} year_::_{duration} years_" : ["{duration} any","{duration} anys"],
    "To configure appointments, add your email address in personal settings." : "Per configurar cites, afegiu la vostra adreça de correu electrònic a la configuració personal.",
    "Public – shown on the profile page" : "Públic – es mostra a la pàgina de perfil",
    "Private – only accessible via secret link" : "Privat – només accessible mitjançant un enllaç secret",
    "Location" : "Ubicació",
    "Description" : "Descripció",
    "Visibility" : "Visibilitat",
    "Duration" : "Durada",
    "Increments" : "Increments",
    "Additional calendars to check for conflicts" : "Calendaris addicionals per comprovar si hi ha conflictes",
    "Pick time ranges where appointments are allowed" : "Trieu intervals de temps on es permeten les cites",
    "to" : "a",
    "Delete slot" : "Suprimeix unitat temporal",
    "No times set" : "Sense horaris establerts",
    "Add" : "Afegeix",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sunday" : "Diumenge",
    "Add time before and after the event" : "Afegiu temps abans i després de l'esdeveniment",
    "Before the event" : "Abans de l'esdeveniment",
    "After the event" : "Després de l’esdeveniment",
    "Planning restrictions" : "Restriccions de planificació",
    "Minimum time before next available slot" : "Temps mínim abans de la propera unitat temporal disponible",
    "Max slots per day" : "Màxim d'unitats temporals per dia",
    "Limit how far in the future appointments can be booked" : "Limiteu fins a quin punt es poden reservar cites futures",
    "Create appointment" : "Crear cita",
    "Edit appointment" : "Edita la cita",
    "Save" : "Desa",
    "Update" : "Actualitza",
    "Please confirm your reservation" : "Si us plau, confirmeu la vostra reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "T'hem enviat un correu electrònic amb els detalls. Si us plau, confirmeu la vostra cita mitjançant l'enllaç del correu electrònic. Ja podeu tancar aquesta pàgina.",
    "Your name" : "El vostre nom",
    "Your email address" : "La vostra adreça de correu",
    "Please share anything that will help prepare for our meeting" : "Si us plau, compartiu qualsevol cosa que ajudi a preparar la nostra reunió",
    "Could not book the appointment. Please try again later or contact the organizer." : "No s'ha pogut reservar la cita. Torneu-ho a provar més tard o contacteu amb l'organitzador.",
    "Book the appointment" : "Reserva la cita",
    "Reminder" : "Recordatori",
    "before at" : "abans a les",
    "Notification" : "Notificació",
    "Email" : "Correu",
    "Audio notification" : "Notificació de so",
    "Other notification" : "Altres notificacions",
    "Relative to event" : "En relació a l'esdeveniment",
    "On date" : "A la data",
    "Edit time" : "Modifica l'hora",
    "Save time" : "Desar l'hora",
    "Remove reminder" : "Suprimeix el recordatori",
    "on" : "a",
    "at" : "a",
    "+ Add reminder" : "+ Afegeix un recordatori",
    "Add reminder" : "Afegeix un recordatori",
    "_second_::_seconds_" : ["segon","segons"],
    "_minute_::_minutes_" : ["minut","minuts"],
    "_hour_::_hours_" : ["hora","hores"],
    "_day_::_days_" : ["dia","dies"],
    "_week_::_weeks_" : ["setmana","setmanes"],
    "Invitation accepted" : "S'ha acceptat la invitació",
    "Available" : "Disponible",
    "Suggested" : "Suggerit",
    "Participation marked as tentative" : "Participació marcada com a provisional",
    "Accepted {organizerName}'s invitation" : "S'ha acceptat la invitació de {organizerName}",
    "Not available" : "No disponible",
    "Invitation declined" : "S'ha declinat la invitació",
    "Declined {organizerName}'s invitation" : "{organizerName}'s ha declinat la invitació",
    "Invitation is delegated" : "La invitació és delegada",
    "Checking availability" : "Consultant disponibilitat",
    "Invitation sent" : "Invitació enviada",
    "Has not responded to {organizerName}'s invitation yet" : "Encara no ha respost a la invitació de {organizerName}",
    "Availability of attendees, resources and rooms" : "Disponibilitat d'assistents, recursos i espais",
    "{organizer} (organizer)" : "{organizer} (organitzador)",
    "Free" : "Disponible",
    "Busy (tentative)" : "Ocupat (provisional)",
    "Busy" : "Ocupat",
    "Out of office" : "Fora de l'oficina",
    "Unknown" : "Desconegut",
    "Accept" : "Accepta",
    "Decline" : "Rebutja",
    "Tentative" : "Provisional",
    "The invitation has been accepted successfully." : "La invitació s'ha acceptat correctament.",
    "Failed to accept the invitation." : "No s'ha pogut acceptar la invitació.",
    "The invitation has been declined successfully." : "La invitació s'ha declinat correctament.",
    "Failed to decline the invitation." : "No s'ha pogut declinar la invitació.",
    "Your participation has been marked as tentative." : "La teva participació s'ha marcat com a provisional.",
    "Failed to set the participation status to tentative." : "No s'ha pogut establir l'estat de participació com a provisional.",
    "Create Talk room for this event" : "Crea una sala a Talk per a aquest esdeveniment",
    "Show busy times" : "Mostra els horaris ocupats",
    "No attendees yet" : "Encara no hi ha cap participant",
    "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala de Talk a la descripció de l'esdeveniment.",
    "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
    "Send email" : "Enviar correu",
    "Chairperson" : "Organització",
    "Required participant" : "Participació obligatòria",
    "Optional participant" : "Participació opcional",
    "Non-participant" : "Sense participació",
    "Remove attendee" : "Suprimeix el participant",
    "Search for emails, users or contacts" : "Cerca correus electrònics, usuaris o contactes",
    "No match found" : "No s'ha trobat cap coincidència",
    "(organizer)" : "(organitza l'esdeveniment)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Per enviar invitacions i atendre les respostes, cal que [linkopen]afegiu la vostra adreça de correu a la vostra configuració personal[linkclose].",
    "Remove color" : "Suprimeix el color",
    "Event title" : "Títol de l'esdeveniment",
    "All day" : "Tot el dia",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "No es pot modificar la configuració de tot el dia per als esdeveniments que formen part d'un conjunt de recurrència.",
    "from {startDate}" : "del {startDate}",
    "from {startDate} at {startTime}" : "del {startDate} a les {startTime}",
    "to {endDate}" : "al {endDate}",
    "to {endDate} at {endTime}" : "al {endDate} a les {endTime}",
    "Repeat" : "Repeteix",
    "End repeat" : "Finalitza la repetició",
    "Select to end repeat" : "Seleccioneu per finalitzar repetició",
    "never" : "mai",
    "on date" : "el dia",
    "after" : "després de",
    "_time_::_times_" : ["vegada","vegades"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Aquest esdeveniment és l'excepció de recurrència d'un conjunt de recurrència. No hi podeu afegir una regla de recurrència.",
    "first" : "primer",
    "third" : "tercer",
    "fourth" : "quart",
    "fifth" : "cinquè",
    "second to last" : "penúltim",
    "last" : "últim",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Els canvis a la regla de recurrència només afectarà en aquesta i futures ocurrències.",
    "Repeat every" : "Repeteix cada",
    "By day of the month" : "Per dia del mes",
    "On the" : "Al",
    "_month_::_months_" : ["mes","mesos"],
    "_year_::_years_" : ["any","anys"],
    "weekday" : "dia de la setmana",
    "weekend day" : "dia de cap de setmana",
    "No recurrence" : "Sense recurrència",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definició de recurrència d'aquest esdeveniment no és del tot compatible amb Nextcloud. Si canvieu les opcions de recurrència, es poden perdre certes recurrències.",
    "Suggestions" : "Suggeriments",
    "No rooms or resources yet" : "Encara no hi ha sales ni recursos",
    "Add resource" : "Afegeix un recurs",
    "Has a projector" : "Té un projector",
    "Has a whiteboard" : "Té una pissarra blanca",
    "Wheelchair accessible" : "Accessible amb cadira de rodes",
    "Remove resource" : "Suprimeix el recurs",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} seient","{seatingCapacity} seients"],
    "Projector" : "Projector",
    "Whiteboard" : "Pissarra blanca",
    "Search for resources or rooms" : "Cerca recursos o sales",
    "available" : "disponible",
    "unavailable" : "no disponible",
    "Room type" : "Tipus de sala",
    "Any" : "Qualsevol",
    "Minimum seating capacity" : "Capacitat mínima de seients",
    "More" : "Més",
    "Update this occurrence" : "Actualitza aquesta ocurrència",
    "Update this and all future" : "Actualitza aquesta i les futures",
    "Public calendar does not exist" : "No existeix un calendari públic",
    "Maybe the share was deleted or has expired?" : "Potser la compartició va ser esborrada o va expirar?",
    "Please select a time zone:" : "Seleccioneu una zona horària:",
    "Pick a time" : "Tria una hora",
    "Pick a date" : "Tria una data",
    "from {formattedDate}" : "de {formattedDate}",
    "to {formattedDate}" : "a {formattedDate}",
    "on {formattedDate}" : "el {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "del {formattedDate} a les {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "al {formattedDate} a les {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a les {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} a les {formattedTime}",
    "Please enter a valid date" : "Indiqueu una data vàlida",
    "Please enter a valid date and time" : "Indiqueu una data i hora vàlides",
    "Type to search time zone" : "Escriviu per cercar la zona horària",
    "Global" : "Global",
    "Select date" : "Seleccioneu una data",
    "Select slot" : "Seleccioneu unitat temporal",
    "No slots available" : "No hi han unitats temporals disponibles",
    "The slot for your appointment has been confirmed" : "S'ha confirmat l’unitat temporal per a la vostra cita",
    "Appointment Details:" : "Detalls de la cita:",
    "Time:" : "Hora:",
    "Booked for:" : "Reservat per a:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Gràcies. La teva reserva de {startDate} a {endDate} s'ha confirmat.",
    "Book another appointment:" : "Reserva una altra cita:",
    "See all available slots" : "Consulta totes les unitat temporals disponibles",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "L’unitat temporal per a la vostra cita de {startDate} a {endDate} ja no està disponible.",
    "Please book a different slot:" : "Reserveu una unitat temporal diferent:",
    "Book an appointment with {name}" : "Reserva una cita amb {name}",
    "No public appointments found for {name}" : "No s'han trobat cites públiques per a {name}",
    "Personal" : "Personal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detecció automàtica de la zona horària va determinar que la vostra zona horària fos UTC.\nÉs probable que això sigui el resultat de les mesures de seguretat del vostre navegador web.\nSi us plau, configureu la vostra zona horària manualment a la configuració del calendari.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No s'ha trobat la vostra zona horària configurada ({timezoneId}). Tornant a l'UTC.\nCanvieu la vostra zona horària a la configuració i informeu d'aquest problema.",
    "No more events today" : "Avui no hi ha més esdeveniments",
    "No upcoming events" : "No hi ha propers esdeveniments",
    "Create a new event" : "Crea un esdeveniment nou",
    "[Today]" : "[Avui]",
    "[Tomorrow]" : "[Demà]",
    "[Yesterday]" : "[Ahir]",
    "[Last] dddd" : "[Últim] dddd",
    "Event does not exist" : "L'esdeveniment no existeix",
    "Duplicate" : "Duplica",
    "Delete this occurrence" : "Suprimeix aquesta ocurrència",
    "Delete this and all future" : "Suprimeix aquesta i les ocurrències futures",
    "Details" : "Detalls",
    "Attendees" : "Assistents",
    "Resources" : "Recursos",
    "Close" : "Tanca",
    "Show more details" : "Mostra més detalls",
    "Subscribe to {name}" : "Subscriure a {name}",
    "Export {name}" : "Exporta {name}",
    "Anniversary" : "Commemoració",
    "Appointment" : "Cita",
    "Business" : "Negocis",
    "Education" : "Formació",
    "Holiday" : "Vacances",
    "Meeting" : "Reunió",
    "Miscellaneous" : "Miscel·lània",
    "Non-working hours" : "Hores no laborals",
    "Not in office" : "Fora de l'oficina",
    "Phone call" : "Trucada telefònica",
    "Sick day" : "Malaltia",
    "Special occasion" : "Ocasió especial",
    "Travel" : "Viatge",
    "Vacation" : "Vacances",
    "Midnight on the day the event starts" : "Mitjanit del dia que comença l'esdeveniment",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dia abans de l'event a les {formattedHourMinute}","%n dies abans de l'esdeveniment a les {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n setmana abans de l'event a les  {formattedHourMinute}","%n setmanes abans de l'esdeveniment a les {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "el dia de l'esdeveniment a les {formattedHourMinute}",
    "at the event's start" : "a l'inici de l'esdeveniment",
    "at the event's end" : "al final de l'esdeveniment",
    "{time} before the event starts" : "{time} abans que comenci l'esdeveniment",
    "{time} before the event ends" : "{time} abans de que acabi l'event",
    "{time} after the event starts" : "{time} després de que comenci l'event",
    "{time} after the event ends" : "{time} després de que acabi l'event",
    "on {time}" : "a les {time}",
    "on {time} ({timezoneId})" : "a les {time} ({timezoneId})",
    "Week {number} of {year}" : "Setmana {number} del {year}",
    "Does not repeat" : "No es repeteix",
    "Daily" : "Diàriament",
    "Weekly" : "Setmanalment",
    "Monthly" : "Mensualment",
    "Yearly" : "Anualment",
    "_Every %n day_::_Every %n days_" : ["Cada %n dia","Cada %n dies"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n setmana","Cada %n setmanes"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n mesos"],
    "_Every %n year_::_Every %n years_" : ["Cada %n any","Cada %n anys"],
    "_on {weekday}_::_on {weekdays}_" : ["el {weekday}","els {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["el dia {dayOfMonthList}","els dies {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "al {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "al {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "al {monthNames} al {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "fins el {untilDate}",
    "_%n time_::_%n times_" : ["%n vegada","%n vegades"],
    "Untitled event" : "Esdeveniment sense títol",
    "Untitled task" : "Tasca sense títol",
    "Please ask your administrator to enable the Tasks App." : "Demaneu al vostre administrador que habiliti l'aplicació de Tasques.",
    "Prev" : "Anterior",
    "Next" : "Següent",
    "Prev year" : "Any anterior",
    "Next year" : "Any següent",
    "Year" : "Any",
    "W" : "S",
    "%n more" : "%n més",
    "No events to display" : "No hi ha esdeveniments per visualitzar",
    "_+%n more_::_+%n more_" : ["i %n més","i %n més"],
    "No events" : "Cap esdeveniment",
    "Create a new event or change the visible time-range" : "Crea un esdeveniment nou o canvia l'interval de temps visible",
    "It might have been deleted, or there was a typo in a link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic en un enllaç",
    "It might have been deleted, or there was a typo in the link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic a l'enllaç",
    "Meeting room" : "Sala de reunions",
    "Lecture hall" : "Sala de lectura",
    "Seminar room" : "Sala de seminaris",
    "Other" : "Altres",
    "When shared show" : "Mostrar quan es comparteix",
    "When shared show full event" : "Quan es comparteix, mostra l'esdeveniment complet",
    "When shared show only busy" : "Quan es comparteix, mostra només si està ocupat",
    "When shared hide this event" : "Quan es comparteix, amaga aquest esdeveniment",
    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits.",
    "Add a location" : "Afegeix una ubicació",
    "Add a description" : "Afegir una descripció",
    "Status" : "Estat",
    "Confirmed" : "Confirmat",
    "Canceled" : "Cancel·lat",
    "Confirmation about the overall status of the event." : "Confirmació sobre l'estat general de l'esdeveniment.",
    "Show as" : "Mostra'm com a",
    "Take this event into account when calculating free-busy information." : "Tenir en compte aquest esdeveniment quan es calculi informació sobre disponibilitat-ocupació.",
    "Categories" : "Categories",
    "Categories help you to structure and organize your events." : "Les categories us ajuden a estructurar i organitzar els vostres esdeveniment.",
    "Search or add categories" : "Cerca o afegeix categories",
    "Add this as a new category" : "Afegeix-ho com una nova categoria",
    "Custom color" : "Color personalitzat",
    "Special color of this event. Overrides the calendar-color." : "Color especial per a aquest event. Sobreescriu el color del calendari.",
    "Chat room for event" : "Sala de xat per a l'esdeveniment",
    "Imported {filename}" : "{filename} importat",
    "Meditation" : "Meditació",
    "Relaxing" : "Relaxant",
    "Relax" : "Relax",
    "Break" : "Descans",
    "Commute" : "Desplaçament",
    "Commuting" : "En desplaçament",
    "Shuttle" : "Llançadora",
    "Invoice" : "Factura",
    "Finance" : "Finances",
    "Bank" : "Banc",
    "Money" : "Diners",
    "Wedding" : "Casament",
    "Dog" : "Gos",
    "Concert" : "Concert",
    "Festival" : "Festival",
    "Theater" : "Teatre",
    "Theatre" : "Teatre",
    "Presentation" : "Presentació",
    "Talk" : "Xerrada",
    "Speech" : "Discurs",
    "Deadline" : "Data límit",
    "Submission" : "Tramesa",
    "Reporting" : "Informes",
    "Camping" : "Acampada",
    "Camp" : "Campament",
    "Election" : "Elecció",
    "Voting" : "Votació",
    "Vote" : "Votació",
    "Barbecue" : "Barbacoa",
    "Barbeque" : "Barbacoa",
    "Garden" : "Jardí",
    "Farm" : "Granja",
    "Movie" : "Pel·lícula",
    "Cinema" : "Cinema",
    "Graduation" : "Graduació",
    "Brainstorm" : "Pluja d'idees",
    "Review" : "Revisió",
    "Audit" : "Auditoria",
    "Inspection" : "Inspecció",
    "Proofreading" : "Correcció de proves",
    "Baseball" : "Beisbol",
    "Meet" : "Reunió",
    "Planning" : "Planificació",
    "Pointing" : "Apuntant",
    "Retrospective" : "Retrospectiva",
    "Office" : "Oficina",
    "Contributor week" : "Setmana del contribuïdor",
    "Mail" : "Correu",
    "Soccer" : "Futbol",
    "Football" : "Futbol americà",
    "Gaming" : "Jugar",
    "Drive" : "Conduir",
    "Driving" : "Conducció",
    "Bicycle" : "Bicicleta",
    "Cycle" : "Ciclisme",
    "Cycling" : "Fer ciclisme",
    "Biking" : "Anar en bici",
    "Bike" : "Bicicleta",
    "Podcast" : "Podcast",
    "Basketball" : "Bàsquet",
    "Fishing" : "Pesca",
    "Hiking" : "Excursió",
    "Hike" : "Passejada",
    "Art" : "Art",
    "Exhibition" : "Exhibició",
    "Museum" : "Museu",
    "Pilates" : "Pilates",
    "Park" : "Parc",
    "Walk" : "Passeig",
    "Studying" : "Estudiar",
    "Doctor" : "Doctor",
    "Health" : "Salut",
    "Dentist" : "Dentista",
    "Hospital" : "Hospital",
    "Interview" : "Entrevista",
    "Training" : "Entrenament",
    "Practice" : "Pràctica",
    "Sports" : "Esport",
    "Exercise" : "Exercici",
    "Work out" : "Entrenament",
    "Working out" : "Entrenament",
    "Gym" : "Gimnàs",
    "Barber" : "Barber",
    "Haircut" : "Perruqueria",
    "Hairdresser" : "Perruquer",
    "Exam" : "Examen",
    "Written test" : "Prova escrita",
    "Oral test" : "Prova oral",
    "Working" : "Feina",
    "New Years Eve" : "Cap d'any",
    "NYE" : "Cap d'any",
    "Fireworks" : "Focs artificials",
    "Running" : "Córrer",
    "Go for a run" : "Sortir a córrer",
    "Marathon" : "Marató",
    "Video-conference" : "Videoconferència",
    "Conference-call" : "Trucada de conferència",
    "Video-call" : "Videotrucada",
    "Video-chat" : "Vídeo-xat",
    "Video-meeting" : "Vídeo-reunió",
    "Call" : "Trucada",
    "Calling" : "Trucar",
    "Christmas" : "Nadal",
    "Conference" : "Conferència",
    "Pizza" : "Pizza",
    "Travelling" : "Viatjar",
    "Trip" : "Viatge",
    "Journey" : "Viatge",
    "Collaborate" : "Col·laborar",
    "Pair" : "Parella",
    "Lecture" : "Classe",
    "Seminar" : "Seminari",
    "Teaching" : "Docència",
    "Photograph" : "Fotografia",
    "Party" : "Festa",
    "Celebration" : "Celebració",
    "Celebrate" : "Celebrar",
    "Birthday" : "Aniversari",
    "Shopping" : "Anar de compres",
    "Groceries" : "Comestibles",
    "Skate" : "Patinar",
    "Skateboard" : "Monopatí",
    "Wine tasting" : "Tasta de vins",
    "Golf" : "Golf",
    "Dinner" : "Sopar",
    "Lunch" : "Dinar",
    "Appointment not found" : "No s'ha trobat la cita",
    "User not found" : "No s'ha trobat l'usuari"
},
"nplurals=2; plural=(n != 1);");
