OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "ユーザーセッションが予期せず期限切れになりました",
    "Provided email-address is not valid" : "メールアドレスが有効ではありません",
    "%s has published the calendar »%s«" : "%sをカレンダー »%s«に登録しました",
    "Unexpected error sending email. Please contact your administrator." : "メール送信時の予期せぬエラー。管理者に連絡してください。",
    "Successfully sent email to %1$s" : "%1$sへのメール送信に成功しました",
    "Hello," : "こんにちは。",
    "We wanted to inform you that %s has published the calendar »%s«." : "%sがカレンダー»%s«に登録されましたのでお知らせします。",
    "Open »%s«" : "»%s«を開く",
    "Cheers!" : "それでは！",
    "Upcoming events" : "今後のイベント",
    "Appointments" : "予定",
    "Schedule an appointment" : "予定を入れる",
    "Dear %s, please confirm your booking" : "%s様、予定を承認してください。",
    "Confirm" : "承認",
    "This confirmation link expires in %s hours." : "承認用リンクの有効期限は1%s時間です。",
    "Date:" : "日時:",
    "Where:" : "場所:",
    "Calendar" : "カレンダー",
    "A Calendar app for Nextcloud" : "NextCloudのカレンダーアプリ",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "カレンダーアプリは、NextcloudのCalDAVサーバーのユーザーインターフェイスです。様々なデバイスからNextcloudにイベントを簡単に同期し、オンラインで編集することができます。\n\n* 🚀  **他のNextcloudアプリとの統合！ ** 現在、連絡先 - 今後も追加予定です。\n* 🌐 **WebCal サポート！ ** お気に入りのチームの試合日をカレンダーで見たいですか？問題ありません!\n* 🙋 **出席者！ **イベントに人を招待する\n* ⌚️ **空き時間/忙しい時間！ ** 出席者がいつ会うことができるかを確認します。\n* ⏰  **リマインダー！ ** ブラウザ内や電子メールでイベントのアラームを取得します。\n* 🔍 検索! 簡単にイベントを見つける\n* ☑️ タスク! 期限付きのタスクをカレンダーで直接確認できる\n* 🙈 **我々は「車輪の再発明」をしない！**偉大な[c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js)と [fullcalendar](https://github.com/fullcalendar/fullcalendar) ライブラリをベースにしたものです。",
    "Previous day" : "前日",
    "Previous week" : "前週",
    "Previous month" : "前月",
    "Next day" : "翌日",
    "Next week" : "翌週",
    "Next month" : "翌月",
    "New event" : "新しいイベント",
    "Today" : "今日",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "List" : "リスト",
    "Preview" : "プレビュー",
    "Copy link" : "リンクをコピー",
    "Edit" : "編集",
    "Delete" : "削除",
    "Appointment link was copied to clipboard" : "予定リンクがクリップボードにコピーされました",
    "Appointment link could not be copied to clipboard" : "予定リンクをクリップボードにコピーできませんでした",
    "Add new" : "新規作成",
    "Untitled calendar" : "無題のカレンダー",
    "Edit name" : "名前を編集",
    "Saving name …" : "名前を保存しています …",
    "Edit color" : "色を編集",
    "Saving color …" : "色を保存しています …",
    "Copy private link" : "プライベートリンクをコピー",
    "Export" : "エクスポート",
    "Unshare from me" : "共有を自分から解除",
    "An error occurred, unable to change visibility of the calendar." : "エラーが発生したため、カレンダーの表示状態を変更できません。",
    "An error occurred, unable to delete the calendar." : "エラーが発生したため、カレンダーを削除できません。",
    "Calendar link copied to clipboard." : "カレンダーリンクをクリップボードにコピー",
    "Calendar link could not be copied to clipboard." : "カレンダーリンクをクリップボードにコピーできませんでした。",
    "An error occurred, unable to rename the calendar." : "エラーが発生したため、カレンダーの名前を変更できません。",
    "An error occurred, unable to change the calendar's color." : "エラーが発生したため、カレンダーの色を変更できません。",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}秒後にカレンダーの共有を解除します"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown}秒後にカレンダーを削除します"],
    "Share link" : "URLで共有",
    "Publish calendar" : "カレンダーを公開",
    "Publishing calendar" : "カレンダーを公開しています",
    "Copy public link" : "公開リンクをコピー",
    "Send link to calendar via email" : "メールでカレンダーへのリンクを送信",
    "Enter one address" : "アドレスを1つ入力してください",
    "Sending email …" : "メールを送信中 …",
    "Copy subscription link" : "購読リンクをコピー",
    "Copying link …" : "リンクをコピーしています …",
    "Copied link" : "リンクをコピーしました",
    "Could not copy link" : "リンクをコピーできませんでした",
    "Copy embedding code" : "埋め込みコードをコピー",
    "Copying code …" : "コードをコピーしています …",
    "Copied code" : "コードをコピーしました",
    "Could not copy code" : "コードをコピーできませんでした",
    "Delete share link" : "共有リンクを削除",
    "Deleting share link …" : "共有リンクを削除しています …",
    "An error occurred, unable to publish calendar." : "エラーが発生したため、カレンダーを公開できません。",
    "An error occurred, unable to send email." : "エラーが発生したため、メールを送信できません。",
    "Embed code copied to clipboard." : "埋め込みコードをクリップボードにコピーしました。",
    "Embed code could not be copied to clipboard." : "埋め込みコードをクリップボードにコピーできませんでした。",
    "Unpublishing calendar failed" : "カレンダーの公開解除に失敗しました",
    "Share with users or groups" : "ユーザーまたはグループと共有する",
    "No users or groups" : "ユーザーまたはグループはありません",
    "can edit" : "編集を許可",
    "Unshare with {displayName}" : "{displayName}との共有を解除",
    "An error occurred, unable to change the unshare the calendar." : "エラーが発生したため、カレンダーの共有を解除できませんでした。",
    "An error occurred, unable to change the permission of the share." : "エラーが発生したため、共有の権限を変更できませんでした。",
    "New calendar" : "新しいカレンダー",
    "Name for new calendar" : "新しいカレンダーの名前",
    "Creating calendar …" : "カレンダーを作成中 …",
    "New calendar with task list" : "タスクリスト付きの新しいカレンダー",
    "New subscription from link (read-only)" : "リンクからの新規加入 (読み取り専用)",
    "Creating subscription …" : "購読を作成中 …",
    "An error occurred, unable to create the calendar." : "エラーが発生したため、カレンダーを作成できません。",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "有効なリンクを入力してください（http:// や https:// 、webcal:// または webcals:// のいずれかで始まる必要があります）",
    "Trash bin" : "ごみ箱",
    "Name" : "名前",
    "Deleted" : "削除済み",
    "Restore" : "復元",
    "Delete permanently" : "完全に削除する",
    "Empty trash bin" : "ゴミ箱を空にする",
    "Unknown calendar" : "不明なカレンダー",
    "Could not load deleted calendars and objects" : "削除されたカレンダーとオブジェクトを読み込めませんでした。",
    "Could not restore calendar or event" : "カレンダーまたはイベントを復元できませんでした。",
    "Do you really want to empty the trash bin?" : "本当にゴミ箱を空にしますか？",
    "Could not update calendar order." : "カレンダーの順番を更新できません。",
    "Import calendars" : "カレンダーのインポート",
    "Please select a calendar to import into …" : "インポートするカレンダーを選択してください …",
    "Filename" : "ファイル名",
    "Calendar to import into" : "インポートするカレンダー",
    "Cancel" : "キャンセル",
    "_Import calendar_::_Import calendars_" : ["カレンダーのインポート"],
    "{filename} could not be parsed" : "{filename} が解析できませんでした",
    "No valid files found, aborting import" : "有効なファイルが見つかりませんでした。インポートを中止します。",
    "Import partially failed. Imported {accepted} out of {total}." : "インポートが部分的に失敗しました。 {total}のうち{accepted}をインポートしました。",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%nイベントのインポートに成功しました"],
    "Automatic" : "自動",
    "Automatic ({detected})" : "自動 ({detected})",
    "New setting was not saved successfully." : "新しい設定は正常に保存されませんでした。",
    "Shortcut overview" : "概要",
    "or" : "或いは",
    "Navigation" : "ナビゲーション",
    "Previous period" : "前の期間",
    "Next period" : "次の期間",
    "Views" : "表示",
    "Day view" : "日表示",
    "Week view" : "週表示",
    "Month view" : "月表示",
    "List view" : "リスト表示",
    "Actions" : "アクション",
    "Create event" : "イベントを作成",
    "Show shortcuts" : "概要の表示",
    "Editor" : "エディタ",
    "Close editor" : "エディタを閉じる",
    "Enable birthday calendar" : "誕生日カレンダーを有効にする",
    "Show tasks in calendar" : "カレンダーにタスクを表示",
    "Enable simplified editor" : "簡易エディターを有効にする",
    "Limit visible events per view" : "表示するイベントを制限する",
    "Show weekends" : "週末を表示する",
    "Show week numbers" : "週番号を表示する",
    "Time increments" : "時間の増加",
    "Default reminder" : "既定のリマインダー",
    "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
    "Personal availability settings" : "個人の稼働率設定",
    "Show keyboard shortcuts" : "キーボード ショートカット",
    "No reminder" : "リマインダーなし",
    "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
    "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
    "Appointment was created successfully" : "予定の作成に成功しました。",
    "Appointment was updated successfully" : "予定は正常に更新されました。",
    "_{duration} minute_::_{duration} minutes_" : ["{duration}分"],
    "0 minutes" : "0分",
    "_{duration} hour_::_{duration} hours_" : ["{duration}時間"],
    "_{duration} day_::_{duration} days_" : ["{duration}日"],
    "_{duration} week_::_{duration} weeks_" : ["{duration}週間"],
    "_{duration} month_::_{duration} months_" : ["{duration}月"],
    "_{duration} year_::_{duration} years_" : ["{duration}年"],
    "To configure appointments, add your email address in personal settings." : "予定を設定するには、個人設定であなたのメールアドレスを追加してください。",
    "Public – shown on the profile page" : "公開 - プロフィールページに表示されます。",
    "Private – only accessible via secret link" : "非公開 - 秘密のリンクからしかアクセスできません。",
    "Location" : "場所",
    "Description" : "説明",
    "Visibility" : "公開レベル",
    "Duration" : "期間",
    "Increments" : "インクリメント",
    "Additional calendars to check for conflicts" : "コンフリクトを確認するための追加カレンダー",
    "Pick time ranges where appointments are allowed" : "予約可能な時間帯を選ぶ",
    "to" : "宛先",
    "Delete slot" : "スロットを削除",
    "No times set" : "時間設定なし",
    "Add" : "追加",
    "Monday" : "月曜日",
    "Tuesday" : "火曜日",
    "Wednesday" : "水曜日",
    "Thursday" : "木曜日",
    "Friday" : "金曜日",
    "Saturday" : "土曜日",
    "Sunday" : "日曜日",
    "Add time before and after the event" : "イベント前後の時間を追加",
    "Before the event" : "開催前",
    "After the event" : "イベント終了後",
    "Planning restrictions" : "プランニングの制限",
    "Minimum time before next available slot" : "次の空きスロットまでの最短時間",
    "Max slots per day" : "1日あたりの最大スロット数",
    "Limit how far in the future appointments can be booked" : "予約可能な時間帯の制限",
    "Create appointment" : "予定を作成",
    "Edit appointment" : "予定を編集",
    "Save" : "保存",
    "Update" : "アップデート",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "詳細をメールでお送りしました。メールに記載されているリンクから予約の確認をお願いします。これでこのページを閉じることができます。",
    "Your name" : "あなたの名前",
    "Your email address" : "あなたのメールアドレス",
    "Please share anything that will help prepare for our meeting" : "会議の準備に役立つことがあれば教えてください。",
    "Could not book the appointment. Please try again later or contact the organizer." : "予約できませんでした。後でもう一度試してみるか、主催者に連絡してください。",
    "Reminder" : "リマインダー",
    "before at" : "次の時間分早めに通知",
    "Notification" : "通知",
    "Email" : "メール",
    "Audio notification" : "音声通知",
    "Other notification" : "その他の通知",
    "Relative to event" : "相対時間",
    "On date" : "日時指定",
    "Edit time" : "時刻を変更",
    "Save time" : "時刻を保存",
    "Remove reminder" : "リマインダーを削除",
    "on" : "曜日",
    "at" : "で",
    "+ Add reminder" : "+ リマインダーを追加",
    "Add reminder" : "リマインダーを追加",
    "_second_::_seconds_" : ["秒"],
    "_minute_::_minutes_" : ["分"],
    "_hour_::_hours_" : ["時間"],
    "_day_::_days_" : ["日"],
    "_week_::_weeks_" : ["週"],
    "Available" : "利用可能",
    "Not available" : "利用できません",
    "Free" : "空き",
    "Busy (tentative)" : "ビジー (暫定)",
    "Busy" : "ビジー",
    "Out of office" : "オフィス外",
    "Unknown" : "不明",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "Tentative" : "暫定的",
    "Create Talk room for this event" : "このイベントに通話ルームを作成する",
    "Show busy times" : "忙しい時間を表示",
    "No attendees yet" : "出席者はまだいません",
    "Error creating Talk room" : "トークルームの作成に失敗しました",
    "Send email" : "メールを送信",
    "Chairperson" : "主宰者",
    "Required participant" : "参加必須",
    "Optional participant" : "任意参加",
    "Non-participant" : "非参加",
    "Remove attendee" : "出席者を削除",
    "No match found" : "一致するものが見つかりません",
    "(organizer)" : "（主催者）",
    "Remove color" : "色を削除",
    "Event title" : "イベントタイトル",
    "All day" : "終日",
    "from {startDate}" : "{startDate}から",
    "from {startDate} at {startTime}" : "{startDate}の{startTime}から",
    "to {endDate}" : "{endDate}まで",
    "to {endDate} at {endTime}" : "{endDate}の{endTime}まで",
    "Repeat" : "繰り返し",
    "End repeat" : "繰り返し終了",
    "Select to end repeat" : "繰り返しの終了を選択",
    "never" : "なし",
    "on date" : "日時指定",
    "after" : "後",
    "_time_::_times_" : ["回数"],
    "first" : "初日",
    "third" : "3日目",
    "fourth" : "4日目",
    "fifth" : "5日目",
    "second to last" : "2日目から最終日",
    "last" : "最後",
    "Repeat every" : "毎日繰り返す",
    "_month_::_months_" : ["月"],
    "_year_::_years_" : ["年"],
    "weekday" : "平日",
    "weekend day" : "週末",
    "Whiteboard" : "ホワイトボード",
    "available" : "利用可能",
    "unavailable" : "利用不可",
    "More" : "もっと見る",
    "Update this and all future" : "これ以降を更新",
    "Public calendar does not exist" : "公開カレンダーは存在しません",
    "Maybe the share was deleted or has expired?" : "共有が削除されたか、期限切れの可能性があります",
    "Please select a time zone:" : "タイムゾーンを選択してください：",
    "Pick a time" : "時間を指定",
    "Pick a date" : "日付を指定",
    "from {formattedDate}" : "{formattedDate}から",
    "to {formattedDate}" : "{formattedDate}まで",
    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}から",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}まで",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "有効な日付を入力してください",
    "Please enter a valid date and time" : "有効な日付と時刻を入力してください",
    "Type to search time zone" : "入力して時間帯を検索",
    "Global" : "グローバル",
    "Select date" : "日付を選択",
    "Appointment Details:" : "予定の詳細：",
    "Time:" : "時刻:",
    "Personal" : "個人",
    "No more events today" : "今日はこれ以上イベントがありません",
    "No upcoming events" : "今後のイベントはありません",
    "Create a new event" : "新しいイベントを作成",
    "[Today]" : "[今日]",
    "[Tomorrow]" : "[明日]",
    "[Yesterday]" : "[昨日]",
    "[Last] dddd" : "[Last]dddd",
    "Event does not exist" : "イベントは存在しません",
    "Delete this occurrence" : "この出来事を削除",
    "Details" : "詳細",
    "Attendees" : "参加者",
    "Resources" : "リソース",
    "Close" : "閉じる",
    "Show more details" : "詳細を見る",
    "Anniversary" : "記念日",
    "Appointment" : "アポイントメント",
    "Business" : "ビジネス",
    "Education" : "学校",
    "Holiday" : "休日",
    "Meeting" : "会議",
    "Miscellaneous" : "雑用",
    "Non-working hours" : "休業時間",
    "Not in office" : "欠勤",
    "Phone call" : "電話",
    "Sick day" : "体調不良",
    "Special occasion" : "特別な用事",
    "Travel" : "旅行",
    "Vacation" : "休暇",
    "at the event's start" : "イベント開始時",
    "at the event's end" : "イベント終了時",
    "{time} before the event starts" : "イベント開始 {time} 前",
    "{time} before the event ends" : "イベント終了 {time} 前",
    "{time} after the event starts" : "イベント開始 {time} 後",
    "{time} after the event ends" : "イベント終了 {time} 後",
    "Week {number} of {year}" : "{year}の{number} 週",
    "Does not repeat" : "繰り返さない",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Monthly" : "毎月",
    "Yearly" : "毎年",
    "_Every %n day_::_Every %n days_" : ["%n日ごと"],
    "_Every %n week_::_Every %n weeks_" : ["%n週ごと"],
    "_Every %n month_::_Every %n months_" : ["%n月ごと"],
    "_Every %n year_::_Every %n years_" : ["%n年ごと"],
    "_%n time_::_%n times_" : ["%n回"],
    "Untitled event" : "無題のイベント",
    "Untitled task" : "タイトルなしタスク",
    "Please ask your administrator to enable the Tasks App." : "「タスク」アプリを有効化のために、管理者さんにお問い合わせください",
    "Prev" : "前へ",
    "Next" : "次へ",
    "Prev year" : "去年",
    "Next year" : "来年",
    "Year" : "年",
    "W" : "W",
    "No events to display" : "表示するイベントはありません",
    "No events" : "イベントはありません",
    "Other" : "その他",
    "When shared show full event" : "共有時にすべてのイベントを表示",
    "When shared show only busy" : "共有時に実行中のみを表示",
    "When shared hide this event" : "共有時にこのイベントを隠す",
    "Add a location" : "住所を追加",
    "Add a description" : "説明を追加",
    "Status" : "ステータス",
    "Confirmed" : "確認済み",
    "Canceled" : "キャンセル済み",
    "Show as" : "として表示",
    "Categories" : "カテゴリ",
    "Search or add categories" : "カテゴリを検索または追加",
    "Add this as a new category" : "これを新しいカテゴリーとして追加",
    "Custom color" : "カスタム色",
    "Chat room for event" : "イベントのチャットルーム",
    "Meditation" : "座禅",
    "Relaxing" : "休暇",
    "Relax" : "休み",
    "Commuting" : "通勤中",
    "Finance" : "金融",
    "Bank" : "銀行",
    "Money" : "お金",
    "Wedding" : "結婚式",
    "Dog" : "犬",
    "Concert" : "演奏会",
    "Festival" : "祭",
    "Presentation" : "プレゼンテーション",
    "Talk" : "トーク",
    "Deadline" : "期限",
    "Camping" : "キャンプ場",
    "Camp" : "キャンプ",
    "Election" : "選挙",
    "Voting" : "投票",
    "Vote" : "投票",
    "Garden" : "花園",
    "Movie" : "ムービー",
    "Cinema" : "映画館",
    "Graduation" : "卒業式",
    "Brainstorm" : "会議",
    "Review" : "レビュー",
    "Baseball" : "野球",
    "Meet" : "打ち合わせ",
    "Planning" : "計画",
    "Office" : "オフィス",
    "Mail" : "メール",
    "Soccer" : "サッカー",
    "Football" : "フットボール",
    "Gaming" : "ゲーム",
    "Drive" : "ドライブ",
    "Driving" : "運転",
    "Bicycle" : "自転車",
    "Cycle" : "自転車",
    "Cycling" : "サイクリング",
    "Biking" : "サイクリング",
    "Bike" : "バイク",
    "Podcast" : "生放送",
    "Basketball" : "バスケットボール",
    "Fishing" : "釣り",
    "Hiking" : "ハイキング",
    "Hike" : "ハイキング",
    "Art" : "芸術",
    "Exhibition" : "展覧会",
    "Museum" : "美術館",
    "Pilates" : "ピラティス",
    "Park" : "公園",
    "Walk" : "散歩",
    "Studying" : "勉強",
    "Doctor" : "病院",
    "Health" : "診断",
    "Dentist" : "歯医者",
    "Hospital" : "病院",
    "Interview" : "インタビュー",
    "Training" : "トレーニング",
    "Sports" : "スポーツ",
    "Exercise" : "エクササイズ",
    "Work out" : "運動",
    "Working out" : "筋トレ",
    "Gym" : "ジム",
    "Barber" : "散髪",
    "Haircut" : "美容院",
    "Exam" : "試験",
    "Working" : "仕事",
    "New Years Eve" : "大晦日",
    "NYE" : "年越し",
    "Fireworks" : "花火",
    "Running" : "ランニング",
    "Go for a run" : "ジョギング",
    "Marathon" : "マラソン",
    "Video-conference" : "ビデオコンファレンス",
    "Conference-call" : "コンファレンスコール",
    "Video-call" : "ビデオコール",
    "Video-chat" : "ビデオチャット",
    "Video-meeting" : "ビデオミーティング",
    "Call" : "電話",
    "Calling" : "連絡",
    "Christmas" : "クリスマス",
    "Conference" : "カンファレンス",
    "Pizza" : "ピザ",
    "Travelling" : "旅行",
    "Trip" : "旅行",
    "Journey" : "旅",
    "Collaborate" : "一緒",
    "Pair" : "ペア",
    "Lecture" : "講義",
    "Seminar" : "ゼミ",
    "Teaching" : "授業",
    "Photograph" : "写真",
    "Party" : "パーティー",
    "Celebration" : "祝",
    "Celebrate" : "お祝い",
    "Birthday" : "誕生日",
    "Shopping" : "買い物",
    "Skate" : "スケート",
    "Skateboard" : "スケートボード",
    "Wine tasting" : "ワイン",
    "Golf" : "ゴルフ",
    "Dinner" : "ディナー",
    "Lunch" : "ランチ",
    "Appointment not found" : "予定が見つかりません",
    "User not found" : "ユーザーが見つかりません"
},
"nplurals=1; plural=0;");
