OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Η συνεδρία-χρήστη έληξε απότομα",
    "Provided email-address is not valid" : "Η διεύθυνση email δεν είναι έγκυρη",
    "%s has published the calendar »%s«" : "Ο/η %s έχει δημοσιεύσει το ημερολόγιο »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Απροσδόκητο σφάλμα στην αποστολή email. Παρακαλώ επικοινωνήστε με τον διαχειριστή.",
    "Successfully sent email to %1$s" : "Επιτυχής αποστολή email %1$s",
    "Hello," : "Γεια σας,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Θα θέλαμε να σας πληροφορήσουμε ότι  ο χρήστης %s δημοσίευσε το ημερολόγιο »%s«.",
    "Open »%s«" : "Άνοιγμα »%s«",
    "Cheers!" : "Με εκτίμηση!",
    "Upcoming events" : "Προσεχή γεγονότα",
    "Appointments" : "Ραντεβού",
    "Schedule appointment \"%s\"" : "Προγραμματίστε ραντεβού%s",
    "Schedule an appointment" : "Προγραμματίστε ένα ραντεβού",
    "Prepare for %s" : "Προετοιμασία για %s",
    "Follow up for %s" : "Επόμενο για %s",
    "Dear %s, please confirm your booking" : "Αγαπητέ/ή %s, παρακαλώ επιβεβαιώστε την κράτησή σας",
    "Confirm" : "Επιβεβαιώνω",
    "This confirmation link expires in %s hours." : "Αυτός ο σύνδεσμος επιβεβαίωσης λήγει σε %s ώρες",
    "Date:" : "Ημερομηνία:",
    "Where:" : "Που:",
    "Calendar" : "Ημερολόγιο",
    "A Calendar app for Nextcloud" : "Eφαρμογή ημερολογίου για το Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Η εφαρμογή Ημερολόγιο είναι μια διεπαφή χρήστη για τον διακομιστή CalDAV του Nextcloud. Συνχρονίστε εύκολα τα συμβάντα σας από διάφορες συσκευές με το Nextcloud και επεξεργαστείτε τα online.\n\n* 🚀 **Συνεργάζεται με άλλες εφαρμογές Nextcloud!** Επί του παρόντος με τις Επαφές - και με άλλες στο μέλλον.\n* 🌐 **Υποστήριξη WebCal!** Θέλετε να δείτε το πρόγραμμα της αγαπημένης σας ομάδας στο ημερολόγιό σας; Κανένα πρόβλημα!\n* 🙋 **Συμμετέχοντες!** Προσκαλέστε άτομα στις εκδηλώσεις σας.\n* ⌚️ **Ελεύθερος/Απασχολημένος!** Δείτε τη διαθεσιμότητα των συνεργατών σας για συνάντηση\n* ⏰ **Υπενθυμίσεις!** Λάβετε ειδοποιήσεις για γεγονότα στον περιηγητή σας ή στο ηλ.ταχυδρομείο σας.\n* 🔍 Αναζήτηση! Εντοπίστε εύκολα γεγονότα που σας ενδιαφέρουν\n* ☑️ Εργασίες! Δείτε τις εργασίες με ημερομηνία λήξεως απευθείας στο ημερολόγιο.\n* 🙈 **Δεν ανακαλύπτουμε τον τροχό!** Με βάση τις βιβλιοθήκες [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) ",
    "Previous day" : "Προηγούμενη ημέρα",
    "Previous week" : "Προηγούμενη εβδομάδα",
    "Previous month" : "Προηγούμενος μήνας",
    "Next day" : "Επόμενη ημέρα",
    "Next week" : "Επόμενη εβδομάδα",
    "Next month" : "Επόμενος μήνας",
    "New event" : "Νέο γεγονός",
    "Today" : "Σήμερα",
    "Day" : "Ημέρα",
    "Week" : "Εβδομάδα",
    "Month" : "Μήνας",
    "List" : "Λίστα",
    "Preview" : "Προεπισκόπηση",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Edit" : "Επεξεργασία",
    "Delete" : "Διαγραφή",
    "Appointment link was copied to clipboard" : "Ο σύνδεσμος του ραντεβού αντιγράφηκε στο πρόχειρο.",
    "Appointment link could not be copied to clipboard" : "Δεν ήταν δυνατή η αντιγραφή του συνδέσμου ραντεβού στο πρόχειρο.",
    "Add new" : "Προσθήκη νέου",
    "Untitled calendar" : "Ημερολόγιο χωρίς τίτλο",
    "Edit name" : "Επεξεργασία ονόματος",
    "Saving name …" : "Αποθήκευση ονόματος …",
    "Edit color" : "Επεξεργασία χρώματος",
    "Saving color …" : "Αποθήκευση χρώματος …",
    "Copy private link" : "Αντιγραφή ιδιωτικού συνδέσμου",
    "Export" : "Εξαγωγή",
    "Unshare from me" : "Διακοπή διαμοιρασμού με εμένα",
    "Disable calendar \"{calendar}\"" : "Απενεργοποίηση ημερολογίου \"{calendar}\"",
    "Disable untitled calendar" : "Απενεργοποίηση ημερολογίου χωρίς τίτλο",
    "Enable calendar \"{calendar}\"" : "Ενεργοποίηση ημερολογίου \"{calendar}\"",
    "Enable untitled calendar" : "Ενεργοποίηση ημερολογίου χωρίς τίτλο",
    "An error occurred, unable to change visibility of the calendar." : "Παρουσιάστηκε σφάλμα, δεν δύναται να αλλάξει η εμφάνιση του ημερολογίου.",
    "An error occurred, unable to delete the calendar." : "Παρουσιάστηκε σφάλμα, δεν δύναται να διαγραφή το ημερολόγιο.",
    "Calendar link copied to clipboard." : "Ο σύνδεσμος ημερολογίου αντιγράφηκε στο πρόχειρο.",
    "Calendar link could not be copied to clipboard." : "Ο σύνδεσμος ημερολογίου δεν μπορεί να αντιγραφή στο πρόχειρο.",
    "An error occurred, unable to rename the calendar." : "Παρουσιάστηκε σφάλμα, δεν δύναται να αλλαχτεί το όνομα του ημερολογίου.",
    "An error occurred, unable to change the calendar's color." : "Παρουσιάστηκε σφάλμα, δεν μπορεί να αλλάξει το χρώμα του ημερολογίου.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Αφαίρεση κοινής χρήσης ημερολογίου σε {countdown} δεύτερα","Αφαίρεση κοινής χρήσης ημερολογίου σε {countdown} δευτερόλεπτα"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Διαγραφή ημερολογίου σε {countdown} δεύτερα","Διαγραφή ημερολογίου σε {countdown} δευτερόλεπτα"],
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Publish calendar" : "Δημοσίευση ημερολογίου",
    "Publishing calendar" : "Δημοσίευση ημερολογίου",
    "Copy public link" : "Αντιγραφή δημόσιου συνδέσμου",
    "Send link to calendar via email" : "Αποστολή συνδέσμου στο ημερολόγιο μέσω email",
    "Enter one address" : "Εισαγωγή μίας διεύθυνσης",
    "Sending email …" : "Αποστολή email  '...'",
    "Copy subscription link" : "Αντιγραφή συνδέσμου συνδρομής",
    "Copying link …" : "Αντιγραφή συνδέσμου '...'",
    "Copied link" : "Αντιγραμμένος σύνδεσμος",
    "Could not copy link" : "Ο σύνδεσμος δεν μπορεί να αντιγραφεί",
    "Copy embedding code" : "Αντιγραφή ενσωματωμένου κώδικα",
    "Copying code …" : "Αντιγραφή κώδικα '...'",
    "Copied code" : "Αντιγραμμένος κώδικας",
    "Could not copy code" : "Ο κώδικας δεν μπορεί να αντιγραφεί",
    "Delete share link" : "Διαγραφή κοινόχρηστου συνδέσμου",
    "Deleting share link …" : "Διαγραφή κοινόχρηστου συνδέσμου '...'",
    "An error occurred, unable to publish calendar." : "Παρουσιάστηκε σφάλμα, δεν θα δημοσιευτεί το ημερολόγιο.",
    "An error occurred, unable to send email." : "Παρουσιάστηκε σφάλμα, δεν θα σταλεί το email.",
    "Embed code copied to clipboard." : "Ο ενσωματωμένος κώδικας αντιγράφηκε στο πρόχειρο.",
    "Embed code could not be copied to clipboard." : "Ο ενσωματωμένος κώδικας δεν μπορεί να αντιγραφεί στο πρόχειρο.",
    "Unpublishing calendar failed" : "Η κατάργηση δημοσιευμένου ημερολογίου απέτυχε",
    "Share with users or groups" : "Κοινή χρήση με χρήστες ή ομάδες",
    "No users or groups" : "Δεν υπάρχουν χρήστες ή ομάδες",
    "can edit" : "δυνατότητα επεξεργασίας",
    "Unshare with {displayName}" : "Κατάργηση κοινής χρήσης με {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Παρουσιάστηκε σφάλμα, δεν είναι δυνατή η αλλαγή της κατάργησης της κοινής χρήσης του ημερολογίου.",
    "An error occurred, unable to change the permission of the share." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η αλλαγή των δικαιωμάτων της κοινής χρήσης.",
    "New calendar" : "Νέο ημερολόγιο",
    "Name for new calendar" : "Όνομα για νέο ημερολόγιο.",
    "Creating calendar …" : "Δημιουργία ημερολογίου '...'",
    "New calendar with task list" : "Νέο ημερολόγιο με λίστα εργασιών",
    "New subscription from link (read-only)" : "Νέα συνδρομή από τον σύνδεσμο (μόνο για ανάγνωση)",
    "Creating subscription …" : "Δημιουργία συνδρομής ...",
    "An error occurred, unable to create the calendar." : "Παρουσιάστηκε σφάλμα, δεν μπορεί να δημιουργηθεί το ημερολόγιο.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Παρακαλώ εισάγετε έγκυρο σύνδεσμο (ξεκινούν με http://, https://, webcal://, ή webcals://)",
    "Trash bin" : "Κάδος απορριμμάτων",
    "Loading deleted items." : "Φόρτωση διαγραμμένων στοιχείων.",
    "You do not have any deleted items." : "Δεν έχετε διαγραμμένα στοιχεία.",
    "Name" : "Όνομα",
    "Deleted" : "Διαγράφηκε",
    "Restore" : "Επαναφορά",
    "Delete permanently" : "Οριστική διαγραφή",
    "Empty trash bin" : "Άδειασμα κάδου",
    "Untitled item" : "Στοιχείο χωρίς όνομα",
    "Unknown calendar" : "Άγνωστο ημερολόγιο",
    "Could not load deleted calendars and objects" : "Δεν ήταν δυνατή η φόρτωση διαγραμμένων ημερολογίων και αντικειμένων",
    "Could not restore calendar or event" : "Δεν ήταν δυνατή η επαναφορά ημερολογίου ή συμβάντος",
    "Do you really want to empty the trash bin?" : "Θέλετε να αδειάσετε τον κάδο απορριμμάτων;",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Τα στοιχεία στον κάδο απορριμμάτων διαγράφονται μετά από {numDays} ημέρα","Τα στοιχεία στον κάδο απορριμμάτων διαγράφονται μετά από {numDays} ημέρες"],
    "Could not update calendar order." : "Δεν μπορεί να γίνει ενημέρωση εντολών ημερολογίου.",
    "Import calendars" : "Εισαγωγή ημερολογίων",
    "Please select a calendar to import into …" : "Παρακαλώ επιλέξτε ημερολόγιο για εισαγωγή σε  ...",
    "Filename" : "Όνομα αρχείου",
    "Calendar to import into" : " Ημερολόγιο για εισαγωγή σε ",
    "Cancel" : "Ακύρωση",
    "_Import calendar_::_Import calendars_" : ["Εισαγωγή ημερολογίου","Εισαγωγή ημερολογίων"],
    "{filename} could not be parsed" : "το {filename} δεν μπορεί να αναλυθεί",
    "No valid files found, aborting import" : "Δεν βρέθηκαν συμβατά αρχεία, ακύρωση εισαγωγής",
    "Import partially failed. Imported {accepted} out of {total}." : "Η εισαγωγή απέτυχε εν μέρει. Εισήχθησαν {accepted} από {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Επιτυχής εισαγωγή %n συμβάν","Επιτυχής εισαγωγή %n συμβάντων"],
    "Automatic" : "Αυτόματο",
    "Automatic ({detected})" : "Αυτόματα ({detected})",
    "New setting was not saved successfully." : "Οι νέες ρυθμίσεις δεν αποθηκεύτηκαν επιτυχώς.",
    "Shortcut overview" : "Επισκόπηση συντόμευσης",
    "or" : "ή",
    "Navigation" : "Πλοήγηση",
    "Previous period" : "Προηγούμενη περίοδος",
    "Next period" : "Επόμενη περίοδος",
    "Views" : "Προβολές",
    "Day view" : "Εμφάνιση ημέρας",
    "Week view" : "Εμφάνιση εβδομάδας",
    "Month view" : "Εμφάνιση μήνα",
    "List view" : "Προβολή λίστας",
    "Actions" : "Ενέργειες",
    "Create event" : "Δημιουργία συμβάντος",
    "Show shortcuts" : "Εμφάνιση συντομεύσεων",
    "Save edited event" : "Αποθήκευση επεξεργασμένης εκδήλωσης",
    "Delete edited event" : "Διαγραφή επεξεργασμένης εκδήλωσης",
    "Duplicate event" : "Αντιγραφή εκδήλωσης",
    "Enable birthday calendar" : "Ενεργοποίηση ημερολογίου γενεθλίων",
    "Show tasks in calendar" : "Εμφάνιση εργασιών στο ημερολόγιο",
    "Enable simplified editor" : "Ενεργοποίηση απλοποιημένου προγράμματος επεξεργασίας",
    "Limit visible events per view" : "Περιορισμός ορατών γεγονότων ανά σελίδα",
    "Show weekends" : "Εμφάνιση σαββατοκύριακων",
    "Show week numbers" : "Εμφάνιση αριθμού εβδομάδας",
    "Time increments" : "Χρόνος μεταξύ δυο ραντεβού",
    "Default reminder" : "Προεπιλεγμένη υπενθύμιση",
    "Copy primary CalDAV address" : "Αντιγραφή κύριας διεύθυνσης CalDAV",
    "Copy iOS/macOS CalDAV address" : "Αντιγραφή διεύθυνσης iOS/macOS CalDAV",
    "Personal availability settings" : "Ρυθμίσεις προσωπικής διαθεσιμότητας",
    "Show keyboard shortcuts" : "Εμφάνιση συντομεύσεων πληκτρολογίου",
    "Calendar settings" : "Ρυθμίσεις ημερολογίου",
    "No reminder" : "Χωρίς υπενθύμιση",
    "CalDAV link copied to clipboard." : "Αντιγράφηκε στο πρόχειρο ο σύνδεσμος CalDAV",
    "CalDAV link could not be copied to clipboard." : "Δεν αντιγράφηκε στο πρόχειρο ο σύνδεσμος CalDAV",
    "Appointment was created successfully" : "Το ραντεβού σας δημιουργήθηκε επιτυχώς",
    "Appointment was updated successfully" : "Το ραντεβού σας ενημερώθηκε επιτυχώς",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} λεπτό","{duration} λεπτά"],
    "0 minutes" : "0  λεπτά",
    "_{duration} hour_::_{duration} hours_" : ["{duration} ώρα","{duration} ώρες"],
    "_{duration} day_::_{duration} days_" : ["{duration} ημέρα","{duration} ημέρες"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} εβδομάδα","{duration} εβδομάδες"],
    "_{duration} month_::_{duration} months_" : ["{duration} μήνα","{duration} μήνες"],
    "_{duration} year_::_{duration} years_" : ["{duration} χρόνο","{duration} χρόνια"],
    "To configure appointments, add your email address in personal settings." : "Για να ρυθμίσετε τα ραντεβού σας, προσθέστε την διεύθυνση email στις προσωπικές ρυθμίσεις",
    "Public – shown on the profile page" : "Δημόσιο - εμφανίζεται στο προφίλ",
    "Private – only accessible via secret link" : "Ιδιωτικό - προσβάσιμο μόνο μέσω κρυφού συνδέσμου",
    "Location" : "Τοποθεσία",
    "Description" : "Περιγραφή",
    "Visibility" : "Ορατότητα",
    "Duration" : "Διάρκεια",
    "Increments" : "Χρόνος μεταξύ δυο ραντεβού",
    "Additional calendars to check for conflicts" : "Επιπρόσθετα ημερολόγια για τον έλεγχο κωλυμάτων",
    "Pick time ranges where appointments are allowed" : "Επιλέξτε το χρονικό περιθώριο οπου επιτρέπονται τα ραντεβού",
    "to" : "προς",
    "Delete slot" : "Διαγραφή θέσης",
    "No times set" : "Δεν υπάρχουν χρόνοι",
    "Add" : "Προσθήκη",
    "Monday" : "Δευτέρα",
    "Tuesday" : "Τρίτη",
    "Wednesday" : "Τετάρτη",
    "Thursday" : "Πέμπτη",
    "Friday" : "Παρασκευή",
    "Saturday" : "Σάββατο",
    "Sunday" : "Κυριακή",
    "Add time before and after the event" : "Προσθέστε χρόνο πριν και μετά από το γεγονός",
    "Before the event" : "Πριν το γεγονός",
    "After the event" : "Μετά το γεγονός",
    "Planning restrictions" : "Περιορισμοί σχεδιασμού",
    "Minimum time before next available slot" : "Ελάχιστος χρόνος πριν το επόμενο διαθέσιμο κενό",
    "Max slots per day" : "Μέγιστες θέσεις ανά ημέρα",
    "Limit how far in the future appointments can be booked" : "Περιορίστε πόσο μακριά μπορούν να κανονιστούν μελλοντικά ραντεβού",
    "Create appointment" : "Δημιουργία ραντεβού",
    "Edit appointment" : "Επεξεργασία ραντεβού",
    "Save" : "Αποθήκευση",
    "Update" : "Ενημέρωση",
    "Please confirm your reservation" : "Επιβεβαιώστε την κράτησή σας",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Σας στείλαμε ενα email με τις λεπτομέρειες. Παρακαλούμε να επιβεβαιώσετε το ραντεβού κάνοντας χρήση του συνδέσμου στο email. Μπορείτε να κλείσετε αυτή την σελίδα ",
    "Your name" : "Το όνομά σας",
    "Your email address" : "Η διεύθυνση ηλεκτρονικού ταχυδρομείου σας",
    "Please share anything that will help prepare for our meeting" : "Παρακαλούμε να μοιραστείτε οτιδήποτε θα βοηθούσε στην προετοιμασία της συνάντησης",
    "Could not book the appointment. Please try again later or contact the organizer." : "Δεν μπορέσαμε να κανουμε την κράτηση του ραντεβού. Παρακαλώ δοκιμάστε ξανά αργότερα ή επικοινωνήστε με τον διοργανωτή",
    "Book the appointment" : "Κλείστε το ραντεβού",
    "Reminder" : "Υπενθύμιση",
    "before at" : "πριν από το",
    "Notification" : "Ειδοποίηση",
    "Email" : "Ηλ. ταχυδρομείο",
    "Audio notification" : "Ηχητική ειδοποίηση",
    "Other notification" : "Άλλη ειδοποίηση",
    "Relative to event" : "Σχετικά με το συμβάν",
    "On date" : "Την ημερομηνία",
    "Edit time" : "Επεξεργασία ώρας",
    "Save time" : "Εξοικονόμηση χρόνου",
    "Remove reminder" : "Διαγραφή υπενθύμισης",
    "on" : "σε",
    "at" : "στις",
    "+ Add reminder" : "+ Προσθήκη υπενθύμισης",
    "Add reminder" : "Προσθήκη υπενθύμισης",
    "_second_::_seconds_" : ["δευτερόλεπτο","δευτερόλεπτα"],
    "_minute_::_minutes_" : ["λεπτό","λεπτά"],
    "_hour_::_hours_" : ["ώρα","ώρες"],
    "_day_::_days_" : ["ημέρα","ημέρες"],
    "_week_::_weeks_" : ["εβδομάδα","εβδομάδες"],
    "Invitation accepted" : "Η πρόσκληση έγινε αποδεκτή.",
    "Available" : "Διαθέσιμα",
    "Suggested" : "Προτεινόμενο",
    "Participation marked as tentative" : "Η συμμετοχή χαρακτηρίστηκε ως με επιφύλαξη",
    "Accepted {organizerName}'s invitation" : "Αποδοχή της πρόσκλησης του/της {organizerName}",
    "Not available" : "Δεν είναι διαθέσιμο",
    "Invitation declined" : "Η πρόσκληση απορρίφθηκε.",
    "Declined {organizerName}'s invitation" : "Απόρριψη της πρόσκλησης του {organizerName}",
    "Invitation is delegated" : "Η πρόσκληση παραπέμφθηκε",
    "Checking availability" : "Έλεγχος διαθεσιμότητας",
    "Invitation sent" : "Η πρόσκληση εστάλη",
    "Has not responded to {organizerName}'s invitation yet" : "Δεν έχετε απαντήσει ακόμα στην πρόσκληση του/της {organizerName}",
    "Availability of attendees, resources and rooms" : "Διαθεσιμότητα των συμμετεχόντων, των πόρων και των δωματίων",
    "{organizer} (organizer)" : "{organizer} (διοργανωτής)",
    "Free" : "Ελεύθερος",
    "Busy (tentative)" : "Απασχολημένος (με επιφύλαξη)",
    "Busy" : "Απασχολημένος",
    "Out of office" : "Εκτός γραφείου",
    "Unknown" : "Άγνωστο",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Tentative" : "Με επιφύλαξη",
    "The invitation has been accepted successfully." : "Η πρόσκληση έγινε αποδεκτή",
    "Failed to accept the invitation." : "Αποτυχία αποδοχής της πρόσκλησης",
    "The invitation has been declined successfully." : "Η πρόσκληση έχει απορριφθεί επιτυχώς",
    "Failed to decline the invitation." : "Αποτυχία απόρριψης της πρόσκλησης",
    "Your participation has been marked as tentative." : "Η συμμετοχή έχει χαρακτηρίστεί ως δοκιμαστική",
    "Failed to set the participation status to tentative." : "Αποτυχία αλλαγής κατάστασης συμμετοχής σε δοκιμαστική.",
    "Create Talk room for this event" : "Δημιουργία δωματίου Talk για το γεγονός",
    "Show busy times" : "Εμφάνιση απασχολημένων ωρών",
    "No attendees yet" : "Δεν υπάρχουν ακόμη συμμετέχοντες",
    "Successfully appended link to talk room to description." : "Ο σύνδεσμος στο δωμάτιο Talk προστέθηκε με επιτυχία στην περιγραφή.",
    "Error creating Talk room" : "Σφάλμα δημιουργίας δωματίου Talk",
    "Send email" : "Αποστολή email",
    "Chairperson" : "Επικεφαλής",
    "Required participant" : "Απαιτείται συμμετοχή",
    "Optional participant" : "Προαιρετική συμμετοχή",
    "Non-participant" : "Μη-συμμετέχοντας",
    "Remove attendee" : "Κατάργηση του συμμετέχοντα",
    "Search for emails, users or contacts" : "Αναζήτηση για ηλ. διευθύνσεις, χρήστες ή επαφές",
    "No match found" : "Δεν βρέθηκε αποτέλεσμα.",
    "(organizer)" : "(organizer)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Για να στείλετε προσκλήσεις και να χειριστείτε τις απαντήσεις, [linkopen]προσθέστε το email σας στις προσωπικές ρυθμίσεις [linkclose].",
    "Remove color" : "Αφαίρεση χρώματος",
    "Event title" : "Τίτλος γεγονότος",
    "All day" : "Ολοήμερο",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Δεν είναι δυνατή η τροποποίηση της ρύθμισης ολοήμερου συμβάντος που αποτελεί μέρος σετ-επανάληψης.",
    "from {startDate}" : "από {startDate}",
    "from {startDate} at {startTime}" : "από {startDate} στις {startTime}",
    "to {endDate}" : "έως {endDate}",
    "to {endDate} at {endTime}" : "έως {endDate} στις {endTime}",
    "Repeat" : "Επανάληψη",
    "End repeat" : "Τέλος επανάληψης",
    "Select to end repeat" : "Επιλέξτε για διακοπή επανάληψης",
    "never" : "ποτέ",
    "on date" : "την ημερομηνία",
    "after" : "μετά",
    "_time_::_times_" : ["φορά","φορές"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Αυτό το συμβάν είναι επανάληψη-εξαίρεση ενός σετ-επανάληψης. Δεν μπορείτε να προσθέσετε κανόνα επανάληψης σε αυτό.",
    "first" : "πρώτο",
    "third" : "τρίτο",
    "fourth" : "τέταρτο",
    "fifth" : "πέμπτο",
    "second to last" : "προτελευταίο",
    "last" : "τελευταίο",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Οι αλλαγές στον κανόνα-επανάληψης θα ισχύουν μόνο για αυτό και για όλα τα μελλοντικά συμβάντα.",
    "Repeat every" : "Επανάληψη κάθε",
    "By day of the month" : "Την ημέρα του μήνα",
    "On the" : "Στο",
    "_month_::_months_" : ["μήνας","μήνες"],
    "_year_::_years_" : ["έτος","έτη"],
    "weekday" : "καθημερινή",
    "weekend day" : "ημέρα Σαββατοκύριακου",
    "No recurrence" : "Καμμία επανάληψη",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Ο τρόπος επανάληψης αυτού του συμβάντος δεν υποστηρίζεται πλήρως από το Nextcloud. Αν επεξεργαστείτε τις επιλογές επανάληψης, ορισμένες επαναλήψεις ενδέχεται να χαθούν.",
    "Suggestions" : "Προτάσεις",
    "No rooms or resources yet" : "Κανένα δωμάτιο ή πόροι ακόμα",
    "Add resource" : "Προσθήκη πηγής",
    "Has a projector" : "Έχει προβολέα",
    "Has a whiteboard" : "Έχει λευκό πίνακα γραφής",
    "Wheelchair accessible" : "Προσβάσιμο με αναπηρικό καρότσι",
    "Remove resource" : "Αφαίρεση πόρου",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} θέση","{seatingCapacity} θέσεις"],
    "Projector" : "Projector",
    "Whiteboard" : "Λευκός πίνακας",
    "Search for resources or rooms" : "Αναζήτηση για πόρους ή δωμάτια",
    "available" : "διαθέσιμο",
    "unavailable" : "μη διαθέσιμο",
    "Room type" : "Τύπος δωματίου",
    "Any" : "Οποιοδήποτε",
    "Minimum seating capacity" : "Ελάχιστος αριθμός θέσεων",
    "More" : "Περισσότερα",
    "Update this occurrence" : "Ενημερώστε αυτό το περιστατικό",
    "Update this and all future" : "Ενημερώστε αυτό και όλα τα μελλοντικά",
    "Public calendar does not exist" : "Το δημόσιο ημερολόγιο δεν υπάρχει",
    "Maybe the share was deleted or has expired?" : "Ίσως το κοινόχρηστο διαγράφηκε ή δεν υπάρχει;",
    "Please select a time zone:" : "Παρακαλούμε επιλέξτε χρονική ζώνη:",
    "Pick a time" : "Επιλογή χρόνου",
    "Pick a date" : "Επιλογή ημερομηνίας",
    "from {formattedDate}" : "από {formattedDate}",
    "to {formattedDate}" : "έως {formattedDate}",
    "on {formattedDate}" : "σε {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "από {formattedDate} στις {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "έως {formattedDate} στις {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "σε {formattedDate} στις {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} στις {formattedTime}",
    "Please enter a valid date" : "Παρακαλώ εισάγετε έγκυρη ημερομηνία",
    "Please enter a valid date and time" : "Παρακαλώ εισάγετε έγκυρη ημερομηνία και ώρα",
    "Type to search time zone" : "Πληκτρολογήστε για αναζήτηση χρονικής ζώνης",
    "Global" : "Καθολικό",
    "Select date" : "Επιλέξτε ημερομηνία",
    "Select slot" : "Επιλογή θέσης",
    "No slots available" : "Καμμια διαθέσιμη θέση",
    "The slot for your appointment has been confirmed" : "H θέση σας για το ραντεβού σας έχει επιβεβαιωθεί",
    "Appointment Details:" : "Λεπτομέρειες Ραντεβού",
    "Time:" : "Χρόνος:",
    "Booked for:" : "Κρατηση για",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Ευχαριστούμε. Η κράτησή σας απο {startDate} εώς {endDate} έχει επιβεβαιωθεί.",
    "Book another appointment:" : "Κλείστε ένα άλλο ραντεβού:",
    "See all available slots" : "Δείτε όλες τις διαθέσιμες θέσεις",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Το κενό για το ραντεβού σας απο {startDate} to {endDate} δεν είναι διαθέσιμο πιά.",
    "Please book a different slot:" : "Παρακαλώ καντε κράτηση σε διαφορετικό κενό:",
    "Book an appointment with {name}" : "Κάντε κράτηση για ραντεβού με τον/την {name}",
    "No public appointments found for {name}" : "Δεν βρέθηκαν ραντεβού για τον/την {name}",
    "Personal" : "Προσωπικά",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Η αυτόματη επιλογή χρονικής ζώνης καθορίστηκε σε UTC.\nΑυτό συμβαίνει συνήθως λόγω ρυθμίσεων ασφαλείας του περιηγητή σας.\nΠαρακαλούμε επιλέξτε τη χρονική ζώνη χειροκίνητα από τις ρυθμίσεις ημερολογίου.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Η χρονική ζώνη ({timezoneId}) που καθορίσατε δεν βρέθηκε. Επαναφορά σε UTC.\nΠαρακαλούμε αλλάξτε τη χρονική ζώνη σας από τις ρυθμίσεις και αναφέρετε το σφάλμα.",
    "No more events today" : "Δεν υπάρχουν άλλα γεγονότα για σήμερα",
    "No upcoming events" : "Κανένα προσεχές γεγονός",
    "Create a new event" : "Δημιουργία νέου γεγονότος",
    "[Today]" : "[Σήμερα]",
    "[Tomorrow]" : "[Αύριο]",
    "[Yesterday]" : "[Χθες]",
    "[Last] dddd" : "[Last] ηηηη",
    "Event does not exist" : "Δεν υπάρχει το γεγονός",
    "Delete this occurrence" : "Διαγράψτε το περιστατικό",
    "Delete this and all future" : "Διαγράψτε αυτό και όλα τα μελλοντικά",
    "Details" : "Λεπτομέρειες",
    "Attendees" : "Συμμετέχοντες",
    "Resources" : "Πηγές",
    "Close" : "Κλείσιμο",
    "Show more details" : "Δείτε περισσότερες λεπτομέρειες",
    "Subscribe to {name}" : "Εγγραφείτε στον {name}",
    "Export {name}" : "Εξαγωγη {name}",
    "Anniversary" : "Επέτειος",
    "Appointment" : "Ραντεβού",
    "Business" : "Επιχείρηση",
    "Education" : "Εκπαίδευση",
    "Holiday" : "Διακοπές",
    "Meeting" : "Συνάντηση",
    "Miscellaneous" : "Διάφορα",
    "Non-working hours" : "Μη εργάσιμες ώρες",
    "Not in office" : "Εκτός γραφείου",
    "Phone call" : "Τηλεφωνική κλήση",
    "Sick day" : "Ημέρα ανάρρωσης",
    "Special occasion" : "Ειδική περίπτωση",
    "Travel" : "Ταξίδι",
    "Vacation" : "Διακοπές",
    "Midnight on the day the event starts" : "Τα μεσάνυχτα της ημέρας που ξεκινά το γεγονός",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n ημέρα πριν το γεγονός σε {formattedHourMinute}","%n ημέρες πριν το γεγονός σε {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n εβδομάδα πριν το γεγονός σε {formattedHourMinute}","%n εβδομάδες πριν το γεγονός σε {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "την ημέρα της γεγονότος σε {formattedHourMinute}",
    "at the event's start" : "στην έναρξη του γεγονότος",
    "at the event's end" : "στο τέλος του γεγονότος",
    "{time} before the event starts" : "{time} πριν την έναρξη του γεγονότος",
    "{time} before the event ends" : "{time} πριν τη λήξη του γεγονότος",
    "{time} after the event starts" : "{time} μετά την έναρξη του γεγονότος",
    "{time} after the event ends" : "{time} μετά τη λήξη του γεγονότος",
    "on {time}" : "στις {time}",
    "on {time} ({timezoneId})" : "στις {time} ({timezoneId})",
    "Week {number} of {year}" : "Εβδομάδα {number} του {year}",
    "Does not repeat" : "Δεν επαναλαμβάνεται",
    "Daily" : "Ημερησίως",
    "Weekly" : "Εβδομαδιαίως",
    "Monthly" : "Μηνιαίως",
    "Yearly" : "Ετησίως",
    "_Every %n day_::_Every %n days_" : ["Κάθε %n ημέρα","Κάθε %n ημέρες"],
    "_Every %n week_::_Every %n weeks_" : ["Κάθε %n εβδομάδα","Κάθε %n εβδομάδες"],
    "_Every %n month_::_Every %n months_" : ["Κάθε %n μήνα","Κάθε %n μήνες"],
    "_Every %n year_::_Every %n years_" : ["Κάθε %n χρόνο","Κάθε %n χρόνια"],
    "_on {weekday}_::_on {weekdays}_" : ["σε {weekday}","σε {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["σε ημέρα {dayOfMonthList}","σε ημέρες {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "την {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "τον {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "τον {monthNames} στις {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "έως {untilDate}",
    "_%n time_::_%n times_" : ["%n φορά","%n φορές"],
    "Untitled event" : "Συμβάν χωρίς τίτλο",
    "Untitled task" : "Εργασία χωρίς όνομα",
    "Please ask your administrator to enable the Tasks App." : "Παρακαλώ ζητήστε από τον διαχειριστή την ενεργοποίηση της εφαρμογής Εργασίες.",
    "Prev" : "Προηγούμενο",
    "Next" : "Επόμενο",
    "Prev year" : "Προηγούμενο έτος",
    "Next year" : "Επόμενο έτος",
    "Year" : "Έτος",
    "W" : "Εβδ",
    "%n more" : "%n επιπλέον",
    "No events to display" : "Κανένα γεγονός για εμφάνιση",
    "_+%n more_::_+%n more_" : ["+ %n επιπλέον","+ %n επιπλέον"],
    "No events" : "Κανένα γεγονός",
    "Create a new event or change the visible time-range" : "Δημιουργήστε ένα νέο γεγονός ή αλλάξτε το χρονικό όριο εμφάνισης.",
    "It might have been deleted, or there was a typo in a link" : "Ίσως έχει διαγραφεί, ή υπάρχει λάθος στην πληκτρολόγηση του συνδέσμου.",
    "It might have been deleted, or there was a typo in the link" : "Ίσως έχει διαγραφεί, ή υπάρχει λάθος στην πληκτρολόγηση του συνδέσμου.",
    "Meeting room" : "Δωμάτιο σύσκεψης",
    "Lecture hall" : "Αίθουσα διδασκαλίας",
    "Seminar room" : "Χώρος σεμιναρίων",
    "Other" : "Άλλο",
    "When shared show" : "Εμφάνιση με τον διαμοιρασμό",
    "When shared show full event" : "Προβολή πλήρους συμβάντος, όταν κοινοποιείται",
    "When shared show only busy" : "Όταν είναι σε κοινή χρήση να προβάλλονται μόνο απασχολημένοι ",
    "When shared hide this event" : "Απόκρυψη αυτού του συμβάντος, όταν κοινοποιείται",
    "The visibility of this event in shared calendars." : "Η ορατότητα του γεγονότος στα ημερολόγια κοινής χρήσης.",
    "Add a location" : "Προσθήκη τοποθεσίας",
    "Add a description" : "Προσθήκη περιγραφής",
    "Status" : "Κατάσταση",
    "Confirmed" : "Επιβεβαιώθηκε",
    "Canceled" : "Ακυρώθηκε",
    "Confirmation about the overall status of the event." : "Επιβεβαίωση της συνολικής κατάστασης του γεγονότος.",
    "Show as" : "Εμφάνιση ως",
    "Take this event into account when calculating free-busy information." : "Λαβετε υποψιν αυτο το γεγονός οταν υπολογίζετε την πληροφορια διαθεσιμος-κατειλημμένος",
    "Categories" : "Κατηγορίες",
    "Categories help you to structure and organize your events." : "Οι κατηγορίες σας βοηθούν να δομήσετε και να οργανώσετε τα γεγονότα σας",
    "Search or add categories" : "Αναζήτηση ή προσθήκη κατηγοριών",
    "Add this as a new category" : "Προσθήκη αυτού σε νέα κατηγορία",
    "Custom color" : "Προσαρμοσμένο χρώμα",
    "Special color of this event. Overrides the calendar-color." : "Ειδικό χρώμα αυτού του γεγονότος. Υπερισχύει του ημερολογίου.",
    "Chat room for event" : "Χώρος άμεσων μηνυμάτων για το γεγονός ",
    "Imported {filename}" : "Εισηγμένο {filename}",
    "Meditation" : "Διαλογισμός",
    "Relaxing" : "Χαλάρωση",
    "Relax" : "Ξεκούραση",
    "Break" : "Διάλειμμα",
    "Commute" : "Μετακίνηση προς την εργασία",
    "Commuting" : "Μετακίνηση",
    "Invoice" : "Tιμολόγιο",
    "Finance" : "Χρηματοοικονομικά",
    "Bank" : "Τράπεζα",
    "Money" : "Χρήματα",
    "Wedding" : "Γάμος",
    "Dog" : "Σκύλος",
    "Concert" : "Συναυλία",
    "Festival" : "Φεστιβάλ",
    "Theater" : "Θέατρο",
    "Theatre" : "Θέατρο",
    "Presentation" : "Παρουσίαση",
    "Talk" : "Ομιλία",
    "Speech" : "Λόγος",
    "Deadline" : "Προθεσμία",
    "Submission" : "Υποβολή",
    "Reporting" : "Αναφορά",
    "Camping" : "Κατασκήνωση",
    "Camp" : "Κατασκήνωση",
    "Election" : "Εκλογή",
    "Voting" : "Ψηφοφορία",
    "Vote" : "Ψήφος",
    "Garden" : "Κήπος",
    "Farm" : "Φάρμα",
    "Movie" : "Ταινία",
    "Cinema" : "Σινεμά",
    "Graduation" : "Αποφοίτηση",
    "Brainstorm" : "Καταιγισμός ιδεών",
    "Review" : "Επισκόπηση",
    "Audit" : "Έλεγχος",
    "Inspection" : "Επιθεώρηση",
    "Proofreading" : "Γρήγορη ανάγνωση",
    "Baseball" : "Μπέιζμπολ",
    "Meet" : "Συνάντηση",
    "Planning" : "Σχεδιασμός",
    "Pointing" : "Επισήμανση",
    "Retrospective" : "Αναδρομικά",
    "Office" : "Γραφείο",
    "Contributor week" : "Εβδομάδα συνεργάτη",
    "Mail" : "Αλληλογραφία",
    "Soccer" : "Ποδόσφαιρο",
    "Football" : "Ποδόσφαιρο",
    "Gaming" : "Παιχνίδια",
    "Drive" : "Οδήγηση",
    "Driving" : "Οδήγηση",
    "Bicycle" : "Ποδήλατο",
    "Cycle" : "Cycle",
    "Cycling" : "Ποδηλασία",
    "Biking" : "Ποδηλασία",
    "Bike" : "Ποδήλατο",
    "Podcast" : "Podcast",
    "Basketball" : "Μπάσκετ",
    "Fishing" : "Ψάρεμα",
    "Hiking" : "Πεζοπορία",
    "Hike" : "Πεζοπόρος",
    "Art" : "Τέχνη",
    "Exhibition" : "Εκθεση",
    "Museum" : "Μουσείο",
    "Pilates" : "Πιλάτες",
    "Park" : "Πάρκο",
    "Walk" : "Περίπατος",
    "Studying" : "Μελέτη",
    "Doctor" : "Ιατρός",
    "Health" : "Υγεία",
    "Dentist" : "Οδοντίατρος",
    "Hospital" : "Νοσοκομείο",
    "Interview" : "Συνέντευξη",
    "Training" : "Training",
    "Practice" : "Πρακτική",
    "Sports" : "Αθλήματα",
    "Exercise" : "Ασκηση",
    "Work out" : "Work out",
    "Working out" : "Working out",
    "Gym" : "Γυμναστήριο",
    "Barber" : "Μπαρμπέρης",
    "Haircut" : "Κόμμωση",
    "Hairdresser" : "Κουρείο",
    "Exam" : "Εξετάσεις",
    "Written test" : "Γραπτή εξέταση",
    "Oral test" : "Προφορική εξέταση",
    "Working" : "Εργαζόμενος",
    "New Years Eve" : "Πρωτοχρονιά",
    "NYE" : "Νέα χρονιά",
    "Fireworks" : "Πυροτεχνήματα",
    "Running" : "Τρέξιμο",
    "Go for a run" : "Πηγαίνετε για ένα τρέξιμο",
    "Marathon" : "Μαραθώνιος",
    "Video-conference" : "Τηλεδιάσκεψη",
    "Conference-call" : "Κλήση τηλεδιάσκεψης",
    "Video-call" : "Κλήση βίντεο",
    "Video-chat" : "Video-chat",
    "Video-meeting" : "Video-συνάντηση",
    "Call" : "Κλήση",
    "Calling" : "Σε κλήση",
    "Christmas" : "Χριστούγεννα",
    "Conference" : "Διάσκεψη",
    "Pizza" : "Πίτσα",
    "Travelling" : "Ταξιδεύοντας",
    "Trip" : "Εκδρομή",
    "Journey" : "Διαδρομή",
    "Collaborate" : "Συνεργασία",
    "Pair" : "Ζεύγος",
    "Lecture" : "Διάλεξη",
    "Seminar" : "Σεμινάριο",
    "Teaching" : "Διδασκαλία",
    "Photograph" : "Φωτογραφία",
    "Party" : "Πάρτυ",
    "Celebration" : "Εορτασμός",
    "Celebrate" : "Εορτασμός",
    "Birthday" : "Γενέθλια",
    "Shopping" : "Ψώνια",
    "Groceries" : "Ψώνια",
    "Skate" : "Πατινάζ",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Γευσιγνωσία κρασιού",
    "Golf" : "Γκόλφ",
    "Dinner" : "Δείπνο",
    "Lunch" : "Γεύμα",
    "Appointment not found" : "Το ραντεβού δεν βρέθηκε",
    "User not found" : "Ο/Η χρήστης δεν βρέθηκε"
},
"nplurals=2; plural=(n != 1);");
