OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "A felhasználói munkamenet váratlanul lejárt",
    "Provided email-address is not valid" : "A megadott e-mail-cím nem érvényes",
    "%s has published the calendar »%s«" : "%s közzétette ezt a naptárt: „%s”",
    "Unexpected error sending email. Please contact your administrator." : "Váratlan hiba üzenetküldéskor. Lépjen kapcsolatba a rendszergazdával.",
    "Successfully sent email to %1$s" : "E-mail sikeresen elküldve ide: %1$s",
    "Hello," : "Üdv,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Szeretnénk tájékoztatni, hogy %s közzétette ezt a naptárt: „%s”.",
    "Open »%s«" : "„%s” megnyitása",
    "Cheers!" : "Üdv!",
    "Upcoming events" : "Közelgő események",
    "Appointments" : "Találkozók",
    "Schedule appointment \"%s\"" : "A(z) „%s” találkozó ütemezése",
    "Schedule an appointment" : "Találkozó ütemezése",
    "Prepare for %s" : "Előkészülés erre: %s",
    "Follow up for %s" : "Utókövetés ehhez: %s",
    "Dear %s, please confirm your booking" : "Kedves %s, erősítse meg a foglalását",
    "Confirm" : "Megerősítés",
    "This confirmation link expires in %s hours." : "Ez a megerősítő hivatkozás %s óra múlva lejár.",
    "Date:" : "Dátum:",
    "Where:" : "Hely:",
    "Calendar" : "Naptár",
    "A Calendar app for Nextcloud" : "Naptár alkalmazás a Nextcloudhoz",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "A Naptár alkalmazás egy felhasználói felület a Nextcloud CalDAV kiszolgálójához. Könnyen szinkronizálhatja a különböző eszközökről származó eseményeket a Nextcloud segítségével, és szerkesztheti azokat online.\n\n* 🚀 ** Integráció más nextcloudos alkalmazásokkal. ** Jelenleg a Névjegyekkel – de még több várható.\n* 🌐 ** WebCal támogatás. ** Szeretné megnézni kedvenc csapata mérkőzéseit a naptárában? Nem probléma.\n* 🙋 ** Résztvevők. ** Hívjon meg embereket az eseményeire\n* ⌚️ ** Szabad/elfoglalt. ** Nézze meg, mikor állnak rendelkezésre a résztvevők\n* ⏰ ** Emlékeztetők! ** Riasztásokat kaphat az eseményekről a böngészőben és e-mailben\n* 🔍 Keresés. Keresse meg eseményeit egyszerűen\n* ☑️ Feladatok. Az esedékes dátummal rendelkező feladatokat közvetlenül a naptárban láthatja\n* 🙈 ** Nem találjuk fel újra a kereket. ** A nagyszerű [c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) és [fullcalendar](https://github.com/fullcalendar/fullcalendar) programkönyvtárak használatával.",
    "Previous day" : "Előző nap",
    "Previous week" : "Előző hét",
    "Previous month" : "Előző hónap",
    "Next day" : "Következő nap",
    "Next week" : "Következő hét",
    "Next month" : "Következő hónap",
    "New event" : "Új esemény",
    "Today" : "Ma",
    "Day" : "Nap",
    "Week" : "Hét",
    "Month" : "Hónap",
    "List" : "Lista",
    "Preview" : "Előnézet",
    "Copy link" : "Hivatkozás másolása",
    "Edit" : "Szerkesztés",
    "Delete" : "Törlés",
    "Appointment link was copied to clipboard" : "Találkozóhivatkozás vágólapra másolva",
    "Appointment link could not be copied to clipboard" : "A találkozóhivatkozást nem sikerült a vágólapra másolni",
    "Add new" : "Új hozzáadása",
    "Untitled calendar" : "Névtelen naptár",
    "Edit name" : "Név szerkesztése",
    "Saving name …" : "Név mentése…",
    "Edit color" : "Színek szerkesztése",
    "Saving color …" : "Szín mentése…",
    "Copy private link" : "Személyes hivatkozás másolása",
    "Export" : "Exportálás",
    "Unshare from me" : "Megosztás visszavonása",
    "Disable calendar \"{calendar}\"" : "A(z) „{calendar}” naptár letiltása",
    "Disable untitled calendar" : "Névtelen naptár letiltása",
    "Enable calendar \"{calendar}\"" : "A(z) „{calendar}” naptár engedélyezése",
    "Enable untitled calendar" : "Névtelen naptár engedélyezése",
    "An error occurred, unable to change visibility of the calendar." : "Hiba lépett fel, a naptár kinézetét nem lehet megváltoztatni.",
    "An error occurred, unable to delete the calendar." : "Hiba lépett fel, a naptárat nem lehet törölni.",
    "Calendar link copied to clipboard." : "Naptári hivatkozás vágólapra másolva.",
    "Calendar link could not be copied to clipboard." : "Naptári hivatkozást nem lehet vágólapra másolni.",
    "An error occurred, unable to rename the calendar." : "Hiba lépett fel, a naptárat nem lehet átnevezni.",
    "An error occurred, unable to change the calendar's color." : "Hiba lépett fel, a naptár színét nem lehet megváltoztatni.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Megosztás leállítása {countdown} másodperc múlva","Megosztás leállítása {countdown} másodperc múlva"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Naptár törlése {countdown} másodperc múlva","Naptár törlése {countdown} másodperc múlva"],
    "Share link" : "Megosztás hivatkozással",
    "Publish calendar" : "Naptár megosztása",
    "Publishing calendar" : "Naptár megosztása",
    "Copy public link" : "Nyilvános hivatkozás másolása",
    "Send link to calendar via email" : "Naptárhivatkozás küldése e-mailben",
    "Enter one address" : "Adjon meg egy címet",
    "Sending email …" : "E-mail küldése…",
    "Copy subscription link" : "Feliratkozási hivatkozás másolása",
    "Copying link …" : "Hivatkozás másolása…",
    "Copied link" : "Hivatkozás másolva",
    "Could not copy link" : "A hivatkozást nem lehet másolni",
    "Copy embedding code" : "Beágyazó kód másolása",
    "Copying code …" : "Kód másolása…",
    "Copied code" : "Kód lemásolva",
    "Could not copy code" : "A kódot nem lehet másolni",
    "Delete share link" : "Megosztási hivatkozás törlése",
    "Deleting share link …" : "Megosztott hivatkozás törlése…",
    "An error occurred, unable to publish calendar." : "Hiba lépett fel, nem lehet közzétenni a naptárat.",
    "An error occurred, unable to send email." : "Hiba lépett fel, nem lehet e-mailt küldeni.",
    "Embed code copied to clipboard." : "A beágyazó kód vágólapra másolva.",
    "Embed code could not be copied to clipboard." : "A beágyazó kód vágólapra másolása sikertelen.",
    "Unpublishing calendar failed" : "Naptár közzétételének visszavonása sikertelen",
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "No users or groups" : "Nincsenek felhasználók vagy csoportok",
    "can edit" : "szerkesztheti",
    "Unshare with {displayName}" : "Megosztás megszüntetése a következővel: {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Hiba történt, nem lehet visszavonni a naptár megosztását.",
    "An error occurred, unable to change the permission of the share." : "Hiba történt, nem lehet megváltoztatni a megosztás jogosultságait.",
    "New calendar" : "Új naptár",
    "Name for new calendar" : "Új naptár neve",
    "Creating calendar …" : "Naptár létrehozása…",
    "New calendar with task list" : "Új naptár feladatlistával",
    "New subscription from link (read-only)" : "Új feliratkozás hivatkozásból (csak olvasható)",
    "Creating subscription …" : "Feliratkozás létrehozása…",
    "An error occurred, unable to create the calendar." : "Hiba történt, a naptárat nem lehet létrehozni.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Érvényes hivatkozást adjon meg (ezek egyikével kezdődjön: http://, https://, webcal://, vagy webcals://)",
    "Trash bin" : "Kuka",
    "Name" : "Név",
    "Deleted" : "Törölt",
    "Restore" : "Helyreállítás",
    "Delete permanently" : "Végleges törlés",
    "Empty trash bin" : "Kuka ürítése",
    "Untitled item" : "Névtelen elem",
    "Unknown calendar" : "Ismeretlen naptár",
    "Could not load deleted calendars and objects" : "A törölt naptárak és objektumok nem tölthetők be",
    "Could not restore calendar or event" : "A naptár vagy esemény nem állítható helyre",
    "Do you really want to empty the trash bin?" : "Biztos, hogy üríti a kukát?",
    "Could not update calendar order." : "Nem sikerült frissíteni a naptárak sorrendjét.",
    "Import calendars" : "Naptárak importálása",
    "Please select a calendar to import into …" : "Válasszon naptárat, amelybe importál…",
    "Filename" : "Fájlnév",
    "Calendar to import into" : "Naptár importálva ide:",
    "Cancel" : "Mégse",
    "_Import calendar_::_Import calendars_" : ["Naptár importálása","Naptárak importálása"],
    "{filename} could not be parsed" : "A {filename} nem dolgozható fel",
    "No valid files found, aborting import" : "Nem található érvényes fájl, importálás megszakítva",
    "Import partially failed. Imported {accepted} out of {total}." : "Az importálás részlegesen sikertelen. {accepted} / {total} lett importálva.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n esemény sikeresen importálva","%n esemény sikeresen importálva"],
    "Automatic" : "Automatikus",
    "Automatic ({detected})" : "Automatikus ({detected})",
    "New setting was not saved successfully." : "Az új beállítások nem lettek elmentve.",
    "Shortcut overview" : "Gyorsbillentyűk áttekintése",
    "or" : "vagy",
    "Navigation" : "Navigáció",
    "Previous period" : "Előző időszak",
    "Next period" : "Következő időszak",
    "Views" : "Megtekintések",
    "Day view" : "Nap nézet",
    "Week view" : "Hét nézet",
    "Month view" : "Hónap nézet",
    "List view" : "Lista nézet",
    "Actions" : "Műveletek",
    "Create event" : "Esemény létrehozása",
    "Show shortcuts" : "Gyorsbillentyűk megjelenítése",
    "Editor" : "Szerkesztő",
    "Close editor" : "Szerkesztő bezárása",
    "Save edited event" : "Szerkesztett esemény mentése",
    "Delete edited event" : "Szerkesztett esemény törlése",
    "Duplicate event" : "Esemény megkettőzése",
    "Enable birthday calendar" : "Születésnapokat tartalamzó naptár engedélyezése",
    "Show tasks in calendar" : "Feladatok megjelenítése a naptárban",
    "Enable simplified editor" : "Egyszerűsített szerkesztő engedélyezése",
    "Limit visible events per view" : "Látható események számának korlátozása nézetenként",
    "Show weekends" : "Hétvégék megjelenítése",
    "Show week numbers" : "Hetek számának megjelenítése",
    "Time increments" : "Idő lépésköze",
    "Default reminder" : "Alapértelmezett emlékeztető",
    "Copy primary CalDAV address" : "Elsődleges CalDAV cím másolása",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV cím másolása",
    "Personal availability settings" : "Személyes elérhetőség beállításai",
    "Show keyboard shortcuts" : "Billentyűparancsok megjelenítése",
    "Calendar settings" : "Naptár beállításai",
    "No reminder" : "Nincs emlékeztető",
    "CalDAV link copied to clipboard." : "CalDAV hivatkozás vágólapra másolva.",
    "CalDAV link could not be copied to clipboard." : "A CalDAV hivatkozást nem lehet vágólapra másolni.",
    "Appointment was created successfully" : "A találkozó sikeresen létrehozva.",
    "Appointment was updated successfully" : "A találkozó sikeresen frissítve.",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} perc","{duration} perc"],
    "0 minutes" : "0 perc",
    "_{duration} hour_::_{duration} hours_" : ["{duration} óra","{duration} óra"],
    "_{duration} day_::_{duration} days_" : ["{duration} nap","{duration} nap"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} hét","{duration} hét"],
    "_{duration} month_::_{duration} months_" : ["{duration} hónap","{duration} hónap"],
    "_{duration} year_::_{duration} years_" : ["{duration} év","{duration} év"],
    "To configure appointments, add your email address in personal settings." : "A találkozók testreszabásához adja hozzá az e-mail-címét a személyes beállításokban.",
    "Public – shown on the profile page" : "Nyilvános – megjelenik a profiloldalán",
    "Private – only accessible via secret link" : "Privát – csak titkos hivatkozáson keresztül érhető el",
    "Location" : "Hely",
    "Description" : "Leírás",
    "Visibility" : "Láthatóság",
    "Duration" : "Időtartam",
    "Increments" : "Lépésköz",
    "Additional calendars to check for conflicts" : "További naptárak az ütközés-ellenőrzéshez",
    "Pick time ranges where appointments are allowed" : "Válasszon időszakokat, amikor a találkozók engedélyezettek",
    "to" : "–",
    "Delete slot" : "Idősáv törlése",
    "No times set" : "Nincs idő megadva",
    "Add" : "Hozzáadás",
    "Monday" : "hétfő",
    "Tuesday" : "kedd",
    "Wednesday" : "szerda",
    "Thursday" : "csütörtök",
    "Friday" : "péntek",
    "Saturday" : "szombat",
    "Sunday" : "vasárnap",
    "Add time before and after the event" : "Idő hozzáadása az esemény előtt és után",
    "Before the event" : "Esemény előtt",
    "After the event" : "Esemény utá",
    "Planning restrictions" : "Tervezési korlátozások",
    "Minimum time before next available slot" : "A következő szabad idősáv előtti minimális idő",
    "Max slots per day" : "Napi idősávok legnagyobb száma",
    "Limit how far in the future appointments can be booked" : "Korlátozás, hogy mennyivel előre lehessen találkozót foglalni",
    "Create appointment" : "Találkozó létrehozása",
    "Edit appointment" : "Találkozó szerkesztése",
    "Save" : "Mentés",
    "Update" : "Frissítés",
    "Please confirm your reservation" : "Erősítse meg a foglalását",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Küldtünk egy e-mailt a részletekkel. Erősítse meg a találkozót a levélben található hivatkozással. Bezárhatja ezt az oldalt.",
    "Your name" : "Az Ön neve",
    "Your email address" : "Az Ön e-mail-címe",
    "Please share anything that will help prepare for our meeting" : "Osszon meg mindent, amely segít a találkozóra felkészüléshez",
    "Could not book the appointment. Please try again later or contact the organizer." : "A találkozót nem sikerült lefoglalni. Próbálja újra, vagy lépjen kapcsolatba a szervezővel.",
    "Book the appointment" : "Találkozó lefoglalása",
    "Reminder" : "Emlékeztető",
    "before at" : "előtt",
    "Notification" : "Értesítés",
    "Email" : "E-mail",
    "Audio notification" : "Hangértesítés",
    "Other notification" : "Egyéb értesítés",
    "Relative to event" : "Az eseményhez viszonyítva",
    "On date" : "Időpontban",
    "Edit time" : "Idő szerkesztése",
    "Save time" : "Időpont mentése",
    "Remove reminder" : "Értesítés eltávolítása",
    "on" : "be",
    "at" : "ekkor: ",
    "+ Add reminder" : "+ Emlékeztető hozzáadása",
    "Add reminder" : "Emlékeztető hozzáadása",
    "_second_::_seconds_" : ["másodperc","másodperc"],
    "_minute_::_minutes_" : ["perc","perce"],
    "_hour_::_hours_" : ["óra","óra"],
    "_day_::_days_" : ["nap","nap"],
    "_week_::_weeks_" : ["hét","hét"],
    "Invitation accepted" : "Meghívás elfogadva",
    "Available" : "Elérhető",
    "Suggested" : "Javasolt",
    "Participation marked as tentative" : "A részvétel feltételesként jelölve",
    "Accepted {organizerName}'s invitation" : "Elfogadta {organizerName} meghívását",
    "Not available" : "Nem érhető el",
    "Invitation declined" : "Meghívás elutasítva",
    "Declined {organizerName}'s invitation" : "Elutasította {organizerName} meghívását",
    "Invitation is delegated" : "Meghívás átruházva",
    "Checking availability" : "Elérhetőség ellenőrzése",
    "Invitation sent" : "Meghívó elküldve",
    "Has not responded to {organizerName}'s invitation yet" : "Még nem válaszolt {organizerName} meghívására",
    "Availability of attendees, resources and rooms" : "A résztvevők, az erőforrások és a szobák rendelkezésre állása",
    "{organizer} (organizer)" : "{organizer} (szervező)",
    "Free" : "Szabad",
    "Busy (tentative)" : "Foglalt (feltételes)",
    "Busy" : "Foglalt",
    "Out of office" : "Irodán kívül",
    "Unknown" : "Ismeretlen",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "Tentative" : "Feltételes",
    "The invitation has been accepted successfully." : "A meghívása sikeresen elfogadva.",
    "Failed to accept the invitation." : "A meghívás elfogadása sikertelen.",
    "The invitation has been declined successfully." : "A meghívás sikeresen elutasítva.",
    "Failed to decline the invitation." : "A meghívás elutasítása sikertelen.",
    "Your participation has been marked as tentative." : "A részvétele feltételesnek lett jelölve.",
    "Failed to set the participation status to tentative." : "A részvétele feltételesként megadása sikertelen.",
    "Create Talk room for this event" : "Beszélgetés szoba létrehozása ehhez az eseményhez",
    "Show busy times" : "Elfoglalt idők megjelenítése",
    "No attendees yet" : "Még nincs résztvevő",
    "Successfully appended link to talk room to description." : "Beszélgetés szoba hivatkozásának a leíráshoz csatolása sikeres.",
    "Error creating Talk room" : "Hiba a Beszélgetés szoba létrehozásakor",
    "Send email" : "E-mail küldése",
    "Chairperson" : "Elnök",
    "Required participant" : "Kötelező résztvevő",
    "Optional participant" : "Opcionális résztvevő",
    "Non-participant" : "Nem résztvevő",
    "Remove attendee" : "Résztvevő eltávolítása",
    "Search for emails, users or contacts" : "E-mailek, felhasználók és névjegyek keresése",
    "No match found" : "Nem található egyezés",
    "(organizer)" : "(szervező)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Meghívók elküldéséhez és a válaszok kezeléséhez [linkopen]adja meg e-mail-címét a személyes beállításokban[linkclose].",
    "Remove color" : "Szín eltávolítása",
    "Event title" : "Esemény címe",
    "All day" : "Egész napos",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Az ismétlődő események egész napos beállítása nem módosítható.",
    "from {startDate}" : "ettől: {startDate}",
    "from {startDate} at {startTime}" : "ettől: {startDate} {startTime}",
    "to {endDate}" : "eddig: {endDate}",
    "to {endDate} at {endTime}" : "eddig: {endDate} {endTime}",
    "Repeat" : "Ismétlés",
    "End repeat" : "Ismétlés vége",
    "Select to end repeat" : "Válassza az ismétlés befejezéséhez",
    "never" : "soha",
    "on date" : "dátumon",
    "after" : "után",
    "_time_::_times_" : ["alkalommal","alkalommal"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ez az esemény egy ismétlődő esemény nem ismétlődő kivétele. Nem adhat hozzá ismétlődési szabályt.",
    "first" : "első",
    "third" : "harmadik",
    "fourth" : "negyedik",
    "fifth" : "ötödik",
    "second to last" : "utolsó előtti",
    "last" : "utolsó",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Az ismétlődési szabály változásai csak erre és minden jövőbeli eseményre vonatkoznak.",
    "Repeat every" : "Ismétlés minden",
    "By day of the month" : "A hónap ezen napján",
    "On the" : "Ekkor: ",
    "_month_::_months_" : ["hónap","hónapok"],
    "_year_::_years_" : ["év","évek"],
    "weekday" : "hétköznap",
    "weekend day" : "hétvége",
    "No recurrence" : "Nincs ismétlődés",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Az esemény ismétlődésének megadását a Nextcloud nem támogatja teljes mértékben. Az ismétlődési lehetőségek szerkesztésekor bizonyos ismétlődések elveszhetnek.",
    "Suggestions" : "Javaslatok",
    "No rooms or resources yet" : "Még nincsenek szobák vagy erőforrások",
    "Add resource" : "Erőforrás hozzáadása",
    "Has a projector" : "Van kivetítő",
    "Has a whiteboard" : "Van fehér tábla",
    "Wheelchair accessible" : "Kerekesszékkel megközelíthető",
    "Remove resource" : "Erőforrás eltávolítása",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} hely","{seatingCapacity} hely"],
    "Projector" : "Kivetítő",
    "Whiteboard" : "Tábla",
    "Search for resources or rooms" : "Szobák vagy erőforrások keresése",
    "available" : "elérhető",
    "unavailable" : "nem érhető el",
    "Room type" : "Szoba típusa",
    "Any" : "Bármely",
    "Minimum seating capacity" : "Ülőhelyek legkisebb száma",
    "More" : "Több",
    "Update this occurrence" : "Ezen előfordulás frissítése",
    "Update this and all future" : "Ezen és az összes jövőbeli frissítése",
    "Public calendar does not exist" : "Nyilvános naptár nem létezik",
    "Maybe the share was deleted or has expired?" : "Lehet, hogy a megosztást törölték, vagy lejárt?",
    "Please select a time zone:" : "Válasszon egy időzónát:",
    "Pick a time" : "Válasszon egy időt",
    "Pick a date" : "Válasszon egy dátumot",
    "from {formattedDate}" : "ettől: {formattedDate}",
    "to {formattedDate}" : "eddig: {formattedDate}",
    "on {formattedDate}" : "ekkor: {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "ettől: {formattedDate} {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "eddig: {formattedDate} {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "ekkor: {formattedDate} {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "Adjon meg egy érvényes dátumot",
    "Please enter a valid date and time" : "Adjon meg egy érvényes dátumot és időt",
    "Type to search time zone" : "Gépeljen az időzóna kereséséhez",
    "Global" : "Globális",
    "Select date" : "Válasszon dátumot",
    "Select slot" : "Válasszon idősávot",
    "No slots available" : "Nincs elérhető idősáv",
    "The slot for your appointment has been confirmed" : "A találkozó idősávja megerősítésre került",
    "Appointment Details:" : "Találkozó részletei:",
    "Time:" : "Idő:",
    "Booked for:" : "Részére lefoglalva:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Köszönjük. A(z) {startdate} és {stopdate} közti foglalása megerősítésre került",
    "Book another appointment:" : "Másik találkozó lefoglalása:",
    "See all available slots" : "Összes elérhető idősáv megtekintése",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "A(z) {startdate} és {stopdate} közti találkozójának idősávja már nem érhető el.",
    "Please book a different slot:" : "Foglaljon egy másik idősávban:",
    "Book an appointment with {name}" : "Találkozó lefoglalása a következővel: {name}",
    "No public appointments found for {name}" : "Nem találhatók nyilvános találkozók a következővel: {name}",
    "Personal" : "Személyes",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Az automatikus időzóna-észlelés UTC-nek észlelte az időzónáját.\nEz valószínűleg a böngésző biztonsági beállításai miatt van.\nÁllítsa be az időzónáját kézzel a naptárbeállításokban.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "A beállított időzóna ({timezoneId}) nem található. Visszaállás UTC-re.\nMódosítsa az időzónát a beállításokban, és jelentse be ezt a hibát.",
    "No more events today" : "Ma nincs több esemény",
    "No upcoming events" : "Nincsenek közelgő események",
    "Create a new event" : "Új esemény létrehozása",
    "[Today]" : "[Ma]",
    "[Tomorrow]" : "[Holnap]",
    "[Yesterday]" : "[Tegnap]",
    "[Last] dddd" : "[Múlt] dddd",
    "Event does not exist" : "Az esemény nem létezik",
    "Duplicate" : "Kettőzés",
    "Delete this occurrence" : "Ezen előfordulás törlése",
    "Delete this and all future" : "Ezen és az összes jövőbeli törlése",
    "Details" : "Részletek",
    "Attendees" : "Résztvevők",
    "Resources" : "Erőforrások",
    "Close" : "Bezárás",
    "Show more details" : "Részletek megjelenítése",
    "Subscribe to {name}" : "Feliratkozás erre: {name}",
    "Export {name}" : "{name} exportálása",
    "Anniversary" : "Évforduló",
    "Appointment" : "Találkozó",
    "Business" : "Üzleti",
    "Education" : "Oktatás",
    "Holiday" : "Szabadság",
    "Meeting" : "Találkozó",
    "Miscellaneous" : "Egyéb",
    "Non-working hours" : "Nem munkaidő",
    "Not in office" : "Nem irodában",
    "Phone call" : "Telefonhívás",
    "Sick day" : "Betegszabadság",
    "Special occasion" : "Különleges alkalom",
    "Travel" : "Utazás",
    "Vacation" : "Nyaralás",
    "Midnight on the day the event starts" : "Az esemény kezdetének napján éjfélkor",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n nappal az esemény előtt {formattedHourMinute}-kor","%n nappal az esemény előtt {formattedHourMinute}-kor"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n héttel az esemény előtt {formattedHourMinute}-kor","%n héttel az esemény előtt {formattedHourMinute}-kor"],
    "on the day of the event at {formattedHourMinute}" : "az esemény napján {formattedHourMinute}-kor",
    "at the event's start" : "az esemény kezdetén",
    "at the event's end" : "az esemény végén",
    "{time} before the event starts" : "{time} idővel az esemény kezdete előtt",
    "{time} before the event ends" : "{time} idővel az esemény vége előtt",
    "{time} after the event starts" : "{time} idővel az esemény kezdete után",
    "{time} after the event ends" : "{time} idővel az esemény vége után",
    "on {time}" : "{time}-kor",
    "on {time} ({timezoneId})" : "{time}-kor ({timezoneId})",
    "Week {number} of {year}" : "{year} {number}. hete",
    "Does not repeat" : "Nem ismétlődik",
    "Daily" : "Naponta",
    "Weekly" : "Hetente",
    "Monthly" : "Havonta",
    "Yearly" : "Évente",
    "_Every %n day_::_Every %n days_" : ["%n naponta","%n naponta"],
    "_Every %n week_::_Every %n weeks_" : ["%n hetente","%n hetente"],
    "_Every %n month_::_Every %n months_" : ["%n havonta","%n havonta"],
    "_Every %n year_::_Every %n years_" : ["%n évente","%n évente"],
    "_on {weekday}_::_on {weekdays}_" : ["ezen a napon: {weekdays}","ezen a napon: {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["a hónap ezen napjain: {dayOfMonthList}","a hónap ezen napjain: {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "ekkor: {ordinalNumber}. {byDaySet}",
    "in {monthNames}" : "{monthNames} hónapban",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames} hónapban ekkor: {ordinalNumber}. {byDaySet}",
    "until {untilDate}" : "eddig: {untilDate}",
    "_%n time_::_%n times_" : ["%n alkalommal","%n alkalommal"],
    "Untitled event" : "Névtelen esemény",
    "Untitled task" : "Névtelen feladat",
    "Please ask your administrator to enable the Tasks App." : "Kérje meg a rendszergazdát, hogy engedélyezze a Feladatok alkalmazást.",
    "Prev" : "Előző",
    "Next" : "Köv.",
    "Prev year" : "Előző év",
    "Next year" : "Köv. év",
    "Year" : "Év",
    "W" : "H",
    "%n more" : "%n további",
    "No events to display" : "Nincs megjelenítendő esemény",
    "_+%n more_::_+%n more_" : ["+%n további","+%n további"],
    "No events" : "Nincs esemény",
    "Create a new event or change the visible time-range" : "Hozzon létre egy új eseményt, vagy módosítsa a látható időtartományt",
    "It might have been deleted, or there was a typo in a link" : "Lehet, hogy törölték, vagy elgépelés volt egy hivatkozásban",
    "It might have been deleted, or there was a typo in the link" : "Lehet, hogy törölték, vagy elgépelés volt a hivatkozásban",
    "Meeting room" : "Tárgyalóterem",
    "Lecture hall" : "Előadóterem",
    "Seminar room" : "Szemináriumterem",
    "Other" : "Egyéb",
    "When shared show" : "Megjelenítés megosztáskor",
    "When shared show full event" : "A teljes esemény megjelenítése megosztáskor",
    "When shared show only busy" : "Csak a foglaltság megjelenítése megosztáskor",
    "When shared hide this event" : "Az esemény elrejtése megosztáskor",
    "The visibility of this event in shared calendars." : "Az esemény láthatósága a megosztott naptárakban.",
    "Add a location" : "Helyszín hozzáadása",
    "Add a description" : "Leírás hozzáadása",
    "Status" : "Állapot",
    "Confirmed" : "Elfogadva",
    "Canceled" : "Lemondva",
    "Confirmation about the overall status of the event." : "Megerősítés az esemény általános állapotáról.",
    "Show as" : "Megjelenítés mint",
    "Take this event into account when calculating free-busy information." : "Ezen esemény figyelembe vétele a foglaltsági információk kiszámításakor.",
    "Categories" : "Kategóriák",
    "Categories help you to structure and organize your events." : "A kategóriák segítenek az események strukturálásában és megszervezésében.",
    "Search or add categories" : "Kategóriák keresése vagy hozzáadása",
    "Add this as a new category" : "Hozzáadás új kategóriaként",
    "Custom color" : "Egyéni szín",
    "Special color of this event. Overrides the calendar-color." : "Megkülönböztető szín ehhez az eseményhez. Felülírja a naptár színét.",
    "Chat room for event" : "Csevegőszoba az eseményhez",
    "Imported {filename}" : "{filename} importálva",
    "Meditation" : "Meditáció",
    "Relaxing" : "Pihenés",
    "Relax" : "Pihenő",
    "Break" : "Szünet",
    "Commute" : "Ingázás",
    "Commuting" : "Ingázás",
    "Shuttle" : "Ingajárat",
    "Invoice" : "Díjbekérő",
    "Finance" : "Pénzügyek",
    "Bank" : "Bank",
    "Money" : "Pénz",
    "Wedding" : "Esküvő",
    "Dog" : "Kutya",
    "Concert" : "Koncert",
    "Festival" : "Fesztivál",
    "Theater" : "Színház",
    "Theatre" : "Színház",
    "Presentation" : "Bemutató",
    "Talk" : "Előadás",
    "Speech" : "Beszéd",
    "Deadline" : "Határidő",
    "Submission" : "Beküldés",
    "Reporting" : "Jelentés",
    "Camping" : "Kemping",
    "Camp" : "Táborozás",
    "Election" : "Választás",
    "Voting" : "Szavazás",
    "Vote" : "Szavazat",
    "Barbecue" : "Grillezés",
    "Barbeque" : "Sütögetés",
    "Garden" : "Kert",
    "Farm" : "Farm",
    "Movie" : "Film",
    "Cinema" : "Mozi",
    "Graduation" : "Ballagás",
    "Brainstorm" : "Ötletelés",
    "Review" : "Visszajelzés",
    "Audit" : "Audit",
    "Inspection" : "Vizsgálat",
    "Proofreading" : "Átolvasás",
    "Baseball" : "Baseball",
    "Meet" : "Találkozás",
    "Planning" : "Tervezés",
    "Pointing" : "Mutatás",
    "Retrospective" : "Visszatekintő",
    "Office" : "Munkahely",
    "Contributor week" : "Közreműködői hét",
    "Mail" : "Levél",
    "Soccer" : "Foci",
    "Football" : "Futball",
    "Gaming" : "Játék",
    "Drive" : "Vezetés",
    "Driving" : "Vezetés",
    "Bicycle" : "Kerékpár",
    "Cycle" : "Bicaj",
    "Cycling" : "Kerékpározás",
    "Biking" : "Kerékpározás",
    "Bike" : "Bicikli",
    "Podcast" : "Podcast",
    "Basketball" : "Kosárlabda",
    "Fishing" : "Horgászás",
    "Hiking" : "Túrázás",
    "Hike" : "Túra",
    "Art" : "Művészet",
    "Exhibition" : "Kiállítás",
    "Museum" : "Múzeum",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Walk" : "Gyaloglás",
    "Studying" : "Tanulás",
    "Doctor" : "Orvos",
    "Health" : "Egészség",
    "Dentist" : "Fogorvos",
    "Hospital" : "Kórház",
    "Interview" : "Interjú",
    "Training" : "Képzés",
    "Practice" : "Gyakorlás",
    "Sports" : "Sportok",
    "Exercise" : "Feladat",
    "Work out" : "Edzés",
    "Working out" : "Edzeni",
    "Gym" : "Tornaterem",
    "Barber" : "Borbély",
    "Haircut" : "Fodrász",
    "Hairdresser" : "Fodrász",
    "Exam" : "Vizsga",
    "Written test" : "Írott teszt",
    "Oral test" : "Szóbeli teszt",
    "Working" : "Munka",
    "New Years Eve" : "Szilveszter",
    "NYE" : "Újév",
    "Fireworks" : "Tüzijáték",
    "Running" : "Futás",
    "Go for a run" : "Futni menni",
    "Marathon" : "Maraton",
    "Video-conference" : "Videókonferencia",
    "Conference-call" : "Konferenciahívás",
    "Video-call" : "Videohívás",
    "Video-chat" : "Videocsevegés",
    "Video-meeting" : "Videotalálkozó",
    "Call" : "Hívás",
    "Calling" : "Hívni",
    "Christmas" : "Karácsony",
    "Conference" : "Konferencia",
    "Pizza" : "Pizza",
    "Travelling" : "Utazás",
    "Trip" : "Kirándulás",
    "Journey" : "Utazgatás",
    "Collaborate" : "Együttműködés",
    "Pair" : "Pár",
    "Lecture" : "Előadás",
    "Seminar" : "Szeminárium",
    "Teaching" : "Tanítás",
    "Photograph" : "Fénykép",
    "Party" : "Parti",
    "Celebration" : "Ünnep",
    "Celebrate" : "Ünneplés",
    "Birthday" : "Születésnap",
    "Shopping" : "Bevásárlás",
    "Groceries" : "Bevásárlás",
    "Skate" : "Korcsolya",
    "Skateboard" : "Gördeszka",
    "Wine tasting" : "Borkóstolás",
    "Golf" : "Golf",
    "Dinner" : "Vacsora",
    "Lunch" : "Ebéd",
    "Appointment not found" : "A találkozó nem található",
    "User not found" : "A felhasználó nem található"
},
"nplurals=2; plural=(n != 1);");
