OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Erabiltzaile-saioa ustekabean iraungi da",
    "Provided email-address is not valid" : "Emandako helbide elektronikoa ez da baliozkoa",
    "%s has published the calendar »%s«" : "%s erabiltzaileak »%s« egutegia argitaratu du",
    "Unexpected error sending email. Please contact your administrator." : "Ustekabeko errorea posta elektronikoa bidaltzean. Jarri harremanetan zure administratzailearekin.",
    "Successfully sent email to %1$s" : "Posta elektronikoa ondo bidali zaio %1$s(r)i",
    "Hello," : "Kaixo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Jakinarazi nahi dizugu %s erabiltzaileak »%s« egutegia argitaratu duela",
    "Open »%s«" : " Ireki »%s«",
    "Cheers!" : "Topa!",
    "Upcoming events" : "Hurrengo gertaerak",
    "Appointments" : "Hitzorduak",
    "Schedule appointment \"%s\"" : "Antolatu \"%s\" hitzordua",
    "Schedule an appointment" : "Antolatu hitzordu bat",
    "Prepare for %s" : "Prestatu %s-rentzat",
    "Follow up for %s" : "%s-(r)en jarraipena",
    "Dear %s, please confirm your booking" : " %s estimatua, berretsi zure erreserba",
    "Confirm" : "Berretsi",
    "This confirmation link expires in %s hours." : "Berrespen-esteka hau %s ordu barru iraungiko da.",
    "Date:" : "Data:",
    "Where:" : "Non:",
    "Calendar" : "Egutegia",
    "A Calendar app for Nextcloud" : "Nextclouderako egutegi app-a",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Egutegi aplikazioa erabiltzaile interfaze bat da, Nextclouden CalDAV zerbitzarirako. Sinkronizatu itzazu gertaerak erraz gailu ugaritatik zure Nextcloud-ekin eta editatu itzazu sarean.\n\n* 🚀 **Integrazioa Nextclouden beste aplikazioekin!** Oraingoz Kontaktuak- laster gehiago.\n* 🌐 **WebCal onartzen da!** Zure kirol talde gustukoenaren partidak egutegian izan nahi? Arazorik ez!\n* 🙋 **Partaideak!** gonbidatu jendea zure gertaeretara\n* ⌚️ **Libre/Lanpetuta:** Ikusi noiz dauden partaideak libre elkartzeko\n* ⏰ **Abisuak!** Jaso alarmak gertaerentzat nabigatzailean edo e-posta bidez\n* 🙈 **Ez dugu gurpila berrasmatu!** [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) eta [fullcalendar](https://github.com/fullcalendar/fullcalendar) liburutegi bikainetan oinarrituta.",
    "Previous day" : "Aurreko eguna",
    "Previous week" : "Aurreko astea",
    "Previous month" : "Aurreko hilabetea",
    "Next day" : "Hurrengo eguna",
    "Next week" : "Hurrengo astea",
    "Next month" : "Hurrengo hilabetea",
    "New event" : "Gertaera berria",
    "Today" : "Gaur",
    "Day" : "Eguna",
    "Week" : "Astea",
    "Month" : "Hilabetea",
    "List" : "Zerrenda",
    "Preview" : "Aurrebista",
    "Copy link" : "Kopiatu esteka",
    "Edit" : "Editatu",
    "Delete" : "Ezabatu",
    "Appointment link was copied to clipboard" : "Hitzorduaren esteka arbelean kopiatu da",
    "Appointment link could not be copied to clipboard" : "Hitzorduaren esteka ezin izan da arbelean kopiatu",
    "Add new" : "Gehitu berria",
    "Untitled calendar" : "Izenik gabeko egutegia",
    "Edit name" : "Editatu izena",
    "Saving name …" : "Izena gordetzen …",
    "Edit color" : "Editatu kolorea",
    "Saving color …" : "Kolorea gordetzen …",
    "Copy private link" : "Kopiatu esteka pribatua",
    "Export" : "Esportatu",
    "Unshare from me" : "Kendu nirekin partekatzea",
    "Disable calendar \"{calendar}\"" : "Desgaitu \"{calendar}\" egutegia",
    "Disable untitled calendar" : "Desgaitu izenbururik gabeko egutegia",
    "Enable calendar \"{calendar}\"" : "Gaitu \"{calendar}\" egutegia",
    "Enable untitled calendar" : "Gaitu izenbururik gabeko egutegia",
    "An error occurred, unable to change visibility of the calendar." : "Errore bat gertatu da, ezin da egutegiaren ikusgaitasuna aldatu.",
    "An error occurred, unable to delete the calendar." : "Errore bat gertatu da, ezin da egutegia ezabatu.",
    "Calendar link copied to clipboard." : "Egutegiko esteka arbelera kopiatu da.",
    "Calendar link could not be copied to clipboard." : "Ezin izan da egutegiko esteka arbelera kopiatu.",
    "An error occurred, unable to rename the calendar." : "Errore bat gertatu da, ezin da egutegia berrizendatu.",
    "An error occurred, unable to change the calendar's color." : "Errore bat gertatu da,  ezin da egutegiaren kolorea aldatu.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Egutegia partekatzea kenduko da segundo {countdown} barru","Egutegia partekatzea kenduko da {countdown} segundo barru"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Egutegia ezabatuko da segundo {countdown} barru","Egutegia ezabatuko da {countdown} segundo barru"],
    "Share link" : "Partekatu esteka",
    "Publish calendar" : "Argitaratu egutegia",
    "Publishing calendar" : "Egutegia argitaratzen",
    "Copy public link" : "Kopiatu esteka publikoa",
    "Send link to calendar via email" : "Bidali esteka egutegira posta elektroniko bidez",
    "Enter one address" : "Sartu helbide bat",
    "Sending email …" : "Posta elektronikoa bidaltzen …",
    "Copy subscription link" : "Kopiatu harpidetza esteka",
    "Copying link …" : "Esteka kopiatzen …",
    "Copied link" : "Esteka kopiatuta",
    "Could not copy link" : "Ezin izan da esteka kopiatu",
    "Copy embedding code" : "Kopiatu kapsulatze-kodea",
    "Copying code …" : "Kodea kopiatzen …",
    "Copied code" : "Kodea kopiatuta",
    "Could not copy code" : "Ezin izan da kodea kopiatu",
    "Delete share link" : "Ezabatu partekatze esteka",
    "Deleting share link …" : "Partekatze esteka ezabatzen  ...",
    "An error occurred, unable to publish calendar." : "Errore bat gertatu da, ezin da egutegia argitaratu",
    "An error occurred, unable to send email." : "Errore bat gertatu da, ezin da posta elektronikoa bidali.",
    "Embed code copied to clipboard." : "Kapsulatze-kodea arbelera kopiatu da.",
    "Embed code could not be copied to clipboard." : "Ezin izan da kapsulatze-kodea arbelera kopiatu.",
    "Unpublishing calendar failed" : "Egutegia desargitaratzeak huts egin du",
    "Share with users or groups" : "Partekatu erabiltzaile edo taldeekin",
    "No users or groups" : "Ez dago erabiltzaile edota talderik",
    "can edit" : "editatu dezake",
    "Unshare with {displayName}" : "Utzi {displayName} erabiltzailearekin partekatzeari",
    "An error occurred, unable to change the unshare the calendar." : "Errore bat gertatu da, ezin da egutegia partekatzeari uztea aldatu.",
    "An error occurred, unable to change the permission of the share." : "Errore bat gertatu da, ezin da partekatzearen baimena aldatu.",
    "New calendar" : "Egutegi berria",
    "Name for new calendar" : "Egutegi berriaren izena",
    "Creating calendar …" : "Egutegia sortzen …",
    "New calendar with task list" : "Egutegi berria ataza zerrendarekin",
    "New subscription from link (read-only)" : "Harpidetza berria estekatik (irakurtzeko soilik)",
    "Creating subscription …" : "Harpidetza sortzen ...",
    "An error occurred, unable to create the calendar." : "Errore bat gertatu da, ezin da egutegia sortu.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Sartu baliozko esteka bat (hauetako batekin hasi behar du: http://, https://, webcal:// edo webcals://)",
    "Trash bin" : "Zakarrontzia",
    "Loading deleted items." : "Ezabatutako elementuak kargatzen.",
    "You do not have any deleted items." : "Ez duzu ezabatutako elementurik.",
    "Name" : "Izena",
    "Deleted" : "Ezabatuta",
    "Restore" : "Berrezarri",
    "Delete permanently" : "Ezabatu betirako",
    "Empty trash bin" : "Hustu zakarrontzia",
    "Untitled item" : "Izen gabeko elementua",
    "Unknown calendar" : "Egutegi ezezaguna",
    "Could not load deleted calendars and objects" : "Ezin izan dira ezabatutako egutegi eta elementuak kargatu",
    "Could not restore calendar or event" : "Ezin izan da egutegia edo gertaera berezarri",
    "Do you really want to empty the trash bin?" : "Ziur zaude zakarrontzia hustu nahi duzula?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Zakarrontziko elementuak egun {numDays} igaro ondoren ezabatzen dira","Zakarrontziko elementuak {numDays} egun igaro ondoren ezabatzen dira"],
    "Could not update calendar order." : "Ezin da egutegi-eskaera eguneratu.",
    "Import calendars" : "Inportatu egutegiak",
    "Please select a calendar to import into …" : "Hautatu egutegia hona inportatzeko ...",
    "Filename" : "Fitxategi-izena",
    "Calendar to import into" : "Hona inportatzeko egutegia",
    "Cancel" : "Ezeztatu",
    "_Import calendar_::_Import calendars_" : ["Inportatu egutegia","Inportatu egutegiak"],
    "{filename} could not be parsed" : "{filename} ezin da analizatu",
    "No valid files found, aborting import" : "Ez da baliodun fitxategirik aurkitu, inportazioa bertan behera uzten",
    "Import partially failed. Imported {accepted} out of {total}." : "Inportazioak huts egin du hein batean. Guztira {total} ziren, {accepted} inportatu dira.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n gertaera behar bezala inportatu dira","%n gertaera behar bezala inportatu dira"],
    "Automatic" : "Automatikoa",
    "Automatic ({detected})" : "Automatikoa ({detected})",
    "New setting was not saved successfully." : "Ezarpen berria ez da behar bezala gorde.",
    "Shortcut overview" : "Lasterbideen informazio orokorra",
    "or" : "edo",
    "Navigation" : "Nabigazioa",
    "Previous period" : "Aurreko aldia",
    "Next period" : "Hurrengo aldia",
    "Views" : "Ikuspegiak",
    "Day view" : "Egun ikuspegia",
    "Week view" : "Aste ikuspegia",
    "Month view" : "Hilabete ikuspegia",
    "List view" : "Zerrenda ikuspegia",
    "Actions" : "Ekintzak",
    "Create event" : "Sortu gertaera",
    "Show shortcuts" : "Erakutsi lasterbideak",
    "Editor" : "Editorea",
    "Close editor" : "Itxi editorea",
    "Save edited event" : "Gorde editatutako gertaera",
    "Delete edited event" : "Ezabatu editatutako gertaera",
    "Duplicate event" : "Bikoiztu gertaera",
    "Enable birthday calendar" : "Gaitu urtebetetzeen egutegia",
    "Show tasks in calendar" : "Erakutsi zereginak egutegian",
    "Enable simplified editor" : "Gaitu editore sinplifikatua",
    "Limit visible events per view" : "Mugatu ikusgai dauden gertaerak",
    "Show weekends" : "Erakutsi asteburuak",
    "Show week numbers" : "Erakutsi aste zenbakiak",
    "Time increments" : " \nDenbora-gehikuntzak",
    "Default reminder" : "Abisu lehenetsia",
    "Copy primary CalDAV address" : "Kopiatu CalDAV helbide nagusia",
    "Copy iOS/macOS CalDAV address" : "Kopiatu iOS/macOS CalDAV helbidea",
    "Personal availability settings" : "Eskuragarritasun pertsonalaren ezarpenak",
    "Show keyboard shortcuts" : "Erakutsi teklatuaren lasterbideak",
    "Calendar settings" : "Egutegiaren ezarpenak",
    "No reminder" : "Abisurik ez",
    "CalDAV link copied to clipboard." : "CalDAV esteka arbelera kopiatu da.",
    "CalDAV link could not be copied to clipboard." : "Ezin izan da CalDAV helbidea arbelera kopiatu.",
    "Appointment was created successfully" : "Hitzordua ondo sortu da",
    "Appointment was updated successfully" : "Hitzordua ondo eguneratu da",
    "_{duration} minute_::_{duration} minutes_" : ["minutu {duration}","{duration} minutu"],
    "0 minutes" : "0 minutu",
    "_{duration} hour_::_{duration} hours_" : ["ordu {duration}","{duration} ordu"],
    "_{duration} day_::_{duration} days_" : ["egun {duration}","{duration} egun"],
    "_{duration} week_::_{duration} weeks_" : ["aste {duration}","{duration} aste"],
    "_{duration} month_::_{duration} months_" : ["hilabete {duration}","{duration} hilabete"],
    "_{duration} year_::_{duration} years_" : ["urte {duration}","{duration} urte"],
    "To configure appointments, add your email address in personal settings." : "Hitzorduak konfiguratzeko, gehitu zure e-posta helbidea ezarpen pertsonaletan.",
    "Public – shown on the profile page" : "Publikoa – profil-orrian erakusten da",
    "Private – only accessible via secret link" : "Pribatua – esteka sekretu bidez soilik ikus daiteke",
    "Location" : "Kokapena",
    "Description" : "Deskribapena",
    "Visibility" : "Ikusgarritasuna",
    "Duration" : "Iraupena",
    "Increments" : "Gehikuntzak",
    "Additional calendars to check for conflicts" : "Gatazkak egiaztatzeko egutegi gehigarriak",
    "Pick time ranges where appointments are allowed" : "Aukeratu hitzorduetan onartzen diren denbora tarteak",
    "to" : "honi",
    "Delete slot" : "Ezabatu tartea",
    "No times set" : "Ez dago denborarik ezarrita",
    "Add" : "Gehitu",
    "Monday" : "Astelehena",
    "Tuesday" : "Asteartea",
    "Wednesday" : "Asteazkena",
    "Thursday" : "Osteguna",
    "Friday" : "Ostirala",
    "Saturday" : "Larunbata",
    "Sunday" : "Igandea",
    "Add time before and after the event" : "Gehitu denbora gertaera baino lehen eta ostean",
    "Before the event" : "Gertaera baino lehen",
    "After the event" : "Gertarearen ostean",
    "Planning restrictions" : "Planifikatze murrizketak",
    "Minimum time before next available slot" : "Denbora minimoa hurrengo tarte eskuragarriarentzat",
    "Max slots per day" : "Tarte kopuru maximoa egunero",
    "Limit how far in the future appointments can be booked" : "Mugatu hitzorduak etorkizuneko zein puntura arte erreserba daitezkeen",
    "Create appointment" : "Sortu hitzordua",
    "Edit appointment" : "Editatu hitzordua",
    "Save" : "Gorde",
    "Update" : "Eguneratu",
    "Please confirm your reservation" : "Berretsi zure erreserba",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Mezu elektroniko bat bidali dizugu xehetasunekin. Mesedez, berretsi zure hitzordua mezu elektronikoaren esteka erabiliz. Orrialde hau itxi dezakezu orain.",
    "Your name" : "Zure izena",
    "Your email address" : "Zure e-posta",
    "Please share anything that will help prepare for our meeting" : "Mesedez, partekatu gure bilera prestatzen lagunduko duen edozer",
    "Could not book the appointment. Please try again later or contact the organizer." : "Ezin izan da hitzordua erreserbatu. Saiatu berriro geroago edo jarri harremanetan administratzalearekin.",
    "Book the appointment" : "Erreserbatu hitzordua",
    "Reminder" : "Oroigarria",
    "before at" : "lehenago hemen",
    "Notification" : "Jakinarazpena",
    "Email" : "Mezu elektronikoa",
    "Audio notification" : "Audio jakinarazpena",
    "Other notification" : "Bestelako jakinarazpena",
    "Relative to event" : "Gertaerarekiko",
    "On date" : "Epean",
    "Edit time" : "Editatu ordua",
    "Save time" : "Gorde ordua",
    "Remove reminder" : "Kendu abisua",
    "on" : "noiz",
    "at" : "non",
    "+ Add reminder" : "+ Gehitu abisua",
    "Add reminder" : "Gehitu oroigarria",
    "_second_::_seconds_" : ["segundo","segundo"],
    "_minute_::_minutes_" : ["minutu","minutu"],
    "_hour_::_hours_" : ["ordu","ordu"],
    "_day_::_days_" : ["egun","egun"],
    "_week_::_weeks_" : ["aste","aste"],
    "Invitation accepted" : "Gonbidapena onartuta",
    "Available" : "Erabilgarri",
    "Suggested" : "Iradokituta",
    "Participation marked as tentative" : "Partaidetza behin-behineko gisa markatu da",
    "Accepted {organizerName}'s invitation" : "{organizerName}(r)en gonbidapena onartuta",
    "Not available" : "Ez dago erabilgarri",
    "Invitation declined" : "Gonbidapena ukatuta",
    "Declined {organizerName}'s invitation" : "{organizerName}(r)en gonbidapena ukatuta",
    "Invitation is delegated" : "Gonbidapena eskuordetuta dago",
    "Checking availability" : "Erabilgarritasuna egiaztatzen",
    "Invitation sent" : "Gonbidapena bidalita",
    "Has not responded to {organizerName}'s invitation yet" : "Oraindik ez dio {organizerName} erabiltzailearen gonbidapenari erantzun",
    "Availability of attendees, resources and rooms" : "Partaide, baliabide eta gelen eskuragarritasuna",
    "{organizer} (organizer)" : "{organizer} (kudeatzailea)",
    "Free" : "Libre",
    "Busy (tentative)" : "Lanpetuta (behin-behinean)",
    "Busy" : "Lanpetua",
    "Out of office" : "Bulegotik kanpo",
    "Unknown" : "Ezezaguna",
    "Accept" : "Onartu",
    "Decline" : "Uko egin",
    "Tentative" : "Behin behinekoa",
    "The invitation has been accepted successfully." : "Gonbidapena behar bezala onartu da.",
    "Failed to accept the invitation." : "Huts egin du gonbidapena onartzen.",
    "The invitation has been declined successfully." : "Gonbidapena behar bezala baztertu da.",
    "Failed to decline the invitation." : "Huts egin du gonbidapena baztertzen.",
    "Your participation has been marked as tentative." : "Zure parte hartzea behin-behineko gisa markatu da.",
    "Failed to set the participation status to tentative." : "Huts egin du zure parte hartzea behin-behineko gisa ezartzen.",
    "Create Talk room for this event" : "Sortu Talk gela gertaera honentzat",
    "Show busy times" : "Erakutsi denbora lanpetuta",
    "No attendees yet" : "Partaiderik ez oraindik",
    "Successfully appended link to talk room to description." : "Ondo erantsi zaio esteka hizketa gelaren deskribapenari.",
    "Error creating Talk room" : "Errorea Talk gela sortzean",
    "Send email" : "Bidali e-posta",
    "Chairperson" : "Mahaiburua",
    "Required participant" : "Beharrezko partaidea",
    "Optional participant" : "Hautazko partaidea",
    "Non-participant" : "Ez da partaidea",
    "Remove attendee" : "Kendu partaidea",
    "Search for emails, users or contacts" : "Bilatu mezu elektronikoak, erabiltzaileak edo kontaktuak",
    "No match found" : "Ez da emaitzarik aurkitu",
    "(organizer)" : "(antolatzailea)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Gonbidapenak bidali eta erantzunak kudeatzeko, [linkopen] gehitu zure posta helbidea ezarpen pertsonaletan[linkclose].",
    "Remove color" : "Kendu kolorea",
    "Event title" : "Gertaeraren izenburua",
    "All day" : "Egun osoa",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Ezin da egun osoko ezarpena aldatu errepikapen multzo baten parte diren gertaeretarako. ",
    "from {startDate}" : "{startDate}tik",
    "from {startDate} at {startTime}" : "{startDate}ko,  {startTime}tik",
    "to {endDate}" : "{endDate} arte",
    "to {endDate} at {endTime}" : "{endDate}ko {endTime} arte",
    "Repeat" : "Errepikatu",
    "End repeat" : "Amaitu errepikapena",
    "Select to end repeat" : "Hautatu errepikapena amaitzeko",
    "never" : "inoiz ez",
    "on date" : "epean",
    "after" : "gero",
    "_time_::_times_" : ["aldiz","aldiz"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ekitaldi hau errepikapen multzo bateko errepikapen salbuespena da. Ezin diozu errepikapen-araurik gehitu.",
    "first" : "lehena",
    "third" : "hirugarrena",
    "fourth" : "laugarrena",
    "fifth" : "bosgarrena",
    "second to last" : "bigarren azkena",
    "last" : "azkena",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Errepikapen arauan egindako aldaketak gertaera honentzat eta etorkizunekoentzat bakarrik aplikatuko dira.",
    "Repeat every" : "Errepikatu zenbatero",
    "By day of the month" : "Hileko egunaren arabera",
    "On the" : "Honetan",
    "_month_::_months_" : ["hilabete","hilabete"],
    "_year_::_years_" : ["urte","urte"],
    "weekday" : "asteguna",
    "weekend day" : "asteburuko eguna",
    "No recurrence" : "Errepikapenik ez",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Gertaera honen errepikapen definizioa ez du guztiz onartzen Nextcloud-ek. Errepikapen aukerak editatzen badituzu, errepikapen batzuk galdu litezke.",
    "Suggestions" : "Iradokizunak",
    "No rooms or resources yet" : "Oraindik ez dago gelarik edo baliabiderik",
    "Add resource" : "Gehitu baliabidea",
    "Has a projector" : "Proiektore bat dauka",
    "Has a whiteboard" : "Arbel zuria dauka",
    "Wheelchair accessible" : "Gurpil-aulkientzako sarbidea",
    "Remove resource" : "Kendu baliabidea",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} eserleku ","{seatingCapacity}  eserleku "],
    "Projector" : "Proiektorea",
    "Whiteboard" : "Arbel zuria",
    "Search for resources or rooms" : "Bilatu baliabideak edo gelak",
    "available" : "erabilgarri",
    "unavailable" : "ez erabilgarri",
    "Room type" : "Gela mota",
    "Any" : "Edozein",
    "Minimum seating capacity" : "Gutxieneko eserleku kopurua",
    "More" : "Gehiago",
    "Update this occurrence" : "Eguneratu gertaera hau",
    "Update this and all future" : "Eguneratu hau eta etorkizuneko guztiak",
    "Public calendar does not exist" : "Egutegi publikoa ez da existitzen",
    "Maybe the share was deleted or has expired?" : "Agian, partekatutakoa ezabatu egin da edo iraungita geratu da?",
    "Please select a time zone:" : "Aukeratu ordu-zona bat:",
    "Pick a time" : "Aukeratu ordua",
    "Pick a date" : "Aukeratu eguna",
    "from {formattedDate}" : "{formattedDate}tik ",
    "to {formattedDate}" : "{formattedDate} arte ",
    "on {formattedDate}" : "{formattedDate}an",
    "from {formattedDate} at {formattedTime}" : "{formattedDate}ko {formattedTime}tik",
    "to {formattedDate} at {formattedTime}" : "{formattedDate}ko {formattedTime} arte",
    "on {formattedDate} at {formattedTime}" : "{formattedDate}ko {formattedTime}etan",
    "{formattedDate} at {formattedTime}" : "{formattedDate}ko {formattedTime}etan",
    "Please enter a valid date" : "Sartu baliozko data",
    "Please enter a valid date and time" : "Sartu baliozko data eta ordua",
    "Type to search time zone" : "Idatzi ordu-zona bilatzeko",
    "Global" : "Orokorra",
    "Select date" : "Hautatu data",
    "Select slot" : "Hautatu tartea",
    "No slots available" : "Ez dago tarterik eskuragarri",
    "The slot for your appointment has been confirmed" : "Zure hitzorduaren tartea berretsi da",
    "Appointment Details:" : "Hitzorduaren xehetasunak:",
    "Time:" : "Noiz:",
    "Booked for:" : "Honetarako erreserbatuta:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Eskerrik asko. {startDate}tik {endDate} arteko erreserba berretsi da.",
    "Book another appointment:" : "Erreserbatu beste hitzordu bat",
    "See all available slots" : "Ikusi eskuragarri dauden tarte guztiak",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "{startDate}tik {endDate} arteko zure hitzorduaren tartea ez dago jada erabilgarri.",
    "Please book a different slot:" : "Mesedez erreserbatu beste tarte bat:",
    "Book an appointment with {name}" : "Hitzordu bat erreserbatu {name}(r)ekin",
    "No public appointments found for {name}" : "Ez da hitzordu publikorik aurkitu {name}rentzat",
    "Personal" : "Pertsonala",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Ordu-eremu detekzio automatikoak zehaztu du zure ordu-eremua UTC dela. \nHau seguru aski zure nabigatzailearen segurtasun neurrien ondorio da.\nZehaztu ezazu zure ordu-eremua eskuz egutegiaren ezarpenetan.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Ezarrita daukazun ordu-eremua ({timezoneId}) ez da aurkitu. UTC-ra itzultzen.\nMesedez, aldatu zure ordu-eremua ezarpenetan eta eman arazoaren berri.",
    "No more events today" : "Ez dago gertaera gehiagorik gaurkoz.",
    "No upcoming events" : "Ez dago gertaerarik datozen egunetan.",
    "Create a new event" : "Sortu gertaera berri bat",
    "[Today]" : "[Today]",
    "[Tomorrow]" : "[Tomorrow]",
    "[Yesterday]" : "[Yesterday]",
    "[Last] dddd" : "[Last] dddd",
    "Event does not exist" : "Ez dago gertaera hori",
    "Duplicate" : "Bikoiztu",
    "Delete this occurrence" : "Ezabatu gertaera hau",
    "Delete this and all future" : "Ezabatu hau eta etorkizunekoak",
    "Details" : "Xehetasunak",
    "Attendees" : "Partaideak",
    "Resources" : "Baliabideak",
    "Close" : "Itxi",
    "Show more details" : "Erakutsi xehetasun gehiago",
    "Subscribe to {name}" : "Harpidetu {name}",
    "Export {name}" : "Esportatu {name}",
    "Anniversary" : "Urtebetetzea",
    "Appointment" : "Hitzordua",
    "Business" : "Lana",
    "Education" : "Hezkuntza",
    "Holiday" : "Jaieguna",
    "Meeting" : "Bilera",
    "Miscellaneous" : "Askotarikoa",
    "Non-working hours" : "Laneko orduetatik kanpo",
    "Not in office" : "Ez nago bulegoan",
    "Phone call" : "Telefono-deia",
    "Sick day" : "Gaixorik",
    "Special occasion" : "Gertaera berezia",
    "Travel" : "Bidaian",
    "Vacation" : "Oporretan",
    "Midnight on the day the event starts" : "Gauerdian gertaera hasten den egunean",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["Egun %n gertaera hasi baino lehen {formattedHourMinute}(e)tan","%n egun gertaera hasi baino lehen {formattedHourMinute}etan"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : [" aste %n gertaera hasi baino lehen {formattedHourMinute}(e)tan","%n aste gertaera hasi baino lehen {formattedHourMinute}etan"],
    "on the day of the event at {formattedHourMinute}" : "Gertaeraren egunean {formattedHourMinute}etan",
    "at the event's start" : "gertaera hasieran",
    "at the event's end" : "gertaera amaieran",
    "{time} before the event starts" : "gertaera hasi baino {time} lehenago",
    "{time} before the event ends" : "gertaera amaitu baino {time} lehenago",
    "{time} after the event starts" : "gertaera hasi baino {time} geroago",
    "{time} after the event ends" : "gertaera amaitu baino {time} geroago",
    "on {time}" : "{time}etan",
    "on {time} ({timezoneId})" : "{time}etan ({timezoneId})",
    "Week {number} of {year}" : "{year}ko {number}. astea",
    "Does not repeat" : "Ez errepikatu",
    "Daily" : "Egunero",
    "Weekly" : "Astero",
    "Monthly" : "Hilabetero",
    "Yearly" : "Urtero",
    "_Every %n day_::_Every %n days_" : ["Egunero","%n egunetik behin"],
    "_Every %n week_::_Every %n weeks_" : ["Astero","%n astetik behin"],
    "_Every %n month_::_Every %n months_" : ["Hilabetero","%n hilabetetik behin"],
    "_Every %n year_::_Every %n years_" : ["Urtero","%n urtetik behin"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}","{weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["{dayOfMonthList} egunean","{dayOfMonthList} egunetan"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber}. {byDaySet}an",
    "in {monthNames}" : "{monthNames}an",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames}ko {ordinalNumber}. {byDaySet}an",
    "until {untilDate}" : "{untilDate} arte",
    "_%n time_::_%n times_" : ["%n","%naldiz"],
    "Untitled event" : "Izenik gabeko gertaera",
    "Untitled task" : "Izenik gabeko zeregina",
    "Please ask your administrator to enable the Tasks App." : "Mesedez eskatu administratzaileari Tasks aplikazioa gaitu dezan.",
    "Prev" : "Aurrekoa",
    "Next" : "Hurrengoa",
    "Prev year" : "Aurreko urtea",
    "Next year" : "Hurrengo urtea",
    "Year" : "Urtea",
    "W" : "A. ",
    "%n more" : "%n gehiago",
    "No events to display" : "Ez dago bistaratzeko gertaerarik",
    "_+%n more_::_+%n more_" : ["+ %n","+ %n"],
    "No events" : "Ez dago gertaerarik",
    "Create a new event or change the visible time-range" : "Sortu gertaera berria edo aldatu ikusgai dagoen epea",
    "It might have been deleted, or there was a typo in a link" : "Baliteke ezabatua izana, edo estekaren batean akatsa egotea.",
    "It might have been deleted, or there was a typo in the link" : "Baliteke ezabatua izana, edo estekan akatsa egotea.",
    "Meeting room" : "Bilera gela",
    "Lecture hall" : "Konferentzia-gela",
    "Seminar room" : "Mintegia",
    "Other" : "Bestelakoa",
    "When shared show" : "Partekatzean erakutsi",
    "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
    "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
    "When shared hide this event" : "Partekatzean ezkutatu gertaera hau",
    "The visibility of this event in shared calendars." : "Gertaera honen ikusgarritasuna egutegi partekatuetan",
    "Add a location" : "Gehitu kokapen bat",
    "Add a description" : "Gehitu deskribapena",
    "Status" : "Egoera",
    "Confirmed" : "Berretsita",
    "Canceled" : "Utzita",
    "Confirmation about the overall status of the event." : "Baieztapena gertaeraren egoera orokorrari buruz.",
    "Show as" : "Erakutsi honela",
    "Take this event into account when calculating free-busy information." : "Kontuan izan gertaera hau libre-lanpetuta informazio kalkuluetan.",
    "Categories" : "Kategoriak",
    "Categories help you to structure and organize your events." : "Kategoriak lagungarri zaizkizu gertaerak egituratu eta antolatzeko.",
    "Search or add categories" : "Bilatu edo gehitu kategoriak",
    "Add this as a new category" : "Gehitu hau kategoria berri bezala",
    "Custom color" : "Kolore pertsonalizatua",
    "Special color of this event. Overrides the calendar-color." : "Gertaera honen kolorea berezia da. Egutegi kolorea baliogabetzen du.",
    "Chat room for event" : "Txat gela gertaera honentzat",
    "Imported {filename}" : "Inportatuta {filename}",
    "Meditation" : "Meditazioa",
    "Relaxing" : "Erlaxatzen",
    "Relax" : "Erlaxazioa",
    "Break" : "Atsedena",
    "Commute" : "Lanerako bidea",
    "Commuting" : "Lanerako bidean",
    "Shuttle" : "Anezka",
    "Invoice" : "Faktura",
    "Finance" : "Finantzak",
    "Bank" : "Bankua",
    "Money" : "Dirua",
    "Wedding" : "Eskontza",
    "Dog" : "Txakurra",
    "Concert" : "Kontzertua",
    "Festival" : "Festibala",
    "Theater" : "Aretoa",
    "Theatre" : "Aretoa",
    "Presentation" : "Aurkezpena",
    "Talk" : "Hizketaldia",
    "Speech" : "Diskurtsoa",
    "Deadline" : "Epemuga",
    "Submission" : "Bidalketa",
    "Reporting" : "Txostena egiten",
    "Camping" : "Kanpina",
    "Camp" : "Kanpatu",
    "Election" : "Hauteskundea",
    "Voting" : "Bozkatzen",
    "Vote" : "Bozkatu",
    "Barbecue" : "Barbakoa",
    "Barbeque" : "Barbakoa",
    "Garden" : "Lorategia",
    "Farm" : "Baserria",
    "Movie" : "Filma",
    "Cinema" : "Zinema",
    "Graduation" : "Graduazioa",
    "Brainstorm" : "Ideia-jasa",
    "Review" : "Berrikusi",
    "Audit" : "Auditoretza",
    "Inspection" : "Inspekzioa",
    "Proofreading" : "Testu-azterketa",
    "Baseball" : "Beisbola",
    "Meet" : "Topaketa",
    "Planning" : "Plangintza",
    "Pointing" : "Honi begira",
    "Retrospective" : "Atzera begirakoa",
    "Office" : "Bulegoa",
    "Contributor week" : "Laguntzailearen astea",
    "Mail" : "Posta",
    "Soccer" : "Futbola",
    "Football" : "Futbol amerikarra",
    "Gaming" : "Bideo-jokoak",
    "Drive" : "Gidatu",
    "Driving" : "Gidatzen",
    "Bicycle" : "Bizikleta",
    "Cycle" : "Bizikletan ibili",
    "Cycling" : "Bizikletan",
    "Biking" : "Motorrean ibili",
    "Bike" : "Bizikleta",
    "Podcast" : "Podcasta",
    "Basketball" : "Saskibaloia",
    "Fishing" : "Arrantza",
    "Hiking" : "Ibilaldia egin",
    "Hike" : "Ibilaldia",
    "Art" : "Artea",
    "Exhibition" : "Erakusketa",
    "Museum" : "Museoa",
    "Pilates" : "Pilates",
    "Park" : "Parkea",
    "Walk" : "Ibili",
    "Studying" : "Ikasten",
    "Doctor" : "Medikua",
    "Health" : "Osasuna",
    "Dentist" : "Dentista",
    "Hospital" : "Ospitalea",
    "Interview" : "Elkarrizketa",
    "Training" : "Entrenamendua",
    "Practice" : "Praktika",
    "Sports" : "Kirolak",
    "Exercise" : "Kirola egin",
    "Work out" : "Gimnasia",
    "Working out" : "Gimnasioan",
    "Gym" : "Gimnasioa",
    "Barber" : "Bizargina",
    "Haircut" : "Ilea moztu",
    "Hairdresser" : "Ile apandegia",
    "Exam" : "Azterketa",
    "Written test" : "Idatzizko azterketa",
    "Oral test" : "Ahozko azterketa",
    "Working" : "Lanean",
    "New Years Eve" : "Urtezaharra",
    "NYE" : "Urte Zaharra",
    "Fireworks" : "Su artifizialak",
    "Running" : "Korrika",
    "Go for a run" : "Korrikaldia",
    "Marathon" : "Maratoia",
    "Video-conference" : "Bideo-konferentzia",
    "Conference-call" : "Konferentzia deia",
    "Video-call" : "Bideo-deia",
    "Video-chat" : "Bideo-txata",
    "Video-meeting" : "Bideo-bilera",
    "Call" : "Deia",
    "Calling" : "Deitzen",
    "Christmas" : "Eguberriak",
    "Conference" : "Biltzarra",
    "Pizza" : "Pizza",
    "Travelling" : "Bidaiatzen",
    "Trip" : "Bidaia",
    "Journey" : "Bidaia",
    "Collaborate" : "Elkarlana",
    "Pair" : "Parekatu",
    "Lecture" : "Hitzaldia",
    "Seminar" : "Mintegia",
    "Teaching" : "Irakasten",
    "Photograph" : "Argazkia",
    "Party" : "Jaia",
    "Celebration" : "Ospakizuna",
    "Celebrate" : "Ospatu",
    "Birthday" : "Jaioteguna",
    "Shopping" : "Erosketak",
    "Groceries" : "Erosketak",
    "Skate" : "Patinatu",
    "Skateboard" : "Patinetea",
    "Wine tasting" : "Ardo dastaketa",
    "Golf" : "Golfa",
    "Dinner" : "Afaria",
    "Lunch" : "Bazkaria",
    "Appointment not found" : "Ez da hitzordua aurkitu",
    "User not found" : "Ez da erabiltzailea aurkitu"
},
"nplurals=2; plural=(n != 1);");
