OC.L10N.register(
    "calendar",
    {
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Quiximos informate de que %s espublizó'l calendariu «%s»",
    "Open »%s«" : "Abrir «%s»",
    "Cheers!" : "¡Salú!",
    "Confirm" : "Confirmar",
    "Calendar" : "Calendariu",
    "New event" : "Eventu nuevu",
    "Today" : "Güei",
    "Day" : "Día",
    "Week" : "Selmana",
    "Month" : "Mes",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar enllaz",
    "Edit" : "Editar",
    "Delete" : "Desaniciar",
    "Export" : "Esportar",
    "Share link" : "Share link",
    "Share with users or groups" : "Compartir con usuarios y grupos",
    "can edit" : "pue editar",
    "New calendar" : "Calendariu nuevu",
    "Name" : "Nome",
    "Deleted" : "Desanicióse",
    "Restore" : "Respaldar",
    "Delete permanently" : "Desaniciar dafechu",
    "Filename" : "Nome de ficheru",
    "Cancel" : "Encaboxar",
    "Automatic" : "Automáticu",
    "List view" : "Vista de llista",
    "Actions" : "Aiciones",
    "Show week numbers" : "Amosar númberos de la selmana",
    "Location" : "Llocalización",
    "Description" : "Descripción",
    "to" : "hasta",
    "Add" : "Amestar",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Sunday" : "Domingu",
    "Save" : "Guardar",
    "Update" : "Anovar",
    "Your email address" : "Direición de corréu-e",
    "Notification" : "Avisu",
    "Email" : "email",
    "Unknown" : "Desconozse",
    "Accept" : "Aceutar",
    "Decline" : "Refugar",
    "Tentative" : "Tentativa",
    "Send email" : "Unviar mensaxe",
    "All day" : "Tol día",
    "Repeat" : "Repitir",
    "never" : "enxamás",
    "after" : "dempués",
    "available" : "disponible",
    "More" : "Más",
    "Global" : "Global",
    "Personal" : "Personal",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Resources" : "Recursos",
    "Close" : "Zarrar",
    "Anniversary" : "Aniversariu",
    "Week {number} of {year}" : "Selmana {number} del {year}",
    "Daily" : "Caldía",
    "Weekly" : "Selmanalmente",
    "Next" : "Siguiente",
    "Other" : "Otru",
    "When shared show full event" : "Amosar l'eventu completu al compartir",
    "When shared show only busy" : "Amosar namás ocupáu al compartir",
    "When shared hide this event" : "Anubrir l'eventu al compartir",
    "Status" : "Estáu",
    "Confirmed" : "Confirmáu",
    "Categories" : "Estayes",
    "Presentation" : "Presentación",
    "Office" : "Oficina",
    "Mail" : "Corréu",
    "Birthday" : "Data de nacencia"
},
"nplurals=2; plural=(n != 1);");
