OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s avaldas kalendri »%s«",
    "Hello," : "Tere,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud kalendri»%s«.",
    "Open »%s«" : "Ava »%s«",
    "Cheers!" : "Tervist!",
    "Confirm" : "Kinnita",
    "Where:" : "Kus:",
    "Calendar" : "Kalender",
    "Previous day" : "Eelmine päev",
    "Previous week" : "Eelmine nädal",
    "Previous month" : "Eelmine kuu",
    "Next day" : "Järgmine päev",
    "Next week" : "Järgmine nädal",
    "Next month" : "Järgmine kuu",
    "New event" : "Uus sündmus",
    "Today" : "Täna",
    "Day" : "Päev",
    "Week" : "Nädal",
    "Month" : "Kuu",
    "Preview" : "Eelvaade",
    "Copy link" : "Kopeeri link",
    "Edit" : "Redigeeri",
    "Delete" : "Kustuta",
    "Untitled calendar" : "Nimetu kalender",
    "Edit name" : "Muuda nime",
    "Saving name …" : "Salvestan nime ...",
    "Edit color" : "Muuda värvi",
    "Saving color …" : "Salvestan värvi ...",
    "Copy private link" : "Kopeeri privaatne link",
    "Export" : "Ekspordi",
    "Share link" : "Jaga link",
    "Publish calendar" : "Avalda kalender",
    "Copy public link" : "Kopeeri avalik link",
    "Delete share link" : "Kustuta jagamise link",
    "Share with users or groups" : "Jaga kasutajate või gruppidega",
    "No users or groups" : "Ei ole kasutajaid või gruppe",
    "can edit" : "saab muuta",
    "Unshare with {displayName}" : "Lõpeta jagamine kasutajaga: {displayName}",
    "New calendar" : "Uus kalender",
    "Name" : "Nimi",
    "Deleted" : "Kustutatud",
    "Restore" : "Taasta",
    "Delete permanently" : "Kustuta jäädavalt",
    "Import calendars" : "Impordi kalendrid",
    "Filename" : "Faili nimi",
    "Cancel" : "Loobu",
    "Automatic" : "Automaatne",
    "List view" : "Nimekirjavaade",
    "Actions" : "Tegevused",
    "Show week numbers" : "Näita nädalanumberid",
    "Location" : "Asukoht",
    "Description" : "Kirjeldus",
    "to" : "saaja",
    "Add" : "Lisa",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sunday" : "Pühapäev",
    "Save" : "Salvesta",
    "Update" : "Uuenda",
    "Your email address" : "Sinu e-posti aadress",
    "Notification" : "Teavitus",
    "Email" : "Epost",
    "On date" : "Kuupäeval",
    "Unknown" : "Teadmata",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Tentative" : "Esialgne",
    "Send email" : "Saada kiri",
    "All day" : "Kogu päev",
    "Repeat" : "Korda",
    "never" : "mitte kunagi",
    "after" : "pärast",
    "More" : "Rohkem",
    "Global" : "Üldine",
    "Personal" : "Isiklik",
    "Details" : "Üksikasjad",
    "Attendees" : "Osalejad",
    "Resources" : "Ressursid",
    "Close" : "Sulge",
    "Anniversary" : "Aastapäev",
    "Appointment" : "Kohtumine",
    "Vacation" : "Puhkus",
    "Week {number} of {year}" : "Nädal nr. {number} aastas {year}",
    "Does not repeat" : "Ei kordu",
    "Daily" : "Iga päev",
    "Weekly" : "Iga nädal",
    "Monthly" : "Igakuine",
    "Yearly" : "Igaastane",
    "Next" : "Järgmine",
    "Other" : "Muu",
    "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
    "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
    "Status" : "Staatus",
    "Confirmed" : "Kinnitatud",
    "Categories" : "Kategooriad",
    "Presentation" : "Esitlus",
    "Talk" : "Talk",
    "Camping" : "Telkimine",
    "Camp" : "Laager",
    "Movie" : "Film",
    "Cinema" : "Kino",
    "Graduation" : "Lõpetamine",
    "Brainstorm" : "Ajutorm",
    "Baseball" : "Pesapall",
    "Office" : "Kontor",
    "Mail" : "Kirjad",
    "Soccer" : "Jalgpall",
    "Football" : "Ameerika jalgpall",
    "Drive" : "Sõit",
    "Bicycle" : "Jalgratas",
    "Biking" : "Jalgrattaga sõitmine",
    "Basketball" : "Korvpall",
    "Fishing" : "Kalapüük",
    "Hiking" : "Matkaminee",
    "Hike" : "Matk",
    "Art" : "Kunst",
    "Exhibition" : "Näitus",
    "Museum" : "Muuseum",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Studying" : "Õppimine",
    "Doctor" : "Arst",
    "Health" : "Tervis",
    "Dentist" : "Hambaarst",
    "Interview" : "Intervjuu",
    "Training" : "Koolitus",
    "Work out" : "Trenn",
    "Working out" : "Treening",
    "Barber" : "Habemeajaja",
    "Haircut" : "Juukselõikus",
    "Exam" : "Eksam",
    "Fireworks" : "Ilutulestik",
    "Running" : "Jooksmine",
    "Go for a run" : "Mine jooksma",
    "Marathon" : "Maraton",
    "Call" : "Telefonikõne",
    "Calling" : "Helistamine",
    "Christmas" : "Jõulud",
    "Conference" : "Konverents",
    "Pizza" : "Pitsa",
    "Travelling" : "Reisimine",
    "Journey" : "Teekond",
    "Collaborate" : "Koostöö",
    "Pair" : "Paar",
    "Lecture" : "Loeng",
    "Seminar" : "Seminar",
    "Photograph" : "Foto",
    "Party" : "Pidu",
    "Celebration" : "Tähistamine",
    "Celebrate" : "Tähista",
    "Birthday" : "Sünnipäev",
    "Skate" : "Uisutamine",
    "Skateboard" : "Rula",
    "Wine tasting" : "Veini degusteerimine",
    "Golf" : "Golf",
    "Dinner" : "Õhtusöök",
    "User not found" : "Kasutajat ei leitud"
},
"nplurals=2; plural=(n != 1);");
