OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "U zdravlje!",
    "Today" : "Today",
    "Preview" : "Pregled",
    "Copy link" : "Kopiraj vezu",
    "Edit" : "Izmeni",
    "Delete" : "Delete",
    "Share link" : "Veza deljenja",
    "can edit" : "može da menja",
    "Name" : "Ime",
    "Deleted" : "Obrisano",
    "Delete permanently" : "Obriši zauvek",
    "Filename" : "Ime fajla",
    "Cancel" : "Cancel",
    "List view" : "Prikaz liste",
    "Description" : "Opis",
    "Add" : "Dodaj",
    "Monday" : "Ponedeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Sreda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sunday" : "Nedelja",
    "Save" : "Save",
    "Update" : "Ažuriraj",
    "Email" : "email",
    "Unknown" : "Nepoznato",
    "never" : "never",
    "More" : "More",
    "Details" : "Detalji",
    "Close" : "Zatvori",
    "Daily" : "дневно",
    "Weekly" : "недељно",
    "Other" : "Ostali",
    "Movie" : "Film",
    "Mail" : "Pošta"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
