OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "La sesión caducó inesperádamente",
    "Provided email-address is not valid" : "El correo electrónico proporcionado no es válido",
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Error inesperado enviando correo. Por favor contacte con el administrador.",
    "Successfully sent email to %1$s" : "Correo enviado correctamente a %1$s",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte de  que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "Appointments" : "Citas",
    "Schedule appointment \"%s\"" : "Programar cita \"%s\"",
    "Schedule an appointment" : "Programar una cita",
    "Prepare for %s" : "Preparación para %s",
    "Follow up for %s" : "Seguimiento para %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Su cita \"%s\" con %s necesita confirmación",
    "Dear %s, please confirm your booking" : "Estimado %s, por favor confirma tu reserva",
    "Confirm" : "Confirmar",
    "This confirmation link expires in %s hours." : "Este enlace de confirmación expira en %s horas.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Si desea cancelar la cita después de todo, contacte al organizador respondiendo a este correo o visitando la página del perfil del mismo.",
    "Your appointment \"%s\" with %s has been accepted" : "Su cita \"%s\" con %s ha sido aceptada",
    "Dear %s, your booking has been accepted." : "Estimado(a) %s, su cita ha sido aceptada.",
    "Appointment for:" : "Cita para:",
    "Date:" : "Fecha:",
    "Where:" : "Dónde:",
    "Your Comment:" : "Su comentario:",
    "Calendar" : "Calendario",
    "A Calendar app for Nextcloud" : "Una app de calendario para Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "La app de Calendario es una interfaz para el servidor CalDAV de Nextcloud. Sincroniza fácilmente eventos de varios dispositivos con tu Nextcloud y edítalos en línea.\n\n* 🚀 **Integración con otras apps de Nextcloud.** Actualmente, Contactos. Y vendrán más.\n* 🌐 **Soporte de WebCal.** ¿Quieres ver los partidos de tu equipo favorito en tu calendario? ¡Sin problema!\n* 🙋 **Asistentes**. Invita gente a tus eventos.\n* ⌚️ **Libre/ocupado**. Comprueba cuándo tus asistentes están disponibles para la reunión.\n* ⏰ **Recordatorios.** Obtén alarmas de eventos en tu navegador y vía correo electrónico.\n🔍 **Búsqueda.** Encuentra tus eventos con facilidad.\n☑️ Tareas. ve las tareas con fecha de finalización directamente en el calendario.\n* 🙈 **No reinventamos la rueda.** Basada en las grandes librerías [c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) y [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Día anterior",
    "Previous week" : "Semana anterior",
    "Previous month" : "Mes anterior",
    "Next day" : "Día siguiente",
    "Next week" : "Semana siguiente",
    "Next month" : "Mes siguiente",
    "New event" : "Nuevo evento",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Preview" : "Vista previa",
    "Copy link" : "Copiar enlace",
    "Edit" : "Editar",
    "Delete" : "Eliminar",
    "Appointment link was copied to clipboard" : "Enlace de la cita copiado al portapapeles",
    "Appointment link could not be copied to clipboard" : "No se ha podido copiar el enlace de la cita al portapapeles",
    "Add new" : "Añadir nuevo",
    "Untitled calendar" : "Calendario sin título",
    "Edit name" : "Editar el nombre",
    "Saving name …" : "Guardando nombre…",
    "Edit color" : "Editar color",
    "Saving color …" : "Guardando color…",
    "Copy private link" : "Copiar enlace privado",
    "Export" : "Exportar",
    "Unshare from me" : "Dejar de compartir conmigo",
    "Disable calendar \"{calendar}\"" : "Desactivar calendario \"{calendar}\"",
    "Disable untitled calendar" : "Desactivar el calendario sin título",
    "Enable calendar \"{calendar}\"" : "Activar calendario \"{calendar}\"",
    "Enable untitled calendar" : "Activar el calendario sin título",
    "An error occurred, unable to change visibility of the calendar." : "Se ha producido un error, no se ha podido cambiar la visibilidad del calendario.",
    "An error occurred, unable to delete the calendar." : "Se ha producido un error, no se ha podido borrar el calendario.",
    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
    "Calendar link could not be copied to clipboard." : "El enlace de calendario no se ha podido copiar al portapapeles. ",
    "An error occurred, unable to rename the calendar." : "Se ha producido un error, no se ha podido renombrar el calendario.",
    "An error occurred, unable to change the calendar's color." : "Se ha producido un error, no se ha podido cambiar el color del calendario.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejando de compartir el calendario en {countdown} segundo","Dejando de compartir el calendario en {countdown} segundos","Dejando de compartir el calendario en {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Borrando el calendario en {countdown} segundo","Eliminando el calendario en {countdown} segundos","Eliminando el calendario en {countdown} segundos"],
    "Share link" : "Compartir enlace",
    "Publish calendar" : "Publicar calendario",
    "Publishing calendar" : "Publicando calendario",
    "Copy public link" : "Copiar enlace público",
    "Send link to calendar via email" : "Enviado enlace al calendario por correo",
    "Enter one address" : "Escriba una dirección",
    "Sending email …" : "Enviando correo…",
    "Copy subscription link" : "Copiar enlace de suscripción",
    "Copying link …" : "Copiando enlace…",
    "Copied link" : "Enlace copiado",
    "Could not copy link" : "No se ha podido copiar el enlace",
    "Copy embedding code" : "Copiar código de insercción",
    "Copying code …" : "Copiando código…",
    "Copied code" : "Código copiado",
    "Could not copy code" : "No se ha podido copiar el código",
    "Delete share link" : "Eliminar enlace compartido",
    "Deleting share link …" : "Eliminando enlace compartido…",
    "An error occurred, unable to publish calendar." : "Se ha producido un error, no se puede publicar el calendario.",
    "An error occurred, unable to send email." : "Se ha producido un error, no se puede enviar el correo.",
    "Embed code copied to clipboard." : "Código incrustado copiado al portapapeles.",
    "Embed code could not be copied to clipboard." : "No se ha podido copiar al portapapeles el código incrustado.",
    "Unpublishing calendar failed" : "Error al cancelar la publicación del calendario",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "can edit" : "puede editar",
    "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Se ha producido un error, no fue posible cambiar el dejar de compartir el calendario.",
    "An error occurred, unable to change the permission of the share." : "Se ha producido un error, no fue posible cambiar los permisos del recurso compartido.",
    "New calendar" : "Nuevo calendario",
    "Name for new calendar" : "Nombre del nuevo calendario",
    "Creating calendar …" : "Creando calendario…",
    "New calendar with task list" : "Nuevo calendario con lista de tareas",
    "New subscription from link (read-only)" : "Nueva suscripción desde el enlace (sólo lectura)",
    "Creating subscription …" : "Creando suscripción…",
    "An error occurred, unable to create the calendar." : "Se ha producido un error, no fue posible crear el calendario.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Por favor escriba un enlace válido (comenzando con http://, https://, webcal://, o webcals://)",
    "Trash bin" : "Papelera",
    "Loading deleted items." : "Cargando elementos eliminados.",
    "You do not have any deleted items." : "Usted no tiene elementos eliminados.",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar permanentemente",
    "Empty trash bin" : "Vaciar papelera",
    "Untitled item" : "Elemento sin nombre",
    "Unknown calendar" : "Calendario desconocido",
    "Could not load deleted calendars and objects" : "No es posible cargar calendarios u objetos eliminados",
    "Could not restore calendar or event" : "No es posible restaurar el calendario o evento",
    "Do you really want to empty the trash bin?" : "¿De verdad quieres vaciar la papelera?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Los elementos en la papelera de reciclaje se eliminan después de {numDays} día","Los elementos en la papelera de reciclaje se eliminan después de {numDays} días","Los elementos en la papelera de reciclaje se eliminan después de {numDays} días"],
    "Could not update calendar order." : "No se puede actualizar el orden del calendario.",
    "Import calendars" : "Importar calendarios",
    "Please select a calendar to import into …" : "Por favor, selecciona un calendario al que importar…",
    "Filename" : "Nombre de archivo",
    "Calendar to import into" : "Calendario en el cual importar",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendario","Importar calendarios","Importar calendarios"],
    "{filename} could not be parsed" : "{filename} no pudo ser analizado",
    "No valid files found, aborting import" : "No se han encontrado archivos válidos, cancelando la importación",
    "Import partially failed. Imported {accepted} out of {total}." : "La importación ha fallado parcialmente. Importados {accepted} sobre {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se ha importado con éxito %n evento.","Se han importado con éxito %n eventos.","Se han importado con éxito %n eventos."],
    "Automatic" : "Automático",
    "Automatic ({detected})" : "Automático ({detected})",
    "New setting was not saved successfully." : "El nuevo ajuste no ha podido ser guardado correctamente.",
    "Shortcut overview" : "Vista general de atajos",
    "or" : "o",
    "Navigation" : "Navegación",
    "Previous period" : "Periodo anterior",
    "Next period" : "Periodo siguiente",
    "Views" : "Vistas",
    "Day view" : "Vista diaria",
    "Week view" : "Vista semanal",
    "Month view" : "Vista mensual",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "Create event" : "Crear evento",
    "Show shortcuts" : "Mostrar atajos",
    "Editor" : "Editor",
    "Close editor" : "Cerrar editor",
    "Save edited event" : "Guardar el evento editado",
    "Delete edited event" : "Borrar el evento editado",
    "Duplicate event" : "Evento duplicado",
    "Enable birthday calendar" : "Permitir calendario de cumpleaños",
    "Show tasks in calendar" : "Ver tareas en el calendario",
    "Enable simplified editor" : "Activar editor simplificado",
    "Limit visible events per view" : "Limite los eventos visibles por vista",
    "Show weekends" : "Mostrar fines de semana",
    "Show week numbers" : "Mostrar numero de semana",
    "Time increments" : "Incrementos de tiempo",
    "Default reminder" : "Recordatorio predeterminado",
    "Copy primary CalDAV address" : "Copiar dirección primaria de CalDAV",
    "Copy iOS/macOS CalDAV address" : "Copiar la dirección CalDAV iOS/macOS",
    "Personal availability settings" : "Ajustes de disponibilidad personal",
    "Show keyboard shortcuts" : "Mostrar atajos de teclado",
    "Calendar settings" : "Configuración del calendario",
    "No reminder" : "No hay recordatorio",
    "CalDAV link copied to clipboard." : "El enlace de CalDAV copiado al portapapeles",
    "CalDAV link could not be copied to clipboard." : "El enlace CalDAV no se puede copiar al portapapeles",
    "Appointment was created successfully" : "Se ha creado la cita exitosamente",
    "Appointment was updated successfully" : "Se ha actualizado la cita exitosamente",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
    "0 minutes" : "0 minutos",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
    "_{duration} day_::_{duration} days_" : ["{duration} día","{duration} días","{duration} días"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semana","{duration} semanas","{duration} semanas"],
    "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} meses","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} año","{duration} años","{duration} años"],
    "To configure appointments, add your email address in personal settings." : "Para configurar citas, añade tu dirección de correo en ajustes personales.",
    "Public – shown on the profile page" : "Público - visible en la página de perfil",
    "Private – only accessible via secret link" : "Privado - solamente accesible vía enlace secreto",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Visibility" : "Visibilidad",
    "Duration" : "Duración",
    "Increments" : "Incrementos",
    "Additional calendars to check for conflicts" : "Calendarios adicionales sobre los que comprobar conflictos",
    "Pick time ranges where appointments are allowed" : "Elegir rangos de tiempo para permitir citas",
    "to" : "para",
    "Delete slot" : "Eliminar espacio",
    "No times set" : "No hay tiempo fijado",
    "Add" : "Añadir",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Add time before and after the event" : "Añadir tiempo antes y después del evento",
    "Before the event" : "Antes del evento",
    "After the event" : "Después del evento",
    "Planning restrictions" : "Restricciones de planificación",
    "Minimum time before next available slot" : "Intervalo de tiempo mínimo antes del siguiente hueco disponible",
    "Max slots per day" : "Cantidad de huecos máxima al día",
    "Limit how far in the future appointments can be booked" : "Limitar con cuánto adelanto se puede pedir una cita",
    "Create appointment" : "Crear cita",
    "Edit appointment" : "Editar cita",
    "Save" : "Guardar",
    "Update" : "Actualizar",
    "Please confirm your reservation" : "Por favor, confirme su reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Te hemos enviado un correo con los detalles. Por favor, confirma tu cita usando el enlace del correo. Ahora puedes cerrar esta página.",
    "Your name" : "Tu nombre",
    "Your email address" : "Tu dirección de correo",
    "Please share anything that will help prepare for our meeting" : "Por favor, comparte algo que ayude a preparar nuestra reunión",
    "Could not book the appointment. Please try again later or contact the organizer." : "No ha sido posible reservar una cita. Por favor, inténtalo más tarde o contacta con el organizador.",
    "Book the appointment" : "Reservar la cita",
    "Reminder" : "Recordatorio",
    "before at" : "antes de las",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Audio notification" : "Notificación de audio",
    "Other notification" : "Otras notificaciones",
    "Relative to event" : "Relativo al evento",
    "On date" : "en fecha",
    "Edit time" : "Hora de edición",
    "Save time" : "Guardar hora",
    "Remove reminder" : "Eliminar recordatorio",
    "on" : "activo",
    "at" : "a",
    "+ Add reminder" : "+ Añadir recordatorio",
    "Add reminder" : "Añadir recordatorio",
    "_second_::_seconds_" : ["segundo","segundos","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos","minutos"],
    "_hour_::_hours_" : ["hora","horas","horas"],
    "_day_::_days_" : ["día","días","días"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "Invitation accepted" : "Invitación aceptada",
    "Available" : "Disponible",
    "Suggested" : "Sugerido",
    "Participation marked as tentative" : "Participación marcada como provisional",
    "Accepted {organizerName}'s invitation" : "Aceptada la invitación de {organizerName}",
    "Not available" : "No disponible",
    "Invitation declined" : "Invitación rechazada",
    "Declined {organizerName}'s invitation" : "Se ha rechazado la invitación de {organizerName}",
    "Invitation is delegated" : "Se ha delegado la invitación",
    "Checking availability" : "Comprobando disponibilidad",
    "Invitation sent" : "Invitación enviada",
    "Has not responded to {organizerName}'s invitation yet" : "Todavía no ha respondido a la invitación de {organizerName}.",
    "Availability of attendees, resources and rooms" : "Disponibilidad de asistentes, recursos y habitaciones",
    "{organizer} (organizer)" : "{organizer} (organizador)",
    "Free" : "Libre",
    "Busy (tentative)" : "Ocupado (provisional)",
    "Busy" : "Ocupado",
    "Out of office" : "Fuera de la oficina",
    "Unknown" : "Desconocido",
    "Accept" : "Acceptar",
    "Decline" : "Declinar",
    "Tentative" : "Pendiente",
    "The invitation has been accepted successfully." : "La invitación se ha aceptado con éxito.",
    "Failed to accept the invitation." : "Fallo al aceptar la invitación.",
    "The invitation has been declined successfully." : "La invitación se ha declinado con éxito.",
    "Failed to decline the invitation." : "Fallo al declinar la invitación.",
    "Your participation has been marked as tentative." : "Se ha marcado tu participación como provisional.",
    "Failed to set the participation status to tentative." : "Fallo al marcar el estado de participación como provisional.",
    "Create Talk room for this event" : "Crear sala de conversación para este evento",
    "Show busy times" : "Mostrar horarios ocupados",
    "No attendees yet" : "Aún no hay asistentes",
    "Successfully appended link to talk room to description." : "Enlace agregado con éxito en la descripción a la sala de conversación.",
    "Error creating Talk room" : "Error al crear la sala de conversación",
    "Send email" : "Enviar email",
    "Chairperson" : "Presidente/a",
    "Required participant" : "Participante requerido",
    "Optional participant" : "Participante opcional",
    "Non-participant" : "No participa",
    "Remove attendee" : "Eliminar asistente",
    "Search for emails, users or contacts" : "Buscar correos, usuarios o contactos",
    "No match found" : "No se ha encontrado ningún resultado",
    "(organizer)" : "(organizador)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar invitaciones y gestionar las respuestas,  [linkopen]añade tu dirección email en los ajustes personales[linkclose].",
    "Remove color" : "Quitar color",
    "Event title" : "Título del evento",
    "All day" : "Todo el día",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "No se puede modificar el ajuste de todo el día en eventos que son parte de una serie recurrente.",
    "from {startDate}" : "desde {startDate}",
    "from {startDate} at {startTime}" : "desde {startDate} a las {startTime}",
    "to {endDate}" : "hasta {endDate}",
    "to {endDate} at {endTime}" : "hasta {endDate} a las {endTime}",
    "Repeat" : "Repetir",
    "End repeat" : "Finalizar repetición",
    "Select to end repeat" : "Seleccionar para finalizar la repetición",
    "never" : "nunca",
    "on date" : "en fecha",
    "after" : "después de",
    "_time_::_times_" : ["vez","veces","veces"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento es la excepción a la serie recurrente. No le puedes añadir una regla recurrente.",
    "first" : "primero",
    "third" : "tercero",
    "fourth" : "cuarto",
    "fifth" : "quinto",
    "second to last" : "penúltimo",
    "last" : "último",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Los cambios en la regla de recurrencia solo se aplicarán a este y a todos los sucesos futuros.",
    "Repeat every" : "Repetir cada",
    "By day of the month" : "Por día del mes",
    "On the" : "En el",
    "_month_::_months_" : ["mes","meses","meses"],
    "_year_::_years_" : ["año","años","años"],
    "weekday" : "día laborable",
    "weekend day" : "día de fin de semana",
    "No recurrence" : "No recurrente",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud no admite totalmente la definición de recurrencia de este evento. Si edita las opciones de recurrencia, ciertas repeticiones pueden perderse.",
    "Suggestions" : "Sugerencias",
    "No rooms or resources yet" : "Aún no hay salas ni recursos",
    "Add resource" : "Añade recurso",
    "Has a projector" : "Tiene un proyector",
    "Has a whiteboard" : "Tiene una pizarra",
    "Wheelchair accessible" : "Accesible en silla de ruedas",
    "Remove resource" : "Quitar recurso",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asiento","{seatingCapacity} asientos","{seatingCapacity} asientos"],
    "Projector" : "Proyector",
    "Whiteboard" : "Pizarra blanca",
    "Search for resources or rooms" : "Buscar recursos o salas",
    "available" : "disponible",
    "unavailable" : "no disponible",
    "Room type" : "Tipo de sala",
    "Any" : "Cualquiera",
    "Minimum seating capacity" : "Capacidad mínima de los asientos",
    "More" : "Más",
    "Update this occurrence" : "Actualiza esta ocurrencia",
    "Update this and all future" : "Actualiza esto y todo futuro",
    "Public calendar does not exist" : "Este calendario público no existe",
    "Maybe the share was deleted or has expired?" : "¿Puede ser que el recurso compartido haya sido borrado o haya caducado?",
    "Please select a time zone:" : "Por favor seleccione una zona horaria:",
    "Pick a time" : "Elige una hora",
    "Pick a date" : "Elige una fecha",
    "from {formattedDate}" : "desde {formattedDate}",
    "to {formattedDate}" : "hasta {formattedDate}",
    "on {formattedDate}" : "en {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "desde {formattedDate} a las {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "hasta {formattedDate} a las {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "en {formattedDate} a las {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} a las {formattedTime}",
    "Please enter a valid date" : "Por favor especifique una fecha  válida",
    "Please enter a valid date and time" : "Por favor especifique valores correctos de fecha y hora",
    "Type to search time zone" : "Escribe para buscar la zona horaria",
    "Global" : "Global",
    "Select date" : "Seleccionar fecha",
    "Select slot" : "Seleccionar hora",
    "No slots available" : "No hay horas disponibles",
    "The slot for your appointment has been confirmed" : "La hora de tu cita ha sido confirmada",
    "Appointment Details:" : "Detalles de la cita:",
    "Time:" : "Hora:",
    "Booked for:" : "Reservado para:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Gracias. Tu reserva de {startDate} a {endDate} ha sido confirmada.",
    "Book another appointment:" : "Reservar otra cita:",
    "See all available slots" : "Ver todos los huecos disponibles",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "La hora de tu cita de {startDate} a  {endDate} ya no está disponible.",
    "Please book a different slot:" : "Por favor, reserva otra hora distinta:",
    "Book an appointment with {name}" : "Reservar una cita con {name}",
    "No public appointments found for {name}" : "No se han encontrado citas públicas para {name}",
    "Personal" : "Personal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detección automática de la zona horaria determinó que tu zona horaria sea UTC. Esto es probablemente el resultado de las medidas de seguridad de su navegador web. Por favor establezca su zona horaria manualmente en la configuración del calendario. ",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se ha encontrado la zona horaria configurada ({timezoneId}). Volviendo a UTC.\nPor favor, cambia tu zona horaria en la configuración e informa de este problema.",
    "No more events today" : "No hay más eventos hoy",
    "No upcoming events" : "No hay eventos próximos",
    "Create a new event" : "Crear un nuevo evento",
    "[Today]" : "[Hoy]",
    "[Tomorrow]" : "[Mañana]",
    "[Yesterday]" : "[Ayer]",
    "[Last] dddd" : "[Último] dddd",
    "Event does not exist" : "el evento no existe",
    "Duplicate" : "Duplicar",
    "Delete this occurrence" : "Eliminar esta ocurrencia",
    "Delete this and all future" : "Eliminar este y los futuros",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Resources" : "Recursos",
    "Close" : "Cerrar",
    "Show more details" : "Ver más detalles",
    "Subscribe to {name}" : "Subscribir a {name}",
    "Export {name}" : "Exportar {name}",
    "Anniversary" : "Aniversario",
    "Appointment" : "Cita",
    "Business" : "Empresa",
    "Education" : "Educación",
    "Holiday" : "Vacaciones",
    "Meeting" : "Reunión",
    "Miscellaneous" : "Varios",
    "Non-working hours" : "Horario no laborable",
    "Not in office" : "Fuera de la oficina",
    "Phone call" : "Llamad de teléfono",
    "Sick day" : "Estoy enfermo",
    "Special occasion" : "Ocasión especial",
    "Travel" : "Viaje",
    "Vacation" : "Vacaciones",
    "Midnight on the day the event starts" : "Medianoche del día en el que comienza el evento",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n día antes del evento, a las {formattedHourMinute}","%n días antes del evento, a las {formattedHourMinute}","%n días antes del evento, a las {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semana antes del evento, a las {formattedHourMinute}","%n semanas antes del evento, a las {formattedHourMinute}","%n semanas antes del evento, a las {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "en el día del evento, a las {formattedHourMinute}",
    "at the event's start" : "al comienzo del evento",
    "at the event's end" : "al final del evento",
    "{time} before the event starts" : "{time} antes de que comience el evento",
    "{time} before the event ends" : "{time} antes de que termine el evento",
    "{time} after the event starts" : "{time} después de que comience el evento",
    "{time} after the event ends" : "{time} después de que termine el evento",
    "on {time}" : "a las {time}",
    "on {time} ({timezoneId})" : "a las {time} ({timezoneld})",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Does not repeat" : "No repetir",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Monthly" : "Mensualmente",
    "Yearly" : "Anualmente",
    "_Every %n day_::_Every %n days_" : ["Cada %n día","Cada %n días","Cada %n días"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n semana","Cada %n semanas","Cada %n semanas"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n año","Cada %n años","Cada %n años"],
    "_on {weekday}_::_on {weekdays}_" : ["en {weekday}","en {weekdays}","en {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["en día {dayOfMonthList}","en los días {dayOfMonthList}","en los días {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "en el {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "n {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "el {ordinalNumber} {byDaySet} de {monthNames} ",
    "until {untilDate}" : "hasta {untilDate}",
    "_%n time_::_%n times_" : ["%n vez","%n veces","%n veces"],
    "Untitled event" : "Evento sin título",
    "Untitled task" : "Tarea sin título",
    "Please ask your administrator to enable the Tasks App." : "Por favor, solicite a su administrador que permita la aplicación de tareas.",
    "Prev" : "Anterior",
    "Next" : "Siguiente",
    "Prev year" : "Año anterior",
    "Next year" : "Año siguiente",
    "Year" : "Año",
    "W" : "S",
    "%n more" : "%n más",
    "No events to display" : "No hay eventos que mostrar",
    "_+%n more_::_+%n more_" : ["+%n más","+%n más","+%n más"],
    "No events" : "No hay eventos",
    "Create a new event or change the visible time-range" : "Crea un evento nuevo o cambia el rango de horas visibles",
    "It might have been deleted, or there was a typo in a link" : "Puede haber sido borrado, o había una errata en el enlace",
    "It might have been deleted, or there was a typo in the link" : "Puede haber sido borrado, o había una errata en el enlace",
    "Meeting room" : "Sala de reuniones",
    "Lecture hall" : "Sala de conferencias",
    "Seminar room" : "Sala de seminario",
    "Other" : "Otro",
    "When shared show" : "Al compartir, mostrar",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar solo ocupado",
    "When shared hide this event" : "Al compartir, ocultar este evento",
    "The visibility of this event in shared calendars." : "Visibilidad de este evento en calendarios compartidos",
    "Add a location" : "Añadir ubicación",
    "Add a description" : "Añadir una descripción",
    "Status" : "Estado",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelado",
    "Confirmation about the overall status of the event." : "Confirmación acerca del estado general del evento.",
    "Show as" : "Mostrar como",
    "Take this event into account when calculating free-busy information." : "Tome este evento en consideración cuando calcule la información acerca de libre-ocupado.",
    "Categories" : "Categorías",
    "Categories help you to structure and organize your events." : "Las categorías le ayudan a estructurar y organizar sus eventos.",
    "Search or add categories" : "Buscar o añadir categorías",
    "Add this as a new category" : "Añadir esto como categoría nueva",
    "Custom color" : "Colores personalizados",
    "Special color of this event. Overrides the calendar-color." : "Color especial de este evento. Se superpone al color de calendario.",
    "Chat room for event" : "Sala de conversación para el evento",
    "Imported {filename}" : "Importado {filename}",
    "Meditation" : "Meditación",
    "Relaxing" : "Relajante",
    "Relax" : "Relajarse",
    "Break" : "Pausa",
    "Commute" : "Desplazamiento",
    "Commuting" : "Desplazándose",
    "Shuttle" : "Lanzadera",
    "Invoice" : "Factura",
    "Finance" : "Finanzas",
    "Bank" : "Banco",
    "Money" : "Dinero",
    "Wedding" : "Boda",
    "Dog" : "Perro",
    "Concert" : "Concierto",
    "Festival" : "Festival",
    "Theater" : "Teatro",
    "Theatre" : "Teatro",
    "Presentation" : "Presentación",
    "Talk" : "Coloquio",
    "Speech" : "Discurso",
    "Deadline" : "Entrega",
    "Submission" : "Envío",
    "Reporting" : "Informe",
    "Camping" : "Camping",
    "Camp" : "Campo",
    "Election" : "Elección",
    "Voting" : "Votación",
    "Vote" : "Votar",
    "Barbecue" : "Parrillada",
    "Barbeque" : "Barbacoa",
    "Garden" : "Jardín",
    "Farm" : "Granja",
    "Movie" : "Película",
    "Cinema" : "Cine",
    "Graduation" : "Graduación",
    "Brainstorm" : "Lluvia de ideas",
    "Review" : "Revisar",
    "Audit" : "Auditoría",
    "Inspection" : "Inspección",
    "Proofreading" : "Corrección de pruebas",
    "Baseball" : "Baseball",
    "Meet" : "Reunirse",
    "Planning" : "Planificando",
    "Pointing" : "Señalando",
    "Retrospective" : "Retrospectiva",
    "Office" : "Oficina",
    "Contributor week" : "Semana del colaborador",
    "Mail" : "Correo electrónico",
    "Soccer" : "Fútbol",
    "Football" : "Rugby",
    "Gaming" : "Video juegos",
    "Drive" : "Conducir",
    "Driving" : "Conducción",
    "Bicycle" : "Bicicleta",
    "Cycle" : "Bici",
    "Cycling" : "Ciclismo",
    "Biking" : "Pedaleando",
    "Bike" : "Bici",
    "Podcast" : "Podcast",
    "Basketball" : "Baloncesto",
    "Fishing" : "Pesca",
    "Hiking" : "Excursionismo",
    "Hike" : "Caminata",
    "Art" : "Arte",
    "Exhibition" : "Exhibición",
    "Museum" : "Museo",
    "Pilates" : "Pilates",
    "Park" : "Parque",
    "Walk" : "Caminata",
    "Studying" : "Estudiando",
    "Doctor" : "Médico",
    "Health" : "Salud",
    "Dentist" : "Dentista",
    "Hospital" : "Hospital",
    "Interview" : "Entrevista",
    "Training" : "Formación",
    "Practice" : "Práctica",
    "Sports" : "Deportes",
    "Exercise" : "Ejercicio",
    "Work out" : "Rutina de ejercicio",
    "Working out" : "Haciendo ejercicio",
    "Gym" : "Gimnasio",
    "Barber" : "Peluquero",
    "Haircut" : "Corte de pelo",
    "Hairdresser" : "Peluquería",
    "Exam" : "Exámen",
    "Written test" : "Test escrito",
    "Oral test" : "Test oral",
    "Working" : "Trabajando",
    "New Years Eve" : "Nochevieja",
    "NYE" : "Nochevieja",
    "Fireworks" : "Fuegos artificiales",
    "Running" : "Corriendo",
    "Go for a run" : "Salir a correr",
    "Marathon" : "Maratón",
    "Video-conference" : "Videoconferencia",
    "Conference-call" : "Llamada de conferencia",
    "Video-call" : "Videollamada",
    "Video-chat" : "Videochat",
    "Video-meeting" : "Video-conferencia",
    "Call" : "Llamada",
    "Calling" : "Llamando",
    "Christmas" : "Navidad",
    "Conference" : "Conferencia",
    "Pizza" : "Pizza",
    "Travelling" : "Viajando",
    "Trip" : "Viaje",
    "Journey" : "Trayecto",
    "Collaborate" : "Colaborar",
    "Pair" : "Par",
    "Lecture" : "Clase/Conferencia",
    "Seminar" : "Seminario",
    "Teaching" : "Cursos",
    "Photograph" : "Fotografía",
    "Party" : "Fiesta",
    "Celebration" : "Celebración",
    "Celebrate" : "Celebrar",
    "Birthday" : "Cumpleaños",
    "Shopping" : "Compras",
    "Groceries" : "Comestibles",
    "Skate" : "Patinar",
    "Skateboard" : "Monopatín",
    "Wine tasting" : "Catando vinos",
    "Golf" : "Golf",
    "Dinner" : "Cena",
    "Lunch" : "Almuerzo",
    "Appointment not found" : "Cita no encontrada",
    "User not found" : "Usuario no encontrado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
