OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "جلسة المستخدم انتهت",
    "Provided email-address is not valid" : "البريد المدخل غير صحيح",
    "%s has published the calendar »%s«" : "%s نشر التقويم »%s«",
    "Unexpected error sending email. Please contact your administrator." : "حدث خطأ اثناء إرسال البريد، تحقق من اعدادات البريد او تواصل مع مسؤول النظام.",
    "Hello," : "مرحبا %s،",
    "We wanted to inform you that %s has published the calendar »%s«." : "المستخدم %s قام بنشر تقويم »%s«.",
    "Open »%s«" : "فتح »%s«",
    "Cheers!" : "تحياتي!",
    "Upcoming events" : "الفعاليات القادمة",
    "Appointments" : "المواعيد",
    "Confirm" : "تأكيد",
    "Date:" : "التاريخ:",
    "Calendar" : "التقويم",
    "A Calendar app for Nextcloud" : "تطبيق التقويم لـ نكست كلاود",
    "Previous day" : "اليوم الماضي",
    "Previous week" : "الاسبوع الماضي",
    "Previous month" : "الشهر الماضي",
    "Next day" : "اليوم القادم",
    "Next week" : "الاسبوع القادم",
    "Next month" : "الشهر القادم",
    "New event" : "حدث جديد",
    "Today" : "اليوم",
    "Day" : "يوم",
    "Week" : "أسبوع",
    "Month" : "شهر",
    "List" : "قائمة",
    "Preview" : "معاينة",
    "Copy link" : "انسخ الرابط",
    "Edit" : "تعديل",
    "Delete" : "حذف ",
    "Untitled calendar" : "تقويم بدون اسم",
    "Edit name" : "تعديل الاسم",
    "Saving name …" : "جاري حفظ الاسم   …",
    "Edit color" : "تعديل اللون",
    "Saving color …" : "جاري حفظ اللون    …",
    "Copy private link" : "نسخ الرابط الخاص",
    "Export" : "تصدير",
    "Unshare from me" : "أنت ألغيت المشاركة",
    "An error occurred, unable to change visibility of the calendar." : "حدث خطأ، لا يمكن تعديل وضعية ظهور التقويم.",
    "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
    "Calendar link copied to clipboard." : "تم نسخ رابط التقويم.",
    "Calendar link could not be copied to clipboard." : "لم نتمكن من نسخ رابط التقويم.",
    "An error occurred, unable to rename the calendar." : "حدث خطأ، لا يمكن تعديل اسم التقويم.",
    "An error occurred, unable to change the calendar's color." : "حدث خطأ، لا يمكن تعديل لون التقويم.",
    "Share link" : "رابط المشاركة",
    "Publish calendar" : "نشر التقويم",
    "Publishing calendar" : "جاري نشر التقويم",
    "Copy public link" : "نسخ الرابط العام",
    "Send link to calendar via email" : "ارسال رابط التقويم عبر البريد",
    "Enter one address" : "ادخل عنوان بريدي واحد",
    "Sending email …" : "جاري ارسال البريد  …",
    "Copy subscription link" : "نسخ رابط الاشتراك",
    "Copying link …" : "جاري نسخ رابط  …",
    "Copied link" : "تم نسخ الرابط",
    "Could not copy link" : "لا يمكن نسخ الرابط",
    "Copy embedding code" : "نسخ الكود المرفق",
    "Copying code …" : "نسخ الكود  …",
    "Copied code" : "تم نسخ الكود",
    "Could not copy code" : "لا يمكن نسخ الكود",
    "Delete share link" : "حذف ارتباط المشاركة",
    "Deleting share link …" : "حذف رابط المشاركة  …",
    "An error occurred, unable to publish calendar." : "حصل خطأ، لا يمكن نشر التقويم",
    "An error occurred, unable to send email." : "حدث خطأ، لا يمكن ارسال البريد.",
    "Embed code copied to clipboard." : "تم نسخ الكود المرفق.",
    "Embed code could not be copied to clipboard." : "لا يمكن نسخ الكود المرفق",
    "Unpublishing calendar failed" : "فشل في الغاء نشر التقويم",
    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
    "No users or groups" : "لا يوجد مستخدمين أو مجموعات",
    "can edit" : "يمكن التحرير",
    "Unshare with {displayName}" : "الغاء المشاركة مع {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "حدث خطأ، لا يمكن تعديل نشر التقويم",
    "An error occurred, unable to change the permission of the share." : "حدث خطأ، لا يمكن تعديل صلاحيات نشر التقويم.",
    "New calendar" : "تقويم جديد",
    "Creating calendar …" : "جاري انشاء تقويم  …",
    "New calendar with task list" : "تقويم جديد مع قائمة مهام",
    "New subscription from link (read-only)" : "مشتركين جدد عن طريق رابط (للقراءة فقط)",
    "Creating subscription …" : "جاري انشاء اشتراك  …",
    "An error occurred, unable to create the calendar." : "حدث خطأ، لا يمكن انشاء التقويم.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "يرجى ادخال رابط صحيح (يبدأ بـ https://, http://, webcals://, webcal://)",
    "Trash bin" : "المهملات",
    "Name" : "الاسم",
    "Deleted" : "تم حذفه",
    "Restore" : "استعادة ",
    "Delete permanently" : "حذف بشكل دائم",
    "Empty trash bin" : "تفريغ سلة المهملات",
    "Untitled item" : "بند غير معنون",
    "Unknown calendar" : "تقويم غير معروف",
    "Could not update calendar order." : "لا يمكن تحديث ترتيب التقويم.",
    "Import calendars" : "استيراد التقويم",
    "Please select a calendar to import into …" : "يرجى اختيار تقويم للاستيراد اليه  …",
    "Filename" : "اسم الملف",
    "Calendar to import into" : "تقويم للاستيراد اليه",
    "Cancel" : "إلغاء",
    "_Import calendar_::_Import calendars_" : ["استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم"],
    "Automatic" : "تلقائي",
    "Automatic ({detected})" : "تلقائي ({detected})",
    "New setting was not saved successfully." : "لم يتم حفظ الاعدادات الجديدة.",
    "Shortcut overview" : "نظرة عامة للاختصارات",
    "or" : "او",
    "Navigation" : "التنقل",
    "Previous period" : "الفترة السابقة",
    "Next period" : "الفترة القادمة",
    "Views" : "مشاهدات",
    "Day view" : "مشاهدات يومية",
    "Week view" : "مشاهدات اسبوعية",
    "Month view" : "مشاهدات شهرية",
    "List view" : "عرض على شكل قائمة",
    "Actions" : "الإجراءات",
    "Create event" : "انشاء فعالية",
    "Show shortcuts" : "انشاء اختصارات",
    "Enable birthday calendar" : "تفعيل تقويم عيد الميلاد",
    "Show tasks in calendar" : "اظهار المهام في التقويم",
    "Enable simplified editor" : "تفعيل المحرر البسيط",
    "Limit visible events per view" : "حصر رؤية الفعاليات بالمشاهدة",
    "Show weekends" : "اظهار ايام نهاية الاسبوع",
    "Show week numbers" : "اظهار ارقام الأسابيع",
    "Copy primary CalDAV address" : "نسخ عنوان CalDAV الرئيسي",
    "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
    "Show keyboard shortcuts" : "اظهار اختصارات لوحة المفاتيح",
    "No reminder" : "لا يوجد تذكير ",
    "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
    "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
    "Location" : "الموقع",
    "Description" : "الوصف",
    "Duration" : "المدة الزمنية",
    "to" : "إلى",
    "Add" : "إضافة",
    "Monday" : "الإثنين",
    "Tuesday" : "الثلاثاء",
    "Wednesday" : "الأربعاء",
    "Thursday" : "الخميس",
    "Friday" : "الجمعة",
    "Saturday" : "السبت",
    "Sunday" : "الأحد",
    "Save" : "حفظ",
    "Update" : "حدث",
    "Your email address" : "عنوان بريديك الإلكتروني",
    "before at" : "قبل",
    "Notification" : "تنبيه",
    "Email" : "البريد الإلكتروني",
    "Audio notification" : "تنبيه صوتي",
    "Other notification" : "تنبيه اخر",
    "Relative to event" : "مرتبط بفعالية",
    "On date" : "في تاريخ",
    "Edit time" : "تعديل الوقت",
    "Save time" : "حفظ الوقت",
    "Remove reminder" : "حذف التذكير",
    "on" : "في",
    "at" : "في",
    "+ Add reminder" : "+ اضافة تذكير",
    "_second_::_seconds_" : ["ثانية","ثانية","ثانية","ثواني","ثواني","ثواني"],
    "Available" : "متوفر",
    "Not available" : "غير متوفر",
    "Availability of attendees, resources and rooms" : "متوفرين من الحضور والموارد والغرف",
    "Free" : "متوفر",
    "Busy (tentative)" : "مشغول (حاليا)",
    "Busy" : "مشغول",
    "Out of office" : "خارج المكتب",
    "Unknown" : "غير معروف",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "Tentative" : "مؤقت",
    "Create Talk room for this event" : "انشاء غرفة تحدث لهذه الفعالية.",
    "Show busy times" : "اظهار الاوقات الممتلئة",
    "No attendees yet" : "لا يوجد حضور بعد",
    "Successfully appended link to talk room to description." : "تم اضافة الرابط في وصف غرفة التحدث بنجاح.",
    "Error creating Talk room" : "خطأ في انشاء غرفة تحدث",
    "Send email" : "إرسال بريد",
    "Chairperson" : "الرئيس",
    "Required participant" : "مشارك مطلوب",
    "Optional participant" : "مشارك اختياري",
    "Non-participant" : "غير مشارك",
    "Remove attendee" : "طرد الحاضر",
    "No match found" : "لا يوجد تطابق",
    "(organizer)" : "(منظم)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "لإرسال الدعوات والتعامل مع الاستجابات [linkopen]اضف بريدك الالكتروني في ملفك الشخصي[linkclose].",
    "Remove color" : "حذف اللون",
    "Event title" : "عنوان الفعالية",
    "All day" : "اليوم بأكمله",
    "from {startDate}" : "منذ تاريخ {startDate}",
    "from {startDate} at {startTime}" : "منذ تاريخ {startDate} في {startTime}",
    "to {endDate}" : "إلى تاريخ {endDate}",
    "to {endDate} at {endTime}" : "إلى {endDate} في {endTime}",
    "Repeat" : "التكرار",
    "End repeat" : "نهاية التكرار",
    "Select to end repeat" : "اختر نهاية التكرار",
    "never" : "بتاتاً",
    "on date" : "في تاريخ",
    "after" : "بعد",
    "first" : "اول",
    "third" : "ثالث",
    "fourth" : "رابع",
    "fifth" : "خامس",
    "second to last" : "الثاني إلى الاخير",
    "last" : "الاخير",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "تغيير قانون التكرار يتم تعيينه لهذا ولظهور المستقبل فقط.",
    "Repeat every" : "تكرار كل",
    "By day of the month" : "يوم من الشهر",
    "On the" : "في الـ",
    "_year_::_years_" : ["سنه","سنه","سنه","سنوات","سنوات","سنوات"],
    "weekday" : "ايام الاسبوع",
    "weekend day" : "يوم نهاية الاسبوع",
    "More" : "المزيد",
    "Update this occurrence" : "تغيير هذا الظهور",
    "Update this and all future" : "تغيير هذا والمستقبل",
    "Public calendar does not exist" : "التقويم العام غير موجود",
    "Maybe the share was deleted or has expired?" : "لربما المشاركة محذوفة أو منتهية؟",
    "Pick a time" : "اختر وقت",
    "Pick a date" : "اختر تاريخ",
    "from {formattedDate}" : "من {formattedDate}",
    "to {formattedDate}" : "إلى {formattedDate}",
    "on {formattedDate}" : "في {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "من {formattedDate} في {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "إلى {formattedDate} في {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "في {formattedDate} في {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} في {formattedTime}",
    "Please enter a valid date" : "اختر تاريخ صحيح",
    "Please enter a valid date and time" : "اختر تاريخ ووقت صحيح",
    "Global" : "عالمي",
    "Personal" : "شخصي",
    "No more events today" : "لا يوجد المزيد من الفعاليات اليوم",
    "No upcoming events" : "ليس هناك فعاليات قادمة",
    "Create a new event" : "انشاء فعالية جديدة",
    "[Today]" : "[اليوم]",
    "[Tomorrow]" : "[الغد]",
    "[Yesterday]" : "[امس]",
    "[Last] dddd" : "[اخر] dddd",
    "Event does not exist" : "الفعالية غير موجودة",
    "Delete this occurrence" : "حذف هذا الظهور",
    "Delete this and all future" : "حذف هذا الظهور والجميع في الستقبل",
    "Details" : "التفاصيل",
    "Attendees" : "المشاركون",
    "Close" : "إغلاق",
    "Show more details" : "اظهار المزيد من التفاصيل",
    "Subscribe to {name}" : "اشتراك مع {name}",
    "Anniversary" : "ذكرى سنوية",
    "Appointment" : "موعد",
    "Business" : "عمل",
    "Education" : "تعليم",
    "Holiday" : "اجازة",
    "Meeting" : "اجتماع",
    "Miscellaneous" : "متنوع",
    "Non-working hours" : "ساعات خارج العمل",
    "Not in office" : "خارج المكتب",
    "Phone call" : "مكالمة هاتفية",
    "Sick day" : "اجازة مرضية",
    "Special occasion" : "حدث خاص",
    "Travel" : "سفر",
    "Vacation" : "اجازة",
    "Midnight on the day the event starts" : "منتصف ليل اليوم الذي يبدأ فيه الحدث",
    "on the day of the event at {formattedHourMinute}" : "في يوم الفعالية في {formattedHourMinute}",
    "at the event's start" : "في بداية الفعالية",
    "at the event's end" : "في نهاية الفعالية",
    "{time} before the event starts" : "{time} قبل بداية الفعالية",
    "{time} before the event ends" : "{time} قبل نهاية الفعالية",
    "{time} after the event starts" : "{time} بعد بداية الفعالية",
    "{time} after the event ends" : "{time} بعد نهاية الفعالية",
    "on {time}" : "في {time}",
    "on {time} ({timezoneId})" : "في {time} ({timezoneId})",
    "Week {number} of {year}" : "اسبوع {number} من {year}",
    "Does not repeat" : "لا يتكرر",
    "Daily" : "يومي",
    "Weekly" : "أسبوعي",
    "Monthly" : "شهري",
    "Yearly" : "سنوي",
    "on the {ordinalNumber} {byDaySet}" : "في الـ {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "في {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "في {monthNames} في الـ {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "حتى {untilDate}",
    "Untitled event" : "فعالية بدون اسم",
    "Untitled task" : "مهمة بدون اسم",
    "Please ask your administrator to enable the Tasks App." : "تواصل مع مسؤول النظام لاستخدام تطبيق المهام.",
    "Next" : "التالي",
    "%n more" : "%n المزيد",
    "No events to display" : "لا يوجد فعاليات",
    "No events" : "لا يوجد فعاليات",
    "Create a new event or change the visible time-range" : "اصنع فعالية جديدة أو قم بتغيير عامل الوقت",
    "It might have been deleted, or there was a typo in a link" : "لربما انحذفت، أو الحروف غير مطابقة في الرابط",
    "It might have been deleted, or there was a typo in the link" : "لربما انحذفت، أو الحروف غير مطابقة في الرابط",
    "Other" : "آخر",
    "When shared show" : "عندما تظهر المشاركة",
    "When shared show full event" : "عرض الفعالية كاملة عند مشاركته",
    "When shared show only busy" : "عرض الازدحام عند مشاركة الفعالية",
    "When shared hide this event" : "إخفاء الحدث عند مشاركته",
    "The visibility of this event in shared calendars." : "ظهور الفعالية في التقويم المشارك مع الآخرين.",
    "Add a location" : "اضافة موقع",
    "Add a description" : "اضافة وصف",
    "Status" : "الحالة",
    "Confirmed" : "مؤكَّد",
    "Canceled" : "ملغي",
    "Confirmation about the overall status of the event." : "التأكيد بخصوص الحالة العامة للفعالية.",
    "Show as" : "أظهر كـ",
    "Take this event into account when calculating free-busy information." : "ضع هذه الفعالية في الاعتبار عندما تكون معلومات الحالة متوفر/ مشغول.",
    "Categories" : "التصنيفات",
    "Categories help you to structure and organize your events." : "التصنيفات تساعدك للهيكله وتنظيم الفعالية.",
    "Search or add categories" : "ابحث او اضف تصنيف",
    "Add this as a new category" : "اضف كـ تصنيف جديد",
    "Custom color" : "لون خاص",
    "Special color of this event. Overrides the calendar-color." : "اللون الخاص للفعالية هذه، يعيد تعيين لون التقويم.",
    "Chat room for event" : "غرفة محادثة للفعالية",
    "Imported {filename}" : "استيراد {filename}",
    "Meditation" : "تفكير",
    "Relaxing" : "لحظة راحة",
    "Relax" : "راحة",
    "Commuting" : "تجوال",
    "Presentation" : "عرض تقديمي",
    "Talk" : "التحدث",
    "Camping" : "تخيم",
    "Camp" : "مخيم",
    "Movie" : "فلم",
    "Cinema" : "سينما",
    "Graduation" : "تخرج",
    "Brainstorm" : "عصف ذهني",
    "Review" : "مراجعة",
    "Baseball" : "بيسبول",
    "Meet" : "اجتماع",
    "Planning" : "تخطيط",
    "Pointing" : "تشكيل",
    "Retrospective" : "استعادة احداث",
    "Office" : "مكتب",
    "Contributor week" : "اسبوع المساهم",
    "Mail" : "البريد",
    "Soccer" : "كرة قدم امريكية",
    "Football" : "كرة قدم",
    "Gaming" : "العاب",
    "Drive" : "سياقه",
    "Bicycle" : "ركوب دراجة",
    "Cycle" : "دراجة هوائية",
    "Biking" : "ركوب الدراجة",
    "Podcast" : "تدوين صوتي",
    "Basketball" : "كرة سلة",
    "Fishing" : "صيد",
    "Hiking" : "التنزه",
    "Hike" : "نزهه",
    "Art" : "فن",
    "Exhibition" : "معرض",
    "Museum" : "متحف",
    "Pilates" : "يوغا",
    "Park" : "حديقة",
    "Studying" : "دراسة",
    "Doctor" : "دكتور",
    "Health" : "صحة",
    "Dentist" : "طبيب أسنان",
    "Hospital" : "مستشفى",
    "Interview" : "مقابلة",
    "Training" : "تدريب",
    "Practice" : "ممارسة",
    "Sports" : "رياضة",
    "Exercise" : "مناوره",
    "Work out" : "تمرين",
    "Working out" : "تمرين",
    "Gym" : "نادي رياضي",
    "Barber" : "صالون الحلاقة",
    "Haircut" : "قص شعر",
    "Exam" : "اختبار",
    "Working" : "جاري العمل",
    "New Years Eve" : "بداية السنة",
    "NYE" : "حفلة بداية السنة",
    "Fireworks" : "العاب نارية",
    "Running" : "ركض",
    "Go for a run" : "الذهاب للركض",
    "Marathon" : "سباق ماراثون",
    "Video-conference" : "اجتماع فيديو",
    "Conference-call" : "اجتماع صوتي",
    "Video-call" : "مكالمة فيديو صوتية",
    "Video-chat" : "مكالمة فيديو محادثة",
    "Video-meeting" : "اجتماع فيديو",
    "Call" : "اتصال",
    "Calling" : "جاري الاتصال",
    "Christmas" : "حفل ديسمبر",
    "Conference" : "مؤتمر",
    "Pizza" : "بيتزا",
    "Travelling" : "مسافر",
    "Journey" : "رحلة",
    "Collaborate" : "يتعاون",
    "Pair" : "اقتران",
    "Lecture" : "محاضرة",
    "Seminar" : "ندوة",
    "Photograph" : "تصوير",
    "Party" : "حفله",
    "Celebration" : "احتفال",
    "Celebrate" : "احتفال",
    "Birthday" : "عيد ميلاد",
    "Shopping" : "تسوق",
    "Skate" : "تزلج",
    "Skateboard" : "لوح تزلج",
    "Wine tasting" : "تذوق",
    "Golf" : "الجولف",
    "Dinner" : "عشاء",
    "Lunch" : "غداء",
    "User not found" : "لم يتم العثور على المستخدم"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
