OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "Provided email address is not valid",
    "%s has published the calendar »%s«" : "%s has published the calendar »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Unexpected error sending email. Please contact your administrator.",
    "Successfully sent email to %1$s" : "Successfully sent email to %1$s",
    "Hello," : "Hello,",
    "We wanted to inform you that %s has published the calendar »%s«." : "We wanted to inform you that %s has published the calendar »%s«.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Cheers!",
    "Upcoming events" : "Upcoming events",
    "Confirm" : "Confirm",
    "Where:" : "Where:",
    "Calendar" : "Calendar",
    "A Calendar app for Nextcloud" : "A Calendar app for Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favourite team’s match days in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events.\n* ⌚️ **Free/Busy!** See when your attendees are available to meet.\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email.\n* 🔍 Search! Find your events at ease.\n* ☑️ Tasks! See tasks with a due date directly in the calendar.\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries.",
    "Previous day" : "Previous day",
    "Previous week" : "Previous week",
    "Previous month" : "Previous month",
    "Next day" : "Next day",
    "Next week" : "Next week",
    "Next month" : "Next month",
    "New event" : "New event",
    "Today" : "Today",
    "Day" : "Day",
    "Week" : "Week",
    "Month" : "Month",
    "List" : "List",
    "Preview" : "Preview",
    "Copy link" : "Copy link",
    "Edit" : "Edit",
    "Delete" : "Delete",
    "Untitled calendar" : "Untitled calendar",
    "Edit color" : "Edit colour",
    "Copy private link" : "Copy private link",
    "Export" : "Export",
    "An error occurred, unable to change visibility of the calendar." : "An error occurred, unable to change visibility of the calendar.",
    "An error occurred, unable to delete the calendar." : "An error occurred, unable to delete the calendar.",
    "Calendar link copied to clipboard." : "Calendar link copied to clipboard.",
    "Calendar link could not be copied to clipboard." : "Calendar link could not be copied to clipboard.",
    "An error occurred, unable to change the calendar's color." : "An error occurred, unable to change the calendar's colour.",
    "Share link" : "Share link",
    "Publish calendar" : "Publish calendar",
    "Publishing calendar" : "Publishing calendar",
    "Share with users or groups" : "Share with users or groups",
    "can edit" : "can edit",
    "New calendar" : "New calendar",
    "Name" : "Surname",
    "Deleted" : "Deleted",
    "Restore" : "Restore",
    "Delete permanently" : "Delete permanently",
    "Empty trash bin" : "Empty trash bin",
    "Filename" : "Filename",
    "Cancel" : "Cancel",
    "Automatic" : "Automatic",
    "or" : "or",
    "List view" : "List view",
    "Actions" : "Actions",
    "Show week numbers" : "Show week numbers",
    "Location" : "Location",
    "Description" : "Description",
    "to" : "to",
    "Add" : "Add",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "Sunday" : "Sunday",
    "Save" : "Save",
    "Update" : "Update",
    "Your email address" : "Your email address",
    "Notification" : "Notification",
    "Email" : "Email",
    "Available" : "Available",
    "Busy" : "Busy",
    "Unknown" : "Unknown",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Tentative" : "Tentative",
    "Send email" : "Send email",
    "All day" : "All day",
    "Repeat" : "Repeat",
    "never" : "never",
    "after" : "after",
    "available" : "available",
    "More" : "More",
    "Global" : "Global",
    "Personal" : "Personal",
    "Details" : "Details",
    "Attendees" : "Attendees",
    "Resources" : "Resources",
    "Close" : "Close",
    "Anniversary" : "Anniversary",
    "Week {number} of {year}" : "Week {number} of {year}",
    "Daily" : "Daily",
    "Weekly" : "Weekly",
    "Prev" : "Prev",
    "Next" : "Next",
    "Other" : "Other",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "Status" : "Status",
    "Confirmed" : "Confirmed",
    "Categories" : "Categories",
    "Custom color" : "Custom colour",
    "Presentation" : "Presentation",
    "Talk" : "Talk",
    "Review" : "Review",
    "Office" : "Office",
    "Mail" : "Mail",
    "Health" : "Health",
    "Birthday" : "Birthday",
    "User not found" : "User not found"
},
"nplurals=2; plural=(n != 1);");
