OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "用戶時段意外地結束",
    "Provided email-address is not valid" : "提供的電郵地址無效",
    "%s has published the calendar »%s«" : "%s 發佈了日曆 »%s«",
    "Unexpected error sending email. Please contact your administrator." : "傳送電子郵件出現意外的錯誤。請聯絡系統管理員。",
    "Successfully sent email to %1$s" : "成功傳送電子郵件給%1$s",
    "Hello," : "嗨，",
    "We wanted to inform you that %s has published the calendar »%s«." : "通知您，%s 發佈了日曆 »%s«。",
    "Open »%s«" : "開啟 »%s«",
    "Cheers!" : "太棒了！",
    "Upcoming events" : "接下來的活動",
    "Appointments" : "預約",
    "Schedule appointment \"%s\"" : "安排預約 \"%s\"",
    "Schedule an appointment" : "安排約會",
    "Prepare for %s" : "準備 %s",
    "Follow up for %s" : "跟進 %s",
    "Your appointment \"%s\" with %s needs confirmation" : "您與 %s 的預約 “%s” 需要確認",
    "Dear %s, please confirm your booking" : "%s，請確認您的預約",
    "Confirm" : "確認",
    "This confirmation link expires in %s hours." : "此確認鏈接將在 %s 小時後過期。",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "如果您想取消預約，請通過回覆此電子郵件或造訪他們的個人資料頁面與您的舉辦者聯絡。",
    "Your appointment \"%s\" with %s has been accepted" : "您與 %s 的預約 “%s” 已被接受",
    "Dear %s, your booking has been accepted." : "親愛的 %s，您的預約已被接受。",
    "Appointment for:" : "預約：",
    "Date:" : "日期：",
    "Where:" : "地點：",
    "Your Comment:" : "您的留言：",
    "Calendar" : "日曆",
    "A Calendar app for Nextcloud" : "Nextcloud 的日曆應用程式",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "日曆應用程式是 Nextcloud 的 CalDAV 伺服器的用戶界面。透過您的 Nextcloud 輕鬆同步來自各裝置的活動，並在線上編輯它們。\n\n* 🚀 **與其他 Nextcloud 應用程式的整合！** 目前為通訊錄，但還會有更多的。\n* 🌐 **支援 WebCal！** 想在您的日曆中檢視您最愛球隊的比賽日期？沒問題！\n* 🙋 **參與者！** 邀請夥伴來參加您的活動\n* ⌚️ **有空／忙碌！** 看看您的參與者們什麼時候可以見面\n* ⏰ **提醒！** 在您的瀏覽器中以及透過電子郵件取得警示\n* 🔍 搜尋！輕鬆找到您的活動\n* ☑️ 任務！直接在日曆中檢視任務的到期日\n* 🙈 **我們並未重新發明輪子！** 以超棒的 [c-dav 函式庫]（https://github.com/nextcloud/cdav-library）、[ical.js]（https://github.com/mozilla-comm/ical.js）與 [fullcalendar]（https://github.com/fullcalendar/fullcalendar）函式庫為基礎。",
    "Previous day" : "前一日",
    "Previous week" : "上星期",
    "Previous month" : "上個月",
    "Next day" : "隔日",
    "Next week" : "下星期",
    "Next month" : "下個月",
    "New event" : "新活動",
    "Today" : "今日",
    "Day" : "日",
    "Week" : "星期",
    "Month" : "月",
    "List" : "清單",
    "Preview" : "預覽",
    "Copy link" : "複製連結",
    "Edit" : "編輯",
    "Delete" : "刪除",
    "Appointment link was copied to clipboard" : "約會連結已複製到剪貼板",
    "Appointment link could not be copied to clipboard" : "約會連結無法複製到剪貼板",
    "Add new" : "新增",
    "Untitled calendar" : "未命名日曆",
    "Edit name" : "編輯名稱",
    "Saving name …" : "儲存名稱 …",
    "Edit color" : "編輯顏色",
    "Saving color …" : "儲存顏色…",
    "Copy private link" : "複製私人連結",
    "Export" : "導出",
    "Unshare from me" : "由我取消的分享",
    "Disable calendar \"{calendar}\"" : "停用日曆 \"{calendar}\"",
    "Disable untitled calendar" : "停用未命名日曆",
    "Enable calendar \"{calendar}\"" : "啟用日曆 \"{calendar}\"",
    "Enable untitled calendar" : "啟用未命名日曆",
    "An error occurred, unable to change visibility of the calendar." : "發生錯誤，無法改變日曆的能見度",
    "An error occurred, unable to delete the calendar." : "發生錯誤，無法刪除日曆",
    "Calendar link copied to clipboard." : "複製日曆連結到剪貼板",
    "Calendar link could not be copied to clipboard." : "日曆連結無法複製到剪貼板",
    "An error occurred, unable to rename the calendar." : "發生錯誤，無法重新命名日曆",
    "An error occurred, unable to change the calendar's color." : "發生錯誤，無法變更日曆的顏色",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後取消日曆分享"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後刪除日曆"],
    "Share link" : "分享連結",
    "Publish calendar" : "發佈日曆",
    "Publishing calendar" : "正在發佈日曆",
    "Copy public link" : "複製公開連結",
    "Send link to calendar via email" : "透過電子郵件傳送日曆連結",
    "Enter one address" : "輸入一個地址",
    "Sending email …" : "正在傳送電子郵件…",
    "Copy subscription link" : "複製訂閱的連結",
    "Copying link …" : "正在複製連結…",
    "Copied link" : "連結已複製",
    "Could not copy link" : "無法複製連結",
    "Copy embedding code" : "複製內嵌程式碼",
    "Copying code …" : "正在複製程式碼…",
    "Copied code" : "已複製程式碼",
    "Could not copy code" : "無法複製程式碼",
    "Delete share link" : "刪除分享連結",
    "Deleting share link …" : "正在刪除共享連結…",
    "An error occurred, unable to publish calendar." : "發生錯誤，無法發佈日曆",
    "An error occurred, unable to send email." : "發生錯誤，無法寄送電子郵件",
    "Embed code copied to clipboard." : "內嵌程式碼已複製到剪貼板",
    "Embed code could not be copied to clipboard." : "無法複製內嵌程式碼到剪貼板",
    "Unpublishing calendar failed" : "取消發佈日曆失敗",
    "Share with users or groups" : "與用戶或群組分享",
    "No users or groups" : "沒有用戶或群組",
    "can edit" : "可編輯",
    "Unshare with {displayName}" : "取消與 {displayName} 的分享",
    "An error occurred, unable to change the unshare the calendar." : "發生錯誤，無法變更日曆",
    "An error occurred, unable to change the permission of the share." : "發生錯誤，無法變更分享權限",
    "New calendar" : "新日曆",
    "Name for new calendar" : "新日曆名字",
    "Creating calendar …" : "正在建立日曆…",
    "New calendar with task list" : "新日曆及任務清單",
    "New subscription from link (read-only)" : "自連結建立新訂閱（唯讀）",
    "Creating subscription …" : "正在建立新訂閱…",
    "An error occurred, unable to create the calendar." : "發生錯誤，無法建立日曆",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "請輸入有效的連結（以 http://，https://，webcal://，或 webcals:// 開頭）",
    "Trash bin" : "回收桶",
    "Loading deleted items." : "正加載已删除的項目。",
    "You do not have any deleted items." : "你没有已删除的項目。",
    "Name" : "姓名",
    "Deleted" : "已刪除",
    "Restore" : "復原",
    "Delete permanently" : "永久刪除",
    "Empty trash bin" : "清空回收桶",
    "Untitled item" : "無題項目",
    "Unknown calendar" : "日曆不詳",
    "Could not load deleted calendars and objects" : "無法加載已刪除日曆或物體",
    "Could not restore calendar or event" : "無法復原日曆或活動",
    "Do you really want to empty the trash bin?" : "您真的想要清空回收桶嗎？",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["回收桶中的項目會在 {numDays} 天後被刪除"],
    "Could not update calendar order." : "無法變更日曆順序",
    "Import calendars" : "匯入日曆",
    "Please select a calendar to import into …" : "請選擇將匯入的日曆",
    "Filename" : "檔案名稱",
    "Calendar to import into" : "將匯入的日曆",
    "Cancel" : "取消",
    "_Import calendar_::_Import calendars_" : ["匯入日曆"],
    "{filename} could not be parsed" : "無法解析 {filename}",
    "No valid files found, aborting import" : "沒有找到有效的檔案，中斷匯入",
    "Import partially failed. Imported {accepted} out of {total}." : "匯入部分失敗，僅成功匯入 {total} 中的 {accepted} 項",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["成功匯入 %n 個活動"],
    "Automatic" : "自動",
    "Automatic ({detected})" : "自動（{detected}）",
    "New setting was not saved successfully." : "新設定未成功儲存",
    "Shortcut overview" : "捷徑簡介",
    "or" : "或者",
    "Navigation" : "導覽列",
    "Previous period" : "前一期間",
    "Next period" : "下一期間",
    "Views" : "視圖",
    "Day view" : "日視圖",
    "Week view" : "週視圖",
    "Month view" : "月視圖",
    "List view" : "清單檢視",
    "Actions" : "操作",
    "Create event" : "建立活動",
    "Show shortcuts" : "顯示捷徑",
    "Editor" : "編輯器",
    "Close editor" : "關閉編輯器",
    "Save edited event" : "儲存已編輯的活動",
    "Delete edited event" : "刪除已編輯的活動",
    "Duplicate event" : "重複活動",
    "Enable birthday calendar" : "啟用生日日曆",
    "Show tasks in calendar" : "在日曆上顯示待辦事項",
    "Enable simplified editor" : "啟用簡化的編輯器",
    "Limit visible events per view" : "限制每個顯示可見的活動數",
    "Show weekends" : "顯示週末",
    "Show week numbers" : "顯示週數",
    "Time increments" : "時間增量",
    "Default reminder" : "默認提醒",
    "Copy primary CalDAV address" : "複製主要的 CalDAV 位址",
    "Copy iOS/macOS CalDAV address" : "複製 iOS/macOS 的 CalDAV 位址",
    "Personal availability settings" : "個人空檔設置",
    "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
    "Calendar settings" : "日曆設定",
    "No reminder" : "無提醒",
    "CalDAV link copied to clipboard." : "已複製 CalDAV 連結至剪貼板",
    "CalDAV link could not be copied to clipboard." : "無法複製 CalDAV 連結至剪貼板",
    "Appointment was created successfully" : "成功創建了預約",
    "Appointment was updated successfully" : "成功更新了預約",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} 分鐘"],
    "0 minutes" : "0 分鐘",
    "_{duration} hour_::_{duration} hours_" : ["{duration} 小時"],
    "_{duration} day_::_{duration} days_" : ["{duration} 天"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} 星期"],
    "_{duration} month_::_{duration} months_" : ["{duration} 月"],
    "_{duration} year_::_{duration} years_" : ["{duration} 年"],
    "To configure appointments, add your email address in personal settings." : "要配置預約，請在個人設置中添加您的電郵地址。",
    "Public – shown on the profile page" : "公開 - 顯示在個人資料頁面上",
    "Private – only accessible via secret link" : "私人 - 只能通過秘密連結進入",
    "Location" : "地點",
    "Description" : "描述",
    "Visibility" : "可見性",
    "Duration" : "歷時",
    "Increments" : "增量",
    "Additional calendars to check for conflicts" : "其他要檢查衝突的日曆",
    "Pick time ranges where appointments are allowed" : "選擇允許預約時間的範圍",
    "to" : "至",
    "Delete slot" : "刪除時段",
    "No times set" : "尚未設置時間",
    "Add" : "添加",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "Sunday" : "星期日",
    "Add time before and after the event" : "添加活動前後的時間",
    "Before the event" : "活動前",
    "After the event" : "活動後",
    "Planning restrictions" : "規劃限制",
    "Minimum time before next available slot" : "下一個可用時段之前的最短時間",
    "Max slots per day" : "每天最多的時段數",
    "Limit how far in the future appointments can be booked" : "限制可以提前多長時間預約",
    "Create appointment" : "創建預約",
    "Edit appointment" : "編輯預約",
    "Save" : "儲存",
    "Update" : "更新",
    "Please confirm your reservation" : "請確認您的預約",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "我們向您發送了一封包含詳細信息的電子郵件。 請使用電子郵件中的連結確認您的預約。 您現在可以關閉此頁面。",
    "Your name" : "您的名字",
    "Your email address" : "您的電郵地址",
    "Please share anything that will help prepare for our meeting" : "請分享任何有助於為我們的會議做準備的信息",
    "Could not book the appointment. Please try again later or contact the organizer." : "無法預約。 請稍後再試或聯絡組織者。",
    "Book the appointment" : "預約",
    "Reminder" : "提醒",
    "before at" : "之前於",
    "Notification" : "通告",
    "Email" : "電子郵件",
    "Audio notification" : "音訊通知",
    "Other notification" : "其他通知",
    "Relative to event" : "相對於活動",
    "On date" : "在特定日期",
    "Edit time" : "編輯時間",
    "Save time" : "儲存時間",
    "Remove reminder" : "刪除提醒",
    "on" : "在",
    "at" : "在",
    "+ Add reminder" : "+ 加入提醒",
    "Add reminder" : "添加提醒",
    "_second_::_seconds_" : ["秒"],
    "_minute_::_minutes_" : ["分鐘"],
    "_hour_::_hours_" : ["時"],
    "_day_::_days_" : ["天"],
    "_week_::_weeks_" : ["星期"],
    "Invitation accepted" : "已接受邀請",
    "Available" : "可用",
    "Suggested" : "建議",
    "Participation marked as tentative" : "參與標記為暫定",
    "Accepted {organizerName}'s invitation" : "已接受 {organizerName} 的邀請",
    "Not available" : "不可用",
    "Invitation declined" : "邀請被婉拒",
    "Declined {organizerName}'s invitation" : "已婉拒 {organizerName} 的邀請",
    "Invitation is delegated" : "邀請已委派",
    "Checking availability" : "檢查可得性",
    "Invitation sent" : "邀請已傳送",
    "Has not responded to {organizerName}'s invitation yet" : "尚未回覆 {organizerName} 的邀請",
    "Availability of attendees, resources and rooms" : "參與者、資源和會議室的可得性",
    "{organizer} (organizer)" : "{organizer}（主辦人）",
    "Free" : "有空",
    "Busy (tentative)" : "忙碌（暫定）",
    "Busy" : "忙碌",
    "Out of office" : "不在辦公室",
    "Unknown" : "不詳",
    "Accept" : "接受",
    "Decline" : "婉拒",
    "Tentative" : "暫定",
    "The invitation has been accepted successfully." : "已成功接受邀請。",
    "Failed to accept the invitation." : "無法接受邀請。",
    "The invitation has been declined successfully." : "已成功婉拒邀請。",
    "Failed to decline the invitation." : "無法婉拒邀請。",
    "Your participation has been marked as tentative." : "您的參與已標記為暫定。",
    "Failed to set the participation status to tentative." : "未能將參與狀態設置為暫定。",
    "Create Talk room for this event" : "建立此活動的線上會議室",
    "Show busy times" : "顯示忙碌時段",
    "No attendees yet" : "還沒有任何參與者",
    "Successfully appended link to talk room to description." : "成功將線上會議室的連結加至活動細節",
    "Error creating Talk room" : "建立線上會議室發生錯誤",
    "Send email" : "傳送電郵",
    "Chairperson" : "主席",
    "Required participant" : "需出席的參與者",
    "Optional participant" : "可不出席的參與者",
    "Non-participant" : "非參與者",
    "Remove attendee" : "移除參與者",
    "Search for emails, users or contacts" : "搜尋電郵地址、用戶或聯絡人",
    "No match found" : "找不到符合的項目",
    "(organizer)" : "（主辦人）",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "若要送出邀請函並處理回覆，[linkopen] 請到個人設定頁加入您的電郵地址 [linkclose]",
    "Remove color" : "移除顏色",
    "Event title" : "活動標題",
    "All day" : "全日",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "無法變更定期重複活動的全日設定",
    "from {startDate}" : "從 {startDate}",
    "from {startDate} at {startTime}" : "從 {startDate} {startTime}",
    "to {endDate}" : "至 {endDate} 止",
    "to {endDate} at {endTime}" : "至 {endDate} {endTime} 止",
    "Repeat" : "重複",
    "End repeat" : "停止重複",
    "Select to end repeat" : "選擇以結束重複",
    "never" : "永不",
    "on date" : "在特定日期",
    "after" : "之後",
    "_time_::_times_" : ["次"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "此活動是一系列重複活動的特例，您無法針對它設定重複規則",
    "first" : "第一",
    "third" : "第三",
    "fourth" : "第四",
    "fifth" : "第五",
    "second to last" : "尾二",
    "last" : "最尾",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "變更的重複規則只會套用至這項活動和重複的未來活動",
    "Repeat every" : "重複循環",
    "By day of the month" : "每月中特定日",
    "On the" : "在",
    "_month_::_months_" : ["月"],
    "_year_::_years_" : ["年"],
    "weekday" : "平日",
    "weekend day" : "週末",
    "No recurrence" : "沒有重複",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud 不完全支援此活動的重複。如果您編輯了重複選項，某些重複可能會遺失。",
    "Suggestions" : "建議",
    "No rooms or resources yet" : "尚無可用會議室或資源",
    "Add resource" : "添加資源",
    "Has a projector" : "有投影機",
    "Has a whiteboard" : "有白板",
    "Wheelchair accessible" : "無障礙通道",
    "Remove resource" : "删除資源",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} 個座位"],
    "Projector" : "投影機",
    "Whiteboard" : "白板",
    "Search for resources or rooms" : "搜尋資源或會議室",
    "available" : "可用",
    "unavailable" : "不可用",
    "Room type" : "房間類型",
    "Any" : "任何",
    "Minimum seating capacity" : "最小座位數量",
    "More" : "更多",
    "Update this occurrence" : "更新此重複",
    "Update this and all future" : "更新此次和以後的活動",
    "Public calendar does not exist" : "公開日曆不存在",
    "Maybe the share was deleted or has expired?" : "分享是否已刪除或過期？",
    "Please select a time zone:" : "請選擇時區：",
    "Pick a time" : "挑選時間",
    "Pick a date" : "挑選日期",
    "from {formattedDate}" : "從 {formattedDate}",
    "to {formattedDate}" : "至 {formattedDate}",
    "on {formattedDate}" : "於 {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "從 {formattedDate} {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "至 {formattedDate} {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "於 {formattedDate} {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "請輸入有效的日期",
    "Please enter a valid date and time" : "請輸入有效的日期和時間",
    "Type to search time zone" : "輸入以搜尋時區",
    "Global" : "全球",
    "Select date" : "選擇日期",
    "Select slot" : "選擇時段",
    "No slots available" : "沒有可用的時段",
    "The slot for your appointment has been confirmed" : "您預約的時間已確認",
    "Appointment Details:" : "預約細節：",
    "Time:" : "時間：",
    "Booked for:" : "已訂：",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "謝謝。您 {startDate} 至 {endDate} 的預訂已確認。",
    "Book another appointment:" : "設置另一個預約：",
    "See all available slots" : "查看所有可用的時段",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "{startDate} 至 {endDate} 的時段不再可用。",
    "Please book a different slot:" : "請選擇另一個時段：",
    "Book an appointment with {name}" : "與 {name} 預約",
    "No public appointments found for {name}" : "找不到 {name} 的公開預約",
    "Personal" : "個人",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自動時區檢測確定您的時區為 UTC。\n這很可能是您的網絡瀏覽器的安全措施的結果。\n請在日曆設置中手動設置您的時區。",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "找不到您選擇的時區 {timezoneId} ，先以 UTC 替代。\n請至設定改變您的時區並舉報此問題。",
    "No more events today" : "今日沒有其他活動",
    "No upcoming events" : "沒有接下來的活動",
    "Create a new event" : "建立新活動",
    "[Today]" : "[今日]",
    "[Tomorrow]" : "[明日]",
    "[Yesterday]" : "[昨日]",
    "[Last] dddd" : "[上] dddd",
    "Event does not exist" : "活動不存在",
    "Duplicate" : "重複",
    "Delete this occurrence" : "刪除此次活動",
    "Delete this and all future" : "刪除此次和以後的活動",
    "Details" : "詳細資料",
    "Attendees" : "參與者",
    "Resources" : "資源",
    "Close" : " 關閉",
    "Show more details" : "顯示更多細節",
    "Subscribe to {name}" : "訂閱 {name}",
    "Export {name}" : "導出 {name}",
    "Anniversary" : "週年",
    "Appointment" : "約會",
    "Business" : "商業",
    "Education" : "教育",
    "Holiday" : "假日",
    "Meeting" : "會議",
    "Miscellaneous" : "其他",
    "Non-working hours" : "非工作時間",
    "Not in office" : "不在辦公室",
    "Phone call" : "通話",
    "Sick day" : "病假",
    "Special occasion" : "特殊場合",
    "Travel" : "旅行",
    "Vacation" : "度假",
    "Midnight on the day the event starts" : "活動開始日的午夜",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["於 {formattedHourMinute} 的活動 %n 日前"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["於 {formattedHourMinute} 的活動 %n 星期前"],
    "on the day of the event at {formattedHourMinute}" : "於 {formattedHourMinute} 的活動當日",
    "at the event's start" : "在活動開始時",
    "at the event's end" : "在活動結束時",
    "{time} before the event starts" : "活動開始前 {time}",
    "{time} before the event ends" : "活動結束前 {time}",
    "{time} after the event starts" : "活動開始後 {time}",
    "{time} after the event ends" : "活動結束後 {time}",
    "on {time}" : "於 {time}",
    "on {time} ({timezoneId})" : "於 {time}（{timezoneId}）",
    "Week {number} of {year}" : "{year} 的第 {number} 星期",
    "Does not repeat" : "不要重複",
    "Daily" : "每日",
    "Weekly" : "每星期",
    "Monthly" : "每月",
    "Yearly" : "每年",
    "_Every %n day_::_Every %n days_" : ["每 %n 日"],
    "_Every %n week_::_Every %n weeks_" : ["每 %n 星期"],
    "_Every %n month_::_Every %n months_" : ["每 %n 月"],
    "_Every %n year_::_Every %n years_" : ["每 %n 年"],
    "_on {weekday}_::_on {weekdays}_" : ["於 {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["在 {dayOfMonthList} 天"],
    "on the {ordinalNumber} {byDaySet}" : "在 {ordinalNumber} {byDaySet} 上",
    "in {monthNames}" : "於 {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "在 {ordinalNumber} {byDaySet} 於 {monthNames}",
    "until {untilDate}" : "到 {untilDate}",
    "_%n time_::_%n times_" : ["%n 次"],
    "Untitled event" : "未命名活動",
    "Untitled task" : "未命名任務",
    "Please ask your administrator to enable the Tasks App." : "請要求您的管理員啟用任務應用程式。",
    "Prev" : "上一個",
    "Next" : "下一個",
    "Prev year" : "上一年",
    "Next year" : "下一年",
    "Year" : "年",
    "W" : "星期",
    "%n more" : "其餘 %n 項",
    "No events to display" : "無可顯示的活動",
    "_+%n more_::_+%n more_" : ["* 和其他 %n 個"],
    "No events" : "無活動",
    "Create a new event or change the visible time-range" : "建立新活動或變更可見的時間範圍",
    "It might have been deleted, or there was a typo in a link" : "其可能已經被刪除，或是連結中有錯字",
    "It might have been deleted, or there was a typo in the link" : "其可能已經被刪除，或是連結中有錯字",
    "Meeting room" : "會議室",
    "Lecture hall" : "講課廳",
    "Seminar room" : "研討室",
    "Other" : "其它",
    "When shared show" : "當分享顯示時",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared show only busy" : "分享的時候顯示忙碌中",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "The visibility of this event in shared calendars." : "此活動在分享的日曆可見程度。",
    "Add a location" : "加入地點",
    "Add a description" : "加入描述",
    "Status" : "狀態",
    "Confirmed" : "已確認",
    "Canceled" : "已取消",
    "Confirmation about the overall status of the event." : "有關活動整體狀態的確認。",
    "Show as" : "顯示為",
    "Take this event into account when calculating free-busy information." : "計算有空與忙碌資訊時，請將此活動考慮在內。",
    "Categories" : "分類",
    "Categories help you to structure and organize your events." : "分類可以幫您整理您的活動",
    "Search or add categories" : "搜尋或加入分類",
    "Add this as a new category" : "將此加入為新分類",
    "Custom color" : "自訂顏色",
    "Special color of this event. Overrides the calendar-color." : "此活動的特殊顏色。覆寫日曆顏色。",
    "Chat room for event" : "活動的聊天室",
    "Imported {filename}" : "匯入的 {filename}",
    "Meditation" : "冥想",
    "Relaxing" : "放鬆",
    "Relax" : "放鬆",
    "Break" : "休息",
    "Commute" : "通勤",
    "Commuting" : "通勤中",
    "Shuttle" : "穿梭巴士",
    "Invoice" : "發票",
    "Finance" : "財政",
    "Bank" : "銀行",
    "Money" : "金錢",
    "Wedding" : "婚禮",
    "Dog" : "狗",
    "Concert" : "音樂會",
    "Festival" : "節日",
    "Theater" : "戲劇",
    "Theatre" : "戲劇",
    "Presentation" : "簡報",
    "Talk" : "講座",
    "Speech" : "演講",
    "Deadline" : "最後期限",
    "Submission" : "遞交",
    "Reporting" : "報告",
    "Camping" : "露營",
    "Camp" : "露營",
    "Election" : "選舉",
    "Voting" : "投票",
    "Vote" : "投票",
    "Barbecue" : "BBQ",
    "Barbeque" : "BBQ",
    "Garden" : "園藝",
    "Farm" : "農務 ",
    "Movie" : "電影",
    "Cinema" : "戲院",
    "Graduation" : "畢業",
    "Brainstorm" : "腦力震盪",
    "Review" : "審閱",
    "Audit" : "審計",
    "Inspection" : "檢查",
    "Proofreading" : "校對",
    "Baseball" : "棒球",
    "Meet" : "會面",
    "Planning" : "規劃",
    "Pointing" : "指向",
    "Retrospective" : "回顧",
    "Office" : "辦公室",
    "Contributor week" : "貢獻週",
    "Mail" : "郵件",
    "Soccer" : "足球",
    "Football" : "美式足球",
    "Gaming" : "打機",
    "Drive" : "駕駛",
    "Driving" : "駕駛",
    "Bicycle" : "單車",
    "Cycle" : "單車",
    "Cycling" : "踩單車 ",
    "Biking" : "電單車",
    "Bike" : "單車",
    "Podcast" : "Podcast",
    "Basketball" : "籃球",
    "Fishing" : "釣魚",
    "Hiking" : "遠足",
    "Hike" : "遠足",
    "Art" : "藝術",
    "Exhibition" : "展覽",
    "Museum" : "博物館",
    "Pilates" : "Pilates",
    "Park" : "公園",
    "Walk" : "步行",
    "Studying" : "讀書",
    "Doctor" : "醫生",
    "Health" : "健康",
    "Dentist" : "牙醫",
    "Hospital" : "醫院",
    "Interview" : "面試",
    "Training" : "訓練",
    "Practice" : "練習",
    "Sports" : "體育",
    "Exercise" : "運動",
    "Work out" : "鍛鍊",
    "Working out" : "鍛鍊",
    "Gym" : "健身室",
    "Barber" : "理髮師",
    "Haircut" : "理髮",
    "Hairdresser" : "髮型師",
    "Exam" : "考試",
    "Written test" : "筆試",
    "Oral test" : "口試",
    "Working" : "工作",
    "New Years Eve" : "除夕",
    "NYE" : "除夕",
    "Fireworks" : "煙花",
    "Running" : "跑步",
    "Go for a run" : "去跑步",
    "Marathon" : "馬拉松",
    "Video-conference" : "視像會議",
    "Conference-call" : "電話會議",
    "Video-call" : "視像通話",
    "Video-chat" : "視像聊天",
    "Video-meeting" : "視像會議",
    "Call" : "通話",
    "Calling" : "通話",
    "Christmas" : "聖誕節",
    "Conference" : "會議",
    "Pizza" : "披薩",
    "Travelling" : "旅行",
    "Trip" : "旅行",
    "Journey" : "旅程",
    "Collaborate" : "協作",
    "Pair" : "配對",
    "Lecture" : "演講",
    "Seminar" : "專題討論",
    "Teaching" : "教學",
    "Photograph" : "攝影",
    "Party" : "派對",
    "Celebration" : "慶祝",
    "Celebrate" : "慶祝活動",
    "Birthday" : "生日",
    "Shopping" : "購物",
    "Groceries" : "雜貨",
    "Skate" : "溜冰",
    "Skateboard" : "滑板",
    "Wine tasting" : "品酒",
    "Golf" : "高爾夫球",
    "Dinner" : "晚餐",
    "Lunch" : "午餐",
    "Appointment not found" : "找不到預約",
    "User not found" : "找不到用戶"
},
"nplurals=1; plural=0;");
