OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Netikėtai pasibaigė naudotojo seanso galiojimas",
    "Provided email-address is not valid" : "Pateiktas el. pašto adresas nėra teisingas",
    "%s has published the calendar »%s«" : "%s paskelbė kalendorių „%s“",
    "Unexpected error sending email. Please contact your administrator." : "Netikėta klaida siunčiant el. laišką. Susisiekite su savo administratoriumi.",
    "Successfully sent email to %1$s" : "El. laiškas sėkmingai išsiųstas į %1$s",
    "Hello," : "Sveiki,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Norėtume informuoti, kad %s paskelbė kalendorių „%s“.",
    "Open »%s«" : "Atverti „%s“",
    "Cheers!" : "Sveikinimai!",
    "Upcoming events" : "Artėjantys įvykiai",
    "Appointments" : "Susitikimai",
    "Confirm" : "Patvirtinti",
    "This confirmation link expires in %s hours." : "Ši patvirtinimo nuoroda baigia galioti po %s val.",
    "Date:" : "Data:",
    "Where:" : "Kur:",
    "Calendar" : "Kalendorius",
    "A Calendar app for Nextcloud" : "Kalendoriaus programėlė, skirta Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Kalendoriaus programėlė yra Nextcloud CalDAV serverio naudotojo sąsaja. Lengvai sinchronizuokite įvykius iš įvairių įrenginių, naudodami Nextcloud ir redaguokite juos internete.\n\n* 🚀 **Integracija su kitomis Nextcloud programėlėmis!** Šiuo metu tik su Adresatais - greitu laiku ir su kitomis.\n* 🌐 **WebCal palaikymas!** Norite savo kalendoriuje matyti mėgstamos komandos rungtynių dienas? Jokių problemų!\n* 🙋 **Kviestiniai!** Pakvieskite žmones prisijungti prie savo įvykių.\n* ⌚️ **Laisva/Užimta!** Matykite, kada jūsų kviestiniai gali susitikti.\n* ⏰ **Priminimai!** Gaukite įvykių signalus savo naršyklėje ar el. paštu.\n* 🔍 Paieška! Lengvai raskite įvykius.\n* ☑️ Užduotys! Matykite užduotis su galutinio termino diena tiesiogiai kalendoriuje.\n* 🙈 **Mes neišradinėjame dviračio!** Pagrįsta puikiomis [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) ir [fullcalendar](https://github.com/fullcalendar/fullcalendar) bibliotekomis.",
    "Previous day" : "Ankstesnė diena",
    "Previous week" : "Ankstesnė savaitė",
    "Previous month" : "Ankstesnis mėnuo",
    "Next day" : "Kita diena",
    "Next week" : "Kita savaitė",
    "Next month" : "Kitas mėnuo",
    "New event" : "Naujas įvykis",
    "Today" : "Šiandiena",
    "Day" : "Diena",
    "Week" : "Savaitė",
    "Month" : "Mėnuo",
    "List" : "Sąrašas",
    "Preview" : "Peržiūra",
    "Copy link" : "Kopijuoti nuorodą",
    "Edit" : "Taisyti",
    "Delete" : "Ištrinti",
    "Appointment link was copied to clipboard" : "Susitikimo nuoroda buvo nukopijuota į iškarpinę",
    "Appointment link could not be copied to clipboard" : "Susitikimo nuorodos nepavyko nukopijuoti į iškarpinę",
    "Add new" : "Pridėti naują",
    "Untitled calendar" : "Kalendorius be pavadinimo",
    "Edit name" : "Taisyti pavadinimą",
    "Saving name …" : "Įrašomas pavadinimas…",
    "Edit color" : "Taisyti spalvą",
    "Saving color …" : "Įrašoma spalva…",
    "Copy private link" : "Kopijuoti privačią nuorodą",
    "Export" : "Eksportuoti",
    "Unshare from me" : "Nustoti bendrinti su manimi",
    "Disable calendar \"{calendar}\"" : "Išjungti kalendorių „{calendar}“",
    "Disable untitled calendar" : "Išjungti kalendorių be pavadinimo",
    "Enable calendar \"{calendar}\"" : "Įjungti kalendorių „{calendar}“",
    "Enable untitled calendar" : "Įjungti kalendorių be pavadinimo",
    "An error occurred, unable to change visibility of the calendar." : "Įvyko klaida, nepavyko pakeisti kalendoriaus matomumo.",
    "An error occurred, unable to delete the calendar." : "Įvyko klaida, nepavyko ištrinti kalendorių.",
    "Calendar link copied to clipboard." : "Kalendoriaus nuoroda nukopijuota į iškarpinę.",
    "Calendar link could not be copied to clipboard." : "Kalendoriaus nuorodos nepavyko nukopijuoti į iškarpinę.",
    "An error occurred, unable to rename the calendar." : "Įvyko klaida, nepavyko pervadinti kalendorių.",
    "An error occurred, unable to change the calendar's color." : "Įvyko klaida, nepavyko pakeisti kalendoriaus spalvos.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalendorius nustojamas bendrinti po {countdown} sekundės","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundės"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendorius ištrinamas po {countdown} sekundės","Kalendorius ištrinamas po {countdown} sekundžių","Kalendorius ištrinamas po {countdown} sekundžių","Kalendorius ištrinamas po {countdown} sekundės"],
    "Share link" : "Bendrinimo nuoroda",
    "Publish calendar" : "Paskelbti kalendorių",
    "Publishing calendar" : "Skelbiamas kalendorius",
    "Copy public link" : "Kopijuoti viešąją nuorodą",
    "Send link to calendar via email" : "Siųsti el. paštu nuorodą į kalendorių",
    "Enter one address" : "Įveskite vieną adresą",
    "Sending email …" : "Siunčiamas el. laiškas…",
    "Copy subscription link" : "Kopijuoti prenumeratos nuorodą",
    "Copying link …" : "Kopijuojama nuoroda…",
    "Copied link" : "Nuoroda nukopijuota",
    "Could not copy link" : "Nepavyko nukopijuoti nuorodos",
    "Copy embedding code" : "Kopijuoti įterpimo kodą",
    "Copying code …" : "Kopijuojamas kodas…",
    "Copied code" : "Kodas nukopijuotas",
    "Could not copy code" : "Nepavyko nukopijuoti kodo",
    "Delete share link" : "Ištrinti bendrinimo nuorodą",
    "Deleting share link …" : "Ištrinama bendrinimo nuoroda…",
    "An error occurred, unable to publish calendar." : "Įvyko klaida, nepavyko paskelbti kalendoriaus.",
    "An error occurred, unable to send email." : "Įvyko klaida, nepavyko išsiųsti el. laiško.",
    "Embed code copied to clipboard." : "Įterpimo kodas nukopijuotas į iškarpinę.",
    "Embed code could not be copied to clipboard." : "Įterpimo kodo nepavyko nukopijuoti į iškarpinę.",
    "Unpublishing calendar failed" : "Nepavyko paskelbti kalendoriaus",
    "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
    "No users or groups" : "Nėra jokių naudotojų ar grupių",
    "can edit" : "gali redaguoti",
    "Unshare with {displayName}" : "Nustoti bendrinti su {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Įvyko klaida, nepavyko pakeisti kalendoriaus nebendrinimo.",
    "An error occurred, unable to change the permission of the share." : "Įvykio klaida, nepavyko pakeisti viešinio leidimo.",
    "New calendar" : "Naujas kalendorius",
    "Name for new calendar" : "Naujo kalendoriaus pavadinimas",
    "Creating calendar …" : "Kuriamas kalendorius…",
    "New calendar with task list" : "Naujas kalendorius su užduočių sąrašu",
    "New subscription from link (read-only)" : "Nauja prenumerata iš nuorodos (tik skaitymui)",
    "Creating subscription …" : "Kuriama prenumerata…",
    "An error occurred, unable to create the calendar." : "Įvyko klaida, nepavyko sukurti kalendoriaus.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Įveskite teisingą nuorodą (prasidedančią http://, https://, webcal:// ar webcals://)",
    "Trash bin" : "Šiukšlinė",
    "Name" : "Pavadinimas",
    "Deleted" : "Ištrintas",
    "Restore" : "Atkurti",
    "Delete permanently" : "Ištrinti negrįžtamai",
    "Empty trash bin" : "Išvalyti šiukšlinę",
    "Unknown calendar" : "Nežinomas kalendorius",
    "Could not load deleted calendars and objects" : "Nepavyko įkelti ištrintų kalendorių ir objektų",
    "Could not restore calendar or event" : "Nepavyko atkurti kalendoriaus ar įvykio",
    "Do you really want to empty the trash bin?" : "Ar tikrai norite išvalyti šiukšlinę?",
    "Could not update calendar order." : "Nepavyko atnaujinti kalendoriaus tvarkos.",
    "Import calendars" : "Importuoti kalendorius",
    "Please select a calendar to import into …" : "Pasirinkite kalendorių į kurį importuoti…",
    "Filename" : "Failo pavadinimas",
    "Calendar to import into" : "Kalendorius, į kurį importuoti",
    "Cancel" : "Atsisakyti",
    "_Import calendar_::_Import calendars_" : ["Importuoti kalendorių","Importuoti kalendorius","Importuoti kalendorius","Importuoti kalendorius"],
    "{filename} could not be parsed" : "Nepavyko išnagrinėti {filename}",
    "No valid files found, aborting import" : "Nerasta jokių tinkamų failų, importavimas nutraukiamas",
    "Import partially failed. Imported {accepted} out of {total}." : "Importavimas dalinai nepavyko. Importuota {accepted} iš {total}.",
    "Automatic" : "Automatinė",
    "Automatic ({detected})" : "Automatinė ({detected})",
    "New setting was not saved successfully." : "Naujas nustatymas nebuvo sėkmingai įrašytas.",
    "Shortcut overview" : "Nuorodų apžvalga",
    "or" : "ar",
    "Navigation" : "Navigacija",
    "Previous period" : "Ankstesnis laikotarpis",
    "Next period" : "Kitas laikotarpis",
    "Views" : "Rodiniai",
    "Day view" : "Dienos rodinys",
    "Week view" : "Savaitės rodinys",
    "Month view" : "Mėnesio rodinys",
    "List view" : "Sąrašo rodinys",
    "Actions" : "Veiksmai",
    "Create event" : "Sukurti įvykį",
    "Show shortcuts" : "Rodyti nuorodas",
    "Editor" : "Redaktorius",
    "Close editor" : "Užverti redaktorių",
    "Save edited event" : "Įrašyti taisytą įvykį",
    "Delete edited event" : "Ištrinti taisytą įvykį",
    "Duplicate event" : "Dubliuoti įvykį",
    "Enable birthday calendar" : "Įjungti gimtadienių kalendorių",
    "Show tasks in calendar" : "Rodyti užduotis kalendoriuje",
    "Enable simplified editor" : "Įjungti supaprastintą redaktorių",
    "Limit visible events per view" : "Riboti matomus įvykius pagal rodinį",
    "Show weekends" : "Rodyti savaitgalius",
    "Show week numbers" : "Rodyti savaičių numerius",
    "Default reminder" : "Numatytasis priminimas",
    "Copy primary CalDAV address" : "Kopijuoti pirminį CalDAV adresą",
    "Copy iOS/macOS CalDAV address" : "Kopijuoti iOS/macOS CalDAV adresą",
    "Personal availability settings" : "Asmeninio pasiekiamumo nustatymai",
    "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
    "Calendar settings" : "Kalendoriaus nustatymai",
    "No reminder" : "Jokio priminimo",
    "CalDAV link copied to clipboard." : "CalDAV nuoroda nukopijuota į iškarpinę.",
    "CalDAV link could not be copied to clipboard." : "Nepavyko nukopijuoti CalDAV nuorodą į iškarpinę.",
    "Appointment was created successfully" : "Susitikimas buvo sėkmingai sukurtas",
    "Appointment was updated successfully" : "Susitikimas buvo sėkmingai atnaujintas",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minutė","{duration} minutės","{duration} minučių","{duration} minutė"],
    "0 minutes" : "0 minučių",
    "_{duration} hour_::_{duration} hours_" : ["{duration} valanda","{duration} valandos","{duration} valandų","{duration} valanda"],
    "_{duration} day_::_{duration} days_" : ["{duration} diena","{duration} dienos","{duration} dienų","{duration} diena"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} savaitė","{duration} savaitės","{duration} savaičių","{duration} savaitė"],
    "_{duration} month_::_{duration} months_" : ["{duration} mėnesis","{duration} mėnesiai","{duration} mėnesių","{duration} mėnesis"],
    "_{duration} year_::_{duration} years_" : ["{duration} metai","{duration} metai","{duration} metų","{duration} metai"],
    "To configure appointments, add your email address in personal settings." : "Norėdami konfigūruoti susitikimus, asmeniniuose nustatymuose pridėkite savo el. pašto adresą.",
    "Public – shown on the profile page" : "Viešas – rodomas profilio puslapyje",
    "Private – only accessible via secret link" : "Privatus – pasiekiamas tik per slaptą nuorodą",
    "Location" : "Vieta",
    "Description" : "Aprašas",
    "Visibility" : "Matomumas",
    "Duration" : "Trukmė",
    "Pick time ranges where appointments are allowed" : "Pasirinkite laiko rėžius, kuomet bus leidžiami susitikimai",
    "to" : "iki",
    "No times set" : "Nėra nustatytų laikų",
    "Add" : "Pridėti",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sunday" : "Sekmadienis",
    "Add time before and after the event" : "Pridėti laiką prieš ir po įvykio",
    "Before the event" : "Prieš įvykį",
    "After the event" : "Po įvykio",
    "Planning restrictions" : "Planavimo apribojimai",
    "Create appointment" : "Sukurti susitikimą",
    "Edit appointment" : "Taisyti susitikimą",
    "Save" : "Įrašyti",
    "Update" : "Atnaujinti",
    "Your name" : "Jūsų vardas",
    "Your email address" : "Jūsų el. pašto adresas",
    "Please share anything that will help prepare for our meeting" : "Pasidalinkite informacija, kuri padės mums pasiruošti šiam susitikimui",
    "Reminder" : "Priminimas",
    "before at" : "prieš įvykį, ties",
    "Notification" : "Pranešimas",
    "Email" : "Elektroninis laiškas",
    "Audio notification" : "Garsinis pranešimas",
    "Other notification" : "Kitas pranešimas",
    "Relative to event" : "Susieta su įvykiu",
    "On date" : "data",
    "Edit time" : "Taisyti laiką",
    "Save time" : "Įrašyti laiką",
    "Remove reminder" : "Šalinti priminimą",
    "on" : "šiomis dienomis",
    "at" : ",",
    "+ Add reminder" : "+ Pridėti priminimą",
    "Add reminder" : "Pridėti priminimą",
    "_second_::_seconds_" : ["sekundė","sekundės","sekundžių","sekundė"],
    "_minute_::_minutes_" : ["minutė","minutės","minučių","minutė"],
    "_hour_::_hours_" : ["valanda","valandos","valandų","valanda"],
    "_day_::_days_" : ["diena","dienos","dienų","diena"],
    "_week_::_weeks_" : ["savaitė","savaitės","savaičių","savaitė"],
    "Available" : "Prieinamas",
    "Checking availability" : "Tikrinamas prieinamumas",
    "Availability of attendees, resources and rooms" : "Kviestinių, išteklių ir kambarių prieinamumas",
    "{organizer} (organizer)" : "{organizer} (organizatorius)",
    "Free" : "Laisvas laikas",
    "Busy (tentative)" : "Užimtas laikas (preliminariai)",
    "Busy" : "Užimtas laikas",
    "Out of office" : "Ne darbo vietoje",
    "Unknown" : "Nežinoma",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Tentative" : "Preliminarus",
    "Create Talk room for this event" : "Sukurti šiam įvykiui pokalbių kambarį",
    "Show busy times" : "Rodyti užimtumo laikus",
    "No attendees yet" : "Kol kas kviestinių nėra",
    "Successfully appended link to talk room to description." : "Pokalbių kambario nuoroda sėkmingai pridėta į aprašą.",
    "Error creating Talk room" : "Klaida sukuriant pokalbių kambarį",
    "Send email" : "Siųsti elektroninį laišką",
    "Chairperson" : "Pirmininkas",
    "Required participant" : "Būtinas dalyvis",
    "Optional participant" : "Nebūtinas dalyvis",
    "Non-participant" : "Ne dalyvis",
    "Remove attendee" : "Šalinti kviestinį",
    "Search for emails, users or contacts" : "Ieškoti el. pašto adresų, naudotojų ar adresatų",
    "No match found" : "Nerasta jokio atitikmens",
    "(organizer)" : "(organizatorius)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Norėdami siųsti pakvietimus ir apdoroti atsakymus, [linkopen]pridėkite į asmeninius nustatymus savo el. pašto adresą[linkclose].",
    "Remove color" : "Šalinti spalvą",
    "Event title" : "Įvykio pavadinimas",
    "All day" : "Visą dieną",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Negalima modifikuoti „Visos dienos“ nustatymą įvykiams, kurie yra pasikartojimo rinkinio dalis.",
    "from {startDate}" : "nuo {startDate}",
    "from {startDate} at {startTime}" : "nuo {startDate}, {startTime}",
    "to {endDate}" : "iki {endDate}",
    "to {endDate} at {endTime}" : "iki {endDate}, {endTime}",
    "Repeat" : "Kartoti",
    "End repeat" : "Užbaigti kartojimą",
    "Select to end repeat" : "Pasirinkite norėdami užbaigti kartojimą",
    "never" : "niekada",
    "on date" : "tam tikrą datą",
    "after" : "po",
    "_time_::_times_" : ["karto","kartų","kartų","karto"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Šis įvykis yra pasikartojimo rinkinio pasikartojimo išimtis. Negalite jam pridėti pasikartojimo taisyklės.",
    "first" : "pirmas",
    "third" : "trečias",
    "fourth" : "ketvirtas",
    "fifth" : "penktas",
    "second to last" : "priešpaskutinis",
    "last" : "paskutinis",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Pakeitimai pasikartojimo taisyklėje bus taikomi tik šiam ir būsimiems pasikartojimams.",
    "Repeat every" : "Kartoti kas",
    "By day of the month" : "Pagal mėnesio dienas",
    "On the" : "Ties",
    "_month_::_months_" : ["mėnesis","mėnesiai","mėnesių","mėnesis"],
    "_year_::_years_" : ["metai","metai","metų","metai"],
    "weekday" : "savaitės darbo dienos",
    "weekend day" : "savaitgalio diena",
    "No recurrence" : "Be pasikartojimo",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud nepalaiko pilnai šio įvykio pasikartojimo apibrėžimo. Jei taisysite pasikartojimo parinktis, tam tikri pasikartojimai gali būti prarasti.",
    "Suggestions" : "Pasiūlymai",
    "No rooms or resources yet" : "Kol kas nėra kambarių ar išteklių",
    "Add resource" : "Pridėti išteklių",
    "Has a projector" : "Yra projektorius",
    "Has a whiteboard" : "Yra rašymo lenta",
    "Wheelchair accessible" : "Prieiga neįgaliųjų vežimėliu",
    "Remove resource" : "Šalinti išteklių",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sėdima vieta","{seatingCapacity} sėdimos vietos","{seatingCapacity} sėdimų vietų","{seatingCapacity} sėdima vieta"],
    "Projector" : "Projektorius",
    "Whiteboard" : "Rašymo lenta",
    "Search for resources or rooms" : "Ieškoti išteklių ar kambarių",
    "available" : "prieinamas",
    "unavailable" : "neprieinamas",
    "Room type" : "Kambario tipas",
    "Any" : "Bet koks",
    "More" : "Daugiau",
    "Update this occurrence" : "Atnaujinti šį pasikartojimą",
    "Update this and all future" : "Atnaujinti šį ir visus būsimus",
    "Public calendar does not exist" : "Viešojo kalendoriaus nėra",
    "Maybe the share was deleted or has expired?" : "Galbūt, viešinys buvo ištrintas arba nebegalioja?",
    "Please select a time zone:" : "Pasirinkite laiko juostą:",
    "Pick a time" : "Pasirinkite laiką",
    "Pick a date" : "Pasirinkite datą",
    "from {formattedDate}" : "nuo {formattedDate}",
    "to {formattedDate}" : "iki {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "nuo {formattedDate}, {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "iki {formattedDate}, {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate}, {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate}, {formattedTime}",
    "Please enter a valid date" : "Įveskite teisingą datą",
    "Please enter a valid date and time" : "Įveskite teisingą datą ir laiką",
    "Type to search time zone" : "Rašykite norėdami ieškoti laiko juostos",
    "Global" : "Visuotinis",
    "Time:" : "Laikas:",
    "Personal" : "Asmeniniai",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatinis laiko juostos aptikimas nustatė, kad jūsų laiko juosta yra UTC.\nTaip, greičiausiai, yra dėl jūsų saityno naršyklės saugos priemonių.\nKalendoriaus nustatymuose prašome rankiniu būdu nusistatyti laiko juostą.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Jūsų konfigūruota laiko juosta ({timezoneId}) nerasta. Grįžtama į UTC.\nPrašome nustatymuose pakeisti savo laiko juostą ir pranešti apie šią problemą.",
    "No more events today" : "Šiandien daugiau įvykių nėra",
    "No upcoming events" : "Artėjančių įvykių nėra",
    "Create a new event" : "Sukurti naują įvykį",
    "[Today]" : "[Šiandien]",
    "[Tomorrow]" : "[Rytoj]",
    "[Yesterday]" : "[Vakar]",
    "Event does not exist" : "Įvykio nėra",
    "Delete this occurrence" : "Ištrinti šį pasikartojimą",
    "Delete this and all future" : "Ištrinti šį ir visus būsimus",
    "Details" : "Išsamiau",
    "Attendees" : "Kviestiniai",
    "Resources" : "Ištekliai",
    "Close" : "Užverti",
    "Show more details" : "Rodyti išsamiau",
    "Subscribe to {name}" : "Prenumeruoti {name}",
    "Export {name}" : "Eksportuoti {name}",
    "Anniversary" : "Metinės",
    "Appointment" : "Paskyrimas",
    "Business" : "Verslas",
    "Education" : "Švietimas",
    "Holiday" : "Šventinė diena",
    "Meeting" : "Susitikimas",
    "Miscellaneous" : "Įvairūs",
    "Non-working hours" : "Ne darbo valandos",
    "Not in office" : "Ne darbo vietoje",
    "Phone call" : "Telefono skambutis",
    "Sick day" : "Nedarbingumo dėl ligos diena",
    "Special occasion" : "Ypatinga proga",
    "Travel" : "Kelionės",
    "Vacation" : "Atostogos",
    "Midnight on the day the event starts" : "Vidurnaktį, įvykio pradžios dieną",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dieną prieš įvykį, ties {formattedHourMinute}","%n dienas prieš įvykį, ties {formattedHourMinute}","%n dienų prieš įvykį, ties {formattedHourMinute}","%n dieną prieš įvykį, ties {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n savaitę prieš įvykį, ties {formattedHourMinute}","%n savaites prieš įvykį, ties {formattedHourMinute}","%n savaičių prieš įvykį, ties {formattedHourMinute}","%n savaitę prieš įvykį, ties {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "įvykio dieną ties {formattedHourMinute}",
    "at the event's start" : "įvykio pradžioje",
    "at the event's end" : "įvykio pabaigoje",
    "{time} before the event starts" : "{time} prieš įvykio pradžią",
    "{time} before the event ends" : "{time} prieš įvykio pabaigą",
    "{time} after the event starts" : "{time} po įvykio pradžios",
    "{time} after the event ends" : "{time} po įvykio pabaigos",
    "on {time}" : "ties {time}",
    "on {time} ({timezoneId})" : "ties {time} ({timezoneId})",
    "Week {number} of {year}" : "{year}-ųjų metų {number} savaitė",
    "Does not repeat" : "Nekartojamas",
    "Daily" : "Kasdien",
    "Weekly" : "Kas savaitę",
    "Monthly" : "Kas mėnesį",
    "Yearly" : "Kas metus",
    "_Every %n day_::_Every %n days_" : ["Kas %n dieną","Kas %n dienas","Kas %n dienų","Kas %n dieną"],
    "_Every %n week_::_Every %n weeks_" : ["Kas %n savaitę","Kas %n savaites","Kas %n savaičių","Kas %n savaitę"],
    "_Every %n month_::_Every %n months_" : ["Kas %n mėnesį","Kas %n mėnesius","Kas %n mėnesių","Kas %n mėnesį"],
    "_Every %n year_::_Every %n years_" : ["Kas %n metus","Kas %n metus","Kas %n metų","Kas %n metus"],
    "_on {weekday}_::_on {weekdays}_" : ["ties {weekday}","ties {weekdays}","ties {weekdays}","ties {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["šiomis dienomis: {dayOfMonthList}","šiomis dienomis: {dayOfMonthList}","šiomis dienomis: {dayOfMonthList}","šiomis dienomis: {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "ties {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "ties {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "ties {monthNames}, ties {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "iki {untilDate}",
    "_%n time_::_%n times_" : ["%n kartą","%n kartus","%n kartų","%n kartą"],
    "Untitled event" : "Įvykis be pavadinimo",
    "Untitled task" : "Užduotis be pavadinimo",
    "Please ask your administrator to enable the Tasks App." : "Paprašykite administratoriaus įjungti Užduočių programą.",
    "Prev" : "Ankstesnis",
    "Next" : "Kitas",
    "Prev year" : "Ankstesni metai",
    "Next year" : "Kiti metai",
    "Year" : "Metai",
    "W" : "Sav.",
    "%n more" : "dar %n",
    "No events to display" : "Nėra rodytinų įvykių",
    "_+%n more_::_+%n more_" : ["+ dar %n","+ dar %n","+ dar %n","+ dar %n"],
    "No events" : "Įvykių nėra",
    "Create a new event or change the visible time-range" : "Sukurti naują įvykį ar keisti matomą laiko rėžį",
    "Meeting room" : "Susitikimų kambarys",
    "Lecture hall" : "Paskaitų auditorija",
    "Seminar room" : "Seminarų salė",
    "Other" : "Kita",
    "When shared show" : "Bendrinant rodyti",
    "When shared show full event" : "Bendrinant, rodyti visą įvykio informaciją",
    "When shared show only busy" : "Bendrinant, rodyti tik kaip užimtą laiką",
    "When shared hide this event" : "Bendrinant, slėpti šį įvykį",
    "The visibility of this event in shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose.",
    "Add a location" : "Pridėti vietą",
    "Add a description" : "Pridėti aprašą",
    "Status" : "Būsena",
    "Confirmed" : "Patvirtintas",
    "Canceled" : "Atsisakytas",
    "Confirmation about the overall status of the event." : "Patvirtinimas apie bendrą įvykio būseną.",
    "Show as" : "Rodyti kaip",
    "Take this event into account when calculating free-busy information." : "Atsižvelgti į šį įvykį apskaičiuojant laisvo ir užimto laiko informaciją.",
    "Categories" : "Kategorijos",
    "Categories help you to structure and organize your events." : "Kategorijos padeda jums struktūrizuoti ir valdyti savo įvykius.",
    "Search or add categories" : "Ieškoti ar pridėti kategorijas",
    "Add this as a new category" : "Pridėti tai kaip naują kategoriją",
    "Custom color" : "Tinkinta spalva",
    "Special color of this event. Overrides the calendar-color." : "Speciali šio įvykio spalva. Nustelbia kalendoriaus spalvą.",
    "Chat room for event" : "Įvykio pokalbių kambarys",
    "Imported {filename}" : "Importuotas {filename}",
    "Meditation" : "Apmąstymas",
    "Relaxing" : "Atsipalaidavimas",
    "Relax" : "Poilsis",
    "Break" : "Pertrauka",
    "Commuting" : "Važinėju",
    "Finance" : "Finansai",
    "Bank" : "Bankas",
    "Money" : "Pinigai",
    "Wedding" : "Vestuvės",
    "Dog" : "Šuo",
    "Concert" : "Koncertas",
    "Festival" : "Festivalis",
    "Theater" : "Teatras",
    "Theatre" : "Teatras",
    "Presentation" : "Pateiktis",
    "Talk" : "Kalba",
    "Speech" : "Kalbėjimas",
    "Deadline" : "Galutinis terminas",
    "Camping" : "Stovyklavimas",
    "Camp" : "Stovykla",
    "Election" : "Rinkimai",
    "Voting" : "Balsavimas",
    "Vote" : "Balsuoti",
    "Barbecue" : "Piknikas",
    "Barbeque" : "Barbekiu",
    "Garden" : "Sodas",
    "Farm" : "Ūkis",
    "Movie" : "Filmas",
    "Cinema" : "Kinas",
    "Graduation" : "Diplomo įteikimas",
    "Brainstorm" : "Įdėjų svarstymas",
    "Review" : "Peržiūra",
    "Baseball" : "Beisbolas",
    "Meet" : "Susitikimas",
    "Planning" : "Planavimas",
    "Pointing" : "Nurodant",
    "Retrospective" : "Retrospektyva",
    "Office" : "Biuras",
    "Contributor week" : "Bendradarbių savaitė",
    "Mail" : "Paštas",
    "Soccer" : "Futbolas",
    "Football" : "Futbolo",
    "Gaming" : "Žaidimas",
    "Drive" : "Vairavimas",
    "Driving" : "Vairavimas",
    "Bicycle" : "Dviračiu",
    "Cycle" : "Dviračiais",
    "Biking" : "Dviratis",
    "Podcast" : "Tinklalaidė",
    "Basketball" : "Krepšinis",
    "Fishing" : "Žvejyba",
    "Hiking" : "Žygį",
    "Hike" : "Žygis",
    "Art" : "Menas",
    "Exhibition" : "Paroda",
    "Museum" : "Muziejus",
    "Pilates" : "Pilatesas",
    "Park" : "Parkas",
    "Studying" : "Mokslai",
    "Doctor" : "Daktaras",
    "Health" : "Sveikata",
    "Dentist" : "Stomatologas",
    "Hospital" : "Ligoninė",
    "Interview" : "Interviu",
    "Training" : "Treniruotė",
    "Practice" : "Pratimai",
    "Sports" : "Sportas",
    "Exercise" : "Mankšta",
    "Work out" : "Sportuoti",
    "Working out" : "Pratimus",
    "Gym" : "Sporto klubas",
    "Barber" : "Kirpėja",
    "Haircut" : "Šukuosena",
    "Hairdresser" : "Kirpėja",
    "Exam" : "Egzaminas",
    "Written test" : "Rašymo testas",
    "Oral test" : "Kalbėjimo testas",
    "Working" : "Darbas",
    "New Years Eve" : "Naujieji metai",
    "NYE" : "Naujųjų metų",
    "Fireworks" : "Fejerverkai",
    "Running" : "Bėgimas",
    "Go for a run" : "Bėgimui",
    "Marathon" : "Maratonas",
    "Video-conference" : "Video konferencija",
    "Conference-call" : "Konferencinis skambutis",
    "Video-call" : "Video skambutis",
    "Video-chat" : "Video pokalbis",
    "Video-meeting" : "Video susitikimas",
    "Call" : "Skambutis",
    "Calling" : "Paskambinti",
    "Christmas" : "Kalėdos",
    "Conference" : "Konferencija",
    "Pizza" : "Pica",
    "Travelling" : "Kelionė",
    "Trip" : "Kelionė",
    "Journey" : "Reisas",
    "Collaborate" : "Bendradarbiavimas",
    "Pair" : "Pora",
    "Lecture" : "Paskaita",
    "Seminar" : "Seminaras",
    "Teaching" : "Mokymai",
    "Photograph" : "Nuotrauka",
    "Party" : "Vakarėlis",
    "Celebration" : "Šventė",
    "Celebrate" : "Švęsti",
    "Birthday" : "Gimtadienis",
    "Shopping" : "Apsipirkti",
    "Skate" : "Riedlentė",
    "Skateboard" : "Riedlentė",
    "Wine tasting" : "Vyno degustacija",
    "Golf" : "Golfas",
    "Dinner" : "Pietūs",
    "Lunch" : "Priešpiečiai",
    "Appointment not found" : "Susitikimas nerastas",
    "User not found" : "Naudotojas nerastas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
