OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Sezení bylo neočekávaně přerušeno",
    "Provided email-address is not valid" : "Zadaná e-mailová adresa není platná",
    "%s has published the calendar »%s«" : "%s zveřejnil(a) kalendář „%s“",
    "Unexpected error sending email. Please contact your administrator." : "Neočekávaná chyba při odesílání e-mailu. Obraťte se správce.",
    "Successfully sent email to %1$s" : "E-mail úspěšně odeslán na %1$s",
    "Hello," : "Dobrý den,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás informovat, že %s právě zveřejnil/a  kalendář „%s“.",
    "Open »%s«" : "Otevřít „%s“",
    "Cheers!" : "Mějte se!",
    "Upcoming events" : "Nadcházející události",
    "Appointments" : "Schůzky",
    "Schedule appointment \"%s\"" : "Naplánovat schůzku „%s“",
    "Schedule an appointment" : "Naplánovat schůzku",
    "Prepare for %s" : "Příprava na %s",
    "Follow up for %s" : "Následné kroky ohledně %s",
    "Your appointment \"%s\" with %s needs confirmation" : "K vaší schůzce „%s“ s %s je třeba potvrzení",
    "Dear %s, please confirm your booking" : "%s, prosíme potvrďte svou rezervaci",
    "Confirm" : "Potvrdit",
    "This confirmation link expires in %s hours." : "Platnost tohoto odkazu pro potvrzení skončí za %s hodin.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Pokud si přejete schůzku přece jen zrušit, obraťte se na organizátora odpovědí na tento e-mail nebo navštívením jeho profilové stránky.",
    "Your appointment \"%s\" with %s has been accepted" : "Vaše schůzka „%s“ s %s byla přijata",
    "Dear %s, your booking has been accepted." : "Vážená/ý %s, vaše rezervace byla přijata.",
    "Appointment for:" : "Schůzka pro:",
    "Date:" : "Datum:",
    "Where:" : "Kde:",
    "Your Comment:" : "Váš komentář:",
    "Calendar" : "Kalendář",
    "A Calendar app for Nextcloud" : "Kalendář pro Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aplikace Kalendář je uživatelské rozhraní pro CalDAV server, vestavěný v Nextcloud. Jednoduše synchronizujte události z různých zařízení s vaším Nextcloud a upravujte je online.\n\n* 🚀 **Napojení na ostatní Nextcloud aplikace!** V tuto chvíli  Kontakty – a další jsou na cestě.\n* 🌐 **Podpora WebCal!** Chcete vidět shodující se dny svého oblíbeného týmu ve svém kalendáři? Žádný problém!\n* 🙋 **Účastníci!** Pozvěte lidi na své události.\n * ⌚️ **Volný/zaneprázdněný!** Zjistěte, zda jsou vámi zamýšlení účastníci schůzky k dispozici\n * ⏰ **Připomínky!** Dostávejte upozornění události v prohlížeči a e-mailem.\n* 🔍 Vyhledávání! Snadno najděte své události\n* ☑️ Úkoly! Zobrazte si úkoly a jejich termíny přímo v kaledáři\n* 🙈 **Nevynalézáme znovu kolo!** Založeno na skvělých softwarových knihovnách [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) a [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Předchozí den",
    "Previous week" : "Předchozí týden",
    "Previous month" : "Předchozí měsíc",
    "Next day" : "Příští den",
    "Next week" : "Příští týden",
    "Next month" : "Příští měsíc",
    "New event" : "Nová událost",
    "Today" : "Dnes",
    "Day" : "Den",
    "Week" : "Týden",
    "Month" : "Měsíc",
    "List" : "Seznam",
    "Preview" : "Náhled",
    "Copy link" : "Zkopírovat odkaz",
    "Edit" : "Upravit",
    "Delete" : "Smazat",
    "Appointment link was copied to clipboard" : "Odkaz na schůzku byl zkopírován do schránky",
    "Appointment link could not be copied to clipboard" : "Odkaz na schůzku se nepodařilo zkopírovat do schránky",
    "Add new" : "Přidat novou",
    "Untitled calendar" : "Nepojmenovaný kalendář",
    "Edit name" : "Upravit název",
    "Saving name …" : "Ukládání názvu…",
    "Edit color" : "Upravit barvu",
    "Saving color …" : "Ukládání barvy…",
    "Copy private link" : "Zkopírovat soukromý odkaz",
    "Export" : "Exportovat",
    "Unshare from me" : "Přestat sdílet",
    "Disable calendar \"{calendar}\"" : "Vypnout kalendář „{calendar}“",
    "Disable untitled calendar" : "Vypnout nenazvaný kalendář",
    "Enable calendar \"{calendar}\"" : "Zapnout kalendář „{calendar}“",
    "Enable untitled calendar" : "Zapnout nenazvaný kalendář",
    "An error occurred, unable to change visibility of the calendar." : "Došlo k chybě, nedaří se změnit viditelnost kalendáře.",
    "An error occurred, unable to delete the calendar." : "Došlo k chybě, kalendář se nepodařilo smazat.",
    "Calendar link copied to clipboard." : "Odkaz kalendáře zkopírován do schránky.",
    "Calendar link could not be copied to clipboard." : "Odkaz na kalendář se nepodařilo zkopírovat do schránky.",
    "An error occurred, unable to rename the calendar." : "Došlo k chybě, kalendář se nepodařilo přejmenovat.",
    "An error occurred, unable to change the calendar's color." : "Došlo k chybě, barvu kalendáře nelze změnit.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalendář přestane být sdílen za {countdown} sekundu","Kalendář přestane být sdílen za {countdown} sekundy","Kalendář přestane být sdílen za {countdown} sekund","Kalendář přestane být sdílen za {countdown} sekundy"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Smazání kalendáře za {countdown} sekundu","Smazání kalendáře za {countdown} sekundy","Smazání kalendáře za {countdown} sekund","Smazání kalendáře za {countdown} sekundy"],
    "Share link" : "Odkaz na sdílení",
    "Publish calendar" : "Zveřejnit kalendář",
    "Publishing calendar" : "Zveřejnění kalendáře",
    "Copy public link" : "Zkopírovat veřejný odkaz",
    "Send link to calendar via email" : "Odeslat odkaz na kalendář prostřednictvím e-mailu",
    "Enter one address" : "Zadejte jednu adresu",
    "Sending email …" : "Posílání e-mailu…",
    "Copy subscription link" : "Zkopírovat odkaz pro přihlášení se k odběru",
    "Copying link …" : "Kopírování odkazu…",
    "Copied link" : "Odkaz zkopírován",
    "Could not copy link" : "Odkaz se nedaří zkopírovat",
    "Copy embedding code" : "Zkopírovat kód pro vložení do HTML",
    "Copying code …" : "Kopírování kódu…",
    "Copied code" : "HTML kód zkopírován",
    "Could not copy code" : "HTML kód se nedaří zkopírovat",
    "Delete share link" : "Smazat sdílecí odkaz",
    "Deleting share link …" : "Mazání odkazu na sdílení…",
    "An error occurred, unable to publish calendar." : "Došlo k chybě, kalendář se nedaří zveřejnit.",
    "An error occurred, unable to send email." : "Došlo k chybě, e-mail se nedaří odeslat.",
    "Embed code copied to clipboard." : "HTML kód, který vložit do kódu stránky, zkopírován do schránky.",
    "Embed code could not be copied to clipboard." : "HTML kód, který vložit do kódu stránky, se nepodařilo zkopírovat do schránky",
    "Unpublishing calendar failed" : "Zrušení zveřejnění kalendáře se nezdařilo",
    "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
    "No users or groups" : "Žádní uživatelé nebo skupiny",
    "can edit" : "může upravovat",
    "Unshare with {displayName}" : "Přestat sdílet s {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Došlo k chybě, nepodařilo se zrušit sdílení kalendáře.",
    "An error occurred, unable to change the permission of the share." : "Došlo k chybě, nepodařilo se změnit přístupová práva k sdílení.",
    "New calendar" : "Nový kalendář",
    "Name for new calendar" : "Název pro nový kalendář",
    "Creating calendar …" : "Vytváření kalendáře…",
    "New calendar with task list" : "Nový kalendář s úkolníkem",
    "New subscription from link (read-only)" : "Nové přihlášení se k odběru z odkazu (pouze pro čtení)",
    "Creating subscription …" : "Vytváření přihlášení se k odběru…",
    "An error occurred, unable to create the calendar." : "Došlo k chybě, kalendář se nepodařilo vytvořit.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vložte platný odkaz (včetně http://, https://, webcal://, nebo webcals:// na začátku)",
    "Trash bin" : "Koš",
    "Loading deleted items." : "Načítání smazaných položek.",
    "You do not have any deleted items." : "Nemáte žádné smazané položky.",
    "Name" : "Název",
    "Deleted" : "Smazáno",
    "Restore" : "Obnovit",
    "Delete permanently" : "Trvale odstranit",
    "Empty trash bin" : "Vyprázdnit koš",
    "Untitled item" : "Nepojmenovaná položka",
    "Unknown calendar" : "Neznámý kalendář",
    "Could not load deleted calendars and objects" : "Nedaří se načíst smazané kalendáře a objekty",
    "Could not restore calendar or event" : "Kalendář nebo událost se nepodařilo obnovit",
    "Do you really want to empty the trash bin?" : "Opravdu chcete koš vyprázdnit?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Položky v koši jsou smazány po uplynutí {numDays} dne","Prvky v koši jsou smazány po uplynutí {numDays} dnů","Položky v koši jsou smazány po uplynutí {numDays} dnů","Položky v koši jsou smazány po uplynutí {numDays} dnů"],
    "Could not update calendar order." : "Pořadí kalendářů se nedaří aktualizovat.",
    "Import calendars" : "Importovat kalendáře",
    "Please select a calendar to import into …" : "Vyberte kalendář do kterého importovat…",
    "Filename" : "Soubor",
    "Calendar to import into" : "Kalendář do kterého importovat",
    "Cancel" : "Storno",
    "_Import calendar_::_Import calendars_" : ["Importovat kalendář","Importovat kalendáře","Importovat kalendářů","Importovat kalendáře"],
    "{filename} could not be parsed" : "{filename} není možné zpracovat",
    "No valid files found, aborting import" : "Nenalezeny žádné platné soubory, import proto bude ukončen",
    "Import partially failed. Imported {accepted} out of {total}." : "Import se z části nezdařil. Naimportováno {accepted} z {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Úspěšně naimportována %n událost","Úspěšně naimportovány %n události","Úspěšně naimportováno %n událostí","Úspěšně naimportovány %n události"],
    "Automatic" : "Automaticky",
    "Automatic ({detected})" : "Automaticky ({detected})",
    "New setting was not saved successfully." : "Nové nastavení se nepodařilo uložit.",
    "Shortcut overview" : "Přehled zkratek",
    "or" : "nebo",
    "Navigation" : "Pohyb",
    "Previous period" : "Předchozí období",
    "Next period" : "Následující období",
    "Views" : "Zobrazení",
    "Day view" : "Denní zobrazení",
    "Week view" : "Týdenní zobrazení",
    "Month view" : "Měsíční zobrazení",
    "List view" : "Zobrazení v seznamu",
    "Actions" : "Akce",
    "Create event" : "Vytvořit událost",
    "Show shortcuts" : "Zobrazit zkratky",
    "Editor" : "Editor",
    "Close editor" : "Zavřít editor",
    "Save edited event" : "Uložit upravenou událost",
    "Delete edited event" : "Smazat upravenou událost",
    "Duplicate event" : "Zduplikovat událost",
    "Enable birthday calendar" : "Zobrazovat kalendář s narozeninami",
    "Show tasks in calendar" : "Zobrazovat úkoly v kalendáři",
    "Enable simplified editor" : "Používat zjednodušený editor",
    "Limit visible events per view" : "Omezit viditelné události v jednotlivých pohledech",
    "Show weekends" : "Zobrazit víkendy",
    "Show week numbers" : "Zobrazovat čísla týdnů",
    "Time increments" : "Přírůstky času",
    "Default reminder" : "Výchozí upomínka",
    "Copy primary CalDAV address" : "Zkopírovat hlavní CalDAV adresu",
    "Copy iOS/macOS CalDAV address" : "Zkopírovat CalDAV adresu pro iOS/macOS",
    "Personal availability settings" : "Nastavení osobní dostupnosti",
    "Show keyboard shortcuts" : "Zobrazit klávesové zkratky",
    "Calendar settings" : "Nastavení kalendáře",
    "No reminder" : "Žádná upomínka",
    "CalDAV link copied to clipboard." : "CalDAV odkaz zkopírován do schránky.",
    "CalDAV link could not be copied to clipboard." : "CalDAV odkaz se nepodařilo zkopírovat do schránky.",
    "Appointment was created successfully" : "Schůzka byla úspěšně vytvořena",
    "Appointment was updated successfully" : "Schůzka byla úspěšně zaktualizována",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minuty","{duration} minut","{duration} minuty"],
    "0 minutes" : "0 minut",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hodina","{duration} hodiny","{duration} hodin","{duration} hodiny"],
    "_{duration} day_::_{duration} days_" : ["{duration} den","{duration} dny","{duration} dnů","{duration} dny"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} týden","{duration} týdny","{duration} týdnů","{duration} týdny"],
    "_{duration} month_::_{duration} months_" : ["{duration} měsíc","{duration} měsíce","{duration} měsíců","{duration} měsíce"],
    "_{duration} year_::_{duration} years_" : ["{duration} rok","{duration} roky","{duration} let","{duration} roky"],
    "To configure appointments, add your email address in personal settings." : "Pokud chcete nastavovat schůzky, je třeba v nastavení, v sekci osobní údaje, zadat svůj e-mail.",
    "Public – shown on the profile page" : "Veřejné – zobrazeno na profilové stránce",
    "Private – only accessible via secret link" : "Soukromé – přístupné pouze přes soukromý odkaz",
    "Location" : "Umístění",
    "Description" : "Popis",
    "Visibility" : "Viditelnost",
    "Duration" : "Trvání",
    "Increments" : "Přírůstky",
    "Additional calendars to check for conflicts" : "Další kalendáře které kontrolovat ohledně konfliktů",
    "Pick time ranges where appointments are allowed" : "Zvolte časové rozsahy, ve kterých jsou povolené schůzky",
    "to" : "do",
    "Delete slot" : "Smazat slot",
    "No times set" : "Nenastaveny žádné časy",
    "Add" : "Přidat",
    "Monday" : "pondělí",
    "Tuesday" : "úterý",
    "Wednesday" : "středa",
    "Thursday" : "čtvrtek",
    "Friday" : "pátek",
    "Saturday" : "sobota",
    "Sunday" : "neděle",
    "Add time before and after the event" : "Přidat čas před a po události",
    "Before the event" : "Před událostí",
    "After the event" : "Po události",
    "Planning restrictions" : "Omezení plánování",
    "Minimum time before next available slot" : "Nejkratší umožněná doba před dalším slotem k dispozici",
    "Max slots per day" : "Nejvýše slotů za den",
    "Limit how far in the future appointments can be booked" : "Omezte jak daleko v budoucnosti bude možné si rezervovat schůzky",
    "Create appointment" : "Vytvořit schůzku",
    "Edit appointment" : "Upravit schůzku",
    "Save" : "Uložit",
    "Update" : "Aktualizovat",
    "Please confirm your reservation" : "Potvrďte svou rezervaci",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "V e-mailu vám pošleme podrobnosti. Prosíme, potvrďte schůzku kliknutím na odkaz v e-mailu. Tuto stránku nyní můžete zavřít.",
    "Your name" : "Vaše jméno",
    "Your email address" : "Vaše e-mailová adresa",
    "Please share anything that will help prepare for our meeting" : "Nasílejte vše co pomůže pro přípravu na naši schůzku",
    "Could not book the appointment. Please try again later or contact the organizer." : "Schůzka nemohla být rezervována. Zkuste to znovu později nebo se obraťte na organizátora.",
    "Book the appointment" : "Zarezervovat schůzku",
    "Reminder" : "Připomínka",
    "before at" : "před v",
    "Notification" : "Upozornění",
    "Email" : "E-mail",
    "Audio notification" : "Zvuková upozornění",
    "Other notification" : "Ostatní upozornění",
    "Relative to event" : "Vztaženo k události",
    "On date" : "Dne",
    "Edit time" : "Okamžik úpravy",
    "Save time" : "Okamžik uložení",
    "Remove reminder" : "Odebrat připomínku",
    "on" : "v",
    "at" : "na",
    "+ Add reminder" : "+ Přidat připomínku",
    "Add reminder" : "Přidat připomínku",
    "_second_::_seconds_" : ["sekunda","sekundy","sekund","sekundy"],
    "_minute_::_minutes_" : ["minuta","minuty","minut","minuty"],
    "_hour_::_hours_" : ["hodina","hodiny","hodin","hodiny"],
    "_day_::_days_" : ["den","dny","dní","dny"],
    "_week_::_weeks_" : ["týden","týdny","týdnů","týdny"],
    "Invitation accepted" : "Pozvání přijato",
    "Available" : "K dispozici",
    "Suggested" : "Doporučeno",
    "Participation marked as tentative" : "Účast označena jako povinná",
    "Accepted {organizerName}'s invitation" : "Pozvánka od {organizerName} přijata",
    "Not available" : "Není k dispozici",
    "Invitation declined" : "Pozvání odmítnuto",
    "Declined {organizerName}'s invitation" : "Odmítnuta pozvánka od {organizerName}",
    "Invitation is delegated" : "Pozvání postoupeno někomu dalšímu",
    "Checking availability" : "Zjišťuje se, zda je k dispozici",
    "Invitation sent" : "Pozvánka odeslána",
    "Has not responded to {organizerName}'s invitation yet" : "Doposud neodpovězeno na pozvánku od {organizerName}",
    "Availability of attendees, resources and rooms" : "Dostupnost účastníků, prostředků a místností",
    "{organizer} (organizer)" : "{organizer} (organizátor/ka)",
    "Free" : "Volné",
    "Busy (tentative)" : "Zaneprázdněno (nezávazně)",
    "Busy" : "Zaneprázdněno",
    "Out of office" : "Mimo kancelář",
    "Unknown" : "Neznámé",
    "Accept" : "Přijmout",
    "Decline" : "Odmítnout",
    "Tentative" : "Nezávazně",
    "The invitation has been accepted successfully." : "Pozvánka byla úspěšně přijata.",
    "Failed to accept the invitation." : "Pozvánku se nepodařilo přijmout.",
    "The invitation has been declined successfully." : "Pozvánka byla úspěšně odmítnuta.",
    "Failed to decline the invitation." : "Pozvánku se nepodařilo odmítnout.",
    "Your participation has been marked as tentative." : "Vaše účast byla označena jako povinná.",
    "Failed to set the participation status to tentative." : "Nepodařilo se nastavit stav účasti na povinnou.",
    "Create Talk room for this event" : "Vytvořit pro tuto událost místnost v Talk",
    "Show busy times" : "Zobrazit, kdy zaneprázněno",
    "No attendees yet" : "Zatím žádní účastníci",
    "Successfully appended link to talk room to description." : "Do popisu úspěšně přidán odkaz na místnost v Talk",
    "Error creating Talk room" : "Chyba při vytváření místnosti v Talk",
    "Send email" : "Odeslat e-mail",
    "Chairperson" : "Předseda/kyně",
    "Required participant" : "Povinný účastník",
    "Optional participant" : "Nepovinní účastníci",
    "Non-participant" : "Neúčastník",
    "Remove attendee" : "Odebrat účastníka",
    "Search for emails, users or contacts" : "Hledat e-maily, uživatele či kontakty",
    "No match found" : "Nenalezena žádná shoda",
    "(organizer)" : "(organizátor(ka))",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Pro rozesílání pozvánek a práci s odpověďmi na ně [linkopen]přidejte svoji  e-mailovou adresu[linkclose] do osobních nastavení.",
    "Remove color" : "Odebrat barvu",
    "Event title" : "Název události",
    "All day" : "Celý den",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "U opakovaných událostí nelze u jednotlivého výskytu zvlášť měnit, zda je událost celodenní či ne.",
    "from {startDate}" : "od {startDate}",
    "from {startDate} at {startTime}" : "od {startDate} v {startTime}",
    "to {endDate}" : "do {endDate}",
    "to {endDate} at {endTime}" : "do {endDate} v {endTime}",
    "Repeat" : "Opakovat",
    "End repeat" : "Konec opakování",
    "Select to end repeat" : "Vyberte konec opakování",
    "never" : "nikdy",
    "on date" : "dne",
    "after" : "po",
    "_time_::_times_" : ["krát","krát","krát","krát"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Tato událost je výjimka v opakované události. Proto k ní nelze přidat pravidlo opakování.",
    "first" : "první",
    "third" : "třetí",
    "fourth" : "čtvrté",
    "fifth" : "páté",
    "second to last" : "po kolik sekund",
    "last" : "poslední",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Změny v opakované události budou mít vliv jen na tuto a budoucí události",
    "Repeat every" : "Opakovat každé",
    "By day of the month" : "Podle dne v měsíci",
    "On the" : "V",
    "_month_::_months_" : ["měsíc","měsíce","měsíců","měsíce"],
    "_year_::_years_" : ["rok","roky","let","roky"],
    "weekday" : "den v týdnu",
    "weekend day" : "den o víkendu",
    "No recurrence" : "Bez opakování",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Definice opakování této události není v Nextcloud zcela podporována. Pokud upravíte volby opakování, některá opakování mohou být ztracena.",
    "Suggestions" : "Doporučení",
    "No rooms or resources yet" : "Zatím žádné místnosti nebo prostředky",
    "Add resource" : "Přidat prostředek",
    "Has a projector" : "Má projektor",
    "Has a whiteboard" : "Má tabuli",
    "Wheelchair accessible" : "Kolečkové křeslo pro invalidy",
    "Remove resource" : "Odebrat prostředek",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} židle","{seatingCapacity} židle","{seatingCapacity} židlí","{seatingCapacity} židle"],
    "Projector" : "Projektor",
    "Whiteboard" : "Tabule",
    "Search for resources or rooms" : "Hledat prostředky nebo místnosti",
    "available" : "dostupné",
    "unavailable" : "není dostupné",
    "Room type" : "Typ místnosti",
    "Any" : "Jakákoli",
    "Minimum seating capacity" : "Minimální kapacita k sezení",
    "More" : "Více",
    "Update this occurrence" : "Aktualizovat tento výskyt",
    "Update this and all future" : "Aktualizovat tento a všechny budoucí",
    "Public calendar does not exist" : "Veřejný kalendář neexistuje",
    "Maybe the share was deleted or has expired?" : "Sdílení byl nejspíš smazáno nebo skončila jeho platnost?",
    "Please select a time zone:" : "Vyberte časové pásmo:",
    "Pick a time" : "Vyberte čas",
    "Pick a date" : "Vyberte datum",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} v {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} v {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} v {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} v {formattedTime}",
    "Please enter a valid date" : "Zadejte platné datum",
    "Please enter a valid date and time" : "Zadejte platný datum a čas",
    "Type to search time zone" : "Psaním vyhledejte časové pásmo",
    "Global" : "Globální",
    "Select date" : "Vybrat datum",
    "Select slot" : "Vybrat slot",
    "No slots available" : "Nejsou k dispozici žádná časová okna",
    "The slot for your appointment has been confirmed" : "Slož pro vaši schůzku byl potvrzen",
    "Appointment Details:" : "Podrobnosti o schůzce:",
    "Time:" : "Čas:",
    "Booked for:" : "Zarezervováno pro:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Děkujeme. Vaše rezervace od {startDate} do {endDate} byla potvrzena.",
    "Book another appointment:" : "Zarezervovat si jinou schůzku:",
    "See all available slots" : "Zobrazit všechny dostupné sloty",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Časové okno pro vaši schůzku od {startDate} do {endDate} už není k dispozici.",
    "Please book a different slot:" : "Prosím zarezervujte si jiné časové okno:",
    "Book an appointment with {name}" : "Zarezervovat si schůzku s {name}",
    "No public appointments found for {name}" : "Pro {name} nebyla nalezena žádná veřejná schůzka",
    "Personal" : "Osobní",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatickým zjištěním časové zóny bylo určeno, že vaše zóna je UTC.\nTo je nejspíš kvůli bezpečnostním opatřením vámi používaného webového prohlížeče.\nV nastavení kalendáře zadejte časovou zónu ručně.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Vámi nastavené časové pásmo ({timezoneId}) nenalezeno. Náhradou bude použit UTC čas.\nZměňte své časové pásmo v nastaveních a nahlaste tento problém vývojářům, děkujeme.",
    "No more events today" : "Dnes už žádné další události",
    "No upcoming events" : "Žádné nadcházející události",
    "Create a new event" : "Vytvořit novou událost",
    "[Today]" : "[Dnes]",
    "[Tomorrow]" : "[Zítra]",
    "[Yesterday]" : "[Včera]",
    "[Last] dddd" : "[Minul.] dddd",
    "Event does not exist" : "Událost neexistuje",
    "Duplicate" : "Zduplikovat",
    "Delete this occurrence" : "Smazat tento výskyt",
    "Delete this and all future" : "Smazat toto a všechny budoucí",
    "Details" : "Podrobnosti",
    "Attendees" : "Účastníci",
    "Resources" : "Prostředky",
    "Close" : "Zavřít",
    "Show more details" : "Zobrazit další podrobnosti",
    "Subscribe to {name}" : "Přihlásit se k odběru {name}",
    "Export {name}" : "Exportovat {name}",
    "Anniversary" : "Výročí",
    "Appointment" : "Schůzka",
    "Business" : "Práce",
    "Education" : "Výuka",
    "Holiday" : "Svátek",
    "Meeting" : "Schůze",
    "Miscellaneous" : "Různé",
    "Non-working hours" : "Mimopracovní hodiny",
    "Not in office" : "Není v kanceláři",
    "Phone call" : "Telefonní hovor",
    "Sick day" : "Zdravotní volno",
    "Special occasion" : "Zvláštní příležitost",
    "Travel" : "Cesta",
    "Vacation" : "Dovolená",
    "Midnight on the day the event starts" : "Nejbližší půlnoc před začátkem události",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n den před událostí v {formattedHourMinute}","%n dny před událostí v {formattedHourMinute}","%n dnů před událostí v {formattedHourMinute}","%n dny před událostí v {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n týden před událostí v {formattedHourMinute}","%n týdny před událostí v {formattedHourMinute}","%n týdnů před událostí v {formattedHourMinute}","%n týdny před událostí v {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "v den událostí v {formattedHourMinute}",
    "at the event's start" : "na začátku události",
    "at the event's end" : "na konci události",
    "{time} before the event starts" : "{time} před začátkem události",
    "{time} before the event ends" : "{time} před skončením události",
    "{time} after the event starts" : "{time} po začátku události",
    "{time} after the event ends" : "{time} po skončení události",
    "on {time}" : "v {time}",
    "on {time} ({timezoneId})" : "v {time} ({timezoneId})",
    "Week {number} of {year}" : "{number}. týden {year}",
    "Does not repeat" : "Neopakuje se",
    "Daily" : "Každodenně",
    "Weekly" : "Týdně",
    "Monthly" : "Měsíčně",
    "Yearly" : "Každoročně",
    "_Every %n day_::_Every %n days_" : ["Každý den","Každé %n dny","Každých %n dnů","Každé %n dny"],
    "_Every %n week_::_Every %n weeks_" : ["Každý týden","Každé %n týdny","Každých %n týdnů","Každé %n týdny"],
    "_Every %n month_::_Every %n months_" : ["Každý měsíc","Každé %n měsíce","Každých %n měsíců","Každé %n měsíce"],
    "_Every %n year_::_Every %n years_" : ["Každý rok","Každé %n roky","Každých %n let","Každé %n roky"],
    "_on {weekday}_::_on {weekdays}_" : ["v {weekdays}","v {weekdays}","v {weekdays}","v {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["dne {dayOfMonthList}","ve dnech {dayOfMonthList}","ve dnech {dayOfMonthList}","ve dnech {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "každý měsíc {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "v {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "v {monthNames} v {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n kát","%n krát","%n krát","%n krát"],
    "Untitled event" : "Nepojmenovaná událost",
    "Untitled task" : "Nepojmenovaný úkol",
    "Please ask your administrator to enable the Tasks App." : "Požádejte správce aby zapnul aplikaci Úkoly.",
    "Prev" : "Předchozí",
    "Next" : "Další",
    "Prev year" : "Předchozí rok",
    "Next year" : "Následující rok",
    "Year" : "Rok",
    "W" : "T",
    "%n more" : "%n další",
    "No events to display" : "Žádné události k zobrazení",
    "_+%n more_::_+%n more_" : ["+%n další","+%n další","+%n dalších","+%n další"],
    "No events" : "Žádné události",
    "Create a new event or change the visible time-range" : "Vytvořit novou událost nebo změňte viditelný časový rozsah",
    "It might have been deleted, or there was a typo in a link" : "Mohl být smazán, nebo v odkazu byl překlep",
    "It might have been deleted, or there was a typo in the link" : "Mohl být smazán, nebo v odkazu byl překlep",
    "Meeting room" : "Zasedací místnost",
    "Lecture hall" : "Posluchárna",
    "Seminar room" : "Místnost pro semináře",
    "Other" : "Jiná",
    "When shared show" : "Při sdílení neskrývat",
    "When shared show full event" : "Když sdíleno zobrazit úplnou událost",
    "When shared show only busy" : "Když sdíleno zobrazit pouze zaneprázdněno",
    "When shared hide this event" : "Pří sdílení tuto událost skrýt",
    "The visibility of this event in shared calendars." : "Viditelnost této události ve sdílených kalendářích.",
    "Add a location" : "Přidat umístění",
    "Add a description" : "Přidat popis",
    "Status" : "Stav",
    "Confirmed" : "Potvrzeno",
    "Canceled" : "Zrušeno",
    "Confirmation about the overall status of the event." : "Potvrzení o celkovém stavu události.",
    "Show as" : "Zobrazit jako",
    "Take this event into account when calculating free-busy information." : "Zohlednit tuto událost při určování zaneprázdněných/volných hodin.",
    "Categories" : "Kategorie",
    "Categories help you to structure and organize your events." : "Kategorie pomáhají udržovat přehled v událostech a strukturovat je.",
    "Search or add categories" : "Hledat nebo přidat kategorie",
    "Add this as a new category" : "Přidat toto jako novou kategorii",
    "Custom color" : "Uživatelsky určená barva",
    "Special color of this event. Overrides the calendar-color." : "Speciální barva této události. Přebíjí barvu kalendáře.",
    "Chat room for event" : "Chat místnost pro událost",
    "Imported {filename}" : "Importováno {filename}",
    "Meditation" : "Meditace",
    "Relaxing" : "Odpočinek",
    "Relax" : "Odpočinek",
    "Break" : "Přestávka",
    "Commute" : "Dojíždět",
    "Commuting" : "Dojíždění",
    "Shuttle" : "Kyvadlová doprava",
    "Invoice" : "Faktura",
    "Finance" : "Finance",
    "Bank" : "Banka",
    "Money" : "Peníze",
    "Wedding" : "Svadba",
    "Dog" : "Pes",
    "Concert" : "Koncert",
    "Festival" : "Festival",
    "Theater" : "Divadlo",
    "Theatre" : "Divadlo",
    "Presentation" : "Prezentace",
    "Talk" : "Hovor",
    "Speech" : "Řeč",
    "Deadline" : "Termín",
    "Submission" : "Odeslání",
    "Reporting" : "Výkaznictví",
    "Camping" : "Kempování",
    "Camp" : "Kemp",
    "Election" : "Volby",
    "Voting" : "Hlasování",
    "Vote" : "Hlasovat",
    "Barbecue" : "Grilování",
    "Barbeque" : "Grilování",
    "Garden" : "Zahrada",
    "Farm" : "Farma",
    "Movie" : "Film",
    "Cinema" : "Kino",
    "Graduation" : "Promoce",
    "Brainstorm" : "Brainstorming",
    "Review" : "Revize",
    "Audit" : "Audit",
    "Inspection" : "Inspekce",
    "Proofreading" : "Korektura",
    "Baseball" : "Baseball",
    "Meet" : "Setkání",
    "Planning" : "Plánování",
    "Pointing" : "Ukazování",
    "Retrospective" : "Retrospektiva",
    "Office" : "Kancelář",
    "Contributor week" : "Týden přispěvatelů",
    "Mail" : "Pošta",
    "Soccer" : "Fotbal",
    "Football" : "Fotbal",
    "Gaming" : "Hraní",
    "Drive" : "Řídit",
    "Driving" : "Potápění",
    "Bicycle" : "Kolo",
    "Cycle" : "Jízda na kole",
    "Cycling" : "Cyklistika",
    "Biking" : "Jízda na kole",
    "Bike" : "Kolo",
    "Podcast" : "Podcast",
    "Basketball" : "Basketball",
    "Fishing" : "Rybaření",
    "Hiking" : "Lezení",
    "Hike" : "Lezení",
    "Art" : "Umění",
    "Exhibition" : "Výstava",
    "Museum" : "Muzeum",
    "Pilates" : "Cvičení",
    "Park" : "Park",
    "Walk" : "Procházka",
    "Studying" : "Studium",
    "Doctor" : "Doktor",
    "Health" : "Zdraví",
    "Dentist" : "Zubař",
    "Hospital" : "Nemocnice",
    "Interview" : "Rozhovor",
    "Training" : "Tréning",
    "Practice" : "Procvičování",
    "Sports" : "Sporty",
    "Exercise" : "Cvičení",
    "Work out" : "Cvičení",
    "Working out" : "Cvičení",
    "Gym" : "Tělocvična",
    "Barber" : "Holič",
    "Haircut" : "Účes",
    "Hairdresser" : "Kadeřník",
    "Exam" : "Zkouška",
    "Written test" : "Písemná zkouška",
    "Oral test" : "Ústní zkouška",
    "Working" : "Práce",
    "New Years Eve" : "Štědrý den",
    "NYE" : "Silvestr",
    "Fireworks" : "Ohňostroj",
    "Running" : "Běhání",
    "Go for a run" : "Jít si zaběhat",
    "Marathon" : "Běh",
    "Video-conference" : "Video-konference",
    "Conference-call" : "Konferenční hovor",
    "Video-call" : "Video-hovor",
    "Video-chat" : "Video-chat",
    "Video-meeting" : "Video-schůze",
    "Call" : "Volání",
    "Calling" : "Volání",
    "Christmas" : "Vánoce",
    "Conference" : "Konference",
    "Pizza" : "Pizza",
    "Travelling" : "Cestování",
    "Trip" : "Výlet",
    "Journey" : "Zájezd",
    "Collaborate" : "Spolupracovat",
    "Pair" : "Dvojice",
    "Lecture" : "Přednáška",
    "Seminar" : "Seminář",
    "Teaching" : "Učení",
    "Photograph" : "Fotografie",
    "Party" : "Párty",
    "Celebration" : "Oslava",
    "Celebrate" : "Slavit",
    "Birthday" : "Narozeniny",
    "Shopping" : "Nakupování",
    "Groceries" : "Potraviny",
    "Skate" : "Skateboard",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Ochutnávka vína",
    "Golf" : "Golf",
    "Dinner" : "Večeře",
    "Lunch" : "Oběd",
    "Appointment not found" : "Schůzka nenalezena",
    "User not found" : "Uživatel nenalezen"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
