OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "用户会话意外过期",
    "Provided email-address is not valid" : "提供的电子邮件地址无效",
    "%s has published the calendar »%s«" : "%s 已经发布了日历 »%s«",
    "Unexpected error sending email. Please contact your administrator." : "发送电子邮件时出现意外错误。请联系您的管理员。",
    "Successfully sent email to %1$s" : "成功将电子邮件发送到 %1$s",
    "Hello," : "你好，",
    "We wanted to inform you that %s has published the calendar »%s«." : "我们想通知您，%s 已发布日历 »%s«。",
    "Open »%s«" : "打开 »%s«",
    "Cheers!" : "干杯！",
    "Upcoming events" : "即将到来的事件",
    "Appointments" : "预约",
    "Schedule appointment \"%s\"" : "安排预约\"%s\"",
    "Schedule an appointment" : "安排预约",
    "Prepare for %s" : "准备 %s",
    "Follow up for %s" : "跟进 %s",
    "Dear %s, please confirm your booking" : "亲爱的 %s，请确认你的登记",
    "Confirm" : "确认",
    "This confirmation link expires in %s hours." : "确认链接将在 %s 小时内过期",
    "Date:" : "日期：",
    "Where:" : "地点：",
    "Calendar" : "日历",
    "A Calendar app for Nextcloud" : "适用于 Nextcloud 的日历应用",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "日历应用是 Nextcloud 的 CalDAV 服务器的一个用户界面。通过适用此应用，您可以轻松地将各种设备上的事件与您的 Nextcloud 同步，并在线编辑它们。\n\n* 🚀 **与其他 Nextcloud 应用的集成！** 目前是通讯录 -- 更多的应用将会支持\n* 🌐 **支持 WebCal！** 想在日历上看到自己最喜欢的球队的比赛日？没问题！\n* 🙋 **与会者！** 邀请人们参加您的事件\n* ⌚️ **空闲/繁忙！** 查看您的与会者何时可以见面\n* ⏰ **提醒！** 通过浏览器和电子邮件获取事件通知报\n* 🔍 搜索！轻松找到你的活动\n* ☑️ 任务！直接在日历中查看即将到期的任务\n* 🙈 **我们没有重新发明轮子！** 基于出色的 [c-dav 库](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) 和 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 库开发。",
    "Previous day" : "前一天",
    "Previous week" : "上周",
    "Previous month" : "上个月",
    "Next day" : "后一天",
    "Next week" : "下周",
    "Next month" : "下个月",
    "New event" : "新事件",
    "Today" : "今天",
    "Day" : "日",
    "Week" : "星期",
    "Month" : "月",
    "List" : "列表",
    "Preview" : "预览",
    "Copy link" : "复制链接",
    "Edit" : "编辑",
    "Delete" : "删除",
    "Appointment link was copied to clipboard" : "预约链接已复制到剪贴板",
    "Appointment link could not be copied to clipboard" : "无法将预约链接复制到剪贴板",
    "Add new" : "新增",
    "Untitled calendar" : "未命名的日历",
    "Edit name" : "编辑名称",
    "Saving name …" : "正在保存名称 …",
    "Edit color" : "编辑颜色",
    "Saving color …" : "正在保存颜色 …",
    "Copy private link" : "复制私有链接",
    "Export" : "导出",
    "Unshare from me" : "我取消的共享",
    "An error occurred, unable to change visibility of the calendar." : "发生错误，无法修改日历的可见性。",
    "An error occurred, unable to delete the calendar." : "发生错误，无法删除日历。",
    "Calendar link copied to clipboard." : "日历链接已复制到剪切板。",
    "Calendar link could not be copied to clipboard." : "日历链接无法复制到剪贴板。",
    "An error occurred, unable to rename the calendar." : "发生错误，无法重命名日历。",
    "An error occurred, unable to change the calendar's color." : "发生错误，无法修改日历颜色。",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["在{countdown}秒内取消共享日历"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["在{countdown}秒内删除日历"],
    "Share link" : "共享链接",
    "Publish calendar" : "发布日历",
    "Publishing calendar" : "正在发布日历",
    "Copy public link" : "复制公开链接",
    "Send link to calendar via email" : "通过电子邮件发送链接到日历",
    "Enter one address" : "输入一个地址",
    "Sending email …" : "正在发送电子邮件 …",
    "Copy subscription link" : "复制订阅链接",
    "Copying link …" : "正在复制链接 …",
    "Copied link" : "已复制链接",
    "Could not copy link" : "无法复制链接",
    "Copy embedding code" : "复制嵌入代码",
    "Copying code …" : "正在复制代码 …",
    "Copied code" : "已复制代码",
    "Could not copy code" : "无法复制代码",
    "Delete share link" : "删除共享链接",
    "Deleting share link …" : "正在删除共享链接 …",
    "An error occurred, unable to publish calendar." : "发生了错误，无法发布日历。",
    "An error occurred, unable to send email." : "发生错误，无法发送电子邮件。",
    "Embed code copied to clipboard." : "嵌入代码已复制到剪贴板。",
    "Embed code could not be copied to clipboard." : "嵌入代码无法复制到剪贴板。",
    "Unpublishing calendar failed" : "取消发布日历失败",
    "Share with users or groups" : "与用户或分组共享",
    "No users or groups" : "无用户或分组",
    "can edit" : "可编辑",
    "Unshare with {displayName}" : "取消与{displayName}的共享",
    "An error occurred, unable to change the unshare the calendar." : "发生了错误，无法取消日历共享。",
    "An error occurred, unable to change the permission of the share." : "发生了错误，无法更改共享权限。",
    "New calendar" : "新建日历",
    "Creating calendar …" : "正在创建日历 …",
    "New calendar with task list" : "带任务列表的新日历",
    "New subscription from link (read-only)" : "来自链接的新订阅（只读）",
    "Creating subscription …" : "正在创建订阅 …",
    "An error occurred, unable to create the calendar." : "发生了错误，无法创建日历。",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "请输入合法的链接（以http://、https://、webcal://、或者webcals://开头）",
    "Trash bin" : "垃圾箱",
    "Name" : "名称",
    "Deleted" : "已删除",
    "Restore" : "还原",
    "Delete permanently" : "永久删除",
    "Empty trash bin" : "清空回收站",
    "Untitled item" : "未命名项",
    "Unknown calendar" : "未知日历",
    "Could not load deleted calendars and objects" : "无法加载已删除的日历和物体",
    "Could not restore calendar or event" : "无法还原日历或事件",
    "Do you really want to empty the trash bin?" : "你真想清空回收站吗？",
    "Could not update calendar order." : "无法更新日历顺序",
    "Import calendars" : "导入日历",
    "Please select a calendar to import into …" : "请选择一个要导入的日历 …",
    "Filename" : "文件名",
    "Calendar to import into" : "要导入的日历",
    "Cancel" : "取消",
    "_Import calendar_::_Import calendars_" : ["导入日历"],
    "{filename} could not be parsed" : "{filename} 无法进行解析",
    "No valid files found, aborting import" : "未找到有效文件，中止导入",
    "Import partially failed. Imported {accepted} out of {total}." : "导入部分失败。已导入{total}个中的{accepted}个。",
    "Automatic" : "自动",
    "Automatic ({detected})" : "自动（{detected}）",
    "New setting was not saved successfully." : "新的设置没有成功保存。",
    "Shortcut overview" : "快捷方式总览",
    "or" : "或",
    "Navigation" : "导航",
    "Previous period" : "上一时段",
    "Next period" : "下一时段",
    "Views" : "视图",
    "Day view" : "日视图",
    "Week view" : "周视图",
    "Month view" : "月视图",
    "List view" : "列表视图",
    "Actions" : "操作",
    "Create event" : "创建事件",
    "Show shortcuts" : "显示快捷方式",
    "Enable birthday calendar" : "启用生日日历",
    "Show tasks in calendar" : "在日历中显示任务",
    "Enable simplified editor" : "启用简化的编辑器",
    "Limit visible events per view" : "限制每个视图的可见事件",
    "Show weekends" : "显示周末",
    "Show week numbers" : "显示星期数",
    "Time increments" : "时间增量",
    "Default reminder" : "默认提醒",
    "Copy primary CalDAV address" : "复制主要的CalDAV地址",
    "Copy iOS/macOS CalDAV address" : "复制iOS/macOS CalDAV地址",
    "Personal availability settings" : "个人可用性设置",
    "Show keyboard shortcuts" : "显示键盘快捷方式",
    "No reminder" : "无提醒",
    "CalDAV link copied to clipboard." : "CalDAV链接已复制到剪贴板。",
    "CalDAV link could not be copied to clipboard." : "CalDAV链接无法复制到剪贴板。",
    "Appointment was created successfully" : "成功创建预约",
    "Appointment was updated successfully" : "成功更新预约",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} 分钟"],
    "0 minutes" : "0 分钟",
    "To configure appointments, add your email address in personal settings." : "要配置预约，请在个人设置中添加您的电子邮件地址。",
    "Public – shown on the profile page" : "公开 - 显示在个人资料页上",
    "Private – only accessible via secret link" : "私密 - 只能通过秘密链接访问",
    "Location" : "地点",
    "Description" : "描述",
    "Visibility" : "可见性",
    "Duration" : "持续时间",
    "Increments" : "增量",
    "Additional calendars to check for conflicts" : "其他要检查冲突的日历",
    "Pick time ranges where appointments are allowed" : "选择允许预约的时间范围",
    "to" : "到",
    "Delete slot" : "删除档期",
    "No times set" : "未设置时间",
    "Add" : "添加",
    "Monday" : "星期一",
    "Tuesday" : "周二",
    "Wednesday" : "周三",
    "Thursday" : "周四",
    "Friday" : "周五",
    "Saturday" : "周六",
    "Sunday" : "周日",
    "Add time before and after the event" : "添加事件前后时间",
    "Before the event" : "事件前",
    "After the event" : "事件后",
    "Planning restrictions" : "规划限制",
    "Minimum time before next available slot" : "最小化下一可用档期前的时间",
    "Max slots per day" : "每日最多档期数",
    "Create appointment" : "创建预约",
    "Edit appointment" : "编辑预约",
    "Save" : "保存",
    "Update" : "更新",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "我们给你发了一封详细的邮件。请使用邮件中的链接确认您的预约。您现在可以关闭此页面。",
    "Your name" : "名字",
    "Your email address" : "你的邮箱地址",
    "Please share anything that will help prepare for our meeting" : "请分享任何能帮助我们准备会议的东西",
    "Could not book the appointment. Please try again later or contact the organizer." : "无法登记预约。请稍后再试或联系组织者。",
    "Book the appointment" : "登记预约",
    "Reminder" : "提醒",
    "before at" : "在此之前：",
    "Notification" : "通知",
    "Email" : "电子邮件",
    "Audio notification" : "语音通知",
    "Other notification" : "其他通知",
    "Relative to event" : "相关事件",
    "On date" : "到期",
    "Edit time" : "编辑时间",
    "Save time" : "保存时间",
    "Remove reminder" : "移除提醒",
    "on" : "于",
    "at" : "在",
    "+ Add reminder" : "+ 添加提醒",
    "Add reminder" : "添加提醒",
    "_second_::_seconds_" : ["秒"],
    "_minute_::_minutes_" : ["分钟"],
    "_hour_::_hours_" : ["小时"],
    "_day_::_days_" : ["天"],
    "_week_::_weeks_" : ["周"],
    "Available" : "可用",
    "Not available" : "不可用",
    "Invitation sent" : "已发送邀请",
    "Availability of attendees, resources and rooms" : "与会者，资源和会议室的可用性",
    "{organizer} (organizer)" : "{organizer} (organizer) ",
    "Free" : "空闲",
    "Busy (tentative)" : "繁忙（暂定）",
    "Busy" : "忙碌",
    "Out of office" : "不在办公室",
    "Unknown" : "未知",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "Tentative" : "暂定",
    "Create Talk room for this event" : "为此事件创建聊天室",
    "Show busy times" : "显示繁忙时间",
    "No attendees yet" : "暂无与会者",
    "Successfully appended link to talk room to description." : "成功将链接添加到聊天室的描述。",
    "Error creating Talk room" : "建立聊天室时发生错误",
    "Send email" : "发送电子邮件",
    "Chairperson" : "主席",
    "Required participant" : "必要的参与者",
    "Optional participant" : "可选的参与者",
    "Non-participant" : "非参与者",
    "Remove attendee" : "移除与会者",
    "Search for emails, users or contacts" : "搜索电子邮件、用户或联系人",
    "No match found" : "未找到匹配项",
    "(organizer)" : "（组织者）",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "为发送邀请和处理回应，[linkopen] 将您的电子邮件地址添加到个人设置中 [linkclose] 。",
    "Remove color" : "移除颜色",
    "Event title" : "事件标题",
    "All day" : "全天",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "无法修改属于递归集的事件的全天设置。 ",
    "from {startDate}" : "始于{startDate}",
    "from {startDate} at {startTime}" : "始于{startDate}的{startTime}",
    "to {endDate}" : "到{endDate}",
    "to {endDate} at {endTime}" : "到{endDate}的{endTime}",
    "Repeat" : "重复",
    "End repeat" : "结束重复",
    "Select to end repeat" : "选择以中止重复",
    "never" : "从不",
    "on date" : "到期",
    "after" : "之后",
    "_time_::_times_" : ["次数"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "此事件是递归集的递归异常。不能给它添加递归规则。 ",
    "first" : "一日",
    "third" : "三日",
    "fourth" : "四日",
    "fifth" : "五日",
    "second to last" : "倒数第二",
    "last" : "最后的",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "对循环规则的更改将只应用于本次和所有未来事件。",
    "Repeat every" : "重复每",
    "By day of the month" : "以每月的天数",
    "On the" : "在",
    "_month_::_months_" : ["月"],
    "_year_::_years_" : ["年"],
    "weekday" : "工作日",
    "weekend day" : "周末",
    "No recurrence" : "无重复",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "此事件的循环定义不能被Nextcloud完全支持。如果您编辑循环选项，某些循环可能会丢失。",
    "Suggestions" : "建议",
    "No rooms or resources yet" : "尚无房间或资源",
    "Add resource" : "添加资源",
    "Has a projector" : "有计划者",
    "Has a whiteboard" : "有白板",
    "Wheelchair accessible" : "残疾人专用",
    "Remove resource" : "删除资源",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} 座位"],
    "Projector" : "投影仪",
    "Whiteboard" : "白板",
    "Search for resources or rooms" : "搜索资源或房间",
    "available" : "可用",
    "unavailable" : "不可用",
    "Room type" : "房间类型",
    "Any" : "任意",
    "Minimum seating capacity" : "最低的座位容量",
    "More" : "更多",
    "Update this occurrence" : "更新此重复事件",
    "Update this and all future" : "更新此项及以后的项目",
    "Public calendar does not exist" : "公开日历不存在",
    "Maybe the share was deleted or has expired?" : "也许共享已删除或过期？",
    "Please select a time zone:" : "请选择一个时区：",
    "Pick a time" : "选择一个时间",
    "Pick a date" : "选择一个日期",
    "from {formattedDate}" : "从 {formattedDate}",
    "to {formattedDate}" : "到 {formattedDate}",
    "on {formattedDate}" : "在 {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "从 {formattedDate} 的 {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "到 {formattedDate} 的 {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "在 {formattedDate} 的 {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} 的 {formattedTime}",
    "Please enter a valid date" : "请输入一个有效的日期",
    "Please enter a valid date and time" : "请输入有效的日期和时间",
    "Type to search time zone" : "输入以搜索时区 ",
    "Global" : "全球",
    "Select date" : "选择日期",
    "Select slot" : "选择档期",
    "No slots available" : "无档期可用",
    "The slot for your appointment has been confirmed" : "已确认了你的预约档期",
    "Appointment Details:" : "预约详情：",
    "Time:" : "时间：",
    "Booked for:" : "已登记：",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "谢谢，已确认了你从 {startDate} 到 {endDate} 的预约",
    "Book another appointment:" : "登记另一个预约：",
    "See all available slots" : "查看所有可用档期",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "从 {startDate} 到 {endDate} 的预约档期已满",
    "Please book a different slot:" : "请登记不同档期：",
    "Book an appointment with {name}" : "登记和 {name} 的约见",
    "No public appointments found for {name}" : "未找到 {name} 的公开预约",
    "Personal" : "个人",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自动时区检测确定您的时区为世界标准时间（UTC）。\n可能性最大的原因是 web 浏览器的安全措施的结果。\n请在日历设置中手动设置时区。",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "找不到您配置的时区 ({timezoneId})。将退回到世界标准时间（UTC）。\n请在设置中更改您的时区并报告此问题。",
    "No more events today" : "今天没有更多事件",
    "No upcoming events" : "没有即将到来的事件",
    "Create a new event" : "创建一个新的事件",
    "[Today]" : "[今天]",
    "[Tomorrow]" : "[明天]",
    "[Yesterday]" : "[昨天]",
    "[Last] dddd" : "[上一个] 工作日",
    "Event does not exist" : "事件不存在",
    "Delete this occurrence" : "删除此重复事件",
    "Delete this and all future" : "删除此项及以后的项目",
    "Details" : "详情",
    "Attendees" : "与会者",
    "Resources" : "资源",
    "Close" : "关闭",
    "Show more details" : "显示更多详情",
    "Subscribe to {name}" : "订阅{name}",
    "Anniversary" : "周年",
    "Appointment" : "预约",
    "Business" : "公司",
    "Education" : "教育",
    "Holiday" : "假日",
    "Meeting" : "会议",
    "Miscellaneous" : "杂项",
    "Non-working hours" : "非工作时间",
    "Not in office" : "不在办公室",
    "Phone call" : "电话通话",
    "Sick day" : "病假",
    "Special occasion" : "特殊场合",
    "Travel" : "旅行",
    "Vacation" : "假期",
    "Midnight on the day the event starts" : "事件开始时当天午夜",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["事件前%n天的 {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["事件发生前%n周的 {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "事件当天的 {formattedHourMinute}",
    "at the event's start" : "事件开始时",
    "at the event's end" : "事件结束时",
    "{time} before the event starts" : "事件开始前 {time}",
    "{time} before the event ends" : "事件结束前 {time}",
    "{time} after the event starts" : "在事件开始后 {time}",
    "{time} after the event ends" : "事件结束后 {time}",
    "on {time}" : "在 {time}",
    "on {time} ({timezoneId})" : "在 {time} （{timezoneId}）",
    "Week {number} of {year}" : "{year}年的第{number}周",
    "Does not repeat" : "不重复",
    "Daily" : "每天",
    "Weekly" : "每周",
    "Monthly" : "每月",
    "Yearly" : "每年",
    "_Every %n day_::_Every %n days_" : ["每 %n 天"],
    "_Every %n week_::_Every %n weeks_" : ["每 %n 周"],
    "_Every %n month_::_Every %n months_" : ["每 %n 个月"],
    "_Every %n year_::_Every %n years_" : ["每 %n 年"],
    "_on {weekday}_::_on {weekdays}_" : ["在 {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["在每月的第 {dayOfMonthList} 天"],
    "on the {ordinalNumber} {byDaySet}" : "在{ordinalNumber} {byDaySet}",
    "in {monthNames}" : "在{monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "在{monthNames}的这些天 {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "直到 {untilDate}",
    "_%n time_::_%n times_" : ["%n次"],
    "Untitled event" : "未命名事件",
    "Untitled task" : "无标题任务",
    "Please ask your administrator to enable the Tasks App." : "请让您的管理员启用这个应用。",
    "Prev" : "上一页",
    "Next" : "下一页",
    "Prev year" : "上一年",
    "Next year" : "下一年",
    "Year" : "年份",
    "W" : "周",
    "%n more" : "%n更多",
    "No events to display" : "没有事件可显示",
    "_+%n more_::_+%n more_" : ["再 +%n 项"],
    "No events" : "无事件",
    "Create a new event or change the visible time-range" : "创建一个新事件或更改可见的时间范围",
    "It might have been deleted, or there was a typo in a link" : "它可能已被删除，或者链接有误",
    "It might have been deleted, or there was a typo in the link" : "它可能已被删除，或者链接有误",
    "Meeting room" : "会议室",
    "Lecture hall" : "演讲厅",
    "Seminar room" : "研讨室",
    "Other" : "其他",
    "When shared show" : "共享时显示",
    "When shared show full event" : "共享时显示完整事件",
    "When shared show only busy" : "共享时仅显示忙碌",
    "When shared hide this event" : "共享时隐藏此事项",
    "The visibility of this event in shared calendars." : "在共享日历中此事项的可见性。",
    "Add a location" : "添加地点",
    "Add a description" : "添加描述",
    "Status" : "状态",
    "Confirmed" : "已确认",
    "Canceled" : "已取消",
    "Confirmation about the overall status of the event." : "对事项总体状态的确认。",
    "Show as" : "显示为",
    "Take this event into account when calculating free-busy information." : "在计算闲忙信息时将此事项考虑在内。",
    "Categories" : "分类",
    "Categories help you to structure and organize your events." : "分类帮助您归类和组织您的事项。",
    "Search or add categories" : "搜索或添加分类",
    "Add this as a new category" : "添加此项作为新的分类",
    "Custom color" : "自定义颜色",
    "Special color of this event. Overrides the calendar-color." : "此事件的特殊颜色。 覆盖日历颜色。",
    "Chat room for event" : "事件聊天室",
    "Imported {filename}" : "已导入 {filename}",
    "Meditation" : "冥想",
    "Relaxing" : "正在放松",
    "Relax" : "放松",
    "Break" : "休息",
    "Commute" : "通勤",
    "Commuting" : "通勤",
    "Shuttle" : "摆渡车",
    "Invoice" : "发票",
    "Finance" : "财务",
    "Bank" : "银行",
    "Money" : "金钱",
    "Wedding" : "婚礼",
    "Dog" : "狗",
    "Concert" : "音乐会",
    "Festival" : "节日",
    "Theater" : "剧院",
    "Theatre" : "剧场",
    "Presentation" : "报告",
    "Talk" : "交谈",
    "Speech" : "演说",
    "Deadline" : "截止期",
    "Submission" : "提交",
    "Reporting" : "报告",
    "Camping" : "正在露营",
    "Camp" : "露营",
    "Election" : "选举",
    "Voting" : "投票",
    "Vote" : "投票",
    "Barbecue" : "烧烤",
    "Barbeque" : "烧烤",
    "Garden" : "园艺",
    "Farm" : "农场",
    "Movie" : "影片",
    "Cinema" : "电影",
    "Graduation" : "毕业",
    "Brainstorm" : "头脑风暴",
    "Review" : "预览",
    "Audit" : "审计",
    "Inspection" : "检查",
    "Proofreading" : "校对",
    "Baseball" : "棒球",
    "Meet" : "见面",
    "Planning" : "规划",
    "Pointing" : "指点",
    "Retrospective" : "怀旧",
    "Office" : "办公",
    "Contributor week" : "贡献者周",
    "Mail" : "邮件",
    "Soccer" : "足球",
    "Football" : "橄榄球",
    "Gaming" : "游戏",
    "Drive" : "驾驶",
    "Driving" : "驾驶",
    "Bicycle" : "自行车",
    "Cycle" : "自行车",
    "Cycling" : "骑车",
    "Biking" : "骑自行车",
    "Bike" : "自行车",
    "Podcast" : "播客",
    "Basketball" : "篮球",
    "Fishing" : "钓鱼",
    "Hiking" : "徒步中",
    "Hike" : "徒步",
    "Art" : "艺术",
    "Exhibition" : "展览",
    "Museum" : "博物馆",
    "Pilates" : "普拉提",
    "Park" : "公园",
    "Walk" : "走路",
    "Studying" : "学习中",
    "Doctor" : "医生",
    "Health" : "健康",
    "Dentist" : "牙医",
    "Hospital" : "医院",
    "Interview" : "面试",
    "Training" : "训练",
    "Practice" : "实践",
    "Sports" : "体育",
    "Exercise" : "练习",
    "Work out" : "锻炼",
    "Working out" : "锻炼中",
    "Gym" : "健身房",
    "Barber" : "理发师",
    "Haircut" : "剪发",
    "Hairdresser" : "美发师",
    "Exam" : "考试",
    "Written test" : "笔试",
    "Oral test" : "口试",
    "Working" : "工作中",
    "New Years Eve" : "除夕",
    "NYE" : "除夕",
    "Fireworks" : "烟花",
    "Running" : "跑步",
    "Go for a run" : "去跑步",
    "Marathon" : "马拉松",
    "Video-conference" : "视频会议",
    "Conference-call" : "电话会议",
    "Video-call" : "视频通话",
    "Video-chat" : "视频聊天",
    "Video-meeting" : "视频会议",
    "Call" : "打电话",
    "Calling" : "呼叫中",
    "Christmas" : "圣诞节",
    "Conference" : "会议",
    "Pizza" : "披萨",
    "Travelling" : "旅行中",
    "Trip" : "旅行",
    "Journey" : "旅行",
    "Collaborate" : "协作",
    "Pair" : "配对",
    "Lecture" : "讲座",
    "Seminar" : "研讨会",
    "Teaching" : "教学",
    "Photograph" : "照片",
    "Party" : "派对",
    "Celebration" : "庆祝活动",
    "Celebrate" : "庆祝",
    "Birthday" : "生日",
    "Shopping" : "购物",
    "Groceries" : "杂货",
    "Skate" : "溜冰",
    "Skateboard" : "滑板",
    "Wine tasting" : "品酒",
    "Golf" : "高尔夫",
    "Dinner" : "晚餐",
    "Lunch" : "午餐",
    "Appointment not found" : "未找到预约",
    "User not found" : "未找到用户"
},
"nplurals=1; plural=0;");
