OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "La session utilisateur a expiré",
    "Provided email-address is not valid" : "L'adresse e-mail fournie n'est pas valide",
    "%s has published the calendar »%s«" : "%s a publié l'agenda «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Erreur inattendue pendant l'envoi de l'e-mail. Veuillez contacter votre administrateur.",
    "Successfully sent email to %1$s" : "Envoi d'e-mail vers %1$s réussi",
    "Hello," : "Bonjour,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Nous voulions vous informer que %s a publié l'agenda « %s ».",
    "Open »%s«" : "Ouvrir «%s»",
    "Cheers!" : "À bientôt !",
    "Upcoming events" : "Événements à venir",
    "Appointments" : "Rendez-vous",
    "Schedule appointment \"%s\"" : "Planifier le rendez-vous \"%s\"",
    "Schedule an appointment" : "Planifier un rendez-vous",
    "Prepare for %s" : "Préparez-vous pour %s",
    "Follow up for %s" : "Suivi pour %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Votre rendez-vous \"%s\" Avec %s nécessite une confirmation",
    "Dear %s, please confirm your booking" : "Cher %s, merci de confirmer votre réservation",
    "Confirm" : "Confirmer",
    "This confirmation link expires in %s hours." : "Ce lien de confirmation expire dans %s heures.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Si vous souhaitez finalement annuler le rendez-vous, merci de contacter l'organisateur en répondant à ce courriel ou en visitant sa page profil.",
    "Your appointment \"%s\" with %s has been accepted" : "Votre rendez-vous \"%s\" avec %s a été accepté",
    "Dear %s, your booking has been accepted." : "Cher %s, votre réservation a été acceptée.",
    "Appointment for:" : "Rendez-vous pour :",
    "Date:" : "Date :",
    "Where:" : "Lieu :",
    "Your Comment:" : "Votre commentaire :",
    "Calendar" : "Agenda",
    "A Calendar app for Nextcloud" : "Application Calendrier pour Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "L'application Agenda est une interface utilisateur pour le serveur CalDAV de Nextcloud. Synchronisez facilement les événements de divers appareils avec votre Nextcloud et modifiez-les en ligne. \n\n* 🚀 ** Intégration avec d'autres applications Nextcloud ! ** Actuellement Contacts - plus à venir. \n* 🌐 ** Assistance WebCal! ** Vous voulez voir les jours de match de votre équipe préférée dans votre calendrier ? Aucun problème ! \n* 🙋 ** Participants ! ** Invitez des personnes à vos événements \n* ⌚️ ** Libre / Occupé : ** Voir quand vos participants sont disponibles pour se rencontrer \n* ⏰ ** Rappels ! ** Obtenez des alarmes pour les événements dans votre navigateur et par e-mail. \n* 🔍 Recherche ! Trouvez facilement vos événements\n* ☑️ Tâches ! Retrouvez les tâches avec une échéance directement dans l'agenda\n* 🙈 ** Nous ne réinventons pas la roue ! ** Basé sur la grande [bibliothèque c-dav] (https://github.com/nextcloud/cdav-library), [ical.js] (https://github.com/mozilla-comm/ical.js) et [fullcalendar] (https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Jour précédent",
    "Previous week" : "Semaine précédente",
    "Previous month" : "Mois précédent",
    "Next day" : "Jour suivant",
    "Next week" : "Semaine prochaine",
    "Next month" : "Mois prochain",
    "New event" : "Nouvel événement",
    "Today" : "Auj.",
    "Day" : "Jour",
    "Week" : "Semaine",
    "Month" : "Mois",
    "List" : "Liste",
    "Preview" : "Prévisualiser",
    "Copy link" : "Copier le lien",
    "Edit" : "Modifier",
    "Delete" : "Supprimer",
    "Appointment link was copied to clipboard" : "Le lien vers l'événement a été copié dans le presse-papiers",
    "Appointment link could not be copied to clipboard" : "Le lien vers l'événement n'a pas pu être copié dans le presse-papiers",
    "Add new" : "Ajouter un nouveau",
    "Untitled calendar" : "Calendrier sans titre",
    "Edit name" : "Modifier le nom",
    "Saving name …" : "Enregistrement du nom en cours …",
    "Edit color" : "Modifier la couleur",
    "Saving color …" : "Enregistrement de la couleur …",
    "Copy private link" : "Copier le lien privé",
    "Export" : "Exporter",
    "Unshare from me" : "Quitter ce partage",
    "Disable calendar \"{calendar}\"" : "Désactiver l'agenda \"{calendar}\"",
    "Disable untitled calendar" : "Désactiver agenda sans titre",
    "Enable calendar \"{calendar}\"" : "Activer l'agenda \"{calendar}\"",
    "Enable untitled calendar" : "Activer agenda sans titre",
    "An error occurred, unable to change visibility of the calendar." : "Une erreur est survenue, impossible de modifier la visibilité de l'agenda.",
    "An error occurred, unable to delete the calendar." : "Une erreur est survenue, impossible de supprimer l'agenda.",
    "Calendar link copied to clipboard." : "Lien de l'agenda copié dans le presse-papier.",
    "Calendar link could not be copied to clipboard." : "Impossible de copier le lien de l'agenda dans le presse-papier.",
    "An error occurred, unable to rename the calendar." : "Une erreur est survenue, impossible de renommer l'agenda.",
    "An error occurred, unable to change the calendar's color." : "Une erreur est survenue, impossible de modifier la couleur de l'agenda.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Suppression du partage de l'agenda dans {countdown} seconde","Suppression du partage de l'agenda dans {countdown} secondes","Suppression du partage de l'agenda dans {countdown} secondes"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Suppression de l'agenda dans {countdown} seconde","Suppression de l'agenda dans {countdown} secondes","Suppression de l'agenda dans {countdown} secondes"],
    "Share link" : "Lien de partage",
    "Publish calendar" : "Publier l'agenda",
    "Publishing calendar" : "Publication de l'agenda en cours",
    "Copy public link" : "Copier le lien public",
    "Send link to calendar via email" : "Envoyer le lien vers l'agenda par e-mail",
    "Enter one address" : "Saisissez une adresse",
    "Sending email …" : "Envoi de l'e-mail...",
    "Copy subscription link" : "Copier le lien d'inscription",
    "Copying link …" : "Copie du lien …",
    "Copied link" : "Lien copié",
    "Could not copy link" : "Impossible de copier le lien",
    "Copy embedding code" : "Copier le code d'intégration",
    "Copying code …" : "Copie du code …",
    "Copied code" : "Code copié",
    "Could not copy code" : "Impossible de copier le code",
    "Delete share link" : "Supprimer le lien de partage",
    "Deleting share link …" : "Suppression du lien partagé …",
    "An error occurred, unable to publish calendar." : "Une erreur est survenue, impossible de publier l'agenda.",
    "An error occurred, unable to send email." : "Une erreur s'est produite, impossible d'envoyer l'e-mail.",
    "Embed code copied to clipboard." : "Code d'intégration copié dans le presse-papier.",
    "Embed code could not be copied to clipboard." : "Le code d'intégration n'a pas pu être copié dans le presse-papier.",
    "Unpublishing calendar failed" : "Impossible de dé-publier l'agenda",
    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
    "No users or groups" : "Aucun utilisateur ni groupe",
    "can edit" : "peut modifier",
    "Unshare with {displayName}" : "Ne plus partager avec {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Une erreur s’est produite, impossible de changer le partage du calendrier.",
    "An error occurred, unable to change the permission of the share." : "Une erreur s’est produite, impossible de changer la permission du partage.",
    "New calendar" : "Nouvel agenda",
    "Name for new calendar" : "Nom du nouvel agenda",
    "Creating calendar …" : "Création de l'agenda …",
    "New calendar with task list" : "Nouvel agenda avec liste de tâches",
    "New subscription from link (read-only)" : "Nouvel abonnement par lien (lecture seule)",
    "Creating subscription …" : "Création de l'abonnement en cours ...",
    "An error occurred, unable to create the calendar." : "Une erreur est survenue, impossible de créer l'agenda.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Veuillez saisir un lien valide (débutant par http://, https://, webcal:// ou webcals://)",
    "Trash bin" : "Corbeille",
    "Loading deleted items." : "Chargement des éléments supprimés.",
    "You do not have any deleted items." : "Vous n'avez aucun élément supprimé.",
    "Name" : "Nom",
    "Deleted" : "Supprimé",
    "Restore" : "Restaurer",
    "Delete permanently" : "Supprimer définitivement",
    "Empty trash bin" : "Vider la corbeille",
    "Untitled item" : "Élément sans titre",
    "Unknown calendar" : "Agenda inconnu",
    "Could not load deleted calendars and objects" : "Impossible de charger les calendriers et objets supprimés",
    "Could not restore calendar or event" : "Impossible de restaurer le calendrier ou l'événement",
    "Do you really want to empty the trash bin?" : "Voulez-vous vraiment vider la corbeille ?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Les éléments dans la corbeille sont supprimés après {numDays} jour","Les éléments dans la corbeille sont supprimés après {numDays} jours","Les éléments dans la corbeille sont supprimés après {numDays} jours"],
    "Could not update calendar order." : "Impossible de mettre à jour l'ordre du calendrier.",
    "Import calendars" : "Importer des calendriers",
    "Please select a calendar to import into …" : "Veuillez sélectionner un agenda dans lequel importer  …",
    "Filename" : "Nom du fichier",
    "Calendar to import into" : "Agenda dans lequel importer",
    "Cancel" : "Annuler",
    "_Import calendar_::_Import calendars_" : ["Importer un agenda","Importer des agendas","Importer des agendas"],
    "{filename} could not be parsed" : "{filename} n'a pas pu être analysé",
    "No valid files found, aborting import" : "Aucun fichier valide trouvé, annulation de l’importation",
    "Import partially failed. Imported {accepted} out of {total}." : "Échec partiel de l’importation. Import de {accepted} sur {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : [" %n évènement importé avec succès","%n évènements importés avec succès","%n évènements importés avec succès"],
    "Automatic" : "Automatique",
    "Automatic ({detected})" : "Automatique ({detected})",
    "New setting was not saved successfully." : "Le nouveau paramètre n'a pas pu être enregistré.",
    "Shortcut overview" : "Aperçu des raccourcis",
    "or" : "ou",
    "Navigation" : "Navigation",
    "Previous period" : "Période précédente",
    "Next period" : "Période suivante",
    "Views" : "Affichages",
    "Day view" : "Affichage journalier",
    "Week view" : "Affichage semaine",
    "Month view" : "Affichage mensuel",
    "List view" : "Affichage liste",
    "Actions" : "Actions",
    "Create event" : "Créer un événement",
    "Show shortcuts" : "Afficher les raccourcis",
    "Editor" : "Éditeur",
    "Close editor" : "Fermer l'éditeur",
    "Save edited event" : "Sauvegarder l'événement édité",
    "Delete edited event" : "Supprimer l'événement édité",
    "Duplicate event" : "Événement en double",
    "Enable birthday calendar" : "Activer l'agenda des anniversaires",
    "Show tasks in calendar" : "Afficher les tâches dans l'agenda",
    "Enable simplified editor" : "Activer l'éditeur simplifié",
    "Limit visible events per view" : "Limiter le nombre d’évènements affichés",
    "Show weekends" : "Afficher les week-ends",
    "Show week numbers" : "Afficher les numéros de semaine",
    "Time increments" : "Incréments de temps",
    "Default reminder" : "Rappel par défaut",
    "Copy primary CalDAV address" : "Copier l'adresse CalDAV principale",
    "Copy iOS/macOS CalDAV address" : "Copier l'adresse CalDAV pour iOS/macOS",
    "Personal availability settings" : "Paramètres de disponibilité personnelle",
    "Show keyboard shortcuts" : "Afficher les raccourcis clavier",
    "Calendar settings" : "Paramètres de l'agenda",
    "No reminder" : "Aucun rappel",
    "CalDAV link copied to clipboard." : "Lien CalDAV copié dans le presse-papier.",
    "CalDAV link could not be copied to clipboard." : "Impossible de copier le lien CalDAV dans le presse-papier.",
    "Appointment was created successfully" : "Le rendez-vous a été créé avec succès",
    "Appointment was updated successfully" : "Le rendez-vous a été modifié avec succès",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes","{duration} minutes"],
    "0 minutes" : "0 minutes",
    "_{duration} hour_::_{duration} hours_" : ["{duration} heure","{duration} heures","{duration} heures"],
    "_{duration} day_::_{duration} days_" : ["{duration} jour","{duration} jours","{duration} jours"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semaine","{duration} semaines","{duration} semaines"],
    "_{duration} month_::_{duration} months_" : ["{duration} mois","{duration} mois","{duration} mois"],
    "_{duration} year_::_{duration} years_" : ["{duration} année","{duration} années","{duration} années"],
    "To configure appointments, add your email address in personal settings." : "Pour configurer les rendez-vous, ajouter votre adresse e-mail dans les paramètres personnels.",
    "Public – shown on the profile page" : "Public - affiché sur la page du profil",
    "Private – only accessible via secret link" : "Privé - uniquement accessible via un lien secret",
    "Location" : "Lieu",
    "Description" : "Description",
    "Visibility" : "Visibilité",
    "Duration" : "Durée",
    "Increments" : "Incréments",
    "Additional calendars to check for conflicts" : "Agendas supplémentaires à vérifier pour les conflits",
    "Pick time ranges where appointments are allowed" : "Sélectionnez les plages de temps pendant lesquelles les rendez-vous sont autorisés",
    "to" : "à",
    "Delete slot" : "Supprimer le créneau",
    "No times set" : "Aucun horaire défini",
    "Add" : "Ajouter",
    "Monday" : "Lundi",
    "Tuesday" : "Mardi",
    "Wednesday" : "Mercredi",
    "Thursday" : "Jeudi",
    "Friday" : "Vendredi",
    "Saturday" : "Samedi",
    "Sunday" : "Dimanche",
    "Add time before and after the event" : "Ajouter du temps avant et après l'évènement",
    "Before the event" : "Avant l'évènement",
    "After the event" : "Après l'évènement",
    "Planning restrictions" : "Restrictions de planning",
    "Minimum time before next available slot" : "Durée minimale avant la prochaine plage disponible",
    "Max slots per day" : "Nombre maximum de créneaux par jour",
    "Limit how far in the future appointments can be booked" : "Limiter le délai dans lequel les rendez-vous futurs peuvent être pris.",
    "Create appointment" : "Créer un rendez-vous",
    "Edit appointment" : "Modifier le rendez-vous",
    "Save" : "Enregistrer",
    "Update" : "Mettre à jour",
    "Please confirm your reservation" : "Veuillez confirmer votre réservation",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Nous vous avons envoyé un e-mail avec les détails. Veuillez confirmer votre rendez-vous en utilisant le lien dans l'e-mail. Vous pouvez maintenant fermer cette page.",
    "Your name" : "Votre nom",
    "Your email address" : "Votre e-mail",
    "Please share anything that will help prepare for our meeting" : "Merci de partager tout ce qui peut être utile à la préparation de notre réunion",
    "Could not book the appointment. Please try again later or contact the organizer." : "Impossible de réserver le rendez-vous. Veuillez réessayer plus tard ou contacter l'organisateur.",
    "Book the appointment" : "Réserver le créneau",
    "Reminder" : "Rappel",
    "before at" : "avant",
    "Notification" : "Notification",
    "Email" : "E-mail",
    "Audio notification" : "Notification sonore",
    "Other notification" : "Autre notification",
    "Relative to event" : "Par rapport à l’événement",
    "On date" : "À une date précise",
    "Edit time" : "Modifier le rappel",
    "Save time" : "Enregistrer le rappel",
    "Remove reminder" : "Supprimer le rappel",
    "on" : "le",
    "at" : "le",
    "+ Add reminder" : "+ Ajouter un rappel",
    "Add reminder" : "Ajouter un rappel",
    "_second_::_seconds_" : ["seconde","secondes","secondes"],
    "_minute_::_minutes_" : ["minute","minutes","minutes"],
    "_hour_::_hours_" : ["heure","heures","heures"],
    "_day_::_days_" : ["jour","jours","jours"],
    "_week_::_weeks_" : ["semaine","semaines","semaines"],
    "Invitation accepted" : "Invitation acceptée",
    "Available" : "Disponible",
    "Suggested" : "Suggéré",
    "Participation marked as tentative" : "Participation marquée comme provisoire",
    "Accepted {organizerName}'s invitation" : "Invitation de {organizerName} acceptée",
    "Not available" : "Non disponible",
    "Invitation declined" : "Invitation déclinée",
    "Declined {organizerName}'s invitation" : "Invitation de {organizerName} déclinée",
    "Invitation is delegated" : "L'invitation est déléguée",
    "Checking availability" : "Vérification de la disponiblité",
    "Invitation sent" : "Invitation envoyée",
    "Has not responded to {organizerName}'s invitation yet" : "N'a pas encore répondu à l'invitation de {organizerName}",
    "Availability of attendees, resources and rooms" : "Disponibilité des participants, ressources et salles.",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "Free" : "Libre",
    "Busy (tentative)" : "Occupé (provisoire)",
    "Busy" : "Occupé",
    "Out of office" : "Absent du bureau",
    "Unknown" : "Inconnu",
    "Accept" : "Accepter",
    "Decline" : "Décliner",
    "Tentative" : "Provisoire",
    "The invitation has been accepted successfully." : "L'invitation a été acceptée.",
    "Failed to accept the invitation." : "Échec lors de l'acceptation de l'invitation.",
    "The invitation has been declined successfully." : "L'invitation a été déclinée.",
    "Failed to decline the invitation." : "Impossible de décliner l'invitation.",
    "Your participation has been marked as tentative." : "Votre participation a été marquée comme provisoire",
    "Failed to set the participation status to tentative." : "Erreur en voulant mettre votre participation comme provisoire.",
    "Create Talk room for this event" : "Créer une salle de discussion pour cet événement",
    "Show busy times" : "Afficher les périodes occupées",
    "No attendees yet" : "Aucun participant pour l'instant",
    "Successfully appended link to talk room to description." : "Le lien vers la discussion a été ajouté à la description",
    "Error creating Talk room" : "Erreur lors de la création de la salle de discussion",
    "Send email" : "Envoyer un e-mail",
    "Chairperson" : "Président",
    "Required participant" : "Participant obligatoire",
    "Optional participant" : "Participant facultatif",
    "Non-participant" : "Ne participe pas",
    "Remove attendee" : "Supprimer le participant",
    "Search for emails, users or contacts" : "Rechercher des e-mails, utilisateurs ou contacts",
    "No match found" : "Aucun résultat trouvé",
    "(organizer)" : "(organisateur)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Pour envoyer des invitations et en gérer les réponses, [linkopen]ajoutez votre adresse e-mail dans vos paramètres personnels[linkclose].",
    "Remove color" : "Supprimer la couleur",
    "Event title" : "Titre de l'événement",
    "All day" : "Toute la journée",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Impossible de modifier le paramètre de la journée entière pour les événements qui font partie d'un ensemble de récurrences.",
    "from {startDate}" : "du {startDate}",
    "from {startDate} at {startTime}" : "du {startDate} à {startTime}",
    "to {endDate}" : "au {endDate}",
    "to {endDate} at {endTime}" : "au {endDate} à {endTime}",
    "Repeat" : "Répéter",
    "End repeat" : "Arrêter la répétition",
    "Select to end repeat" : "Sélectionner pour terminer la répétition",
    "never" : "jamais",
    "on date" : "à une date précise",
    "after" : "après ",
    "_time_::_times_" : ["fois","fois","fois"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Cet événement est une exception dans un ensemble de récurrences. Vous ne pouvez pas y ajouter une règle de récurrence.",
    "first" : "premier",
    "third" : "troisième",
    "fourth" : "quatrième",
    "fifth" : "cinquième",
    "second to last" : "avant-dernier",
    "last" : "dernier",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Les modifications apportées à la règle de récurrence ne s’appliqueront qu’à cet événement et à tous les événements futurs.",
    "Repeat every" : "Répéter chaque",
    "By day of the month" : "Par jour du mois",
    "On the" : "Le",
    "_month_::_months_" : ["mois","mois","mois"],
    "_year_::_years_" : ["année","années","années"],
    "weekday" : "jour de la semaine",
    "weekend day" : "jour de weekend",
    "No recurrence" : "Pas de récurrence ",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La définition de la récurrence de cet événement n’est pas entièrement prise en charge par Nextcloud. Si vous modifiez les options de récurrence, certaines récurrences peuvent être perdues.",
    "Suggestions" : "Suggestions",
    "No rooms or resources yet" : "Aucun lieu ou ressource pour le moment",
    "Add resource" : "Ajouter une ressource",
    "Has a projector" : "Dispose d'un projecteur",
    "Has a whiteboard" : "Dispose d'un tableau blanc",
    "Wheelchair accessible" : "Accessible en fauteuil roulant",
    "Remove resource" : "Supprimer la ressource",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} place assise","{seatingCapacity} places assises","{seatingCapacity} places assises"],
    "Projector" : "Projecteur",
    "Whiteboard" : "Tableau blanc",
    "Search for resources or rooms" : "Rechercher une ressource ou un lieu",
    "available" : "disponible",
    "unavailable" : "indisponible",
    "Room type" : "Type de salle",
    "Any" : "Toutes",
    "Minimum seating capacity" : "Nombre minimum de places assises",
    "More" : "Plus",
    "Update this occurrence" : "Mettre à jour cette occurrence",
    "Update this and all future" : "Mettre à jour cette occurrence et toutes les prochaines",
    "Public calendar does not exist" : "L'agenda public n'existe pas",
    "Maybe the share was deleted or has expired?" : "Le partage a expiré ou a été supprimé ?",
    "Please select a time zone:" : "Veuillez sélectionner un fuseau horaire : ",
    "Pick a time" : "Indiquez une heure",
    "Pick a date" : "Indiquez une date",
    "from {formattedDate}" : "du {formattedDate}",
    "to {formattedDate}" : "au {formattedDate}",
    "on {formattedDate}" : "le {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "du {formattedDate} à {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "au {formattedDate} à {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "le {formattedDate} à {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} à {formattedTime}",
    "Please enter a valid date" : "Veuillez saisir une date valide",
    "Please enter a valid date and time" : "Veuillez saisir une date et une heure valides",
    "Type to search time zone" : "Commencer la saisie pour rechercher le fuseau horaire",
    "Global" : "Général",
    "Select date" : "Sélectionner la date",
    "Select slot" : "Sélectionnez le créneau",
    "No slots available" : "Aucun créneau disponible",
    "The slot for your appointment has been confirmed" : "Le créneau pour votre rendez-vous a été confirmé",
    "Appointment Details:" : "Détails du rendez-vous :",
    "Time:" : "Horaire :",
    "Booked for:" : "Réservé pour :",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Merci. Votre réservation de {startDate} à {endDate} a été confirmée.",
    "Book another appointment:" : "Réserver un autre rendez-vous :",
    "See all available slots" : "Voir tous les créneaux disponibles",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Le créneau pour votre rendez-vous du {startDate} au {endDate} n'est plus disponible.",
    "Please book a different slot:" : "Merci de réserver un autre créneau :",
    "Book an appointment with {name}" : "Réserver un rendez-vous avec {name}",
    "No public appointments found for {name}" : "Aucun rendez-vous public trouvé pour {name}",
    "Personal" : "Personnel",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La détection automatique a déterminé que votre fuseau horaire était UTC.\nIl s'agit très probablement du résultat des mesures de sécurité de votre navigateur Web.\nVeuillez régler votre fuseau horaire manuellement dans les paramètres du calendrier.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Le fuseau horaire configuré ({timezoneId}) n'a pas été trouvé. Retour à l'UTC.\nVeuillez modifier votre fuseau horaire dans les paramètres et signaler ce problème.",
    "No more events today" : "Aucun autre événement aujourd'hui",
    "No upcoming events" : "Aucun événement à venir",
    "Create a new event" : "Créer un nouvel événement",
    "[Today]" : "[Aujourd'hui]",
    "[Tomorrow]" : "[Demain]",
    "[Yesterday]" : "[Hier]",
    "[Last] dddd" : "dddd [dernier]",
    "Event does not exist" : "L'événement n'existe pas",
    "Duplicate" : "Dupliquer",
    "Delete this occurrence" : "Supprimer cette occurrence",
    "Delete this and all future" : "Supprimer cette occurrence et toutes les prochaines",
    "Details" : "Détails",
    "Attendees" : "Participants",
    "Resources" : "Ressources",
    "Close" : "Fermer",
    "Show more details" : "Afficher plus de détails",
    "Subscribe to {name}" : "S'abonner à {name}",
    "Export {name}" : "Exporter {name}",
    "Anniversary" : "Anniversaire",
    "Appointment" : "Rendez-vous",
    "Business" : "Entreprise",
    "Education" : "Éducation",
    "Holiday" : "Vacances",
    "Meeting" : "Réunion",
    "Miscellaneous" : "Divers",
    "Non-working hours" : "Heures non travaillées",
    "Not in office" : "Absent du bureau",
    "Phone call" : "Appel téléphonique",
    "Sick day" : "Maladie",
    "Special occasion" : "Occasion spéciale",
    "Travel" : "Voyage",
    "Vacation" : "Congé",
    "Midnight on the day the event starts" : "Dès minuit, le jour de l'évènement",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n jour avant l'évènement, à {formattedHourMinute}","%n jours avant l'évènement, à {formattedHourMinute}","%n jours avant l'évènement, à {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semaine avant l'évènement, à {formattedHourMinute}","%n semaines avant l'évènement, à {formattedHourMinute}","%n semaines avant l'évènement, à {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "le jour de l'évènement, à {formattedHourMinute}",
    "at the event's start" : "au début de l'évènement",
    "at the event's end" : "à la fin de l'évènement",
    "{time} before the event starts" : "{time} avant le début de l'évènement",
    "{time} before the event ends" : "{time} avant la fin de l'évènement",
    "{time} after the event starts" : "{time} après le début de l'évènement",
    "{time} after the event ends" : "{time} après la fin de l'évènement",
    "on {time}" : "le {time}",
    "on {time} ({timezoneId})" : "le {time} ({timezoneId})",
    "Week {number} of {year}" : "Semaine {number} de {year}",
    "Does not repeat" : "Ne se répète pas.",
    "Daily" : "Journalier",
    "Weekly" : "Hebdomadaire",
    "Monthly" : "Mensuel",
    "Yearly" : "Annuel",
    "_Every %n day_::_Every %n days_" : ["Tout les %n jour","Tous les %n jours","Tous les %n jours"],
    "_Every %n week_::_Every %n weeks_" : ["Toute les %n semaine","Toutes les %n semaines","Toutes les %n semaines"],
    "_Every %n month_::_Every %n months_" : ["Tous les %n mois","Tous les %n mois","Tous les %n mois"],
    "_Every %n year_::_Every %n years_" : ["Tous les %n ans","Tous les %n ans","Tous les %n ans"],
    "_on {weekday}_::_on {weekdays}_" : ["le {weekday}","les {weekdays}","les {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["le {dayOfMonthList}","les {dayOfMonthList}","les {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "le {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "en {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "en {monthNames}, le {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "jusqu'au {untilDate}",
    "_%n time_::_%n times_" : ["%n fois","%n fois","%n fois"],
    "Untitled event" : "Événement sans titre",
    "Untitled task" : "Tâche sans titre",
    "Please ask your administrator to enable the Tasks App." : "Veuillez demander à votre administrateur d’activer l'application Tasks.",
    "Prev" : "Préc.",
    "Next" : "Suiv.",
    "Prev year" : "Année préc.",
    "Next year" : "Année suiv.",
    "Year" : "Année",
    "W" : "S",
    "%n more" : "%n de plus",
    "No events to display" : "Aucun événement à afficher",
    "_+%n more_::_+%n more_" : ["+%n de plus","+%n de plus","+%n de plus"],
    "No events" : "Pas d'évènements",
    "Create a new event or change the visible time-range" : "Créer un nouvel évènement ou modifier la période visible",
    "It might have been deleted, or there was a typo in a link" : "Il a peut-être été supprimé, ou il y a une erreur dans le lien",
    "It might have been deleted, or there was a typo in the link" : "Il a peut-être été supprimé, ou il y a une erreur dans le lien",
    "Meeting room" : "Salle de réunion",
    "Lecture hall" : "Salle de lecture",
    "Seminar room" : "Salle de séminaire",
    "Other" : "Autre",
    "When shared show" : "Si partagé, afficher",
    "When shared show full event" : "Si partagé, afficher l'évènement entier",
    "When shared show only busy" : "Si partagé, afficher seulement comme occupé",
    "When shared hide this event" : "Si partagé, masquer l'évènement",
    "The visibility of this event in shared calendars." : "Visibilité de cet évènement dans les agendas partagés.",
    "Add a location" : "Ajouter un lieu",
    "Add a description" : "Ajouter une description",
    "Status" : "Statut",
    "Confirmed" : "Confirmé",
    "Canceled" : "Annulé",
    "Confirmation about the overall status of the event." : "Confirmation du statut de l'évènement.",
    "Show as" : "Afficher comme",
    "Take this event into account when calculating free-busy information." : "Prendre en compte cet évènement dans le calcul du temps de disponibilité.",
    "Categories" : "Catégories",
    "Categories help you to structure and organize your events." : "Les catégories vous aident à structurer vos évènements.",
    "Search or add categories" : "Rechercher ou ajouter des catégories",
    "Add this as a new category" : "Ajouter comme nouvelle catégorie",
    "Custom color" : "Couleur personnalisée",
    "Special color of this event. Overrides the calendar-color." : "Couleur de l'évènement. Remplace la couleur de l'agenda.",
    "Chat room for event" : "Salle de discussion de cet événement",
    "Imported {filename}" : "{filename} importé",
    "Meditation" : "Méditation",
    "Relaxing" : "Détente",
    "Relax" : "Détente",
    "Break" : "Pause",
    "Commute" : "Transport",
    "Commuting" : "En transit",
    "Shuttle" : "Navette",
    "Invoice" : "Facture",
    "Finance" : "Finance",
    "Bank" : "Banque",
    "Money" : "Argent",
    "Wedding" : "Mariage",
    "Dog" : "Chien",
    "Concert" : "Concert",
    "Festival" : "Festival",
    "Theater" : "Théâtre",
    "Theatre" : "Théâtre",
    "Presentation" : "Présentation",
    "Talk" : "Discussion",
    "Speech" : "Prise de parole",
    "Deadline" : "Date limite",
    "Submission" : "Envoi",
    "Reporting" : "Rapports",
    "Camping" : "Camping",
    "Camp" : "Camping",
    "Election" : "Élection",
    "Voting" : "Vote",
    "Vote" : "Vote",
    "Barbecue" : "Barbecue",
    "Barbeque" : "Barbecue",
    "Garden" : "Jardin",
    "Farm" : "Ferme",
    "Movie" : "Film",
    "Cinema" : "Cinéma",
    "Graduation" : "Examen",
    "Brainstorm" : "Réunion",
    "Review" : "Revoir",
    "Audit" : "Audit",
    "Inspection" : "Inspection",
    "Proofreading" : "Relecture",
    "Baseball" : "Baseball",
    "Meet" : "Rencontre",
    "Planning" : "Planning",
    "Pointing" : "Pointage",
    "Retrospective" : "Rétrospective",
    "Office" : "Bureau",
    "Contributor week" : "Semaine des contributeurs",
    "Mail" : "Mail",
    "Soccer" : "Football",
    "Football" : "Football",
    "Gaming" : "Jeu",
    "Drive" : "Trajet en voiture",
    "Driving" : "Conduite",
    "Bicycle" : "Vélo",
    "Cycle" : "Vélo",
    "Cycling" : "Vélo",
    "Biking" : "Vélo",
    "Bike" : "Vélo",
    "Podcast" : "Podcast",
    "Basketball" : "Basketball",
    "Fishing" : "Pêche",
    "Hiking" : "Randonnée",
    "Hike" : "Randonnée",
    "Art" : "Art",
    "Exhibition" : "Exposition",
    "Museum" : "Musée",
    "Pilates" : "Pilates",
    "Park" : "Promenade au parc",
    "Walk" : "Marche",
    "Studying" : "Études",
    "Doctor" : "Docteur",
    "Health" : "Santé",
    "Dentist" : "Dentiste",
    "Hospital" : "Hôpital",
    "Interview" : "Interview",
    "Training" : "Entraînement",
    "Practice" : "Entraînement",
    "Sports" : "Sports",
    "Exercise" : "Sport",
    "Work out" : "Sport",
    "Working out" : "Entraînement",
    "Gym" : "Gym",
    "Barber" : "Barbier",
    "Haircut" : "Coiffeur",
    "Hairdresser" : "Coiffeur",
    "Exam" : "Examen",
    "Written test" : "Test écrit",
    "Oral test" : "Test oral",
    "Working" : "Travail",
    "New Years Eve" : "Jour de l'An",
    "NYE" : "Jour de l'An",
    "Fireworks" : "Feu artifice",
    "Running" : "Course à pied",
    "Go for a run" : "Jogging",
    "Marathon" : "Marathon",
    "Video-conference" : "Visioconférence",
    "Conference-call" : "Conférence téléphonique",
    "Video-call" : "Appel vidéo",
    "Video-chat" : "Conversation vidéo",
    "Video-meeting" : "Rendez-vous en visioconférence",
    "Call" : "Appel",
    "Calling" : "Appeler",
    "Christmas" : "Noël",
    "Conference" : "Conférence",
    "Pizza" : "Pizza",
    "Travelling" : "Voyager",
    "Trip" : "Voyage",
    "Journey" : "Trajet",
    "Collaborate" : "Collaboration",
    "Pair" : "Pair",
    "Lecture" : "Lecture",
    "Seminar" : "Séminaire",
    "Teaching" : "Enseignement",
    "Photograph" : "Photographe",
    "Party" : "Fête",
    "Celebration" : "Fête",
    "Celebrate" : "Fête",
    "Birthday" : "Anniversaire",
    "Shopping" : "Courses",
    "Groceries" : "Courses",
    "Skate" : "Skate-board",
    "Skateboard" : "Skate-board",
    "Wine tasting" : "Dégustation de vin",
    "Golf" : "Golf",
    "Dinner" : "Diner",
    "Lunch" : "Repas",
    "Appointment not found" : "Rendez-vous non trouvé",
    "User not found" : "Utilisateur non trouvé"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
