OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "واہ!",
    "Calendar" : "کیلنڈر",
    "Today" : "آج",
    "Week" : "ہفتہ",
    "Month" : "ماہ",
    "Edit" : "تدوین کریں",
    "Delete" : "حذف کریں",
    "Share link" : "اشتراک لنک",
    "can edit" : "تبدیل کر سکے ھیں",
    "New calendar" : "جدید کیلنڈر",
    "Name" : "اسم",
    "Deleted" : "حذف شدہ ",
    "Restore" : "بحال",
    "Cancel" : "منسوخ کریں",
    "Location" : "مقام",
    "Description" : "تصریح",
    "Add" : "شامل کریں",
    "Monday" : "سوموار",
    "Tuesday" : "منگل",
    "Wednesday" : "بدھ",
    "Thursday" : "جمعرات",
    "Friday" : "جمعہ",
    "Saturday" : "ہفتہ",
    "Sunday" : "اتوار",
    "Save" : "حفظ",
    "Email" : "email",
    "Repeat" : "دہرایں",
    "never" : "never",
    "More" : "مزید",
    "Personal" : "شخصی",
    "Close" : "بند ",
    "Next" : "اگلا",
    "Other" : "دیگر",
    "Birthday" : "سالگرہ"
},
"nplurals=2; plural=(n != 1);");
