OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Käyttäjäistunto vanheni odottamatta",
    "Provided email-address is not valid" : "Sähköpostiosoite on virheellinen",
    "%s has published the calendar »%s«" : "%s on julkaissut kalenterin  »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Odottamaton virhe sähköpostia lähettäessä. Ole yhteydessä ylläpitoon.",
    "Successfully sent email to %1$s" : "Sähköposti lähetetty taholle %1$s",
    "Hello," : "Hei",
    "We wanted to inform you that %s has published the calendar »%s«." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin »%s«.",
    "Open »%s«" : "Avaa »%s«",
    "Cheers!" : "Kiitos!",
    "Upcoming events" : "Tulevat tapahtumat",
    "Appointments" : "Tapaamiset",
    "Schedule appointment \"%s\"" : "Ajoita tapaaminen \"%s\"",
    "Schedule an appointment" : "Ajoita tapaaminen",
    "Prepare for %s" : "Valmistaudu tapahtumaan \"%s\"",
    "Your appointment \"%s\" with %s needs confirmation" : "Tapaaminen \"%s\"  henkilön %s kanssa vaatii vahvistamisen",
    "Dear %s, please confirm your booking" : "%s, ole hyvä ja vahvista varauksesi",
    "Confirm" : "Vahvista",
    "This confirmation link expires in %s hours." : "Tämä vahvistuslinkki umpeutuu %s tunnin kuluttua.",
    "Your appointment \"%s\" with %s has been accepted" : "Tapaaminen \"%s\" henkilön %s kanssa on hyväksytty",
    "Dear %s, your booking has been accepted." : "%s, varauksesi on hyväksytty.",
    "Date:" : "Päivämäärä:",
    "Where:" : "Paikka:",
    "Your Comment:" : "Kommenttisi:",
    "Calendar" : "Kalenteri",
    "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Kalenterisovellus on käyttöliittymä Nextcloudin CalDAV-palvelimelle. Nextcloudin avulla synkronoit helposti tapahtumasi eri laitteiden välillä  ja muokkaat niitä selaimessa.\n\n* 🚀 **Integraatio muiden Nextcloud-sovellusten kanssa!** Tällä hetkellä tuettuna Kontaktit-sovellus - lisää tulossa.\n* 🌐 **WebCal-tuki!** Haluatko nähdä lempijoukkueesi ottelupäivät kalenterissasi? Ei ongelmaa!\n* 🙋 **Osallistujat!** Kutsu ihmisiä tapahtumiisi\n* ⌚️ **Vapaa/Varattu!** Näe milloin osallistujat ovat käytettävissä tapaamiseen\n* ⏰ **Muistutukset!** Hälytykset tapahtumille selaimessa ja sähköpostilla\n* 🔍 Etsi! Löydä tapahtumasi helposti\n* ☑️ Tehtävät! Määräpäivät näytetään kalenterissa\n* 🙈 **Emme keksi pyörää uudelleen!** Perustuu mahtaviin [c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) ja [fullcalendar](https://github.com/fullcalendar/fullcalendar) kirjastoihin.",
    "Previous day" : "Edellinen päivä",
    "Previous week" : "Edellinen viikko",
    "Previous month" : "Edellinen kuukausi",
    "Next day" : "Seuraava päivä",
    "Next week" : "Seuraava viikko",
    "Next month" : "Seuraava kuukausi",
    "New event" : "Uusi tapahtuma",
    "Today" : "Tänään",
    "Day" : "Päivä",
    "Week" : "Viikko",
    "Month" : "Kuukausi",
    "List" : "Lista",
    "Preview" : "Esikatselu",
    "Copy link" : "Kopioi linkki",
    "Edit" : "Muokkaa",
    "Delete" : "Poista",
    "Appointment link was copied to clipboard" : "Linkki tapaamiseen kopioitiin leikepöydälle",
    "Appointment link could not be copied to clipboard" : "Linkkiä tapaamiseen ei voitu kopioida leikepöydälle",
    "Add new" : "Lisää uusi",
    "Untitled calendar" : "Nimetön kalenteri",
    "Edit name" : "Muokkaa nimeä",
    "Saving name …" : "Tallennetaan nimi …",
    "Edit color" : "Muokkaa väriä",
    "Saving color …" : "Tallennetaan väri …",
    "Copy private link" : "Kopioi yksityinen linkki",
    "Export" : "Vie",
    "Unshare from me" : "Lopeta jako minulle",
    "Disable calendar \"{calendar}\"" : "Poista käytöstä kalenteri \"{calendar}\"",
    "Disable untitled calendar" : "Poista nimetön kalenteri käytöstä",
    "Enable calendar \"{calendar}\"" : "Ota käyttöön kalenteri \"{calendar}\"",
    "Enable untitled calendar" : "Ota nimetön kalenteri käyttöön",
    "An error occurred, unable to change visibility of the calendar." : "Tapahtui virhe. Kalenterin näkyvyyttä ei voitu muuttaa.",
    "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
    "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
    "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
    "An error occurred, unable to rename the calendar." : "Tapahtui virhe, kalenterin nimeäminen uudelleen ei onnistu.",
    "An error occurred, unable to change the calendar's color." : "Tapahtui virhe, kalenterin värin muuttaminen ei onnistu.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Poistetaan kalenterin jako {countdown} sekunnin kuluttua","Poistetaan kalenterin jako {countdown} sekunnin kuluttua"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Poistetaan kalenteri {countdown} sekunnin kuluttua","Poistetaan kalenteri {countdown} sekunnin kuluttua"],
    "Share link" : "Jaa linkki",
    "Publish calendar" : "Julkaise kalenteri",
    "Publishing calendar" : "Julkaistaan kalenteri",
    "Copy public link" : "Kopioi julkinen linkki",
    "Send link to calendar via email" : "Lähetä kalenteriin johtava linkki sähköpostitse",
    "Enter one address" : "Kirjoita yksi osoite",
    "Sending email …" : "Lähetetään sähköpostia …",
    "Copy subscription link" : "Kopioi tilauslinkki",
    "Copying link …" : "Kopioidaan linkki …",
    "Copied link" : "Linkki kopioitu",
    "Could not copy link" : "Linkkiä ei voitu kopioida",
    "Copy embedding code" : "Kopioi upotuskoodi",
    "Copying code …" : "Kopioidaan koodi …",
    "Copied code" : "Koodi kopioitu",
    "Could not copy code" : "Koodia ei voitu kopioida",
    "Delete share link" : "Poista jakolinkki",
    "Deleting share link …" : "Poistetaan jakolinkki …",
    "An error occurred, unable to publish calendar." : "Tapahtui virhe, kalenterin julkaiseminen ei onnistu.",
    "An error occurred, unable to send email." : "Tapahtui virhe. Sähköpostia ei voitu lähettää.",
    "Embed code copied to clipboard." : "Upotuskoodi kopioitu leikepöydälle.",
    "Embed code could not be copied to clipboard." : "Upotuskoodia ei voitu kopioida leikepöydälle.",
    "Unpublishing calendar failed" : "Kalenterin julkaisun peruminen epäonnistui",
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "No users or groups" : "Ei käyttäjiä tai ryhmiä",
    "can edit" : "voi muokata",
    "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Tapahtui virhe, kalenterin poissa jakamista ei voi muokata.",
    "An error occurred, unable to change the permission of the share." : "Tapahtui virhe, jaon käyttöoikeuksia ei pysty muokkaamaan.",
    "New calendar" : "Uusi kalenteri",
    "Name for new calendar" : "Uuden kalenterin nimi",
    "Creating calendar …" : "Luodaan kalenteri …",
    "New calendar with task list" : "Uusi kalenteri tehtävälistan kera",
    "New subscription from link (read-only)" : "Uusi tilaus linkistä (vain luku)",
    "Creating subscription …" : "Luodaan tilaus …",
    "An error occurred, unable to create the calendar." : "Tapahtui virhe, kalenteria ei voitu luoda.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Anna kelvollinen linkki (alkaen http://, https://, webcal:// tai webcals://)",
    "Trash bin" : "Roskakori",
    "Loading deleted items." : "Ladataan poistettuja kohteita.",
    "You do not have any deleted items." : "Sinulla ei ole poistettuja kohteita.",
    "Name" : "Nimi",
    "Deleted" : "Poistettu",
    "Restore" : "Palauta",
    "Delete permanently" : "Poista pysyvästi",
    "Empty trash bin" : "Tyhjennä roskakori",
    "Untitled item" : "Nimetön kohde",
    "Unknown calendar" : "Tuntematon kalenteri",
    "Could not load deleted calendars and objects" : "Poistettuja kalentereita tai objekteja ei voitu ladata",
    "Could not restore calendar or event" : "Kalenteria tai tapahtumaa ei voitu palauttaa",
    "Do you really want to empty the trash bin?" : "Haluatko varmasti tyhjentää roskakorin?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Roskakorissa olevat kohteet poistetaan {numDays} päivän jälkeen","Roskakorissa olevat kohteet poistetaan {numDays} päivän jälkeen"],
    "Could not update calendar order." : "Kalenterin järjestystä ei voitu päivittää.",
    "Import calendars" : "Tuo kalenterit",
    "Please select a calendar to import into …" : "Valitse kalenteri, johon tuodaan …",
    "Filename" : "Tiedostonimi",
    "Calendar to import into" : "Kalenteri johon tuodaan",
    "Cancel" : "Peruuta",
    "_Import calendar_::_Import calendars_" : ["Tuo kalenteri","Tuo kalenterit"],
    "{filename} could not be parsed" : "Tiedostoa {filename} ei voitu jäsentää",
    "No valid files found, aborting import" : "Kelvollisia tiedostoja ei löytynyt, lopetetaan tuonti",
    "Import partially failed. Imported {accepted} out of {total}." : "Tuonti epäonnistui osittain. Tuotiin {accepted}/{total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Tuotiin onnistuneesti %n tapahtuma","Tuotiin onnistuneesti %n tapahtumaa"],
    "Automatic" : "Automaattinen",
    "Automatic ({detected})" : "Automaattinen ({detected})",
    "New setting was not saved successfully." : "Uutta asetusta ei tallennettu onnistuneesti.",
    "Shortcut overview" : "Pikakuvakenäkymä",
    "or" : "tai",
    "Navigation" : "Navigointi",
    "Previous period" : "Edellinen jakso",
    "Next period" : "Seuraava jakso",
    "Views" : "Näkymät",
    "Day view" : "Päivänäkymä",
    "Week view" : "Viikkonäkymä",
    "Month view" : "Kuukausinäkymä",
    "List view" : "Listanäkymä",
    "Actions" : "Toiminnot",
    "Create event" : "Luo tapahtuma",
    "Show shortcuts" : "Näytä pikanäppäimet",
    "Editor" : "Muokkain",
    "Close editor" : "Sulje muokkain",
    "Save edited event" : "Tallenna muokattu tapahtuma",
    "Delete edited event" : "Poista muokattu tapahtuma",
    "Duplicate event" : "Tee kaksoiskappale tapahtumasta",
    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
    "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
    "Limit visible events per view" : "Rajoita näytettäviä tapahtumia näkymää kohden",
    "Show weekends" : "Näytä viikonloput",
    "Show week numbers" : "Näytä viikkonumerot",
    "Time increments" : "Aikavälit",
    "Default reminder" : "Oletusmuistutus",
    "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
    "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
    "Calendar settings" : "Kalenteriasetukset",
    "No reminder" : "Ei muistutusta",
    "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
    "Appointment was created successfully" : "Tapaaminen luotiin onnistuneesti",
    "Appointment was updated successfully" : "Tapaaminen päivitettiin onnistuneesti",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuutti","{duration} minuuttia"],
    "0 minutes" : "0 minuuttia",
    "_{duration} hour_::_{duration} hours_" : ["{duration} tunti","{duration} tuntia"],
    "_{duration} day_::_{duration} days_" : ["{duration} päivä","{duration} päivää"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} viikko","{duration} viikkoa"],
    "_{duration} month_::_{duration} months_" : ["{duration} kuukausi","{duration} kuukautta"],
    "_{duration} year_::_{duration} years_" : ["{duration} vuosi","{duration} vuotta"],
    "To configure appointments, add your email address in personal settings." : "Lisää sähköpostiosoitteesi henkilökohtaisissa asetuksissa hallitaksesi tapaamisia.",
    "Public – shown on the profile page" : "Julkinen – näytetään profiilisivulla",
    "Private – only accessible via secret link" : "Yksityinen – nähtävissä vain salaisella linkillä",
    "Location" : "Sijainti",
    "Description" : "Kuvaus",
    "Visibility" : "Näkyvyys",
    "Duration" : "Kesto",
    "Increments" : "Aikaväli",
    "Additional calendars to check for conflicts" : "Lisäkalenterit, jotka tarkistetaan ristiriitojen varalta",
    "Pick time ranges where appointments are allowed" : "Valitse aikavälit joihin sallitaan tapaamisia",
    "to" : "päättyen",
    "Delete slot" : "Poista aikarako",
    "No times set" : "Ei asetettuja aikoja",
    "Add" : "Lisää",
    "Monday" : "Maanantai",
    "Tuesday" : "Tiistai",
    "Wednesday" : "Keskiviikko",
    "Thursday" : "Torstai",
    "Friday" : "Perjantai",
    "Saturday" : "Lauantai",
    "Sunday" : "Sunnuntai",
    "Add time before and after the event" : "Lisää aikaa ennen tapahtuman alkua ja tapahtuman jälkeen",
    "Before the event" : "Ennen tapahtumaa",
    "After the event" : "Tapahtuman jälkeen",
    "Planning restrictions" : "Suunnittelurajoitukset",
    "Minimum time before next available slot" : "Vähimmäisaika ennen seuraavaa saatavilla olevaa aikarakoa",
    "Max slots per day" : "Aikarakoja enintään päivää kohden",
    "Limit how far in the future appointments can be booked" : "Rajoita kuinka pitkälle tulevaisuuteen tapaamisia on mahdollista varata",
    "Create appointment" : "Luo tapaaminen",
    "Edit appointment" : "Muokkaa tapaamista",
    "Save" : "Tallenna",
    "Update" : "Päivitä",
    "Please confirm your reservation" : "Vahvista varauksesi",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Lähetimme sinulle sähköpostin yksityiskohtien kera. Ole hyvä ja hyväksy tapaamisesi käyttäen linkkiä sähköpostissa. Voit sulkea tämän sivun.",
    "Your name" : "Nimesi",
    "Your email address" : "Sähköpostiosoitteesi",
    "Please share anything that will help prepare for our meeting" : "Jaa mitä tahansa, mikä auttaa valmistautumaan kokoukseen",
    "Could not book the appointment. Please try again later or contact the organizer." : "Tapaamista ei voitu kirjata. Ole hyvä ja yritä myöhemmin uudelleen tai ota yhteyttä järjestäjään.",
    "Book the appointment" : "Kirjaa tapaaminen",
    "Reminder" : "Muistutus",
    "before at" : "ennen",
    "Notification" : "Ilmoitus",
    "Email" : "Sähköposti",
    "Audio notification" : "Ääni-ilmoitus",
    "Other notification" : "Muu ilmoitus",
    "Relative to event" : "Liittyy tapahtumaan",
    "On date" : "Päivänä",
    "Edit time" : "Muokkaa aikaa",
    "Save time" : "Tallenna aika",
    "Remove reminder" : "Poista muistutus",
    "on" : "päivä",
    "at" : "kellonaika",
    "+ Add reminder" : "+ Lisää muistutus",
    "Add reminder" : "Lisää muistutus",
    "_second_::_seconds_" : ["sekunti","sekuntia"],
    "_minute_::_minutes_" : ["minuutti","minuuttia"],
    "_hour_::_hours_" : ["tunti","tuntia"],
    "_day_::_days_" : ["päivä","päivää"],
    "_week_::_weeks_" : ["viikko","viikkoa"],
    "Invitation accepted" : "Kutsu hyväksytty",
    "Available" : "Saatavilla",
    "Suggested" : "Ehdotettu",
    "Participation marked as tentative" : "Osallistuminen merkitty alustavaksi",
    "Accepted {organizerName}'s invitation" : "Hyväksytty järjestäjän {organizerName} kutsu",
    "Not available" : "Ei saatavilla",
    "Invitation declined" : "Kieltäydytty kutsusta",
    "Declined {organizerName}'s invitation" : "Kieltäytyi järjestäjän {organizerName} kutsusta",
    "Invitation is delegated" : "Kutsu on delegoitu",
    "Checking availability" : "Tarkistetaan saatavuutta",
    "Invitation sent" : "Kutsu lähetetty",
    "Has not responded to {organizerName}'s invitation yet" : "Ei ole vielä vastanut järjestäjän {organizerName} kutsuun",
    "Availability of attendees, resources and rooms" : "Osallistujien, resurssien ja huoneiden saatavuus",
    "{organizer} (organizer)" : "{organizer} (järjestäjä)",
    "Free" : "Vapaa",
    "Busy (tentative)" : "Varattu (alustava)",
    "Busy" : "Varattu",
    "Out of office" : "Ulkona toimistolta",
    "Unknown" : "Tuntematon",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Tentative" : "Alustava",
    "The invitation has been accepted successfully." : "Kutsu on hyväksytty.",
    "Failed to accept the invitation." : "Kutsun hyväksyminen epäonnistui.",
    "The invitation has been declined successfully." : "Kieltäydytty kutsusta onnistuneesti.",
    "Failed to decline the invitation." : "Kutsusta kieltäytyminen epäonnistui.",
    "Your participation has been marked as tentative." : "Osallistumisesi on merkitty alustavaksi.",
    "Failed to set the participation status to tentative." : "Osallistumisen tilan asettaminen alustavaksi epäonnistui.",
    "Create Talk room for this event" : "Luo Talk-huone tälle tapahtumalle",
    "Show busy times" : "Näytä varatut ajat",
    "No attendees yet" : "Ei vielä osallistujia",
    "Successfully appended link to talk room to description." : "Linkki Talk-huoneeseen lisättiin onnistuneesti kuvaukseen.",
    "Error creating Talk room" : "Virhe luotaessa Talk-huonetta",
    "Send email" : "Lähetä sähköposti",
    "Chairperson" : "Puheenjohtaja",
    "Required participant" : "Vaadittu osallistuja",
    "Optional participant" : "Valinnainen osallistuja",
    "Non-participant" : "Osallistumaton",
    "Remove attendee" : "Poista osallistuja",
    "Search for emails, users or contacts" : "Etsi sähköpostiosoitteita, käyttäjiä tai yhteystietoja",
    "No match found" : "Ei tuloksia",
    "(organizer)" : "(järjestäjä)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "[linkopen]Lisää sähköpostiosoitteesi henkilökohtaisiin asetuksiisi[linkclose] lähettääksesi kutsuja ja hallitaksesi vastauksia.",
    "Remove color" : "Poista väri",
    "Event title" : "Tapahtuman otsikko",
    "All day" : "Koko päivä",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Koko päivän tapahtumia, jotka ovat osa toistuvaa tapahtumaa, ei voida muokata.",
    "from {startDate}" : "alkaen {startDate}",
    "from {startDate} at {startTime}" : "alkaen {startDate} klo {startTime}",
    "to {endDate}" : "päättyen {endDate}",
    "to {endDate} at {endTime}" : "päättyen {endDate} klo {endTime}",
    "Repeat" : "Toista",
    "End repeat" : "Lopeta toisto",
    "Select to end repeat" : "Valitse lopettaaksesi toiston",
    "never" : "ei koskaan",
    "on date" : "päivänä",
    "after" : "jälkeen",
    "_time_::_times_" : ["kerran","kertaa"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Tämä tapahtuma on toistuvaan tapahtumaan tehty poikkeus. Et voi lisätä tähän uutta toistuvuutta.",
    "first" : "ensimmäinen",
    "third" : "kolmas",
    "fourth" : "neljäs",
    "fifth" : "viides",
    "second to last" : "toiseksi viimeinen",
    "last" : "viimeinen",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Muutokset toistuvuusasetukseen vaikuttavat vain tähän ja tuleviin tapahtumakertoihin.",
    "Repeat every" : "Toista joka",
    "By day of the month" : "Kuukauden päivän mukaan",
    "On the" : "Ajankohtana",
    "_month_::_months_" : ["kuukausi","kuukautta"],
    "_year_::_years_" : ["vuosi","vuotta"],
    "weekday" : "viikonpäivä",
    "weekend day" : "viikonloppupäivä",
    "No recurrence" : "Ei toistumista",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Tapahtuman toistuvuusasetus ei ole Nextcloudin tukema. Jos muokkaat toistuvuusasetusta, jotkin toistuvista tapahtumista saattavat kadota.",
    "Suggestions" : "Ehdotukset",
    "No rooms or resources yet" : "Ei huoneita tai resursseja vielä",
    "Add resource" : "Lisää resurssi",
    "Has a projector" : "On projektori",
    "Has a whiteboard" : "On valkotaulu",
    "Wheelchair accessible" : "Pääsy pyörätuolilla",
    "Remove resource" : "Poista resurssi",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} istumapaikka","{seatingCapacity} istumapaikkaa"],
    "Projector" : "Projektori",
    "Whiteboard" : "Valkotaulu",
    "Search for resources or rooms" : "Etsi resursseja tai huoneita",
    "available" : "saatavilla",
    "unavailable" : "ei saatavilla",
    "Room type" : "Huoneen tyyppi",
    "Any" : "Mikä tahansa",
    "Minimum seating capacity" : "Istumapaikkoja vähintään",
    "More" : "Lisää",
    "Update this occurrence" : "Päivitä tämä esiintymä",
    "Update this and all future" : "Päivitä tämä ja kaikki tulevat",
    "Public calendar does not exist" : "Julkista kalenteria ei ole olemassa",
    "Maybe the share was deleted or has expired?" : "Kenties jako poistettiin tai se vanheni.",
    "Please select a time zone:" : "Valitse aikavyöhyke:",
    "Pick a time" : "Valitse aika",
    "Pick a date" : "Valitse päivä",
    "from {formattedDate}" : "alkaen {formattedDate}",
    "to {formattedDate}" : "päättyen {formattedDate}",
    "on {formattedDate}" : "päivänä {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "alkaen {formattedDate} klo {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "päättyen {formattedDate} klo {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "päivänä {formattedDate} klo {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} klo {formattedTime}",
    "Please enter a valid date" : "Kirjoita kelvollinen päivä",
    "Please enter a valid date and time" : "Kirjoita kelvollinen päivä ja aika",
    "Type to search time zone" : "Kirjoita etsiäksesi aikavyöhykettä",
    "Global" : "Julkinen",
    "Select date" : "Valitse päivämäärä",
    "Select slot" : "Valitse aikarako",
    "No slots available" : "Aikarakoja ei ole saatavilla",
    "The slot for your appointment has been confirmed" : "Aikarako tapaamiselle on vahvistettu",
    "Appointment Details:" : "Tapaamisen yksityiskohdat:",
    "Time:" : "Aika:",
    "Booked for:" : "Varattu:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Kiitos. varauksesi {startDate} - {endDate} on vahvistettu.",
    "Book another appointment:" : "Varaa toinen tapaaminen:",
    "See all available slots" : "Näytä kaikki saatavilla olevat aikaraot",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Aikarako tapaamiselle, {startDate} - {endDate}, ei ole enää saatavilla.",
    "Please book a different slot:" : "Varaa muu aikarako:",
    "Book an appointment with {name}" : "Varaa tapaaminen käyttäjän {name} kanssa",
    "No public appointments found for {name}" : "Käyttäjän {name} julkisia tapaamisia ei löydy",
    "Personal" : "Henkilökohtainen",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automaattinen aikavyöhykkeentunnistus määritti aikavyöhykkeesi olevan UTC. \nTämä johtuu todennäköisesti selaimesi tietoturva-asetuksista.\nOle hyvä ja aseta aikavyöhykkeesi manuaalisesti kalenterin asetuksista.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Asettamaasi aikavyöhykettä ({timezoneId}) ei löytynyt. Vaihdetaan takaisin UTC:hen.\nOle hyvä ja vaihda aikavyöhykkeesi asetuksista ja ilmoita tästä ongelmasta.",
    "No more events today" : "Ei enempää tapahtumia tänään",
    "No upcoming events" : "Ei tulevia tapahtumia",
    "Create a new event" : "Luo uusi tapahtuma",
    "[Today]" : "[Tänään]",
    "[Tomorrow]" : "[Huomenna]",
    "[Yesterday]" : "[Eilen]",
    "[Last] dddd" : "[Viimeinen] dddd",
    "Event does not exist" : "Tapahtumaa ei ole olemassa",
    "Delete this occurrence" : "Poista tämä esiintymä",
    "Delete this and all future" : "Poista tämä ja kaikki tulevat",
    "Details" : "Tiedot",
    "Attendees" : "Osallistujat",
    "Resources" : "Resurssit",
    "Close" : "Sulje",
    "Show more details" : "Näytä lisää tietoja",
    "Subscribe to {name}" : "Tilaa {name}",
    "Export {name}" : "Vie {name}",
    "Anniversary" : "Vuosipäivä",
    "Appointment" : "Tapaaminen",
    "Business" : "Business",
    "Education" : "Koulutus",
    "Holiday" : "Loma",
    "Meeting" : "Kokous",
    "Miscellaneous" : "Sekalaiset",
    "Non-working hours" : "Ei-työnalaiset tunnit",
    "Not in office" : "Pois työpaikalta",
    "Phone call" : "Puhelinkeskustelu",
    "Sick day" : "Sairauspäivä",
    "Special occasion" : "Erikoistilaisuus",
    "Travel" : "Matka",
    "Vacation" : "Vapaalla töistä",
    "Midnight on the day the event starts" : "Keskiyöllä tapahtumapäivänä",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n päivä ennen tapahtumaa klo {formattedHourMinute}","%n  päivää ennen tapahtumaa klo {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n viikko ennen tapahtumaa klo {formattedHourMinute}","%n viikkoa ennen tapahtumaa klo {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "tapahtumapäivänä klo {formattedHourMinute}",
    "at the event's start" : "tapahtuman alkaessa",
    "at the event's end" : "tapahtuman päättyessä",
    "{time} before the event starts" : "{time} ennen tapahtuman alkua",
    "{time} before the event ends" : "{time} ennen tapahtuman päättymistä",
    "{time} after the event starts" : "{time} tapahtuman alkamisen jälkeen",
    "{time} after the event ends" : "{time} tapahtuman päättymisen jälkeen",
    "on {time}" : "klo {time}",
    "on {time} ({timezoneId})" : "klo {time} ({timezoneId})",
    "Week {number} of {year}" : "Viikko {number} vuonna {year}",
    "Does not repeat" : "Ei toistu",
    "Daily" : "Päivittäin",
    "Weekly" : "Viikottain",
    "Monthly" : "Kuukausittain",
    "Yearly" : "Vuosittain",
    "_Every %n day_::_Every %n days_" : ["Päivittäin","Joka %n. päivä"],
    "_Every %n week_::_Every %n weeks_" : ["Viikottain","Joka %n. viikko "],
    "_Every %n month_::_Every %n months_" : ["Kuukausittain","Joka %n. kuukausi"],
    "_Every %n year_::_Every %n years_" : ["Vuosittain","Joka %n. vuosi"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}na","viikonpäivinä {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["päivänä {dayOfMonthList}","päivinä {dayOfMonthList}"],
    "in {monthNames}" : "kuukausina {monthNames}",
    "until {untilDate}" : "{untilDate} asti",
    "_%n time_::_%n times_" : ["%n kerran","%n kertaa"],
    "Untitled event" : "Nimetön tapahtuma",
    "Untitled task" : "Nimetön tehtävä",
    "Please ask your administrator to enable the Tasks App." : "Pyydä järjestelmänvalvojaa ottamaan Tasks-sovellus käyttöön",
    "Prev" : "Edellinen",
    "Next" : "Seuraava",
    "Prev year" : "Edellinen vuosi",
    "Next year" : "Seuraava vuosi",
    "Year" : "Vuosi",
    "W" : "Vko",
    "%n more" : "%n lisää",
    "No events to display" : "Ei tapahtumia näytettäväksi",
    "_+%n more_::_+%n more_" : ["+%n lisää","+%n lisää"],
    "No events" : "Ei tapahtumia",
    "Create a new event or change the visible time-range" : "Luo uusi tapahtuma tai vaihda näkyvää aikajanaa",
    "It might have been deleted, or there was a typo in a link" : "Se saattaa olla poistettu, tai linkissä oli kirjoitusvirhe",
    "It might have been deleted, or there was a typo in the link" : "Se saattaa olla poistettu, tai linkissä oli kirjoitusvirhe",
    "Meeting room" : "Kokoushuone",
    "Lecture hall" : "Luentosali",
    "Seminar room" : "Seminaarihuone",
    "Other" : "Muu",
    "When shared show" : "Jaettaessa näytä",
    "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
    "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
    "When shared hide this event" : "Jaettaessa piilota tämä tapahtuma",
    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa.",
    "Add a location" : "Lisää sijainti",
    "Add a description" : "Lisää kuvaus",
    "Status" : "Tila",
    "Confirmed" : "Vahvistettu",
    "Canceled" : "Peruttu",
    "Confirmation about the overall status of the event." : "Vahvistus tapahtuman yleiskuvasta.",
    "Show as" : "Näytä muodossa",
    "Take this event into account when calculating free-busy information." : "Huomioi tämä tapahtuma laskettaessa vapaita ja varattuja ajankohtia.",
    "Categories" : "Luokat",
    "Categories help you to structure and organize your events." : "Luokat auttavat sinua asettamaan tapahtumia rakenteellisiksi ja hallitsemaan niitä.",
    "Search or add categories" : "Etsi tai lisää luokkia",
    "Add this as a new category" : "Lisää tämä uutena luokkana",
    "Custom color" : "Mukautettu väri",
    "Special color of this event. Overrides the calendar-color." : "Tämän tapahtuman erikoisväri. Ylittää kalenterin väriarvon.",
    "Chat room for event" : "Tapahtuman keskusteluhuone",
    "Imported {filename}" : "Tuotiin {filename}",
    "Meditation" : "Meditaatio",
    "Relaxing" : "Rentoutumista",
    "Relax" : "Rentoutumista",
    "Break" : "Tauko",
    "Commuting" : "Työmatkalla",
    "Invoice" : "Lasku",
    "Finance" : "Talous",
    "Bank" : "Pankki",
    "Money" : "Raha",
    "Wedding" : "Häät",
    "Dog" : "Koira",
    "Concert" : "Konsertti",
    "Festival" : "Festivaali",
    "Theater" : "Teatteri",
    "Theatre" : "Teatteri",
    "Presentation" : "Esitys",
    "Talk" : "Puhe",
    "Speech" : "Puhe",
    "Deadline" : "Deadline",
    "Submission" : "Lähetys",
    "Reporting" : "Raportointi",
    "Camping" : "Telttailua",
    "Camp" : "Leiri",
    "Election" : "Vaalit",
    "Voting" : "Äänestys",
    "Vote" : "Äänestä",
    "Barbecue" : "Grillaus",
    "Barbeque" : "Grillaus",
    "Garden" : "Puutarha",
    "Farm" : "Maatila",
    "Movie" : "Elokuva",
    "Cinema" : "Elokuvateatteri",
    "Graduation" : "Valmistujaiset",
    "Brainstorm" : "Brainstorm",
    "Review" : "Esikatsele",
    "Audit" : "Auditointi",
    "Inspection" : "Tarkastus",
    "Proofreading" : "Oikoluku",
    "Baseball" : "Pesäpallo",
    "Meet" : "Liity",
    "Planning" : "Suunnittelua",
    "Pointing" : "Osoittaa",
    "Retrospective" : "Retrospektiivinen",
    "Office" : "Toimisto",
    "Contributor week" : "Tukijaviikko",
    "Mail" : "Sähköposti",
    "Soccer" : "Jalkapallo",
    "Football" : "Jalkapallo",
    "Gaming" : "Pelailua",
    "Drive" : "Ajo",
    "Driving" : "Ajaminen",
    "Bicycle" : "Polkupyöräily",
    "Cycle" : "Polkupyöräily",
    "Cycling" : "Pyöräily",
    "Biking" : "Polkupyöräily",
    "Bike" : "Polkupyörä",
    "Podcast" : "Podcast",
    "Basketball" : "Koripallo",
    "Fishing" : "Kalastus",
    "Hiking" : "Retkeily",
    "Hike" : "Vaellus",
    "Art" : "Taide",
    "Exhibition" : "Näyttely",
    "Museum" : "Museo",
    "Pilates" : "Pilates",
    "Park" : "Puisto",
    "Walk" : "Kävely",
    "Studying" : "Opiskelua",
    "Doctor" : "Lääkäri",
    "Health" : "Terveys",
    "Dentist" : "Hammaslääkäri",
    "Hospital" : "Sairaala",
    "Interview" : "Haastattelu",
    "Training" : "Treenit",
    "Practice" : "Harjoittele",
    "Sports" : "Liikuntaa",
    "Exercise" : "Harjoitukset",
    "Work out" : "Bodausta",
    "Working out" : "Kuntosali",
    "Gym" : "Sali",
    "Barber" : "Parturi",
    "Haircut" : "Kampaamo",
    "Hairdresser" : "Kampaaja",
    "Exam" : "Koe",
    "Written test" : "Kirjallinen testi",
    "Oral test" : "Suullinen testi",
    "Working" : "Töitä",
    "New Years Eve" : "Uudenvuodenaatto",
    "NYE" : "NYE",
    "Fireworks" : "Ilotulitus",
    "Running" : "Juoksua",
    "Go for a run" : "Mene lenkille",
    "Marathon" : "Maraton",
    "Video-conference" : "Videokonfrenssi",
    "Conference-call" : "Neuvottelupuhelu",
    "Video-call" : "Videopuhelu",
    "Video-chat" : "Videokeskustelu",
    "Video-meeting" : "Videokokous",
    "Call" : "Puhelu",
    "Calling" : "Puhelu",
    "Christmas" : "Joulu",
    "Conference" : "Konfrenssi",
    "Pizza" : "Pizza",
    "Travelling" : "Reissaamista",
    "Trip" : "Matka",
    "Journey" : "Matka",
    "Collaborate" : "Yhteistyötä",
    "Pair" : "Yhdistä",
    "Lecture" : "Luento",
    "Seminar" : "Seminaari",
    "Teaching" : "Opettamista",
    "Photograph" : "Valokuvaus",
    "Party" : "Juhlat",
    "Celebration" : "Juhlintaa",
    "Celebrate" : "Juhli",
    "Birthday" : "Syntymäpäivä",
    "Shopping" : "Ostokset",
    "Groceries" : "Ostokset",
    "Skate" : "Skeittausta",
    "Skateboard" : "Skeittaus",
    "Wine tasting" : "Viininmaistelu",
    "Golf" : "Golf",
    "Dinner" : "Illallinen",
    "Lunch" : "Lounas",
    "Appointment not found" : "Tapaamista ei löydy",
    "User not found" : "Käyttäjää ei löydy"
},
"nplurals=2; plural=(n != 1);");
