OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s хэрэглэгч »%s« календарийг нийтлэв",
    "Hello," : "Сайн байна уу",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s хэрэглэгч нь  »%s« календарийг нийтэлснийг үүгээр мэдэгдэе.",
    "Open »%s«" : "»%s« нээх",
    "Cheers!" : "Болж байна!",
    "Confirm" : "Батлах",
    "Calendar" : "Календарь",
    "New event" : "Шинэ үйл явдал",
    "Today" : "Өнөөдөр",
    "Day" : "Өдөр",
    "Week" : "Долоо хоног",
    "Month" : "Сар",
    "Preview" : "шалгах",
    "Copy link" : "Холбоос хуулах",
    "Edit" : "засварлах",
    "Delete" : "Устгах",
    "Export" : "Экспорт",
    "Share link" : "Холбоос хуваалцах",
    "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
    "can edit" : "засаж чадна",
    "New calendar" : "Шинэ цагийн хуваарь",
    "Name" : "Нэр",
    "Deleted" : "Устгагдсан",
    "Restore" : "Сэргээх",
    "Delete permanently" : "бүр мөсөн устгах",
    "Filename" : "Файлын нэр",
    "Cancel" : "Цуцлах",
    "Actions" : "Үйл ажиллагаа",
    "Show week numbers" : "7 хоногийн дугаарыг харуулах",
    "Location" : "Байршил",
    "Description" : "Тодорхойлолт",
    "to" : "Дуусах нь",
    "Add" : "нэмэх",
    "Monday" : "даваа",
    "Tuesday" : "мягмар",
    "Wednesday" : "лхагва",
    "Thursday" : "пүрэв",
    "Friday" : "баасан",
    "Saturday" : "бямба",
    "Sunday" : "ням гариг",
    "Save" : "Хадгалах",
    "Update" : "Шинэчлэх",
    "Notification" : "Мэдэгдэл",
    "Email" : "Цахим шуудан",
    "Available" : "Боломжтой",
    "Unknown" : "Үл танигдах зүйл",
    "Accept" : "Хүлээн зөвшөөрөх",
    "Decline" : "Зөвшөөрөхгүй",
    "Tentative" : "Урьдчилсан тов",
    "Repeat" : "Давтах",
    "never" : "хэзээ ч үгүй",
    "after" : "дараа",
    "More" : "Дэлгэрэнгүй",
    "Global" : "Нийтийн",
    "Personal" : "Хувийн",
    "Details" : "Дэлгэрэнгүй",
    "Attendees" : "Оролцогчид",
    "Close" : "Хаах",
    "Week {number} of {year}" : "{year} оны {number}-р долоо хоног ",
    "Daily" : "Өдөр бүр",
    "Weekly" : "Долоо хоног бүр",
    "Next" : "дараагийх",
    "Other" : "Бусад",
    "When shared show full event" : "Түгээсэн тохиолдолд үйл явдлыг бүтнээр нь харуул",
    "When shared show only busy" : "Түгээсэн тохиолдолд зөвхөн завгүй гэж харуул",
    "When shared hide this event" : "Түгээсэн тохиолдолд энэ үйл явдлыг нуу",
    "Status" : "төлөв",
    "Confirmed" : "Баталгаажсан",
    "Categories" : "төрөл",
    "Mail" : "Цахим шуудан",
    "Birthday" : "Төрсөн өдөр"
},
"nplurals=2; plural=(n != 1);");
