OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "نشست کاربر به طور غیر منتظره منقضی شد",
    "Provided email-address is not valid" : "ایمیل ارائه شده معتبر نیست",
    "%s has published the calendar »%s«" : "%sتقویم %s را منتشر کرده است.",
    "Unexpected error sending email. Please contact your administrator." : "خطای غیر منتظره در ارسال ایمیل. لطفا با مدیر خود تماس بگیرید.",
    "Hello," : "سلام،",
    "We wanted to inform you that %s has published the calendar »%s«." : "مایل هستیم به شما اطلاع دهیم که %s تقویم شماره %s را منتشر کرده است.",
    "Open »%s«" : "باز کن »%s«",
    "Cheers!" : "سلامتی!",
    "Upcoming events" : "رویدادهای پیش‌رو",
    "Appointments" : "قرارها",
    "Confirm" : "تائید",
    "Date:" : "تاریخ:",
    "Where:" : "مکان:",
    "Calendar" : "تقویم",
    "A Calendar app for Nextcloud" : "یک برنامه تقویم برای نکست کلود",
    "Previous day" : "روز قبل",
    "Previous week" : "هفته قبل",
    "Previous month" : "ماه قبل",
    "Next day" : "روز بعد",
    "Next week" : "هفته بعد",
    "Next month" : "ماه بعد",
    "New event" : "رویداد جدید",
    "Today" : "امروز",
    "Day" : "روز",
    "Week" : "هفته",
    "Month" : "ماه",
    "List" : "لیست",
    "Preview" : "پیش‌نمایش",
    "Copy link" : "کپی کردن لینک",
    "Edit" : "ویرایش",
    "Delete" : "حذف",
    "Add new" : "افزودن مورد تازه",
    "Untitled calendar" : "تقویم بدون عنوان",
    "Edit name" : "ویرایش نام",
    "Saving name …" : "ذخیره نام",
    "Edit color" : "ویرایش رنگ",
    "Saving color …" : "ذخیره رنگ",
    "Copy private link" : "کپی کردن پیوند خصوصی",
    "Export" : "دریافت خروجی",
    "Unshare from me" : "بی خبر از من",
    "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
    "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
    "An error occurred, unable to rename the calendar." : "خطایی روی داد ، قادر به تغییر نام تقویم نیست.",
    "An error occurred, unable to change the calendar's color." : "خطایی روی داد ، قادر به تغییر رنگ تقویم نیست.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه","اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه ها"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["حذف تقویم در {شمارش معکوس} ثانیه ها","حذف تقویم در {شمارش معکوس} ثانیه ها"],
    "Share link" : "لینک را به اشتراک بگذارید",
    "Publish calendar" : "تقویم را منتشر کنید",
    "Publishing calendar" : "در حال انتشار تقویم ",
    "Copy public link" : "پیوند عمومی را کپی کنید",
    "Send link to calendar via email" : "ارسال پیوند به تقویم از طریق ایمیل",
    "Enter one address" : "یک آدرس وارد کنید",
    "Sending email …" : "ارسال ایمیل…",
    "Copy subscription link" : "پیوند اشتراک را کپی کنید",
    "Copying link …" : "کپی پیوند ...",
    "Copied link" : "پیوند کپی شد",
    "Could not copy link" : "نمی توان پیوند را کپی کرد",
    "Copy embedding code" : "کد تعبیه شده را کپی کنید",
    "Copying code …" : "کپی کردن کد ...",
    "Copied code" : "کد کپی شد",
    "Could not copy code" : "نمی توان کد را کپی کرد",
    "Delete share link" : "پیوند اشتراک را حذف کنید",
    "Deleting share link …" : "در حال حذف پیوند اشتراک ...",
    "An error occurred, unable to publish calendar." : "خطایی روی داد ، قادر به انتشار تقویم نیست.",
    "An error occurred, unable to send email." : "خطایی روی داد ، قادر به ارسال ایمیل نیست.",
    "Embed code copied to clipboard." : "کد قرار داده شده در حافظه کپی شد.",
    "Embed code could not be copied to clipboard." : "کد جاسازی را نمی توان در کلیپ بورد کپی کرد.",
    "Unpublishing calendar failed" : "عدم انتشار تقویم موفقیت آمیز نبود",
    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
    "can edit" : "می توان ویرایش کرد",
    "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "خطایی روی داد ، قادر به تغییر تقویم عدم اشتراک گذاری نیست.",
    "An error occurred, unable to change the permission of the share." : "خطایی روی داد ، قادر به تغییر مجوز اشتراک نیست.",
    "New calendar" : "تقویم جدید",
    "Creating calendar …" : "ایجاد تقویم ...",
    "New calendar with task list" : "تقویم جدید با لیست کارها",
    "New subscription from link (read-only)" : "اشتراک جدید از پیوند (فقط خواندنی)",
    "Creating subscription …" : "ایجاد اشتراک…",
    "An error occurred, unable to create the calendar." : "خطایی روی داد ، قادر به ایجاد تقویم نیست.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "لطفاً یک پیوند معتبر وارد کنید (با شروع http: // ، https: // ، webcal: // ، یا صفحات وب: //)",
    "Trash bin" : "زباله‌دان",
    "Name" : "نام",
    "Deleted" : "حذف شده",
    "Restore" : "بازیابی",
    "Delete permanently" : "حذف قطعی",
    "Empty trash bin" : "خالی کردن سطل زباله",
    "Import calendars" : "وارد کردن تقویم ها",
    "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
    "Filename" : "نام فایل",
    "Calendar to import into" : "تقویم برای وارد کردن",
    "Cancel" : "منصرف شدن",
    "_Import calendar_::_Import calendars_" : ["وارد کردن تقویم","وارد کردن تقویم ها"],
    "Import partially failed. Imported {accepted} out of {total}." : "وارد کردن تا حدودی انجام نشد. وارد شده {accepted} بیرون از {total}.",
    "Automatic" : "خودکار",
    "Automatic ({detected})" : "خودکار ({شناسایی})",
    "New setting was not saved successfully." : "تنظیم جدید با موفقیت ذخیره نشد.",
    "or" : "یا",
    "List view" : "نمایش لیست",
    "Actions" : "فعالیت ها",
    "Enable birthday calendar" : "تقویم تولد را فعال کنید",
    "Enable simplified editor" : "ویرایشگر ساده شده را فعال کنید",
    "Show weekends" : "آخر هفته ها را نشان دهید",
    "Show week numbers" : "نمایش شماره های هفته",
    "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
    "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
    "Calendar settings" : "تنظیمات تقویم",
    "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
    "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
    "Location" : "محل",
    "Description" : "توضیحات",
    "Duration" : "مدت زمان",
    "to" : "به",
    "Add" : "افزودن",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنجشنبه",
    "Friday" : "جمعه",
    "Saturday" : "شنبه",
    "Sunday" : "یکشنبه",
    "Save" : "ذخیره",
    "Update" : "به روز رسانی",
    "Your email address" : "پست الکترونیکی شما",
    "before at" : "قبل از در",
    "Notification" : "اطلاع",
    "Email" : "ایمیل",
    "Audio notification" : "اعلان صوتی",
    "Other notification" : "سایر اعلان ها",
    "Relative to event" : "نسبت به واقعه",
    "On date" : "در تاریخ",
    "Edit time" : "ویرایش زمان",
    "Save time" : "صرفه جویی در وقت",
    "Remove reminder" : "یادآوری را حذف کنید",
    "on" : "بر",
    "at" : "در",
    "+ Add reminder" : "+ اضافه کردن یادآوری",
    "_second_::_seconds_" : ["ثانیه","ثانیه ها"],
    "_minute_::_minutes_" : ["دقایق","دقیقه ها"],
    "_hour_::_hours_" : ["ساعت","ساعت ها"],
    "_day_::_days_" : ["روز","روز ها"],
    "_week_::_weeks_" : ["هفته","هفته ها"],
    "Available" : "در دسترس",
    "Availability of attendees, resources and rooms" : "در دسترس بودن شرکت کنندگان ، منابع و اتاق ها",
    "Free" : "رایگان",
    "Busy (tentative)" : "مشغول (آزمایشی)",
    "Busy" : "مشغول",
    "Out of office" : "بیرون از دفتر",
    "Unknown" : "نامشخص",
    "Accept" : "تایید",
    "Decline" : "کاهش می یابد",
    "Tentative" : "آزمایشی",
    "Create Talk room for this event" : "اتاق گفتگو را برای این رویداد ایجاد کنید",
    "Show busy times" : " نمایش  زمان‌های  شلوغ",
    "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
    "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
    "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
    "Send email" : "ارسال ایمیل",
    "Chairperson" : "رئیس",
    "Required participant" : "شرکت کننده مورد نیاز",
    "Optional participant" : "شرکت کننده اختیاری",
    "Non-participant" : "غیر شرکت کننده",
    "Remove attendee" : "شرکت کننده را حذف کنید",
    "No match found" : "هیچ تطبیقی یافت نشد",
    "(organizer)" : "(تنظیم کننده)",
    "Event title" : "عنوان رویداد",
    "All day" : "تمام روز",
    "from {startDate}" : "از {startDate}",
    "from {startDate} at {startTime}" : "از {startDate} در {startTime}",
    "to {endDate}" : "به {endDate}",
    "to {endDate} at {endTime}" : "به {endDate} در {endTime}",
    "Repeat" : "تکرار",
    "End repeat" : "پایان تکرار ",
    "Select to end repeat" : "برای پایان دادن به تکرار انتخاب کنید",
    "never" : "هرگز",
    "on date" : "در تاریخ",
    "after" : "بعد از",
    "_time_::_times_" : ["بار","بارها"],
    "first" : "اولین",
    "third" : "سوم",
    "fourth" : "چهارم",
    "fifth" : "پنجم",
    "second to last" : "دوم تا آخرین",
    "last" : "آخر",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "تغییر در قانون بازگشتی فقط در مورد این و همه وقایع آینده اعمال خواهد شد.",
    "Repeat every" : "همه را تکرار کنید",
    "By day of the month" : "تا روز ماه",
    "On the" : "در",
    "_month_::_months_" : ["ماه","ماه ها"],
    "_year_::_years_" : ["سال","سال ها"],
    "weekday" : "روز هفته",
    "weekend day" : " آخر  هفته",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "تعریف بازگشتی از این رویداد توسط نکست کلود کاملاً پشتیبانی نمی شود. اگر گزینه های بازگشتی را ویرایش کنید ، ممکن است بازگشتی های خاصی از بین بروند.",
    "available" : "در دسترس",
    "More" : "بیش‌تر",
    "Update this occurrence" : "این رویداد را به روز کنید",
    "Update this and all future" : "این و همه آینده را به روز کنید",
    "Public calendar does not exist" : "تقویم عمومی وجود ندارد",
    "Maybe the share was deleted or has expired?" : "شاید اشتراک حذف شده باشد یا منقضی شده باشد؟",
    "from {formattedDate}" : "از {formattedDate}",
    "to {formattedDate}" : "به {formattedDate}",
    "on {formattedDate}" : "در {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "از {formattedDate} در {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "به {formattedDate} در {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "در {formattedDate} در {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} در {formattedTime}",
    "Please enter a valid date" : "لطفا یک تاریخ معتبر وارد کنید",
    "Please enter a valid date and time" : "لطفاً یک تاریخ و زمان معتبر وارد کنید",
    "Global" : "عمومی",
    "Personal" : "شخصی",
    "No more events today" : "هیچ رویداد دیگری برای امروز وجود ندارد",
    "No upcoming events" : "رویداد پیش‌رویی وجود ندارد",
    "Event does not exist" : "رویداد وجود ندارد",
    "Delete this occurrence" : "این رخداد را حذف کنید",
    "Delete this and all future" : "این و همه آینده را حذف کنید",
    "Details" : "جزئیات",
    "Attendees" : "شرکت کنندگان",
    "Resources" : "منابع",
    "Close" : "بستن",
    "Show more details" : "جزئیات بیشتر را نشان دهید",
    "Subscribe to {name}" : "اشتراک در {name}",
    "Export {name}" : "دریافت خروجی از {name}",
    "Anniversary" : "سالگرد",
    "Appointment" : "وقت ملاقات",
    "Business" : "کسب و کار",
    "Education" : "تحصیلات",
    "Holiday" : "تعطیلات",
    "Meeting" : "ملاقات",
    "Miscellaneous" : "متفرقه",
    "Non-working hours" : "ساعات غیر کاری",
    "Not in office" : "در دفتر نیست",
    "Phone call" : "تماس تلفنی",
    "Sick day" : "روز بیماری",
    "Special occasion" : "مناسبت ویژه",
    "Travel" : "مسافرت رفتن",
    "Vacation" : "تعطیلات",
    "Midnight on the day the event starts" : "نیمه شب در روز آغاز این رویداد",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n روز قبل از این رویداد در {formattedHourMinute}","%n روزهای قبل از این رویداد در {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n هفته قبل از این رویداد در {formattedHourMinute}","%n هفته قبل از این رویدادها در {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "در روز رویداد در {formattedHourMinute}",
    "at the event's start" : "در شروع رویداد",
    "at the event's end" : "در پایان رویداد",
    "{time} before the event starts" : "{زمان} قبل از شروع رویداد",
    "{time} before the event ends" : "{زمان} قبل از پایان این رویداد",
    "{time} after the event starts" : "{زمان} بعد از شروع رویداد",
    "{time} after the event ends" : "{زمان} پس از پایان این رویداد",
    "on {time}" : "به {موقع}",
    "on {time} ({timezoneId})" : "در {time} ({timezoneId})",
    "Week {number} of {year}" : "هفته {number} از {year}",
    "Does not repeat" : "تکرار نمی کند",
    "Daily" : "روزانه",
    "Weekly" : "هفته گی",
    "Monthly" : "ماهانه",
    "Yearly" : "سالانه",
    "_Every %n day_::_Every %n days_" : ["هر %n روز","هر %n روزها"],
    "_Every %n week_::_Every %n weeks_" : ["هر %n هفته","هر %n هفته"],
    "_Every %n month_::_Every %n months_" : ["هر %n ماه","هر %n ماه ها"],
    "_Every %n year_::_Every %n years_" : ["هر %n سال","هر %n سال ها"],
    "_on {weekday}_::_on {weekdays}_" : ["در {weekday}","در {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["در روز {dayOfMonthList}","در روزها {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "روی {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "درون {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "در {monthNames} در {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "تا زمان {untilDate}",
    "_%n time_::_%n times_" : ["%n بار","%n بارها"],
    "Untitled event" : "رویداد بدون عنوان",
    "Prev" : "مقدمه",
    "Next" : "بعدی",
    "Year" : "سال",
    "No events to display" : "هیچ رویدادی برای نمایش وجود ندارد",
    "_+%n more_::_+%n more_" : ["+%n بیشتر","+%n بیشتر"],
    "No events" : "رویدادی وجود ندارد",
    "Create a new event or change the visible time-range" : "یک رویداد تازه بسازید یا بازه زمانی خود را تغییر بدهید",
    "Other" : "دیگر",
    "When shared show" : "هنگام نمایش مشترک",
    "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
    "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
    "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک.",
    "Add a location" : "افزودن یک محل",
    "Add a description" : "یک توضیح بنویسید",
    "Status" : "وضعیت",
    "Confirmed" : "تایید شده",
    "Confirmation about the overall status of the event." : "تأیید درباره وضعیت کلی این رویداد.",
    "Show as" : "نمایش به عنوان",
    "Take this event into account when calculating free-busy information." : "هنگام محاسبه اطلاعات شلوغ رایگان ، این رویداد را در نظر بگیرید.",
    "Categories" : "دسته بندی ها",
    "Categories help you to structure and organize your events." : "دسته بندی ها به شما کمک می کنند تا وقایع خود را تنظیم و سازماندهی کنید.",
    "Search or add categories" : "دسته ها را جستجو یا اضافه کنید",
    "Add this as a new category" : "این را به عنوان یک دسته جدید اضافه کنید",
    "Custom color" : "رنگ سفارشی",
    "Special color of this event. Overrides the calendar-color." : "رنگ ویژه این رویداد. رنگ تقویم را نادیده می گیرد.",
    "Chat room for event" : "اتاق گپ برای رویداد",
    "Imported {filename}" : "وارد شده {نام پرونده}",
    "Meditation" : "مراقبه",
    "Relaxing" : "آرامش بخش",
    "Relax" : "آروم باش",
    "Commuting" : "رفت و آمد",
    "Money" : "پول",
    "Presentation" : "ارائه",
    "Talk" : "گفتگو",
    "Camping" : "چادر زدن",
    "Camp" : "اردوگاه",
    "Movie" : "فیلم",
    "Cinema" : "سینما",
    "Graduation" : "فارغ التحصیلی",
    "Brainstorm" : "ایده پردازی",
    "Review" : "مرور",
    "Baseball" : "بیسبال",
    "Meet" : "ملاقات",
    "Planning" : "برنامه ریزی",
    "Pointing" : "اشاره",
    "Retrospective" : "گذشته نگر",
    "Office" : "دفتر",
    "Contributor week" : "هفته مشارکت کننده",
    "Mail" : "ایمیل",
    "Soccer" : "فوتبال",
    "Football" : "فوتبال",
    "Gaming" : "بازی",
    "Drive" : "راندن",
    "Bicycle" : "دوچرخه",
    "Cycle" : "چرخه",
    "Biking" : "دوچرخه سواری",
    "Podcast" : "پادکست",
    "Basketball" : "بسکتبال",
    "Fishing" : "ماهیگیری",
    "Hiking" : "پیاده روی",
    "Hike" : "پیاده روی",
    "Art" : "هنر",
    "Exhibition" : "نمایشگاه",
    "Museum" : "موزه",
    "Pilates" : "پیلاتس",
    "Park" : "پارک",
    "Studying" : "در حال مطالعه",
    "Doctor" : "دکتر",
    "Health" : "سلامتی",
    "Dentist" : "دندانپزشک",
    "Hospital" : "بیمارستان",
    "Interview" : "مصاحبه",
    "Training" : "آموزش",
    "Practice" : "تمرین",
    "Sports" : "ورزش ها",
    "Exercise" : "ورزش",
    "Work out" : "کار کردن",
    "Working out" : "کار کردن",
    "Gym" : "سالن ورزش",
    "Barber" : "سلمانی",
    "Haircut" : "اصلاح مو",
    "Exam" : "امتحان",
    "Working" : "کار کردن",
    "New Years Eve" : "سال نو",
    "NYE" : "NYE",
    "Fireworks" : "آتش بازی",
    "Running" : "در حال دویدن",
    "Go for a run" : "برو برای اجرا",
    "Marathon" : "ماراتن",
    "Call" : "زنگ زدن",
    "Calling" : "صدا زدن",
    "Christmas" : "کریسمس",
    "Conference" : "کنفرانس",
    "Pizza" : "پیتزا",
    "Travelling" : "مسافرت",
    "Journey" : "سفر",
    "Collaborate" : "همکاری",
    "Pair" : "جفت",
    "Lecture" : "سخنرانی",
    "Seminar" : "سمینار",
    "Photograph" : "عکس",
    "Party" : "مهمانی - جشن",
    "Celebration" : "جشن",
    "Celebrate" : "جشن گرفتن",
    "Birthday" : "روزتولد",
    "Shopping" : "خريد كردن",
    "Skate" : "اسکیت",
    "Skateboard" : "صفحه اسکیت",
    "Wine tasting" : "مزه کردن شراب",
    "Golf" : "گلف",
    "Dinner" : "شام",
    "Lunch" : "ناهار",
    "User not found" : "کاربر یافت نشد"
},
"nplurals=2; plural=(n > 1);");
