OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Gebruikerssessie onverwacht vervallen",
    "Provided email-address is not valid" : "Het opgegeven e-mailadres is niet geldig",
    "%s has published the calendar »%s«" : "%s heeft de kalender gepubliceerd \"%s\"",
    "Unexpected error sending email. Please contact your administrator." : "Kon e-mail niet versturen. Neem contact op met je beheerder.",
    "Successfully sent email to %1$s" : "E-mail is succesvol verzonden naar %1$s",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "We willen je laten weten dat %s de agenda %s heeft gepubliceerd.",
    "Open »%s«" : "Open \"%s\"",
    "Cheers!" : "Proficiat!",
    "Upcoming events" : "Aanstaande activiteiten",
    "Appointments" : "Afspraken",
    "Schedule appointment \"%s\"" : "Plan afspraak \"%s\"",
    "Schedule an appointment" : "Plan een afspraak",
    "Prepare for %s" : "Voorbereiden op %s",
    "Follow up for %s" : "Follow-up voor %s",
    "Dear %s, please confirm your booking" : "Beste %s, bevestig alsjeblieft je boeking",
    "Confirm" : "Bevestigen",
    "This confirmation link expires in %s hours." : "Deze bevestigingslink verloopt over %s uur.",
    "Date:" : "Datum:",
    "Where:" : "Waar:",
    "Calendar" : "Agenda",
    "A Calendar app for Nextcloud" : "Een agenda-app voor Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "De Calendar app is een toegang tot de Nextcloud CalDAV server. Synchroniseer makkelijk activiteiten tussen al je toestellen dank zij Nextcloud en wijzig ze online.\n\n* 🚀 **Integratie met andere Nextcloud apps!** Momenteel Contacten - er komen er nog.\n* 🌐 **WebCal Ondersteuning!** Wil je je de speeldagen van je favoriete ploeg in je calendar zien? Geen probleem!\n* 🙋 **Genodigden!** Nodig mensen uit op je activiteiten\n* ⌚️ **Beschikbaar/Bezet!** Zie wanneer je genodigden beschikbaar zijn om af te spreken\n* ⏰ **Herinneringen!** Ontvang waarschuwingen voor activiteiten in je browser en via email\n* 🔍 Zoek! Vind je activiteiten makkelijk terug\n* ☑️ Taken! Zie taken met een gewenste datum direct in de calendar\n* 🙈 **We gaan het wiel niet heruitvinden!** Gebaseerd op de krachtige [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) en [fullcalendar](https://github.com/fullcalendar/fullcalendar) bibliotheken.",
    "Previous day" : "Vorige dag",
    "Previous week" : "Vorige week",
    "Previous month" : "Vorige maand",
    "Next day" : "Volgende dag",
    "Next week" : "Volgende week",
    "Next month" : "Volgende maand",
    "New event" : "Nieuwe afspraak",
    "Today" : "Vandaag",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "List" : "Lijst",
    "Preview" : "Voorbeeld",
    "Copy link" : "Link kopiëren",
    "Edit" : "Bewerk",
    "Delete" : "Verwijderen",
    "Appointment link was copied to clipboard" : "Afspraaklink gekopieerd naar klembord",
    "Appointment link could not be copied to clipboard" : "Afspraaklink kon niet naar klembord gekopieerd worden",
    "Add new" : "Nieuwe toevoegen",
    "Untitled calendar" : "Naamloze calender",
    "Edit name" : "Naam bewerken",
    "Saving name …" : "Opslaan naam ...",
    "Edit color" : "Kleur bewerken",
    "Saving color …" : "Opslaan kleur ...",
    "Copy private link" : "Privélink kopiëren",
    "Export" : "Exporteren",
    "Unshare from me" : "Stop delen met mij",
    "Disable calendar \"{calendar}\"" : "Maak agenda \"{calendar}\" onbeschikbaar",
    "Disable untitled calendar" : "Maak naamloze agenda onbeschikbaar",
    "Enable calendar \"{calendar}\"" : "Maak agenda \"{calendar}\" beschikbaar",
    "Enable untitled calendar" : "Maak naamloze agenda beschikbaar",
    "An error occurred, unable to change visibility of the calendar." : "Er is een fout opgetreden waardoor de zichtbaarheid van de agenda niet kan worden gewijzigd.",
    "An error occurred, unable to delete the calendar." : "Er is een fout opgetreden waardoor de agenda niet kan worden verwijderd.",
    "Calendar link copied to clipboard." : "Agendalink gekopiëerd naar klembord",
    "Calendar link could not be copied to clipboard." : "De agendalink kon niet naar het klembord worden gekopieerd.",
    "An error occurred, unable to rename the calendar." : "Er is een fout opgetreden waardoor de agenda niet kan worden hernoemd.",
    "An error occurred, unable to change the calendar's color." : "Er is een fout opgetreden, de kleur van de agenda kan niet worden gewijzigd.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Het delen van de agenda wordt in {countdown} seconde gestopt","Het delen van de agenda wordt in {countdown} seconden gestopt"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Agenda wordt verwijderd in {countdown} seconde","Agenda wordt verwijderd in {countdown} seconden"],
    "Share link" : "Delen link",
    "Publish calendar" : "Agenda publiceren",
    "Publishing calendar" : "Agenda publiceren",
    "Copy public link" : "Kopieer openbare link",
    "Send link to calendar via email" : "Stuur link naar de agenda via e-mail",
    "Enter one address" : "Geef één adres op",
    "Sending email …" : "Versturen e-mail …",
    "Copy subscription link" : "Kopieer abonnementslink",
    "Copying link …" : "Kopiëren link …",
    "Copied link" : "Link gekopieerd",
    "Could not copy link" : "Kan link niet kopiëren",
    "Copy embedding code" : "Kopieer embedded code",
    "Copying code …" : "Kopiëren code  ...",
    "Copied code" : "Code gekopieerd",
    "Could not copy code" : "Kan code niet kopiëren",
    "Delete share link" : "Verwijder deellink",
    "Deleting share link …" : "Verwijderen deellink ...",
    "An error occurred, unable to publish calendar." : "Er is een fout opgetreden, kan agenda niet publiceren.",
    "An error occurred, unable to send email." : "Er is een fout opgetreden, kon e-mail niet versturen.",
    "Embed code copied to clipboard." : "Embed code gekopieerd naar klembord",
    "Embed code could not be copied to clipboard." : "Embed code kan niet gekopieerd worden naar klembord",
    "Unpublishing calendar failed" : "Agenda depubliceren is niet gelukt",
    "Share with users or groups" : "Deel met gebruikers of groepen",
    "No users or groups" : "Geen gebruikers of groepen",
    "can edit" : "kan wijzigen",
    "Unshare with {displayName}" : "Stop delen met {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Er is een fout opgetreden waardoor het wijzigen van het delen van de agenda niet gelukt is.",
    "An error occurred, unable to change the permission of the share." : "Er is een fout opgetreden, het is niet mogelijk om de machtiging van de share te wijzigen",
    "New calendar" : "Nieuwe agenda",
    "Name for new calendar" : "Naam van nieuwe kalender",
    "Creating calendar …" : "Creëren agenda ...",
    "New calendar with task list" : "Nieuwe agenda met taak lijst",
    "New subscription from link (read-only)" : "Nieuw abonnement via link (alleen lezen)",
    "Creating subscription …" : "Creëren abonnement ...",
    "An error occurred, unable to create the calendar." : "Er is een fout opgetreden waardoor het niet mogelijk is om de agenda te creëren.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Geef geldige urls op - die moeten starten met http://, https://, webcal:// of webcals://",
    "Trash bin" : "Prullenbak",
    "You do not have any deleted items." : "Je hebt geen verwijderde items.",
    "Name" : "Naam",
    "Deleted" : "Verwijderd",
    "Restore" : "Herstellen",
    "Delete permanently" : "Definitief verwijderen",
    "Empty trash bin" : "Leeg de prullenbak",
    "Untitled item" : "Object zonder titel",
    "Unknown calendar" : "Onbekende kalender",
    "Could not load deleted calendars and objects" : "Kon de verwijderde agenda en objecten niet herstellen",
    "Could not restore calendar or event" : "Kon de agenda en objecten niet herstellen",
    "Do you really want to empty the trash bin?" : "Wil je de prullenbak echt leegmaken?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Items in de prullenmand worden na {numDays} dag verwijderd","Items in de prullenmand worden na {numDays} dagen verwijderd"],
    "Could not update calendar order." : "Kon de volgorde van agenda's niet bijwerken.",
    "Import calendars" : "Importeer agenda's",
    "Please select a calendar to import into …" : "Selecteer een agenda om naar te importeren  ...",
    "Filename" : "Bestandsnaam",
    "Calendar to import into" : "Agenda om naar te importeren",
    "Cancel" : "Annuleren",
    "_Import calendar_::_Import calendars_" : ["Importeer agenda","Importeer agenda's"],
    "{filename} could not be parsed" : "{filename} kon niet worden geanalyseerd",
    "No valid files found, aborting import" : "Geen geldige bestand gevonden, import afgebroken",
    "Import partially failed. Imported {accepted} out of {total}." : "Import is gedeeltelijk gelukt. Geïmporteerd {accepted} van de {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%nafspraak succesvol geïmporteerd","%n afspraken succesvol geïmporteerd"],
    "Automatic" : "Automatisch",
    "Automatic ({detected})" : "Automatisch ({detected})",
    "New setting was not saved successfully." : "De nieuwe instelling is niet goed opgeslagen.",
    "Shortcut overview" : "Snelkoppeling overzicht",
    "or" : "of",
    "Navigation" : "Navigatie",
    "Previous period" : "Vorige periode",
    "Next period" : "Volgende periode",
    "Views" : "Bekeken",
    "Day view" : "Dagoverzicht",
    "Week view" : "Weekoverzicht",
    "Month view" : "Maandoverzicht",
    "List view" : "Lijstweergave",
    "Actions" : "Acties",
    "Create event" : "Creëer afspraak",
    "Show shortcuts" : "Toon sneltoetsen",
    "Editor" : "Editor",
    "Close editor" : "Sluit editor",
    "Save edited event" : "Aangepaste afspraak opslaan",
    "Delete edited event" : "Aangepaste afspraak verwijderen",
    "Duplicate event" : "Duplicaat afspraak",
    "Enable birthday calendar" : "Verjaardagskalender inschakelen",
    "Show tasks in calendar" : "Toon taken in agenda",
    "Enable simplified editor" : "Eenvoudige editor inschakelen",
    "Limit visible events per view" : "Beperk aantal zichtbare afspraken per overzicht",
    "Show weekends" : "Toon weekenden",
    "Show week numbers" : "Tonen weeknummers",
    "Time increments" : "Time-toename",
    "Default reminder" : "Standaard herinnering",
    "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
    "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
    "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
    "Show keyboard shortcuts" : "Toon sneltoetsen",
    "Calendar settings" : "Agenda instellingen",
    "No reminder" : "Geen herinnering",
    "CalDAV link copied to clipboard." : "CalDAV link gekopiëerd naar klembord.",
    "CalDAV link could not be copied to clipboard." : "CalDAV link kon niet worden gekopieerd naar klembord.",
    "Appointment was created successfully" : "Afspraak succesvol gecreëerd",
    "Appointment was updated successfully" : "Afspraak succesvol geüpdatet",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuut","{duration} minuten"],
    "0 minutes" : "0 minuten",
    "_{duration} hour_::_{duration} hours_" : ["{duration} uur","{duration} uur"],
    "_{duration} day_::_{duration} days_" : ["{duration} dag","{duration} dagen"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} week","{duration} weken"],
    "_{duration} month_::_{duration} months_" : ["{duration} maand","{duration} maanden"],
    "_{duration} year_::_{duration} years_" : ["{duration} jaar","{duration} jaar"],
    "To configure appointments, add your email address in personal settings." : "Om afspraken te configureren, voeg je e-mailadres toe in persoonlijke instellingen.",
    "Public – shown on the profile page" : "Openbaar – zichtbaar op de profielpagina",
    "Private – only accessible via secret link" : "Privé – alleen toegankelijk via geheime link",
    "Location" : "Locatie",
    "Description" : "Omschrijving",
    "Visibility" : "Zichtbaarheid",
    "Duration" : "Duur",
    "Increments" : "Stappen",
    "Additional calendars to check for conflicts" : "Extra agenda's om te controleren op conflicten",
    "Pick time ranges where appointments are allowed" : "Selecteer tijden waar afspraken toegestaan zijn",
    "to" : "aan",
    "Delete slot" : "Verwijder tijdslot",
    "No times set" : "Geen tijden ingesteld",
    "Add" : "Toevoegen",
    "Monday" : "maandag",
    "Tuesday" : "dinsdag",
    "Wednesday" : "woensdag",
    "Thursday" : "donderdag",
    "Friday" : "vrijdag",
    "Saturday" : "zaterdag",
    "Sunday" : "zondag",
    "Add time before and after the event" : "Voeg tijd voor en na afspraak toe",
    "Before the event" : "Voor de afspraak",
    "After the event" : "Na de afspraak",
    "Planning restrictions" : "Planningsbeperkingen",
    "Minimum time before next available slot" : "Minimale tijd voor volgend beschikbaar tijdslot",
    "Max slots per day" : "Max tijdsloten per dag",
    "Limit how far in the future appointments can be booked" : "Beperk hoe in de toekomst afspraken toegevoerd kunnen worden",
    "Create appointment" : "Creëer afspraak",
    "Edit appointment" : "Bewerk afspraak",
    "Save" : "Opslaan",
    "Update" : "Bijwerken",
    "Please confirm your reservation" : "Gelieve jouw reservatie te bevestigen.",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "We hebben je een e-mail met details verzonden. Bevestig je afspraak met de link in de e-mail. Je kunt deze pagina sluiten.",
    "Your name" : "Je naam",
    "Your email address" : "Je e-mailadres",
    "Please share anything that will help prepare for our meeting" : "Deel alsjeblieft alles wat kan helpen in de voorbereiding van de afspraak",
    "Could not book the appointment. Please try again later or contact the organizer." : "Kon afspraak niet boeken. Probeer later opnieuw of neem contact op met de organisator.",
    "Book the appointment" : "Boek de afspraak",
    "Reminder" : "Herinnering",
    "before at" : "ervoor om",
    "Notification" : "Melding",
    "Email" : "Email",
    "Audio notification" : "Audio melding",
    "Other notification" : "Andere melding",
    "Relative to event" : "Relatief tot afspraak",
    "On date" : "Op datum",
    "Edit time" : "Bewerk tijd",
    "Save time" : "Bewaar tijd",
    "Remove reminder" : "Verwijder herinnering",
    "on" : "op",
    "at" : "om",
    "+ Add reminder" : "+ Toevoegen herinnering",
    "Add reminder" : "Voeg herinnering toe",
    "_second_::_seconds_" : ["seconde","seconden"],
    "_minute_::_minutes_" : ["minuut","minuten"],
    "_hour_::_hours_" : ["uur","uren"],
    "_day_::_days_" : ["dag","dagen"],
    "_week_::_weeks_" : ["week","weken"],
    "Invitation accepted" : "Uitnodiging geaccepteerd",
    "Available" : "Beschikbaar",
    "Suggested" : "Aanbevolen",
    "Accepted {organizerName}'s invitation" : "Uitnodiging van {organizerName} aanvaard",
    "Not available" : "Niet beschikbaar",
    "Invitation declined" : "Uitnodiging geweigerd",
    "Declined {organizerName}'s invitation" : "Uitnodiging van {organizerName} geweigerd",
    "Invitation is delegated" : "Uitnodiging is gedelegeerd",
    "Checking availability" : "Beschikbaarheid controleren",
    "Invitation sent" : "Uitnodiging verstuurd",
    "Availability of attendees, resources and rooms" : "Beschikbaarheid van aanwezigen, objecten en ruimtes",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "Free" : "Vrij",
    "Busy (tentative)" : "Bezig (voorlopig)",
    "Busy" : "Bezet",
    "Out of office" : "Niet op kantoor",
    "Unknown" : "Onbekend",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "Tentative" : "Voorlopig",
    "The invitation has been accepted successfully." : "De uitnodiging is succesvol geaccepteerd.",
    "Failed to accept the invitation." : "Aanemen van uitnodiging is mislukt",
    "The invitation has been declined successfully." : "De uitnodiging is succesvol geweigerd.",
    "Failed to decline the invitation." : "Afwijzen van uitnodiging is mislukt",
    "Your participation has been marked as tentative." : "Uw deelname is aangeduid als voorlopig.",
    "Create Talk room for this event" : "Creëer Talk-ruimte voor deze afspraak",
    "Show busy times" : "Toon drukke tijden",
    "No attendees yet" : "Nog geen deelnemers",
    "Successfully appended link to talk room to description." : "Met succes een link naar de gespreksruimte toegevoegd aan de beschrijving.",
    "Error creating Talk room" : "Fout tijdens aanmaken gespreksruimte",
    "Send email" : "Verstuur e-mail",
    "Chairperson" : "Voorzitter",
    "Required participant" : "Vereiste deelnemer",
    "Optional participant" : "Optionele deelnemer",
    "Non-participant" : "Geen deelnemer",
    "Remove attendee" : "Verwijder genodigde",
    "Search for emails, users or contacts" : "Zoek naar e-mails, gebruikers of contactpersonen",
    "No match found" : "Geen overeenkomst gevonden",
    "(organizer)" : "(organisator)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Om uitnodigingen te versturen en antwoorden te behandelen,  [linkopen]voeg je e-mailadres toe in persoonlijke instellingen[linkclose].",
    "Remove color" : "Verwijderen kleur",
    "Event title" : "Afspraaknaam",
    "All day" : "Hele dag",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Het lukt niet om de gehele-dag instelling aan te passen voor afspraken die onderdeel zijn van een herhaalde-set.",
    "from {startDate}" : "vanaf {startDate}",
    "from {startDate} at {startTime}" : "vanaf {startDate} om {startTime}",
    "to {endDate}" : "tot {endDate}",
    "to {endDate} at {endTime}" : "tot {endDate} om {endTime}",
    "Repeat" : "Herhaling",
    "End repeat" : "Beëindig herhalen",
    "Select to end repeat" : "Selecteer om herhaling te beëindigen",
    "never" : "geen",
    "on date" : "op datum",
    "after" : "na",
    "_time_::_times_" : ["keer","keer"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Deze afspraak is een uitzondering van een herhaalde-set. Je kunt hieraan geen herhalingsregel toevoegen.",
    "first" : "eerste",
    "third" : "derde",
    "fourth" : "vierde",
    "fifth" : "vijfde",
    "second to last" : "op 2 na laatste",
    "last" : "laatste",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Wijzigingen op de herhaling zal alleen worden toegepast op deze en toekomstige afspraken.",
    "Repeat every" : "Herhaal elke",
    "By day of the month" : "Op dag van de maand",
    "On the" : "Op de",
    "_month_::_months_" : ["maand","maanden"],
    "_year_::_years_" : ["jaar","jaren"],
    "weekday" : "weekdag",
    "weekend day" : "weekend dag",
    "No recurrence" : "Geen herhaling",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "De herhaal instelling van deze afspraak wordt niet volledig ondersteund door Nextcloud. Als je de herhaal instellingen wijzigt, gaan bepaalde herhalingen mogelijk verloren.",
    "Suggestions" : "Suggesties",
    "No rooms or resources yet" : "Nog geen kamers of bronnen",
    "Add resource" : "Voeg resource toe",
    "Has a projector" : "Heeft een projector",
    "Has a whiteboard" : "Heeft een whiteboard",
    "Wheelchair accessible" : "Rolstoel toegangelijk",
    "Remove resource" : "Verwijder bron",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} plaats","{seatingCapacity} plaatsen"],
    "Projector" : "Projector",
    "Whiteboard" : "Whiteboard",
    "Search for resources or rooms" : "Zoeken naar bronnen of kamers",
    "available" : "beschikbaar",
    "unavailable" : "niet beschikbaar",
    "Room type" : "Kamer type",
    "Any" : "Alle",
    "Minimum seating capacity" : "Minimale zit capaciteit",
    "More" : "Meer",
    "Update this occurrence" : "Update deze afspraak",
    "Update this and all future" : "Update deze en toekomstige",
    "Public calendar does not exist" : "Publieke agenda bestaat niet",
    "Maybe the share was deleted or has expired?" : "Mogelijk is het gedeelde item verwijderd of verlopen?",
    "Please select a time zone:" : "Selecteer een tijdzone:",
    "Pick a time" : "Kies een tijd",
    "Pick a date" : "Kies een datum",
    "from {formattedDate}" : "van {formattedDate}",
    "to {formattedDate}" : "tot {formattedDate}",
    "on {formattedDate}" : "op {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "van {formattedDate} om {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "tot {formattedDate} om {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "op {formattedDate} om {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} om {formattedTime}",
    "Please enter a valid date" : "Geef een geldige datum op",
    "Please enter a valid date and time" : "Geef een geldige datum en tijdstip op",
    "Type to search time zone" : "Type om tijdzone te zoeken",
    "Global" : "Globaal",
    "Select date" : "Selecteer datum",
    "Select slot" : "Selecteer tijdslot",
    "No slots available" : "Geen tijdsloten beschikbaar",
    "The slot for your appointment has been confirmed" : "Het tijdslot van je afspraak is bevestigd",
    "Appointment Details:" : "Afspraak Details:",
    "Time:" : "Tijd:",
    "Booked for:" : "Geboekt voor:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Bedankt. Je boeking van {startDate} tot {endDate} is bevestigd.",
    "Book another appointment:" : "Boek nog een afspraak:",
    "See all available slots" : "Bekijk alle beschikbare tijdsloten",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Het tijdslot voor je afspraak van {startDate} tot {endDate} is niet meer beschikbaar.",
    "Please book a different slot:" : "Boek alsjeblieft een ander tijdslot:",
    "Book an appointment with {name}" : "Boek een afspraak met {name}",
    "No public appointments found for {name}" : "Geen publieke afspraken gevonden voor {name}",
    "Personal" : "Persoonlijk",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "De automatisch gedetecteerde tijdzone is UTC.\nDit komt waarschijnlijk door beveiligingsmaatregelen van je webbrowser. Stel de tijdzone handmatig in bij de agenda-instellingen.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Je ingestelde tijdzone ({timezoneId}) werd niet gevonden. Er wordt teruggevallen op UTC.\nWijzig je tijdzone in instellingen en meld het incident.",
    "No more events today" : "Geen activiteiten meer vandaag",
    "No upcoming events" : "Geen aanstaande activiteiten",
    "Create a new event" : "Maak een nieuwe activiteit",
    "[Today]" : "[Vandaag]",
    "[Tomorrow]" : "[Morgen]",
    "[Yesterday]" : "[Gisteren]",
    "[Last] dddd" : "[Last] dddd",
    "Event does not exist" : "Activiteit bestaat niet",
    "Duplicate" : "Duplicaat",
    "Delete this occurrence" : "Verwijder deze afspraak",
    "Delete this and all future" : "Verwijder deze en toekomstige",
    "Details" : "Details",
    "Attendees" : "Deelnemers",
    "Resources" : "Bronnen",
    "Close" : "Sluiten",
    "Show more details" : "Toon meer details",
    "Subscribe to {name}" : "Abonneren op {name}",
    "Export {name}" : "Exporteer {name}",
    "Anniversary" : "Verjaardag",
    "Appointment" : "Afspraak",
    "Business" : "Zakelijk",
    "Education" : "Onderwijs",
    "Holiday" : "Vakantie",
    "Meeting" : "Vergadering",
    "Miscellaneous" : "Diversen",
    "Non-working hours" : "buiten werkuren",
    "Not in office" : "Niet in het kantoor",
    "Phone call" : "Telefoongesprek",
    "Sick day" : "Ziektedag",
    "Special occasion" : "Bijzondere gelegenheid",
    "Travel" : "Reizen",
    "Vacation" : "Vakantie",
    "Midnight on the day the event starts" : "Middernacht op de dag van de afspraak",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dag voor het begin van de afspraak om {formattedHourMinute}","%n dagen voor het begin van de afspraak om {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n week voor de afspraak om {formattedHourMinute}","%n weken voor de afspraak om {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "op de dag van de afspraak om {formattedHourMinute}",
    "at the event's start" : "bij het begin van de afspraak",
    "at the event's end" : "op het eind van de afspraak",
    "{time} before the event starts" : "{time} voor begin van de afspraak",
    "{time} before the event ends" : "{time} voor het eind van de afspraak",
    "{time} after the event starts" : "{time} na begin van de afspraak",
    "{time} after the event ends" : "{time} na afloop van de afspraak",
    "on {time}" : "om {time}",
    "on {time} ({timezoneId})" : "om {time} ({timezoneId})",
    "Week {number} of {year}" : "Week {number} van {year}",
    "Does not repeat" : "Niet herhalen",
    "Daily" : "Dagelijks",
    "Weekly" : "Wekelijks",
    "Monthly" : "Maandelijks",
    "Yearly" : "Jaarlijks",
    "_Every %n day_::_Every %n days_" : ["Elke dag","Elke%n dag"],
    "_Every %n week_::_Every %n weeks_" : ["Elke week","Elke %n weken"],
    "_Every %n month_::_Every %n months_" : ["Elke maand","Elke %n maand"],
    "_Every %n year_::_Every %n years_" : ["Elk jaar","Elk %n jaar"],
    "_on {weekday}_::_on {weekdays}_" : ["op {weekday}","op {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["op dag {dayOfMonthList}","op de dagen {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "op de {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "in {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "in {monthNames} op de {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "tot {untilDate}",
    "_%n time_::_%n times_" : ["%n keer","%n keer"],
    "Untitled event" : "Afspraken zonder naam",
    "Untitled task" : "Naamloze taak",
    "Please ask your administrator to enable the Tasks App." : "Vraag je beheerder om de Taken App te installeren.",
    "Prev" : "Vorig",
    "Next" : "Volg.",
    "Prev year" : "Vorig jaar",
    "Next year" : "Volgend jaar",
    "Year" : "Jaar",
    "W" : "W",
    "%n more" : "+%n meer",
    "No events to display" : "Geen activiteiten meer te tonen",
    "_+%n more_::_+%n more_" : ["+%n meer","+%n meer"],
    "No events" : "Geen activiteiten",
    "Create a new event or change the visible time-range" : "Maak een nieuwe activiteit of wijzig de zichtbare tijdsperiode",
    "It might have been deleted, or there was a typo in a link" : "Het zou kunnen verwijderd zijn, of er stond een typfout in de link.",
    "It might have been deleted, or there was a typo in the link" : "Het zou kunnen verwijderd zijn, of er stond een typfout in de link.",
    "Meeting room" : "Meetingroom",
    "Lecture hall" : "Collegezaal",
    "Seminar room" : "Seminarroom",
    "Other" : "Andere",
    "When shared show" : "Wanneer gedeeld toon",
    "When shared show full event" : "Wanneer gedeeld, toon gehele afspraak",
    "When shared show only busy" : "Wanneer gedeeld, toon alleen onbeschikbaarheid",
    "When shared hide this event" : "Wanneer gedeeld, verberg deze afspraak",
    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's.",
    "Add a location" : "Een locatie toevoegen",
    "Add a description" : "Voeg een omschrijving toe",
    "Status" : "Status",
    "Confirmed" : "Bevestigd",
    "Canceled" : "Geannuleerd",
    "Confirmation about the overall status of the event." : "Bevestiging over de globale status van de afspraak.",
    "Show as" : "Toon als",
    "Take this event into account when calculating free-busy information." : "Houd rekening met deze afspraak bij het berekenen van vrij-bezetinformatie.",
    "Categories" : "Categorieën",
    "Categories help you to structure and organize your events." : "Categorieën helpen je om je afspraken te structureren en organiseren.",
    "Search or add categories" : "Zoek categorieën of voeg deze toe",
    "Add this as a new category" : "Voeg dit toe als een nieuwe categorie",
    "Custom color" : "Kleur op maat",
    "Special color of this event. Overrides the calendar-color." : "Bijzondere kleur van deze afspraak. Overschrijft de agenda kleur.",
    "Chat room for event" : "Spreekkamer voor afspraak",
    "Imported {filename}" : "Geïmporteerd {filename}",
    "Meditation" : "Meditatie",
    "Relaxing" : "Relaxen",
    "Relax" : "Relax",
    "Break" : "Pauze",
    "Commute" : "Woon-werk",
    "Commuting" : "Woon-werk",
    "Shuttle" : "Shuttle",
    "Invoice" : "Factuur",
    "Finance" : "Financieel",
    "Bank" : "Bank",
    "Money" : "Geld",
    "Wedding" : "Bruiloft",
    "Dog" : "Hond",
    "Concert" : "Concert",
    "Festival" : "Festival",
    "Theater" : "Theater",
    "Theatre" : "Theater",
    "Presentation" : "Presentatie",
    "Talk" : "Talk",
    "Speech" : "Speech",
    "Deadline" : "Deadline",
    "Submission" : "Aanlevering",
    "Reporting" : "Rapportage",
    "Camping" : "Camping",
    "Camp" : "Kamp",
    "Election" : "Verkiezing",
    "Voting" : "Stemming",
    "Vote" : "Stemmen",
    "Barbecue" : "Barbecue",
    "Barbeque" : "Barbeque",
    "Garden" : "Tuin",
    "Farm" : "Boerderij",
    "Movie" : "Film",
    "Cinema" : "Bioscoop",
    "Graduation" : "Uitreiking",
    "Brainstorm" : "Brainstorm",
    "Review" : "Voorbeeld",
    "Audit" : "Audit",
    "Inspection" : "Inspectie",
    "Proofreading" : "Proofreading",
    "Baseball" : "Baseball",
    "Meet" : "Afspraak",
    "Planning" : "Planning",
    "Pointing" : "Wijzend naar",
    "Retrospective" : "Terugblikkend",
    "Office" : "Kantoor",
    "Contributor week" : "Bijdrager week",
    "Mail" : "E-mail",
    "Soccer" : "Voetbal",
    "Football" : "Voetballen",
    "Gaming" : "Gaming",
    "Drive" : "Rijdend",
    "Driving" : "Rijden",
    "Bicycle" : "Fiets",
    "Cycle" : "Fietsen",
    "Cycling" : "Fietsen",
    "Biking" : "Fietsen",
    "Bike" : "Fiets",
    "Podcast" : "Podcast",
    "Basketball" : "Basketball",
    "Fishing" : "Vissen",
    "Hiking" : "Hiking",
    "Hike" : "Hike",
    "Art" : "Kunst",
    "Exhibition" : "Tentoonstelling",
    "Museum" : "Museum",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Walk" : "Wandelen",
    "Studying" : "Studeren",
    "Doctor" : "Dokter",
    "Health" : "Gezondheid",
    "Dentist" : "Tandarts",
    "Hospital" : "Ziekenhuis",
    "Interview" : "Interview",
    "Training" : "Training",
    "Practice" : "Praktijk",
    "Sports" : "Sport",
    "Exercise" : "Oefenen",
    "Work out" : "Trainen",
    "Working out" : "Trainen",
    "Gym" : "Turnles",
    "Barber" : "Kapper",
    "Haircut" : "Kapper",
    "Hairdresser" : "Kapper",
    "Exam" : "Examen",
    "Written test" : "Schrifteleijke overhoring",
    "Oral test" : "Mondelinge overhoring",
    "Working" : "Werk",
    "New Years Eve" : "Oudejaarsavond",
    "NYE" : "Oud en nieuw",
    "Fireworks" : "Vuurwerk",
    "Running" : "Hardlopen",
    "Go for a run" : "Een eindje gaan lopen",
    "Marathon" : "Marathon",
    "Video-conference" : "Video conference",
    "Conference-call" : "Conference call",
    "Video-call" : "Videogesprek",
    "Video-chat" : "Video chat",
    "Video-meeting" : "Video vergadering",
    "Call" : "Gesprek",
    "Calling" : "Bellen",
    "Christmas" : "Kerst",
    "Conference" : "Conferentie",
    "Pizza" : "Pizza",
    "Travelling" : "Reizen",
    "Trip" : "Reis",
    "Journey" : "Reis",
    "Collaborate" : "Samenwerken",
    "Pair" : "Paar",
    "Lecture" : "Lezing",
    "Seminar" : "Seminarie",
    "Teaching" : "Lesgeven",
    "Photograph" : "Foto",
    "Party" : "Party",
    "Celebration" : "Viering",
    "Celebrate" : "Vieren",
    "Birthday" : "Verjaardag",
    "Shopping" : "Winkelen",
    "Groceries" : "Boodschappen",
    "Skate" : "Skate",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Wijnproeverij",
    "Golf" : "Golf",
    "Dinner" : "Diner",
    "Lunch" : "Lunch",
    "Appointment not found" : "Afspraak niet gevonden",
    "User not found" : "Gebruiker niet gevonden"
},
"nplurals=2; plural=(n != 1);");
