OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendar",
    "Today" : "Hari ini",
    "Day" : "Hari",
    "Week" : "Minggu",
    "Month" : "Bulan",
    "Edit" : "Sunting",
    "Delete" : "Padam",
    "Export" : "Eksport",
    "Share link" : "Share link",
    "can edit" : "boleh mengubah",
    "New calendar" : "Kalendar baru",
    "Name" : "Nama",
    "Deleted" : "Dipadam",
    "Restore" : "Pulihkan",
    "Cancel" : "Batal",
    "Location" : "Lokasi",
    "Description" : "Keterangan",
    "to" : "kepada",
    "Add" : "Tambah",
    "Monday" : "Isnin",
    "Tuesday" : "Selasa",
    "Wednesday" : "Rabu",
    "Thursday" : "Khamis",
    "Friday" : "Jumaat",
    "Saturday" : "Sabtu",
    "Sunday" : "Ahad",
    "Save" : "Simpan",
    "Update" : "Kemaskini",
    "Your email address" : "Alamat emel anda",
    "Email" : "Email",
    "Repeat" : "Ulang",
    "never" : "jangan",
    "More" : "Lanjutan",
    "Personal" : "Peribadi",
    "Attendees" : "Jemputan",
    "Close" : "Tutup",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "Next" : "Seterus",
    "Other" : "Lain",
    "Mail" : "Mel",
    "Birthday" : "Hari lahir"
},
"nplurals=1; plural=0;");
