OC.L10N.register(
    "calendar",
    {
    "Calendar" : "يىلنامە",
    "Today" : "بۈگۈن",
    "Week" : "ھەپتە",
    "Month" : "ئاي",
    "Edit" : "تەھرىر",
    "Delete" : "ئۆچۈر",
    "Export" : "چىقار",
    "Share link" : "Share link",
    "New calendar" : "يېڭى يىلنامە",
    "Name" : "ئاتى",
    "Deleted" : "ئۆچۈرۈلدى",
    "Delete permanently" : "مەڭگۈلۈك ئۆچۈر",
    "Cancel" : "ۋاز كەچ",
    "Actions" : "مەشغۇلاتلار",
    "Location" : "ئورنى",
    "Description" : "چۈشەندۈرۈش",
    "Add" : "قوش",
    "Monday" : "دۈشەنبە",
    "Tuesday" : "سەيشەنبە",
    "Wednesday" : "چارشەنبە",
    "Thursday" : "پەيشەنبە",
    "Friday" : "جۈمە",
    "Saturday" : "شەنبە",
    "Sunday" : "يەكشەنبە",
    "Save" : "ساقلا",
    "Update" : "يېڭىلا",
    "Your email address" : "تورخەت ئادرېسىڭىز",
    "Email" : "تورخەت",
    "Repeat" : "قايتىلا",
    "never" : "ھەرگىز",
    "More" : "تېخىمۇ كۆپ",
    "Personal" : "شەخسىي",
    "Attendees" : "قاتناشقۇچىلار",
    "Close" : "ياپ",
    "Next" : "كېيىنكى",
    "Other" : "باشقا",
    "Birthday" : "تۇغۇلغان كۈن"
},
"nplurals=2; plural=(n != 1);");
