OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Sitzung unerwartet abgelaufen",
    "Provided email-address is not valid" : "Angegebene E-Mail-Adresse ist ungültig",
    "%s has published the calendar »%s«" : "%s hat den Kalender »%s« veröffentlicht",
    "Unexpected error sending email. Please contact your administrator." : "Unerwarteter Fehler beim Senden der E-Mail. Bitte kontaktiere den Administrator.",
    "Successfully sent email to %1$s" : "E-Mail erfolgreich an %1$s gesendet",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Information: %s hat den Kalender »%s« veröffentlicht.",
    "Open »%s«" : "»%s« öffnen",
    "Cheers!" : "Noch einen schönen Tag!",
    "Upcoming events" : "Anstehende Termine",
    "Appointments" : "Termine",
    "Schedule appointment \"%s\"" : "Termin planen \"%s\"",
    "Schedule an appointment" : "Vereinbare einen Termin",
    "Prepare for %s" : "Bereite dich auf %s vor",
    "Follow up for %s" : "Nachverfolgung für %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Für deine Terminvereinbarung \"%s\" mit %s steht die Bestätigung noch aus.",
    "Dear %s, please confirm your booking" : "Hallo%s, bitte bestätige die Terminbuchung",
    "Confirm" : "Bestätigen",
    "This confirmation link expires in %s hours." : "Dieser Bestätigungslink läuft in %s Stunden ab.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Wenn du den Termin doch stornieren möchtest, wende dich bitte an deinen Organisator, indem du auf diese E-Mail antwortest oder dessen Profilseite besuchst.",
    "Your appointment \"%s\" with %s has been accepted" : "Deine Terminvereinbarung \"%s\" mit %s wurde angenommen.",
    "Dear %s, your booking has been accepted." : "Hallo %s, dein Buchung wurde akzeptiert.",
    "Appointment for:" : "Termin für:",
    "Date:" : "Datum:",
    "Where:" : "Ort:",
    "Your Comment:" : "Dein Kommentar:",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "Eine Kalender-App für Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Die Calendar-App ist die Oberfläche für Nextclouds CalDAV-Server. Termine können auf einfache Weise über verschiedene Geräte hinweg mit Nextcloud synchronisiert und online bearbeitet werden.\n\n* 🚀 ** Integration mit anderen Nextcloud Apps!** Aktuell Kontakte - weitere folgen.\n* 🌐 **WebCal-Unterstützung!** Möchtest du die Spieltage deines Lieblingsteams in deinem Kalender verfolgen? Kein Problem!\n* 🙋 **Teilnehmer!** Lade Teilnehmer zu deinen Terminen ein.\n* ⌚️ **Frei/Besetzt:** Sehe, wann deine Teilnehmer für ein Treffen verfügbar sind\n* ⏰ **Erinnerungen!** Erhalte Alarme für Termine innerhalb deines Browsers und per E-Mail.\n* 🔍 Suche! Finde deine Termine ganz einfach\n* ☑️ Aufgaben! Sehe deine Aufgaben mit Fälligkeitsdatum direkt in deinem Kalender\n* 🙈 **Wir erfinden das Rad nicht neu!** Die App basiert auf den großartigen [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) und [fullcalendar](https://github.com/fullcalendar/fullcalendar) Bibliotheken.",
    "Previous day" : "Vorheriger Tag",
    "Previous week" : "Vorherige Woche",
    "Previous month" : "Vorheriger Monat",
    "Next day" : "Nächster Tag",
    "Next week" : "Nächste Woche",
    "Next month" : "Nächster Monat",
    "New event" : "Neuer Termin",
    "Today" : "Heute",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "List" : "Liste",
    "Preview" : "Vorschau",
    "Copy link" : "Link kopieren",
    "Edit" : "Bearbeiten",
    "Delete" : "Löschen",
    "Appointment link was copied to clipboard" : "Link für den Termin wurde in die Zwischenablage kopiert",
    "Appointment link could not be copied to clipboard" : "Link für den Termin konnte nicht in die Zwischenablage kopiert werden",
    "Add new" : "Neu hinzufügen",
    "Untitled calendar" : "Unbenannter Kalender",
    "Edit name" : "Name bearbeiten",
    "Saving name …" : "Speichere Namen …",
    "Edit color" : "Farbe bearbeiten",
    "Saving color …" : "Speichere Farbe …",
    "Copy private link" : "Privaten Link kopieren",
    "Export" : "Exportieren",
    "Unshare from me" : "Nicht mehr mit mir teilen",
    "Disable calendar \"{calendar}\"" : "Kalender \"{calendar}\" deaktivieren",
    "Disable untitled calendar" : "Unbenannte Kalender deaktivieren",
    "Enable calendar \"{calendar}\"" : "Kalender \"{calendar}\" aktivieren",
    "Enable untitled calendar" : "Unbenannte Kalender aktivieren",
    "An error occurred, unable to change visibility of the calendar." : "Es ist ein Fehler aufgetreten, die Sichtbarkeit des Kalenders konnte nicht geändert werden.",
    "An error occurred, unable to delete the calendar." : "Es ist ein Fehler aufgetreten, Kalender konnte nicht gelöscht werden.",
    "Calendar link copied to clipboard." : "Kalender-Link in die Zwischenablage kopiert.",
    "Calendar link could not be copied to clipboard." : "Kalender-Link konnte nicht in die Zwischenablage kopiert werden.",
    "An error occurred, unable to rename the calendar." : "Es ist ein Fehler aufgetreten, Kalender konnte nicht umbenannt werden.",
    "An error occurred, unable to change the calendar's color." : "Es ist ein Fehler aufgetreten, die Farbe des Kalenders konnte nicht geändert werden.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalenderfreigabe wird in {countdown} Sekunde beendet","Kalenderfreigabe wird in {countdown} Sekunden beendet"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalender wird in {countdown} Sekunden gelöscht","Kalender werden in {countdown} Sekunden gelöscht"],
    "Share link" : "Link teilen",
    "Publish calendar" : "Kalender veröffentlichen",
    "Publishing calendar" : "Veröffentliche Kalender",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Send link to calendar via email" : "Link zum Kalender als E-Mail verschicken",
    "Enter one address" : "Eine Adresse eingeben",
    "Sending email …" : "Sende E-Mail …",
    "Copy subscription link" : "Abonnement-Link kopieren",
    "Copying link …" : "Link wird kopiert …",
    "Copied link" : "Link kopiert",
    "Could not copy link" : "Link konnte nicht kopiert werden",
    "Copy embedding code" : "Einbettungscode kopieren",
    "Copying code …" : "Kopiere Code …",
    "Copied code" : "Code kopiert",
    "Could not copy code" : "Code konnte nicht kopiert werden",
    "Delete share link" : "Freigabe-Link löschen",
    "Deleting share link …" : "Freigabe-Link löschen …",
    "An error occurred, unable to publish calendar." : "Es ist ein Fehler aufgetreten, Kalender konnte nicht veröffentlicht werden.",
    "An error occurred, unable to send email." : "Es ist ein Fehler aufgetreten, E-Mail konnte nicht versandt werden.",
    "Embed code copied to clipboard." : "Einbettungscode in die Zwischenablage kopiert.",
    "Embed code could not be copied to clipboard." : "Einbettungscode konnte nicht in die Zwischenablage kopiert werden.",
    "Unpublishing calendar failed" : "Aufhebung der Veröffentlichung des Kalenders fehlgeschlagen",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "No users or groups" : "Keine Benutzer oder Gruppen",
    "can edit" : "kann bearbeiten",
    "Unshare with {displayName}" : "Mit {displayName} nicht mehr teilen",
    "An error occurred, unable to change the unshare the calendar." : "Es ist ein Fehler aufgetreten, die Freigabe des Kalenders konnte nicht aufgehoben werden.",
    "An error occurred, unable to change the permission of the share." : "Es ist ein Fehler aufgetreten, die Berechtigung für die Freigabe konnte nicht geändert werden.",
    "New calendar" : "Neuer Kalender",
    "Name for new calendar" : "Name für neuen Kalender",
    "Creating calendar …" : "Erstelle Kalender …",
    "New calendar with task list" : "Neuer Kalender mit Aufgabenliste",
    "New subscription from link (read-only)" : "Neues Abonnement aus Link (schreibgeschützt)",
    "Creating subscription …" : "Erstelle Abonnement …",
    "An error occurred, unable to create the calendar." : "Es ist ein Fehler aufgetreten, der Kalender konnte nicht erstellt werden.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Bitte einen gültigen Link eingeben (beginnend mit http://, https://, webcal://, oder webcals://)",
    "Trash bin" : "Papierkorb",
    "Loading deleted items." : "Lade gelöschte Elemente",
    "You do not have any deleted items." : "Du hast keine gelöschten Elemente",
    "Name" : "Name",
    "Deleted" : "Gelöscht",
    "Restore" : "Wiederherstellen",
    "Delete permanently" : "Endgültig löschen",
    "Empty trash bin" : "Papierkorb leeren",
    "Untitled item" : "Eintrag ohne Namen",
    "Unknown calendar" : "Unbekannter Kalender",
    "Could not load deleted calendars and objects" : "Gelöschte Kalender und Objekte konnten nicht geladen werden",
    "Could not restore calendar or event" : "Kalender oder Termin konnte nicht wiederhergestellt werden",
    "Do you really want to empty the trash bin?" : "Möchtest du wirklich den Papierkorb leeren?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Element im Papierkorb wird nach {numDays} Tagen gelöscht","Elemente im Papierkorb werden nach {numDays} Tagen gelöscht"],
    "Could not update calendar order." : "Kalenderreihenfolge konnte nicht aktualisiert werden.",
    "Import calendars" : "Kalender importieren",
    "Please select a calendar to import into …" : "Bitte wähle einen Kalender aus, in den importiert werden soll …",
    "Filename" : "Dateiname",
    "Calendar to import into" : "Kalender in den importiert werden soll.",
    "Cancel" : "Abbrechen",
    "_Import calendar_::_Import calendars_" : ["Kalender importieren","Kalender importieren"],
    "{filename} could not be parsed" : "{filename} konnte nicht analysiert werden",
    "No valid files found, aborting import" : "Keine gültige Dateien gefunden, Import wird abgebrochen.",
    "Import partially failed. Imported {accepted} out of {total}." : "Der Import ist teilweise fehlgeschlagen. {accepted} von {total} importiert.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Erfolgreich %n Termin importiert","Erfolgreich %n Termine importiert"],
    "Automatic" : "Automatisch",
    "Automatic ({detected})" : "Automatisch ({detected})",
    "New setting was not saved successfully." : "Neue Einstellung konnte nicht gespeichert werden.",
    "Shortcut overview" : "Übersicht der Tastaturkürzel",
    "or" : "oder",
    "Navigation" : "Navigation",
    "Previous period" : "Vorherige Zeitspanne",
    "Next period" : "Nächste Zeitspanne",
    "Views" : "Ansichten",
    "Day view" : "Tagesansicht",
    "Week view" : "Wochenansicht",
    "Month view" : "Monatsansicht",
    "List view" : "Listenansicht",
    "Actions" : "Aktionen",
    "Create event" : "Termin erstellen",
    "Show shortcuts" : "Tastaturkürzel anzeigen",
    "Editor" : "Editor",
    "Close editor" : "Bearbeitung schließen",
    "Save edited event" : "Bearbeitetes Ereignis speichern",
    "Delete edited event" : "Bearbeitetes Ereignis löschen",
    "Duplicate event" : "Termin duplizieren",
    "Enable birthday calendar" : "Geburtstagskalender aktivieren",
    "Show tasks in calendar" : "Aufgaben im Kalender anzeigen",
    "Enable simplified editor" : "Einfachen Editor aktivieren",
    "Limit visible events per view" : "Sichtbare Ereignisse pro Ansicht begrenzen",
    "Show weekends" : "Wochenenden anzeigen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Time increments" : "Zeitschritte",
    "Default reminder" : "Standarderinnerung",
    "Copy primary CalDAV address" : "Primäre CalDAV-Adresse kopieren",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV-Adresse kopieren",
    "Personal availability settings" : "Persönliche Einstellungen zur Verfügbarkeit",
    "Show keyboard shortcuts" : "Tastaturkürzel anzeigen",
    "Calendar settings" : "Kalender-Einstellungen",
    "No reminder" : "Keine Erinnerung",
    "CalDAV link copied to clipboard." : "CalDAV-Link in die Zwischenablage kopiert.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-Link konnte nicht in die Zwischenablage kopiert werden.",
    "Appointment was created successfully" : "Termin wurde erstellt",
    "Appointment was updated successfully" : "Termin wurde aktualisiert",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} Minute","{duration} Minuten"],
    "0 minutes" : "0 Minuten",
    "_{duration} hour_::_{duration} hours_" : ["{duration} Stunde","{duration} Stunden"],
    "_{duration} day_::_{duration} days_" : ["{duration} Tag","{duration} Tage"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} Woche","{duration} Wochen"],
    "_{duration} month_::_{duration} months_" : ["{duration} Monat","{duration} Monate"],
    "_{duration} year_::_{duration} years_" : ["{duration} Jahr","{duration} Jahre"],
    "To configure appointments, add your email address in personal settings." : "Um Termine zu vereinbaren, füge deine E-Mail-Adresse in den persönlichen Einstellungen hinzu.",
    "Public – shown on the profile page" : "Öffentlich – wird auf der Profilseite angezeigt",
    "Private – only accessible via secret link" : "Privat – nur über geheimen Link sichtbar",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Visibility" : "Sichtbarkeit",
    "Duration" : "Dauer",
    "Increments" : "Schritte",
    "Additional calendars to check for conflicts" : "Zusätzliche Kalender zur Überprüfung auf Konflikte",
    "Pick time ranges where appointments are allowed" : "Wähle Zeitbereiche, in denen Termine erlaubt sind",
    "to" : "bis",
    "Delete slot" : "Zeitfenster löschen",
    "No times set" : "Keine Zeiten gesetzt",
    "Add" : "Hinzufügen",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sunday" : "Sonntag",
    "Add time before and after the event" : "Zeit vor und nach dem Termin hinzufügen",
    "Before the event" : "Vor dem Termin",
    "After the event" : "Nach dem Termin",
    "Planning restrictions" : "Planungsbeschränkungen",
    "Minimum time before next available slot" : "Mindestzeit bis zum nächsten verfügbaren Zeitfenster",
    "Max slots per day" : "Maximale Zeitfenster pro Tag",
    "Limit how far in the future appointments can be booked" : "Begrenzung, wie weit in der Zukunft Termine gebucht werden können",
    "Create appointment" : "Termin erstellen",
    "Edit appointment" : "Termin bearbeiten",
    "Save" : "Speichern",
    "Update" : "Aktualisieren",
    "Please confirm your reservation" : "Bitte bestätige deine Reservierung",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Wir haben dir eine E-Mail mit Details gesendet. Bitte bestätige deinen Termin über den Link in der E-Mail. Du kannst diese Seite jetzt schließen.",
    "Your name" : "Dein Name",
    "Your email address" : "Deine E-Mail-Adresse",
    "Please share anything that will help prepare for our meeting" : "Bitte sende uns alles, was zur Vorbereitung unseres Treffens beiträgt.",
    "Could not book the appointment. Please try again later or contact the organizer." : "Termin konnte nicht gebucht werden. Bitte versuche es später erneut oder wende dich an den Organisator.",
    "Book the appointment" : "Den Termin buchen",
    "Reminder" : "Erinnerung",
    "before at" : "vorher um",
    "Notification" : "Benachrichtigung",
    "Email" : "E-Mail-Adresse",
    "Audio notification" : "Audio-Benachrichtigung",
    "Other notification" : "Andere Benachrichtigung",
    "Relative to event" : "Relativ zum Termin",
    "On date" : "Am Datum",
    "Edit time" : "Zeit ändern",
    "Save time" : "Zeit speichern",
    "Remove reminder" : "Erinnerung entfernen",
    "on" : "am",
    "at" : "um",
    "+ Add reminder" : "+ Erinnerung hinzufügen",
    "Add reminder" : "Erinnerung hinzufügen",
    "_second_::_seconds_" : ["Sekunde","Sekunden"],
    "_minute_::_minutes_" : ["Minute","Minuten"],
    "_hour_::_hours_" : ["Stunde","Stunden"],
    "_day_::_days_" : ["Tag","Tage"],
    "_week_::_weeks_" : ["Woche","Wochen"],
    "Invitation accepted" : "Einladung angenommen",
    "Available" : "Verfügbar",
    "Suggested" : "Vorgeschlagen",
    "Participation marked as tentative" : "Teilnahme als vorläufig markiert",
    "Accepted {organizerName}'s invitation" : "Einladung von {organizerName} angenommen",
    "Not available" : "Nicht verfügbar",
    "Invitation declined" : "Einladung abgelehnt",
    "Declined {organizerName}'s invitation" : "Einladung von {organizerName} abgelehnt",
    "Invitation is delegated" : "Einladung ist weitergeleitet",
    "Checking availability" : "Verfügbarkeit prüfen",
    "Invitation sent" : "Einladung verschickt",
    "Has not responded to {organizerName}'s invitation yet" : "Hat noch nicht auf die Einladung von {organizerName} geantwortet",
    "Availability of attendees, resources and rooms" : "Verfügbarkeit von Teilnehmern, Resourcen und Räumen",
    "{organizer} (organizer)" : "{organizer} (Organisator)",
    "Free" : "Frei",
    "Busy (tentative)" : "Beschäftigt (vorläufig)",
    "Busy" : "Beschäftigt",
    "Out of office" : "Nicht im Büro",
    "Unknown" : "Unbekannt",
    "Accept" : "Annehmen",
    "Decline" : "Ablehnen",
    "Tentative" : "Vorläufig",
    "The invitation has been accepted successfully." : "Die Einladung wurde angenommen.",
    "Failed to accept the invitation." : "Die Einladung konnte nicht angenommen werden.",
    "The invitation has been declined successfully." : "Die Einladung wurde erfolgreich abgelehnt.",
    "Failed to decline the invitation." : "Die Einladung konnte nicht abgelehnt werden.",
    "Your participation has been marked as tentative." : "Deine Teilnahme wurde als vorläufig markiert.",
    "Failed to set the participation status to tentative." : "Deine Teilnahme konnte nicht als vorläufig markiert werden.",
    "Create Talk room for this event" : "Besprechungsraum für diesen Termin erstellen",
    "Show busy times" : "Belegte Zeiten anzeigen",
    "No attendees yet" : "Keine Teilnehmer bislang",
    "Successfully appended link to talk room to description." : "Link zur Beschreibung des Besprechungsraums hinzugefügt.",
    "Error creating Talk room" : "Fehler beim Erstellen des Besprechungsraumes",
    "Send email" : "E-Mail senden",
    "Chairperson" : "Vorsitz",
    "Required participant" : "Benötigter Teilnehmer",
    "Optional participant" : "Optionaler Teilnehmer",
    "Non-participant" : "Nicht-Teilnehmer",
    "Remove attendee" : "Teilnehmer entfernen",
    "Search for emails, users or contacts" : "Suche nach E-Mails, Benutzern oder Kontakten",
    "No match found" : "Keine Übereinstimmung gefunden",
    "(organizer)" : "(Organisator)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Um das Senden von Einladungen und deren Antworten zu ermöglichen, [linkopen] füge deine E-Mail-Adresse in den persönlichen Einstellungen hinzu.[linkclose].",
    "Remove color" : "Farbe entfernen",
    "Event title" : "Titel des Termins",
    "All day" : "Ganztägig",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Die Einstellung ganztägig kann für sich wiederholende Termine nicht geändert werden.",
    "from {startDate}" : "von {startDate}",
    "from {startDate} at {startTime}" : "von {startDate} um {startTime}",
    "to {endDate}" : "bis {endDate}",
    "to {endDate} at {endTime}" : "bis {endDate} um {endTime}",
    "Repeat" : "Wiederholen",
    "End repeat" : "Wiederholung beenden",
    "Select to end repeat" : "Auswählen um Wiederholung beenden",
    "never" : "Niemals",
    "on date" : "am Datum",
    "after" : "Nach",
    "_time_::_times_" : ["Mal","Mal"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Dieser Termin ist die Wiederholungsausnahme eines sich wiederholenden Termins. Du kannst keine Wiederholungsregel hinzufügen.",
    "first" : "ersten",
    "third" : "dritten",
    "fourth" : "vierten",
    "fifth" : "fünften",
    "second to last" : "vorletzten",
    "last" : "letzten",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Änderungen an der Wiederholungsregel werden nur auf dieses und alle zukünftigen Wiederholungen angewendet.",
    "Repeat every" : "Wiederhole jeden",
    "By day of the month" : "Nach Tag des Monats",
    "On the" : "Am",
    "_month_::_months_" : ["Monat","Monate"],
    "_year_::_years_" : ["Jahr","Jahre"],
    "weekday" : "Wochentag",
    "weekend day" : "Wochenendtag",
    "No recurrence" : "Keine Wiederholung",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Die Wiederholungs-Definition dieses Termins wird nicht vollständig von Nextcloud unterstützt. Wenn du die Wiederholungs-Optionen bearbeitest, könnten bestimmte Wiederholungen verlorengehen.",
    "Suggestions" : "Vorschläge",
    "No rooms or resources yet" : "Noch keine Räume oder Ressourcen",
    "Add resource" : "Ressource hinzufügen",
    "Has a projector" : "Hat einen Projektor",
    "Has a whiteboard" : "Hat ein Whiteboard",
    "Wheelchair accessible" : "Barrierefrei",
    "Remove resource" : "Ressource entfernen",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} Platz","{seatingCapacity} Plätze"],
    "Projector" : "Projektor",
    "Whiteboard" : "Whiteboard",
    "Search for resources or rooms" : "Nach Ressourcen oder Räumen suchen",
    "available" : "verfügbar",
    "unavailable" : "Nicht verfügbar",
    "Room type" : "Raum-Typ",
    "Any" : "Irgendein",
    "Minimum seating capacity" : "Mindestsitzplatzkapazität",
    "More" : "Mehr",
    "Update this occurrence" : "Diese Wiederholung aktualisieren",
    "Update this and all future" : "Aktualisiere dieses und alle Künftigen",
    "Public calendar does not exist" : "Öffentlicher Kalender existiert nicht",
    "Maybe the share was deleted or has expired?" : "Vielleicht wurde die Freigabe gelöscht oder ist abgelaufen?",
    "Please select a time zone:" : "Bitte eine Zeitzone wählen:",
    "Pick a time" : "Zeit auswählen",
    "Pick a date" : "Datum auswählen",
    "from {formattedDate}" : "Von {formattedDate}",
    "to {formattedDate}" : "bis {formattedDate}",
    "on {formattedDate}" : "am {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "von {formattedDate} um {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "bis {formattedDate} um {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "am {formattedDate} um {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} um {formattedTime}",
    "Please enter a valid date" : "Bitte ein gültiges Datum angeben",
    "Please enter a valid date and time" : "Bitte gültiges Datum und Uhrzeit angeben",
    "Type to search time zone" : "Zum Suchen der Zeitzone tippen",
    "Global" : "Weltweit",
    "Select date" : "Datum auswählen",
    "Select slot" : "Zeitfenster auswählen",
    "No slots available" : "Keine Zeitfenster verfügbar",
    "The slot for your appointment has been confirmed" : "Das Zeitfenster für deinen Termin wurde bestätigt",
    "Appointment Details:" : "Termindetails:",
    "Time:" : "Zeit:",
    "Booked for:" : "Gebucht für:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Danke schön. Deine Buchung vom {startDate} bis {endDate} wurde bestätigt.",
    "Book another appointment:" : "Einen weiteren Termin buchen:",
    "See all available slots" : "Alle verfügbaren Zeitfenster anzeigen",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Das Zeitfenster für deinen Termin von {startDate} bis {endDate} ist nicht mehr verfügbar.",
    "Please book a different slot:" : "Buche bitte ein anderes Zeitfenster:",
    "Book an appointment with {name}" : "Buche einen Termin mit {name}",
    "No public appointments found for {name}" : "Keine öffentlichen Termine für {name} gefunden",
    "Personal" : "Persönlich",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Die automatische Erkennung der Zeitzone hat als Ergebnis UTC ermittelt.\nDies ist meist das Ergebnis von Sicherheitsmaßnahmen deines Webbrowsers.\nBitte stelle deine Zeitzone manuell in den Kalendereinstellungen ein.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Die konfigurierte Zeitzone ({timezoneId}) wurde nicht gefunden. Rückfall auf UTC.\nBitte die Zeitzone in den Einstellungen ändern und dieses Problem melden.",
    "No more events today" : "Heute keine weiteren Termine",
    "No upcoming events" : "Keine anstehenden Termine",
    "Create a new event" : "Neuen Termin erstellen",
    "[Today]" : "[Heute]",
    "[Tomorrow]" : "[Morgen]",
    "[Yesterday]" : "[Gestern]",
    "[Last] dddd" : "[Letzten] dddd",
    "Event does not exist" : "Der Termin existiert nicht",
    "Duplicate" : "Duplizieren",
    "Delete this occurrence" : "Diese Wiederholung löschen",
    "Delete this and all future" : "Dieses und alle Künftigen löschen",
    "Details" : "Details",
    "Attendees" : "Teilnehmer",
    "Resources" : "Ressourcen",
    "Close" : "Schließen",
    "Show more details" : "Weitere Einzelheiten anzeigen",
    "Subscribe to {name}" : "{name} abonnieren",
    "Export {name}" : "Exportiere {name}",
    "Anniversary" : "Jahrestag",
    "Appointment" : "Verabredung",
    "Business" : "Geschäftlich",
    "Education" : "Bildung",
    "Holiday" : "Feiertag",
    "Meeting" : "Treffen",
    "Miscellaneous" : "Verschiedenes",
    "Non-working hours" : "Arbeitsfreie Stunden",
    "Not in office" : "Nicht im Büro",
    "Phone call" : "Anruf",
    "Sick day" : "Krankheitstag",
    "Special occasion" : "Besondere Gelegenheit",
    "Travel" : "Reise",
    "Vacation" : "Urlaub",
    "Midnight on the day the event starts" : "Mitternacht am Tag des Starts des Termins",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n Tag vor dem Start des Termins um {formattedHourMinute}","%n Tage vor dem Start des Termins um {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n Woche vor dem Start des Termins um {formattedHourMinute}","%n Wochen vor dem Start des Termins um {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "Am Tag des Termins um {formattedHourMinute}",
    "at the event's start" : "Zu Beginn des Termins",
    "at the event's end" : "Am Ende des Termins",
    "{time} before the event starts" : "{time} vor Beginn des Termins",
    "{time} before the event ends" : "{time} vor Ende des Termins",
    "{time} after the event starts" : "{time} nach Beginn des Termins",
    "{time} after the event ends" : "{time} nach Ende des Termins",
    "on {time}" : "um {time}",
    "on {time} ({timezoneId})" : "um {time} ({timezoneId})",
    "Week {number} of {year}" : "Woche {number} aus {year}",
    "Does not repeat" : "Wiederholt sich nicht",
    "Daily" : "Täglich",
    "Weekly" : "Wöchentlich",
    "Monthly" : "Monatlich",
    "Yearly" : "Jährlich",
    "_Every %n day_::_Every %n days_" : ["Jeden %n Tag","Alle %n Tage"],
    "_Every %n week_::_Every %n weeks_" : ["Jede %n Woche","Alle %n Wochen"],
    "_Every %n month_::_Every %n months_" : ["Jeden %n Monat","Alle %n Monate"],
    "_Every %n year_::_Every %n years_" : ["Jedes %n Jahr","Alle %n Jahre"],
    "_on {weekday}_::_on {weekdays}_" : ["am {weekday}","am {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["am Tag {dayOfMonthList}","an den Tagen {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "am {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "im {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "im {monthNames} am {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "bis {untilDate}",
    "_%n time_::_%n times_" : ["%n mal","%n mal"],
    "Untitled event" : "Unbenannter Termin",
    "Untitled task" : "Unbenannte Aufgabe",
    "Please ask your administrator to enable the Tasks App." : "Bitte deinen Administrator die Aufgaben-App (Tasks) zu aktivieren.",
    "Prev" : "Voriges",
    "Next" : "Nächstes",
    "Prev year" : "Voriges Jahr",
    "Next year" : "Nächstes Jahr",
    "Year" : "Jahr",
    "W" : "W",
    "%n more" : "%n weitere",
    "No events to display" : "Keine Ereignisse zum Anzeigen",
    "_+%n more_::_+%n more_" : ["+%n weitere","+%n weitere"],
    "No events" : "Keine Termine",
    "Create a new event or change the visible time-range" : "Neuen Termin erstellen oder den sichtbaren Zeitbereich ändern",
    "It might have been deleted, or there was a typo in a link" : "Möglicherweise wurde dies gelöscht oder es gab einen Tippfehler in einem Link",
    "It might have been deleted, or there was a typo in the link" : "Möglicherweise wurde dies gelöscht oder es gab einen Tippfehler in einem Link",
    "Meeting room" : "Besprechungsraum",
    "Lecture hall" : "Hörsaal",
    "Seminar room" : "Seminarraum",
    "Other" : "Sonstiges",
    "When shared show" : "Wenn geteilt, zeige",
    "When shared show full event" : "Wenn geteilt, zeige den vollständigen Termin an",
    "When shared show only busy" : "Wenn geteilt, zeige nur den Status \"beschäftigt\" an",
    "When shared hide this event" : "Wenn geteilt, zeige diesen Termin nicht an",
    "The visibility of this event in shared calendars." : "Sichtbarkeit dieses Termins in geteilten Kalendern.",
    "Add a location" : "Ort hinzufügen",
    "Add a description" : "Beschreibung hinzufügen",
    "Status" : "Status",
    "Confirmed" : "Bestätigt",
    "Canceled" : "Abgesagt",
    "Confirmation about the overall status of the event." : "Bestätigung über den Gesamtstatus des Termins.",
    "Show as" : "Anzeigen als",
    "Take this event into account when calculating free-busy information." : "Diesen Termin bei der Berechnung der Frei- / Gebucht-Informationen berücksichtigen.",
    "Categories" : "Kategorien",
    "Categories help you to structure and organize your events." : "Mithilfe von Kategorien kannst du deine Termine strukturieren und organisieren.",
    "Search or add categories" : "Suche oder füge Kategorien hinzu",
    "Add this as a new category" : "Dies als neue Kategorie hinzufügen",
    "Custom color" : "Benutzerdefinierte Farbe",
    "Special color of this event. Overrides the calendar-color." : "Sonderfarbe für diesen Termin. Überschreibt die Kalenderfarbe.",
    "Chat room for event" : "Chat-Raum für Termin",
    "Imported {filename}" : "{filename} importiert ",
    "Meditation" : "Meditation",
    "Relaxing" : "Entspannen",
    "Relax" : "Entspannen",
    "Break" : "Pause",
    "Commute" : "Pendelt",
    "Commuting" : "Pendelt",
    "Shuttle" : "Pendelverkehr",
    "Invoice" : "Rechnung",
    "Finance" : "Finanzen",
    "Bank" : "Bank",
    "Money" : "Geld",
    "Wedding" : "Hochzeit",
    "Dog" : "Hund",
    "Concert" : "Konzert",
    "Festival" : "Festival",
    "Theater" : "Theater",
    "Theatre" : "Theater",
    "Presentation" : "Präsentation",
    "Talk" : "Talk",
    "Speech" : "Gespräch",
    "Deadline" : "Abgabefrist",
    "Submission" : "Einreichung",
    "Reporting" : "Berichten",
    "Camping" : "Camping",
    "Camp" : "Zelten",
    "Election" : "Wahl",
    "Voting" : "Abstimmen",
    "Vote" : "Stimme",
    "Barbecue" : "Grillen",
    "Barbeque" : "Grillen",
    "Garden" : "Garten",
    "Farm" : "Bauernhof",
    "Movie" : "Film",
    "Cinema" : "Kino",
    "Graduation" : "Abschluss",
    "Brainstorm" : "Ideenfindung",
    "Review" : "Überprüfen",
    "Audit" : "Überprüfung",
    "Inspection" : "Überprüfung",
    "Proofreading" : "Korrekturlesen",
    "Baseball" : "Baseball",
    "Meet" : "Treffen",
    "Planning" : "Planung",
    "Pointing" : "Hinweis",
    "Retrospective" : "Rückblick",
    "Office" : "Büro",
    "Contributor week" : "Woche der Mitwirkenden",
    "Mail" : "E-Mail",
    "Soccer" : "Fußball",
    "Football" : "Football",
    "Gaming" : "Gaming",
    "Drive" : "Fahren",
    "Driving" : "Autofahren",
    "Bicycle" : "Fahrrad",
    "Cycle" : "Radfahren",
    "Cycling" : "Radfahren",
    "Biking" : "Fahrradfahren",
    "Bike" : "Fahrrad",
    "Podcast" : "Podcast",
    "Basketball" : "Basketball",
    "Fishing" : "Angeln",
    "Hiking" : "Wandern",
    "Hike" : "Wanderung",
    "Art" : "Kunst",
    "Exhibition" : "Ausstellung",
    "Museum" : "Museum",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Walk" : "Gehen",
    "Studying" : "Studieren",
    "Doctor" : "Arzt",
    "Health" : "Gesundheit",
    "Dentist" : "Zahnarzt",
    "Hospital" : "Krankenhaus",
    "Interview" : "Interview",
    "Training" : "Training",
    "Practice" : "Übung",
    "Sports" : "Sport",
    "Exercise" : "Bewegung",
    "Work out" : "Training",
    "Working out" : "Trainieren",
    "Gym" : "Fitnessstudio",
    "Barber" : "Rasur",
    "Haircut" : "Friseur",
    "Hairdresser" : "Friseur",
    "Exam" : "Prüfung",
    "Written test" : "Schriftliche Prüfung",
    "Oral test" : "Mündliche Prüfung",
    "Working" : "Arbeiten",
    "New Years Eve" : "Silvesterabend",
    "NYE" : "NYE",
    "Fireworks" : "Feuerwerk",
    "Running" : "Laufen",
    "Go for a run" : "Laufen gehen",
    "Marathon" : "Marathon",
    "Video-conference" : "Videokonferenz",
    "Conference-call" : "Konferenzanruf",
    "Video-call" : "Videoanruf",
    "Video-chat" : "Videochat",
    "Video-meeting" : "Videomeeting",
    "Call" : "Anruf",
    "Calling" : "Anrufen",
    "Christmas" : "Weihnachten",
    "Conference" : "Konferenz",
    "Pizza" : "Pizza",
    "Travelling" : "Reisen",
    "Trip" : "Reise",
    "Journey" : "Reise",
    "Collaborate" : "Zusammenarbeiten",
    "Pair" : "Paar",
    "Lecture" : "Vorlesung",
    "Seminar" : "Seminar",
    "Teaching" : "Unterrichten",
    "Photograph" : "Fotografie",
    "Party" : "Party",
    "Celebration" : "Feier",
    "Celebrate" : "Feiern",
    "Birthday" : "Geburtstag",
    "Shopping" : "Einkaufen",
    "Groceries" : "Lebensmittel",
    "Skate" : "Skaten",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Weinprobe",
    "Golf" : "Golf",
    "Dinner" : "Abendessen",
    "Lunch" : "Mittagessen",
    "Appointment not found" : "Termin nicht gefunden",
    "User not found" : "Benutzer nicht gefunden"
},
"nplurals=2; plural=(n != 1);");
