OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Sesiunea-Utilizatorului a expirat în mod neașteptat",
    "Provided email-address is not valid" : "Adresa de email furnizată este invalidă",
    "%s has published the calendar »%s«" : "%sa publicat calendarul »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Eroare neașteptată la trimiterea emailului. Vă rog contactați-vă administratorul.",
    "Successfully sent email to %1$s" : "Email trimis cu succes la %1$s",
    "Hello," : "Salut,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vă informăm că %sa publicat calendarul »%s«.",
    "Open »%s«" : "Accesează »%s«",
    "Cheers!" : "Noroc!",
    "Upcoming events" : "Evenimente viitoare",
    "Appointments" : "Întâlniri",
    "Schedule appointment \"%s\"" : "Planifică programarea \"%s\"",
    "Schedule an appointment" : "Planifică o programare",
    "Prepare for %s" : "Pregăteste-te de %s",
    "Follow up for %s" : "Urmărește-ne pentru %s",
    "Dear %s, please confirm your booking" : "Dragă %s, te rog să confirmi rezervarea ta",
    "Confirm" : "Confirmă",
    "This confirmation link expires in %s hours." : "Acest link de confirmare expira în %s ore. ",
    "Date:" : "Data:",
    "Where:" : "Unde:",
    "Calendar" : "Calendar",
    "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
    "Previous day" : "Ziua anterioară",
    "Previous week" : "Săptămâna anterioară",
    "Previous month" : "Luna anterioară",
    "Next day" : "Ziua următoare",
    "Next week" : "Saptămâna următoare",
    "Next month" : "Luna următoare",
    "New event" : "Eveniment nou",
    "Today" : "Astăzi",
    "Day" : "Zi",
    "Week" : "Săptămâna",
    "Month" : "Luna",
    "List" : "Listă",
    "Preview" : "Previzualizare",
    "Copy link" : "Copiază link",
    "Edit" : "Editează",
    "Delete" : "Șterge",
    "Appointment link was copied to clipboard" : "Linkul programării a fost copiat în clipboard",
    "Appointment link could not be copied to clipboard" : "Linkul programării nu a putut fi copiat în clipboard",
    "Add new" : "Adaugă nou",
    "Untitled calendar" : "Calendar nedenumit",
    "Edit name" : "Modifică numele",
    "Saving name …" : "Se salvează numele ...",
    "Edit color" : "Modifică culoarea",
    "Saving color …" : "Se salvează culoarea  ...",
    "Copy private link" : "Copiază link privat",
    "Export" : "Exportă",
    "Unshare from me" : "Anulare partajarea cu mine",
    "An error occurred, unable to change visibility of the calendar." : "A apărut o eroare, nu se poate schimba vizibilitatea calendarului.",
    "An error occurred, unable to delete the calendar." : "A apărut o eroare, nu se poate șterge calendarul.",
    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
    "An error occurred, unable to rename the calendar." : "A apărut o eroare, acest calendar nu se poate redenumi.",
    "An error occurred, unable to change the calendar's color." : "A apărut o eroare, nu se poate schimba culoarea calendarului.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Oprirea partajării calendarului in {countdown} secundă","Oprirea partajării calendarului în {countdown} secunde","Oprirea partajării calendarului în {countdown} de secunde"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Se șterge calendarul în {countdown} secundă","Se șterge calendarul în {countdown} secunde","Se șterge calendarul în {countdown} de secunde"],
    "Share link" : "Partajază legătură",
    "Publish calendar" : "Publică calendarul",
    "Publishing calendar" : "Se publică calendarul",
    "Copy public link" : "Copiză link-ul public",
    "Send link to calendar via email" : "Trimite link-ul către calendar folosind email",
    "Enter one address" : "Introdu o adresă",
    "Sending email …" : "Email-ul se trimite ...",
    "Copy subscription link" : "Copiază linkul abonamentului",
    "Copying link …" : "Copiază link ...",
    "Copied link" : "Link copiat",
    "Could not copy link" : "Nu s-a putut copia link-ul",
    "Copy embedding code" : "Copiați codul de încorporare",
    "Copying code …" : "Se copiază codul ...",
    "Copied code" : "Codul a fost copiat",
    "Could not copy code" : "Nu sa putut copia codul",
    "Delete share link" : "Șterge linkul partajat",
    "Deleting share link …" : "Se şterge linkul de partajare ...",
    "An error occurred, unable to publish calendar." : "A apărut o eroare, nu se poate publica calendarul.",
    "An error occurred, unable to send email." : "A apărut o eroare, nu se poate trimite email-ul.",
    "Embed code copied to clipboard." : "Codul a fost copiat în clipboard.",
    "Embed code could not be copied to clipboard." : "Codul nu a putut fi copiat in clipboard.",
    "Unpublishing calendar failed" : "Retragerea calendarului a eşuat",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "No users or groups" : "Nu sunt utilizatori sau grupuri",
    "can edit" : "poate edita",
    "Unshare with {displayName}" : "Retrage cu {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "A apărut o eroare, nu se poate schimba retragerea calendarului.",
    "An error occurred, unable to change the permission of the share." : "A apărut o eroare, nu se poate schimba permisiunile fişierelor partajate.",
    "New calendar" : "Calendar nou",
    "Name for new calendar" : "Numele noului calendar",
    "Creating calendar …" : "Se creează un calendar nou ...",
    "New calendar with task list" : "Calendar nou cu listă",
    "New subscription from link (read-only)" : "Abonament nou folosind un link (doar citirea calendarului)",
    "Creating subscription …" : "Se creează abonamentul ...",
    "An error occurred, unable to create the calendar." : "A apărut o eroare, nu se poate creea acest calendar.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vă rugăm să introduceți un link valid (ce începe cu ttp://, https://, webcal://, sau webcals://)",
    "Trash bin" : "Coș de gunoi",
    "Name" : "Nume",
    "Deleted" : "Șters",
    "Restore" : "Restaurare",
    "Delete permanently" : "Șterge permanent",
    "Empty trash bin" : "Golește coșul de gunoi",
    "Unknown calendar" : "Calendar necunoscut",
    "Could not load deleted calendars and objects" : "Nu s-au putut încărca obiectele și calendarele",
    "Could not restore calendar or event" : "Nu s-a putut restaura calendarul sau evenimentul",
    "Do you really want to empty the trash bin?" : "Doriti sigur sa goliți conținutul coșului de gunoi ?",
    "Could not update calendar order." : "Nu s-a putut actualiza ordinea calendarului.",
    "Import calendars" : "Importă calendare",
    "Please select a calendar to import into …" : "Vă rugăm să selectaţi un calendar în care să importaţi ...",
    "Filename" : "Nume fișier",
    "Calendar to import into" : "Calendarul în care se importă",
    "Cancel" : "Anulează",
    "_Import calendar_::_Import calendars_" : ["Importă calendar","Importă calendare","Importă calendare"],
    "{filename} could not be parsed" : "{filename} nu a putut fi analizat",
    "No valid files found, aborting import" : "Nu au fost găsite fişiere valide, importarea se opreşte",
    "Import partially failed. Imported {accepted} out of {total}." : "Importarea a eşuat parţial. S-au importat  {accepted} din {total}.",
    "Automatic" : "Automat",
    "Automatic ({detected})" : "Automat ({detectat})",
    "New setting was not saved successfully." : "Noile setări nu au fost salvate cu succes.",
    "Shortcut overview" : "Prezentare generală a comenzilor rapide",
    "or" : "sau",
    "Navigation" : "Navigare",
    "Previous period" : "Perioada anterioară",
    "Next period" : "Perioada următoare",
    "Views" : "Mod de viziualizare",
    "Day view" : "Vizualizare pe zi",
    "Week view" : "Vizualizare pe săptămână",
    "Month view" : "Vizualizare pe lună",
    "List view" : "Vizualizare sub formă de listă",
    "Actions" : "Acțiuni",
    "Create event" : "Creează eveniment",
    "Show shortcuts" : "Arată scurtături",
    "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
    "Show tasks in calendar" : "Arată sarcinile în calendar",
    "Enable simplified editor" : "Activează editorul simplificat",
    "Limit visible events per view" : "Limitează evenimentele vizibile în fiecare mod de vizualizare",
    "Show weekends" : "Arată weekend-uri",
    "Show week numbers" : "Afișați numerele săptămânilor",
    "Time increments" : "Incremente de timp",
    "Default reminder" : "Memento implicit",
    "Copy primary CalDAV address" : "Copiază adresa primară CalDAV",
    "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
    "Personal availability settings" : "Setări de disponibilitate",
    "Show keyboard shortcuts" : "Arată scurtături",
    "No reminder" : "Fără mementouri",
    "CalDAV link copied to clipboard." : "Link-ul CAlDAV a fost copiat în clipboard.",
    "CalDAV link could not be copied to clipboard." : "Linkul CalDAV nu a putut fi copiat în clipboard.",
    "Appointment was created successfully" : "Programarea a fost creeata cu succes",
    "Appointment was updated successfully" : "Programarea a fost actualizată cu succes",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minute","{duration} de minute"],
    "0 minutes" : "0 minute",
    "_{duration} hour_::_{duration} hours_" : ["{duration} oră","{duration} ore","{duration} de ore"],
    "_{duration} day_::_{duration} days_" : ["{duration} zi","{duration} zile","{duration} de zile"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} săptămână","{duration} săptămâni","{duration} de săptămâni"],
    "_{duration} month_::_{duration} months_" : ["{duration} lună","{duration} luni","{duration} de luni"],
    "_{duration} year_::_{duration} years_" : ["{duration} an","{duration} ani","{duration} ani"],
    "To configure appointments, add your email address in personal settings." : "Pentru a configura programările, adăugați-vă adresa email în setările personale.",
    "Public – shown on the profile page" : "Public- arată pepagina de profil",
    "Private – only accessible via secret link" : "Private - accesibil doar prin folosirea unui link secret",
    "Location" : "Locație",
    "Description" : "Descriere",
    "Visibility" : "Vizibil",
    "Duration" : "Durată",
    "Increments" : "Incremente",
    "Additional calendars to check for conflicts" : "Calendarele adiționale să fie verificate pentru conflicte ",
    "Pick time ranges where appointments are allowed" : "Alege intervale de timp în cadrul cărora programările sunt permise",
    "to" : "către",
    "Delete slot" : "Șterge slotul",
    "No times set" : "Nici-un timp setat",
    "Add" : "Adaugă",
    "Monday" : "Luni",
    "Tuesday" : "Marți",
    "Wednesday" : "Miercuri",
    "Thursday" : "Joi",
    "Friday" : "Vineri",
    "Saturday" : "Sâmbătă",
    "Sunday" : "Duminică",
    "Add time before and after the event" : "Adaugă un interval de timp înainte și după eveniment",
    "Before the event" : "Înainte și după",
    "After the event" : "După eveniment",
    "Planning restrictions" : "Planifică retricții",
    "Minimum time before next available slot" : "Timpul minim înaintea următorului slot de timp disponibil",
    "Max slots per day" : "Numărul de sloturi pe zi",
    "Limit how far in the future appointments can be booked" : "Limitează cât timp în viitor programările pot fi create",
    "Create appointment" : "Creează programare",
    "Edit appointment" : "Editează programarea",
    "Save" : "Salvează",
    "Update" : "Actualizare",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ți-am trimis un email cu detalii. Te rugăm să confirmi programarea ta folosind linkul din email. Poți închide această pagină acum.",
    "Your name" : "Numele tău",
    "Your email address" : "Adresa ta de email",
    "Please share anything that will help prepare for our meeting" : "Te rugăm să împărtășești orice informație ce ne poate ajuta în pregătirea pentru ședința noastră.",
    "Could not book the appointment. Please try again later or contact the organizer." : "Nu s-a putut creea evenimentul. Vă rugăm să încercați mai târziu sau să contactați organizatorul.",
    "Book the appointment" : "Creează programarea",
    "Reminder" : "Memento",
    "before at" : "Înainte de la",
    "Notification" : "Notificări",
    "Email" : "Email",
    "Audio notification" : "Notificări audio",
    "Other notification" : "Alte notificări",
    "Relative to event" : "Raportat la eveniment",
    "On date" : "Pe data",
    "Edit time" : "Editează ora",
    "Save time" : "Salvează ora",
    "Remove reminder" : "Elimină memento",
    "on" : "pe",
    "at" : "la",
    "+ Add reminder" : "+ Adaugă memento",
    "Add reminder" : "Adaugă memento",
    "_second_::_seconds_" : ["secundă","secunde","secunde"],
    "_minute_::_minutes_" : ["minut","minute","minute"],
    "_hour_::_hours_" : ["oră","ore","ore"],
    "_day_::_days_" : ["zi","zile","zile"],
    "_week_::_weeks_" : ["săptămână","săptămâni","săptămâni"],
    "Available" : "Disponibil",
    "Not available" : "Nu este disponibil",
    "Availability of attendees, resources and rooms" : "Disponibilitatea participanților, resurse și camere",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "Busy (tentative)" : "Ocupat (tetentativ)",
    "Busy" : "Ocupat",
    "Out of office" : "În afara serviciului",
    "Unknown" : "Necunoscut",
    "Accept" : "Accept",
    "Decline" : "Refuză",
    "Tentative" : "Tentativă",
    "The invitation has been accepted successfully." : "Invitația a fost acceptată cu succes.",
    "Failed to accept the invitation." : "Nu s-a acceptat invitația.",
    "The invitation has been declined successfully." : "Invitația a fost refuzată cu succes.",
    "Failed to decline the invitation." : "Invitația nu a putut fi refuzată.",
    "Your participation has been marked as tentative." : "Participarea a fost marcată ca o încercare.",
    "Create Talk room for this event" : "Creează o cameră Talk pentru acest eveniment",
    "No attendees yet" : "Nu exista participați încă",
    "Error creating Talk room" : "Camera Talk nu a putut fi creată",
    "Send email" : "Trimite email-ul",
    "Chairperson" : "Președinte",
    "Required participant" : "Participanți necesari",
    "Optional participant" : "Participanți opționali",
    "Remove attendee" : "Elimină participant",
    "(organizer)" : "(organizator)",
    "Remove color" : "Șterge culoarea",
    "Event title" : "Titlul evenimentului",
    "All day" : "Toată ziua",
    "from {startDate}" : "începând cu {startDate}",
    "from {startDate} at {startTime}" : "începând cu {startDate} de la {startTime}",
    "to {endDate}" : "către {endDate}",
    "to {endDate} at {endTime}" : "către {endDate} până la {endTime}",
    "Repeat" : "Repetă",
    "End repeat" : "Încheie seria",
    "Select to end repeat" : "Selectează pentru a încheia seria",
    "never" : "niciodată",
    "on date" : "la data ",
    "after" : "după",
    "first" : "primul",
    "third" : "al treilea",
    "fourth" : "al patrulea",
    "fifth" : "al cincilea",
    "second to last" : "penultimul",
    "last" : "ultimul",
    "Repeat every" : "Se repetă la fiecare",
    "By day of the month" : "după ziua lunii",
    "On the" : "Pe",
    "_month_::_months_" : ["lună","luni","luni"],
    "_year_::_years_" : ["an","ani","ani"],
    "Suggestions" : "Sugestii",
    "Add resource" : "Adaugă resurse",
    "Has a projector" : "Conține un proiector",
    "Has a whiteboard" : "Conține o tablă de scris",
    "Wheelchair accessible" : "Accesibilă folosind un scaun cu rotile",
    "Remove resource" : "Elimină resurse",
    "Projector" : "Proiector",
    "Whiteboard" : "Tablă de scris",
    "Search for resources or rooms" : "Caută resurse sau camere",
    "available" : "disponibil",
    "unavailable" : "nedisponibil",
    "Room type" : "Tipul de cameră",
    "Any" : "Toate",
    "Minimum seating capacity" : "Capacitatea minimă",
    "More" : "Mai mult",
    "Update this occurrence" : "Actualizați această ședință",
    "Public calendar does not exist" : "Calendarul public nu există",
    "Please select a time zone:" : "Te rugăm să alegeți un fus orar:",
    "Pick a time" : "Alege un interval orar",
    "Pick a date" : "Alege o dată",
    "Global" : "Global",
    "Time:" : "Timp:",
    "Booked for:" : "Rezervat pentru:",
    "Personal" : "Personal",
    "Details" : "Detalii",
    "Attendees" : "Participanți",
    "Close" : "Închide",
    "Anniversary" : "Aniversare",
    "Vacation" : "Vacanță",
    "Midnight on the day the event starts" : "La miezul nopții în ziua în care evenimentul începe",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : [" %n zi înainte de evenimentul de la {formattedHourMinute}","%n zile înainte de evenimentul de la {formattedHourMinute}","%n de zile înainte de evenimentul de la {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n săptămână înainte de evenimentul de la {formattedHourMinute}","%n săptămânii înainte de evenimentul de la {formattedHourMinute}","%n de săptămânii înainte de evenimentul de la {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "în ziua evenimentului de la {formattedHourMinute}",
    "at the event's start" : "La începutul evenimentului",
    "at the event's end" : "la finalul evenimentului",
    "{time} before the event starts" : "{time} înainte ca evenimentul să înceapă",
    "{time} before the event ends" : "{time} înainte de finalul evenimentului",
    "{time} after the event starts" : "{time} după ce evenimentul începe",
    "{time} after the event ends" : "{time} după ce evenimentul se termină",
    "on {time}" : "la {time}",
    "on {time} ({timezoneId})" : "la {time} ({timezoneId})",
    "Week {number} of {year}" : "Săptămâna {number} din {year}",
    "Does not repeat" : "Nu se repetă",
    "Daily" : "Zilnic",
    "Weekly" : "Săptămânal",
    "Monthly" : "Lunar",
    "Yearly" : "Anual",
    "_Every %n day_::_Every %n days_" : ["La fiecare %n zi","La fiecare %n zile","La fiecare %n de zile"],
    "_Every %n week_::_Every %n weeks_" : ["La fiecare %n zi","La fiecare %n săptămâni","La fiecare %n de săptămâni"],
    "_Every %n month_::_Every %n months_" : ["La fiecare %n lună","La fiecare luni","La fiecare %n de luni"],
    "_Every %n year_::_Every %n years_" : ["La fiecare %n an","La fiecare %n ani","La fiecare %n de ani"],
    "_on {weekday}_::_on {weekdays}_" : ["în {weekdays}","în {weekdays}","în {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["în ziua de {dayOfMonthList}","în zilele de {dayOfMonthList}","în zilele de {dayOfMonthList}"],
    "in {monthNames}" : "în {monthNames}",
    "until {untilDate}" : "până {untilDate}",
    "_%n time_::_%n times_" : ["%n zi","%n zile","%n de zile"],
    "Untitled event" : "Eveniment fără titlu",
    "Untitled task" : "Sarcină fără titlu",
    "Please ask your administrator to enable the Tasks App." : "Vă rugăm să întrebați administratorul dmneavoastră să pornească aplicația Task.",
    "Prev" : "Precedent",
    "Next" : "Următorul",
    "Prev year" : "Anul anterior",
    "Next year" : "Aanul viitor",
    "Year" : "An",
    "W" : "W",
    "%n more" : "%n mai mult",
    "No events to display" : "Nu sunt evenimente de afișat",
    "_+%n more_::_+%n more_" : ["+%n în plus","+%n în plus","+%n în plus"],
    "No events" : "Niciun eveniment",
    "Create a new event or change the visible time-range" : "Creează un  eveniment nou sau schimbă intervalul de timp",
    "It might have been deleted, or there was a typo in a link" : "Probail a fost șters, sau a fost o greașeală în linkul primit",
    "It might have been deleted, or there was a typo in the link" : "Probail a fost șters, sau a fost o greașeală în linkul primit",
    "Meeting room" : "Sală de ședințe",
    "Lecture hall" : "Sala de lectură",
    "Seminar room" : "Sală de seminar",
    "Other" : "Altele",
    "When shared show" : "Cănd se partajează mai jos",
    "When shared show full event" : "Arată tot evenimentul la partajare",
    "When shared show only busy" : "Arată doar ocupat la partajare",
    "When shared hide this event" : "Ascunde evenimentul la partajare",
    "The visibility of this event in shared calendars." : "Vizibilitatea acestui eveniment în calendarele partajate.",
    "Add a location" : "Adaugă o locație",
    "Add a description" : "Adauga o descripție",
    "Status" : "Stare",
    "Confirmed" : "Confirmat",
    "Canceled" : "Anulat",
    "Confirmation about the overall status of the event." : "Confirmarea statusului evenimentului.",
    "Show as" : "Arată-ne",
    "Take this event into account when calculating free-busy information." : "Ține cont de acest eveniment în momentul calculării timpului liber.",
    "Categories" : "Categorii",
    "Commuting" : "În deplasare",
    "Talk" : "Discuție",
    "Movie" : "Film",
    "Mail" : "Mail",
    "Sports" : "Sport",
    "Exercise" : "Exerciții fizice",
    "Work out" : "Antrenament",
    "Working out" : "Antrenare",
    "Gym" : "Sală de sport",
    "Barber" : "Frizerie",
    "Haircut" : "Tunsoare",
    "Hairdresser" : "Frizer",
    "Exam" : "Examen",
    "Written test" : "Test scris",
    "Oral test" : "Test oral",
    "Working" : "Muncă",
    "New Years Eve" : "Revelion",
    "NYE" : "NYE",
    "Fireworks" : "Artificii",
    "Running" : "Alergat",
    "Go for a run" : "Dute la alergat",
    "Marathon" : "on",
    "Video-conference" : "Conferință video",
    "Conference-call" : "Apel tip conferință",
    "Video-call" : "Apel video",
    "Video-chat" : "Apel video",
    "Video-meeting" : "Șediță video",
    "Calling" : "Apelare",
    "Christmas" : "Crăciun",
    "Conference" : "Conferință",
    "Pizza" : "Pizza",
    "Travelling" : "Călătorie",
    "Trip" : "Excursie",
    "Journey" : "Călătorie",
    "Collaborate" : "Colaborează",
    "Pair" : "Pereche",
    "Lecture" : "Ore de curs",
    "Seminar" : "Seminar",
    "Teaching" : "Predare",
    "Photograph" : "Fotografie",
    "Party" : "Petrecere",
    "Celebration" : "Sărbătorire",
    "Celebrate" : "Serbează",
    "Birthday" : "Zi de naștere",
    "Shopping" : "Shopping",
    "Groceries" : "Cumpărături",
    "Skate" : "Skate",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Degustare de vin",
    "Golf" : "Golf",
    "Dinner" : "Cină",
    "Lunch" : "Prânz",
    "Appointment not found" : "Programarea nu a fost găsită",
    "User not found" : "Utilizatorul nu a fost găsit"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
