OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Kullanıcı oturumunun geçerlilik süresi beklenmedik şekilde doldu",
    "Provided email-address is not valid" : "Belirtilen e-posta adresi geçersiz",
    "%s has published the calendar »%s«" : "%s, »%s« takvimini yayınladı",
    "Unexpected error sending email. Please contact your administrator." : "E-posta gönderilirken beklenmeyen bir sorun çıktı. Lütfen BT yöneticiniz ile görüşün.",
    "Successfully sent email to %1$s" : "E-posta %1$s adresine gönderildi",
    "Hello," : "Merhaba,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Bu ileti %s tarafından »%s« takviminin yayınlandığını bildirmek için gönderilmiştir.",
    "Open »%s«" : "»%s« aç",
    "Cheers!" : "Görüşmek üzere",
    "Upcoming events" : "Yaklaşan etkinlikler",
    "Appointments" : "Randevular",
    "Schedule appointment \"%s\"" : "\"%s\" randevusu al",
    "Schedule an appointment" : "Bir randevu alın",
    "Prepare for %s" : "%s için hazırlan",
    "Follow up for %s" : "%s için takip",
    "Your appointment \"%s\" with %s needs confirmation" : "\"%s\" randevunuzun (%s ile) onaylanması gerekiyor",
    "Dear %s, please confirm your booking" : "Sayın %s, lütfen randevunuzu onaylayın",
    "Confirm" : "Onayla",
    "This confirmation link expires in %s hours." : "Bu onay bağlantısının geçerlilik süresi %s saat sonra dolacak.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Sonuçta randevuyu iptal etmek isterseniz, lütfen bu e-postayı yanıtlayarak ya da profil sayfasını ziyaret ederek düzenleyici ile görüşün.",
    "Your appointment \"%s\" with %s has been accepted" : "\"%s\" randevunuz (%s ile) onaylandı",
    "Dear %s, your booking has been accepted." : "Sayın %s, randevunuz onaylandı.",
    "Appointment for:" : "Randevu:",
    "Date:" : "Tarih:",
    "Where:" : "Yer:",
    "Your Comment:" : "Yorumunuz:",
    "Calendar" : "Takvim",
    "A Calendar app for Nextcloud" : "Nextcloud takvim uygulaması",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Takvim uygulaması Nextcloud CalDAV sunucusunun kullanıcı arayüzüdür. Çeşitli aygıtlar üzerindeki etkinlikleri kolayca Nextcloud hesabınız ile eşitler ve çevrimiçi olarak düzenlemenizi sağlar.\n\n* 🚀 **Diğer Nextcloud uygulamaları ile bütünleşiktir!** Şu anda Kişiler, diğerleri yolda.\n* 🌐 **WebCal Desteği!** Tuttuğunuz takımın maçlarını takvimde görmek isterseniz sorun değil!\n* 🙋 **Katılımcılar!** Etkinliklerinize kişileri çağırabilirsiniz\n* ⌚️ **Serbest/Meşgul:** Katılımcılarınız ile ne zaman görüşebileceğinize bakabilirsiniz\n* ⏰ **Anımsatıcılar!** Etkinlik bildirimlerini web tarayıcınızdan ve e-posta olarak alabilirsiniz\n* 🔍 Arama! Etkinliklerinizi kolayca bulabilirsiniz\n* ☑️ Görevler! Görevleri bitiş tarihleri ile takvim üzerinde görebilirsiniz\n* 🙈 **Tekerleği yeniden keşfetmiyoruz!** Harika [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) ve [fullcalendar](https://github.com/fullcalendar/fullcalendar) kitaplıklarını kullanıyoruz.",
    "Previous day" : "Önceki gün",
    "Previous week" : "Önceki hafta",
    "Previous month" : "Önceki ay",
    "Next day" : "Sonraki gün",
    "Next week" : "Sonraki hafta",
    "Next month" : "Sonraki ay",
    "New event" : "Yeni etkinlik",
    "Today" : "Bugün",
    "Day" : "Gün",
    "Week" : "Hafta",
    "Month" : "Ay",
    "List" : "Listele",
    "Preview" : "Ön izleme",
    "Copy link" : "Bağlantıyı kopyala",
    "Edit" : "Düzenle",
    "Delete" : "Sil",
    "Appointment link was copied to clipboard" : "Randevu bağlantısı panoya kopyalandı",
    "Appointment link could not be copied to clipboard" : "Randevu bağlantısı panoya kopyalanamadı",
    "Add new" : "Yeni ekle",
    "Untitled calendar" : "Adlandırılmamış takvim",
    "Edit name" : "Adı düzenle",
    "Saving name …" : "Ad kaydediliyor …",
    "Edit color" : "Rengi düzenle",
    "Saving color …" : "Renk kaydediliyor …",
    "Copy private link" : "Kişisel bağlantıyı kopyala",
    "Export" : "Dışa aktar",
    "Unshare from me" : "Benimle paylaşımı kaldır",
    "Disable calendar \"{calendar}\"" : "\"{calendar}\" takvimini devre dışı bırak",
    "Disable untitled calendar" : "Adlandırılmamış takvimi devre dışı bırak",
    "Enable calendar \"{calendar}\"" : "\"{calendar}\" takvimini etkinleştir",
    "Enable untitled calendar" : "Adlandırılmamış takvimi etkinleştir",
    "An error occurred, unable to change visibility of the calendar." : "Bir sorun çıktı. Takvimin görünürlüğü değiştirilemedi.",
    "An error occurred, unable to delete the calendar." : "Bir sorun çıktı. Takvim silinemedi.",
    "Calendar link copied to clipboard." : "Takvim bağlantısı panoya kopyalandı.",
    "Calendar link could not be copied to clipboard." : "Takvim bağlantısı panoya kopyalanamadı.",
    "An error occurred, unable to rename the calendar." : "Bir sorun çıktı. Takvim yeniden adlandırılamadı.",
    "An error occurred, unable to change the calendar's color." : "Bir sorun çıktı. Takvimin rengi değiştirilemedi.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Takvim {countdown} saniye içinde paylaşımdan kaldırılacak","Takvim {countdown} saniye içinde paylaşımdan kaldırılacak"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Takvim {countdown} saniye içinde silinecek","Takvim {countdown} saniye içinde silinecek"],
    "Share link" : "Paylaşım bağlantısı",
    "Publish calendar" : "Takvimi yayınla",
    "Publishing calendar" : "Takvim yayınlanıyor",
    "Copy public link" : "Herkese açık bağlantıyı kopyala",
    "Send link to calendar via email" : "Takvim bağlantısını e-posta ile gönder",
    "Enter one address" : "Bir adres yazın",
    "Sending email …" : "E-posta kaydediliyor …",
    "Copy subscription link" : "Abonelik bağlantısını kopyala",
    "Copying link …" : "Bağlantı kopyalanıyor …",
    "Copied link" : "Bağlantı kopyalandı",
    "Could not copy link" : "Bağlantı kopyalanamadı",
    "Copy embedding code" : "Gömme kodunu kopyala",
    "Copying code …" : "Kod kopyalanıyor …",
    "Copied code" : "Kod kopyalandı",
    "Could not copy code" : "Kod kopyalanamadı",
    "Delete share link" : "Paylaşım bağlantısını sil",
    "Deleting share link …" : "Paylaşım bağlantısı siliniyor …",
    "An error occurred, unable to publish calendar." : "Bir sorun çıktı. Takvim yayınlanamadı.",
    "An error occurred, unable to send email." : "Bir sorun çıktığından e-posta gönderilemedi.",
    "Embed code copied to clipboard." : "Gömme kodu panoya kopyalandı.",
    "Embed code could not be copied to clipboard." : "Gömme kodu panoya kopyalanamadı.",
    "Unpublishing calendar failed" : "Takvim yayından kaldırılamadı",
    "Share with users or groups" : "Kullanıcı ya da gruplar ile paylaş",
    "No users or groups" : "Herhangi bir kullanıcı ya da grup yok",
    "can edit" : "düzenleyebilir",
    "Unshare with {displayName}" : "{displayName} ile paylaşımı kaldır",
    "An error occurred, unable to change the unshare the calendar." : "Bir sorun çıktı. Takvimin paylaşımdan kaldırma ayarı değiştirilemedi.",
    "An error occurred, unable to change the permission of the share." : "Bir sorun çıktı. Takvimin izin ayarı değiştirilemedi.",
    "New calendar" : "Takvim ekle",
    "Name for new calendar" : "Yeni takvimin adı",
    "Creating calendar …" : "Takvim oluşturuluyor …",
    "New calendar with task list" : "Görev listesi ile yeni takvim",
    "New subscription from link (read-only)" : "Bağlantıdan yeni abonelik (salt okunur)",
    "Creating subscription …" : "Abonelik oluşturuluyor …",
    "An error occurred, unable to create the calendar." : "Bir sorun çıktı. Takvim eklenemedi.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lütfen geçerli bir bağlantı yazın (http://, https://, webcal:// ya da webcals:// ile başlayan)",
    "Trash bin" : "Çöp kutusu",
    "Loading deleted items." : "Silinmiş ögeler yükleniyor.",
    "You do not have any deleted items." : "Silinmiş herhangi bir ögeniz yok.",
    "Name" : "Ad",
    "Deleted" : "Silinmiş",
    "Restore" : "Geri yükle",
    "Delete permanently" : "Kalıcı olarak sil",
    "Empty trash bin" : "Çöp kutusunu boşalt",
    "Untitled item" : "Adlandırılmamış öge",
    "Unknown calendar" : "Bilinmeyen takvim",
    "Could not load deleted calendars and objects" : "Silinmiş takvim ve nesneler yüklenemedi",
    "Could not restore calendar or event" : "Takvim ya da etkinlik geri yüklenemedi",
    "Do you really want to empty the trash bin?" : "Çöp kutusunu boşaltmak istediğinize emin misiniz?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Çöp kutusundaki ögeler {numDays} gün sonra silinir","Çöp kutusundaki ögeler {numDays} gün sonra silinir"],
    "Could not update calendar order." : "Takvim sıralaması güncellenemedi.",
    "Import calendars" : "Takvimleri içe aktar",
    "Please select a calendar to import into …" : "Lütfen içine aktarılacak bir takvim seçin …",
    "Filename" : "Dosya adı",
    "Calendar to import into" : "İçine aktarılacak takvim",
    "Cancel" : "İptal",
    "_Import calendar_::_Import calendars_" : ["Takvimi içe aktar","Takvimleri içe aktar"],
    "{filename} could not be parsed" : "{filename} işlenemedi",
    "No valid files found, aborting import" : "Geçerli bir dosya bulunamadı, içe aktarım iptal ediliyor",
    "Import partially failed. Imported {accepted} out of {total}." : "Etkinliklerin tümü içe aktarılamadı. İçe aktarılan: {accepted}, toplam: {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n etkinlik içe aktarıldı","%n etkinlik içe aktarıldı"],
    "Automatic" : "Otomatik",
    "Automatic ({detected})" : "Otomatik ({detected})",
    "New setting was not saved successfully." : "Yeni ayarlar kaydedilemedi.",
    "Shortcut overview" : "Kısayol özeti",
    "or" : "ya da",
    "Navigation" : "Gezinme",
    "Previous period" : "Önceki dönem",
    "Next period" : "Sonraki dönem",
    "Views" : "Görünümler",
    "Day view" : "Günlük görünüm",
    "Week view" : "Haftalık görünüm",
    "Month view" : "Aylık görünüm",
    "List view" : "Liste görünümü",
    "Actions" : "İşlemler",
    "Create event" : "Etkinlik ekle",
    "Show shortcuts" : "Kısayolları görüntüle",
    "Editor" : "Düzenleyici",
    "Close editor" : "Düzenleyiciyi kapat",
    "Save edited event" : "Düzenlenmiş etkinliği kaydet",
    "Delete edited event" : "Düzenlenmiş etkinliği sil",
    "Duplicate event" : "Etkinliği kopyala",
    "Enable birthday calendar" : "Doğum günü takvimi kullanılsın",
    "Show tasks in calendar" : "Görevler takvimde görüntülensin",
    "Enable simplified editor" : "Basitleştirilmiş düzenleyici kullanılsın",
    "Limit visible events per view" : "Bir kerede görüntülenecek etkinlik sayısı",
    "Show weekends" : "Hafta sonları görüntülensin",
    "Show week numbers" : "Hafta numaraları görüntülensin",
    "Time increments" : "Zaman artışı",
    "Default reminder" : "Varsayılan anımsatıcı",
    "Copy primary CalDAV address" : "Birincil CalDAV adresini kopyala",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV adresini kopyala",
    "Personal availability settings" : "Kişisel uygunluk ayarları",
    "Show keyboard shortcuts" : "Kısayol tuşlarını görüntüle",
    "Calendar settings" : "Takvim ayarları",
    "No reminder" : "Herhangi bir anımsatıcı yok",
    "CalDAV link copied to clipboard." : "CalDAV bağlantısı panoya kopyalandı.",
    "CalDAV link could not be copied to clipboard." : "CalDAV bağlantısı panoya kopyalanamadı.",
    "Appointment was created successfully" : "Randevu oluşturuldu",
    "Appointment was updated successfully" : "Randevu güncellendi",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} dakika","{duration} dakika"],
    "0 minutes" : "0 dakika",
    "_{duration} hour_::_{duration} hours_" : ["{duration} saat","{duration} saat"],
    "_{duration} day_::_{duration} days_" : ["{duration} gün","{duration} gün"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} hafta","{duration} hafta"],
    "_{duration} month_::_{duration} months_" : ["{duration} ay","{duration} ay"],
    "_{duration} year_::_{duration} years_" : ["{duration} yıl","{duration} yıl"],
    "To configure appointments, add your email address in personal settings." : "Randevuları yapılandırmak için kişisel ayarlar bölümünden e-posta adresinizi yazın.",
    "Public – shown on the profile page" : "Herkese açık - Profil sayfasında görüntülenir",
    "Private – only accessible via secret link" : "Bireysel - Yalnızca gizli bir bağlantı ile erişilebilir",
    "Location" : "Konum",
    "Description" : "Açıklama",
    "Visibility" : "Görünürlük",
    "Duration" : "Süre",
    "Increments" : "Artımlar",
    "Additional calendars to check for conflicts" : "Çakışmaların denetleneceği diğer takvimler",
    "Pick time ranges where appointments are allowed" : "Randevuların verilebileceği zaman aralıklarını seçin",
    "to" : "ile",
    "Delete slot" : "Aralığı sil",
    "No times set" : "Herhangi bir zaman ayarlanmamış",
    "Add" : "Ekle",
    "Monday" : "Pazartesi",
    "Tuesday" : "Salı",
    "Wednesday" : "Çarşamba",
    "Thursday" : "Perşembe",
    "Friday" : "Cuma",
    "Saturday" : "Cumartesi",
    "Sunday" : "Pazar",
    "Add time before and after the event" : "Etkinlik öncesi ve sonrası zaman ekle",
    "Before the event" : "Etkinlik öncesi",
    "After the event" : "Etkinlik sonrası",
    "Planning restrictions" : "Planlama kısıtlamaları",
    "Minimum time before next available slot" : "Sonraki uygun aralıktan önceki en az süre",
    "Max slots per day" : "Bir gündeki en fazla aralık",
    "Limit how far in the future appointments can be booked" : "Gelecekteki randevuların ne kadar uzağa ayırtılabileceğini sınırlayın",
    "Create appointment" : "Randevu ekle",
    "Edit appointment" : "Randevuyu düzenle",
    "Save" : "Kaydet",
    "Update" : "Güncelle",
    "Please confirm your reservation" : "Lütfen randevunuzu onaylayın",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Randevu bilgilerinizi içeren bir e-posta gönderildi. Randevunuzu onaylamak için lütfen e-posta içeriğindeki bağlantıya tıklayın. Bu sayfayı kapatabilirsiniz.",
    "Your name" : "Adınız",
    "Your email address" : "E-posta adresiniz",
    "Please share anything that will help prepare for our meeting" : "Lütfen görüşmeye hazırlanmak için yardımcı olabilecek şeyleri paylaşın",
    "Could not book the appointment. Please try again later or contact the organizer." : "Randevu alınamadı. Lütfen bir süre sonra yeniden deneyin ya da düzenleyici ile görüşün.",
    "Book the appointment" : "Randevu al",
    "Reminder" : "Anımsatıcı",
    "before at" : "şundan önce",
    "Notification" : "Bildirim",
    "Email" : "E-posta",
    "Audio notification" : "Sesli bildirim",
    "Other notification" : "Diğer bildirim",
    "Relative to event" : "Etkinliğe göre",
    "On date" : "Şu tarihte",
    "Edit time" : "Zamanı düzenle",
    "Save time" : "Zamanı kaydet",
    "Remove reminder" : "Anımsatıcıyı kaldır",
    "on" : "şu gün",
    "at" : "şu saatte",
    "+ Add reminder" : "+ Anımsatıcı ekle",
    "Add reminder" : "Anımsatıcı ekle",
    "_second_::_seconds_" : ["saniye","saniye"],
    "_minute_::_minutes_" : ["dakika","dakika"],
    "_hour_::_hours_" : ["saat","saat"],
    "_day_::_days_" : ["gün","gün"],
    "_week_::_weeks_" : ["hafta","hafta"],
    "Invitation accepted" : "Çağrı onaylandı",
    "Available" : "Uygun",
    "Suggested" : "Önerildi",
    "Participation marked as tentative" : "Katılım belirsiz olarak işaretlendi",
    "Accepted {organizerName}'s invitation" : "{organizerName} tarafından yapılan çağrı onaylandı",
    "Not available" : "Kullanılamaz",
    "Invitation declined" : "Çağrı reddedildi",
    "Declined {organizerName}'s invitation" : "{organizerName} tarafından yapılan çağrı reddedildi",
    "Invitation is delegated" : "Çağrı iletildi",
    "Checking availability" : "Uygunluk denetleniyor",
    "Invitation sent" : "Çağrı gönderildi",
    "Has not responded to {organizerName}'s invitation yet" : "{organizerName} tarafından yapılan çağrıyı yanıtlamadı",
    "Availability of attendees, resources and rooms" : "Katılımcı, kaynak ve odaların kullanılabilirliği",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "Free" : "Serbest",
    "Busy (tentative)" : "Meşgul (belirsiz)",
    "Busy" : "Meşgul",
    "Out of office" : "İş yeri dışında",
    "Unknown" : "Bilinmiyor",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "Tentative" : "Belirsiz",
    "The invitation has been accepted successfully." : "Çağrı kabul edildi.",
    "Failed to accept the invitation." : "Çağrı kabul edilemedi.",
    "The invitation has been declined successfully." : "Çağrı reddedildi.",
    "Failed to decline the invitation." : "Çağrı reddedilemedi.",
    "Your participation has been marked as tentative." : "Katılım durumunuz belirsiz olarak işaretlendi.",
    "Failed to set the participation status to tentative." : "Katılım durumunuz belirsiz olarak işaretlenemedi.",
    "Create Talk room for this event" : "Bu etkinlik için Talk odası oluştur",
    "Show busy times" : "Meşgul zamanlar görüntülensin",
    "No attendees yet" : "Henüz bir katılımcı yok",
    "Successfully appended link to talk room to description." : "Bağlantı Talk odası açıklamasına eklendi.",
    "Error creating Talk room" : "Talk odası oluştururken sorun çıktı",
    "Send email" : "E-posta gönder",
    "Chairperson" : "Oturum başkanı",
    "Required participant" : "Zorunlu katılımcı",
    "Optional participant" : "İsteğe bağlı katılımcı",
    "Non-participant" : "Katılımcı değil",
    "Remove attendee" : "Katılımcıyı çıkar",
    "Search for emails, users or contacts" : "E-posta, kullanıcı ya da kişi arama",
    "No match found" : "Herhangi bir sonuç bulunamadı",
    "(organizer)" : "(düzenleyen)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Çağrı göndermek ve yanıtları işlemek için, [linkopen]kişisel ayarlar bölümünden e-posta adresinizi ekleyin[linkclose].",
    "Remove color" : "Rengi kaldır",
    "Event title" : "Etkinlik başlığı",
    "All day" : "Tüm gün",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Bir yinelenme kümesinin ögesi olan etkinlikler tüm gün olarak ayarlanamaz.",
    "from {startDate}" : "{startDate} tarihinden",
    "from {startDate} at {startTime}" : "{startDate} - {startTime} saatinden",
    "to {endDate}" : "{endDate} tarihine",
    "to {endDate} at {endTime}" : "{endDate} - {endTime} saatine",
    "Repeat" : "Yineleme",
    "End repeat" : "Yinelenme sonu",
    "Select to end repeat" : "Yinelenme sonunu seçin",
    "never" : "asla",
    "on date" : "şu tarihte",
    "after" : "şundan sonra",
    "_time_::_times_" : ["kez","kez"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Bu etkinlik bir yinelenen etkinlik kümesinin ögesi. Bu nedenle bu ögeye bir yinelenme kuralı ekleyemezsiniz.",
    "first" : "birinci",
    "third" : "üçüncü",
    "fourth" : "dördüncü",
    "fifth" : "beşinci",
    "second to last" : "ikinciden sonuncuya",
    "last" : "sonuncu",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Yinelenme kuralındaki değişiklikler yalnızca bu ve sonraki etkinlikler için geçerli olacak.",
    "Repeat every" : "Yinelenme sıklığı",
    "By day of the month" : "Ayın gününde",
    "On the" : "Şu zamanda",
    "_month_::_months_" : ["ay","ay"],
    "_year_::_years_" : ["yıl","yıl"],
    "weekday" : "hafta içi günleri",
    "weekend day" : "hafta sonu günü",
    "No recurrence" : "Yinelenme yok",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Bu etkinliğin yinelenme ayarları Nextcloud tarafından tam olarak desteklenmiyor. Yinelenme ayarlarını düzenlerseniz yinelenen bazı etkinlikler kaybolabilir.",
    "Suggestions" : "Öneriler",
    "No rooms or resources yet" : "Henüz bir oda ya da kaynak yok",
    "Add resource" : "Kaynak ekle",
    "Has a projector" : "Projeksiyon var",
    "Has a whiteboard" : "Beyaz tahta var",
    "Wheelchair accessible" : "Tekerlekli sandalyeye uygun",
    "Remove resource" : "Kaynağı sil",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} koltuk","{seatingCapacity} koltuk"],
    "Projector" : "Projeksiyon",
    "Whiteboard" : "Beyaz tahta",
    "Search for resources or rooms" : "Kaynak ya da oda arama",
    "available" : "kullanılabilir",
    "unavailable" : "kullanılamaz",
    "Room type" : "Oda türü",
    "Any" : "Tümü",
    "Minimum seating capacity" : "En az oturma yeri sayısı",
    "More" : "Diğer",
    "Update this occurrence" : "Bu etkinliği güncelle",
    "Update this and all future" : "Bu ve sonraki etkinlikleri güncelle",
    "Public calendar does not exist" : "Herkese açık takvim bulunamadı",
    "Maybe the share was deleted or has expired?" : "Paylaşım silinmiş ya da geçerlilik süresi dolmuş olabilir mi?",
    "Please select a time zone:" : "Lütfen bir saat dilimi seçin:",
    "Pick a time" : "Bir saat seçin",
    "Pick a date" : "Bir tarih seçin",
    "from {formattedDate}" : "{formattedDate} tarihinden",
    "to {formattedDate}" : "{formattedDate} tarihine",
    "on {formattedDate}" : "{formattedDate} tarihinde",
    "from {formattedDate} at {formattedTime}" : "{formattedDate} tarihi {formattedTime} saatinden",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} tarihi {formattedTime} saatine",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} tarihi {formattedTime} saatinde",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} saatinde",
    "Please enter a valid date" : "Lütfen geçerli bir tarih yazın",
    "Please enter a valid date and time" : "Lütfen geçerli bir tarih ve saat yazın",
    "Type to search time zone" : "Saat dilimi aramak için yazmaya başlayın",
    "Global" : "Genel",
    "Select date" : "Tarih seçin",
    "Select slot" : "Aralık seçin",
    "No slots available" : "Seçilebilecek bir aralık yok",
    "The slot for your appointment has been confirmed" : "Randevunuzun aralığı onaylandı",
    "Appointment Details:" : "Randevu bilgileri:",
    "Time:" : "Saat:",
    "Booked for:" : "Ayırtılan:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Teşekkürler. {startDate} - {endDate} randevunuz onaylandı.",
    "Book another appointment:" : "Başka bir randevu daha al:",
    "See all available slots" : "Tüm aralıkları görüntüle",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Randevunuzun {startDate} - {endDate} aralığı artık uygun değil.",
    "Please book a different slot:" : "Lütfen farklı bir aralık seçin:",
    "Book an appointment with {name}" : "{name} için bir randevu alın",
    "No public appointments found for {name}" : "{name} için herkese açık bir randevu bulunamadı",
    "Personal" : "Kişisel",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Otomatik saat dilimi algılaması saat diliminizi UTC olarak belirledi.\nBu durum genellikle web tarayıcınızın sağladığı bir güvenlik önleminden kaynaklanır.\nLütfen takvim ayarları bölümünden saat diliminizi el ile ayarlayın.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Yapılandırılmış saat diliminiz {{timezoneId}} bulunamadı. UTC dilimine dönülüyor.\nLütfen ayarlardan saat diliminizi değiştirin ve bu sorunu bildirin.",
    "No more events today" : "Bugün başka bir etkinlik yok",
    "No upcoming events" : "Yaklaşan bir etkinlik yok",
    "Create a new event" : "Etkinlik ekle",
    "[Today]" : "[Bugün]",
    "[Tomorrow]" : "[Yarın]",
    "[Yesterday]" : "[Dün]",
    "[Last] dddd" : "[Son] dddd",
    "Event does not exist" : "Etkinlik bulunamadı",
    "Duplicate" : "Kopyala",
    "Delete this occurrence" : "Bu etkinliği sil",
    "Delete this and all future" : "Bu ve sonraki etkinlikleri sil",
    "Details" : "Ayrıntılar",
    "Attendees" : "Katılanlar",
    "Resources" : "Kaynaklar",
    "Close" : "Kapat",
    "Show more details" : "Diğer ayrıntıları görüntüle",
    "Subscribe to {name}" : "{name} takvimine abone ol",
    "Export {name}" : "{name} dışa aktar",
    "Anniversary" : "Yıl dönümü",
    "Appointment" : "Randevu",
    "Business" : "İş",
    "Education" : "Eğitim",
    "Holiday" : "Tatil",
    "Meeting" : "Toplantı",
    "Miscellaneous" : "Diğer",
    "Non-working hours" : "Çalışma dışı saatler",
    "Not in office" : "İş yerinde değil",
    "Phone call" : "Telefon çağrısı",
    "Sick day" : "Hastalık",
    "Special occasion" : "Özel durum",
    "Travel" : "Gezi",
    "Vacation" : "Tatil",
    "Midnight on the day the event starts" : "Etkinliğin başladığı günün gece yarısı",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["etkinlikten %n gün önce {formattedHourMinute}","etkinlikten %n gün önce {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["etkinlikten %n hafta önce {formattedHourMinute}","etkinlikten %n hafta önce {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "etkinlik gününde {formattedHourMinute} saatinde",
    "at the event's start" : "etkinlik başlangıcında",
    "at the event's end" : "etkinlik bitiminde",
    "{time} before the event starts" : "etkinlik başlamadan {time} önce",
    "{time} before the event ends" : "etkinlik bitiminden {time} önce",
    "{time} after the event starts" : "etkinlik başlangıcından {time} sonra",
    "{time} after the event ends" : "etkinlik bitiminden {time} sonra",
    "on {time}" : "{time} saatinde",
    "on {time} ({timezoneId})" : "{time} ({timezoneId}) zamanında",
    "Week {number} of {year}" : "{year} yılının {number}. haftasında",
    "Does not repeat" : "Yinelenmiyor",
    "Daily" : "Günlük",
    "Weekly" : "Haftalık",
    "Monthly" : "Aylık",
    "Yearly" : "Yıllık",
    "_Every %n day_::_Every %n days_" : ["1%n günde bir","1%n günde bir"],
    "_Every %n week_::_Every %n weeks_" : ["1%n haftada bir","1%n haftada bir"],
    "_Every %n month_::_Every %n months_" : ["1%n ayda bir","1%n ayda bir"],
    "_Every %n year_::_Every %n years_" : ["1%n yılda bir","1%n yılda bir"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday} gününde","{weekdays} günlerinde"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["{dayOfMonthList} gününde","{dayOfMonthList} günlerinde"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet} gününde",
    "in {monthNames}" : "{monthNames} aylarında",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames} aylarında {ordinalNumber} {byDaySet} gününde",
    "until {untilDate}" : "{untilDate} tarihine kadar",
    "_%n time_::_%n times_" : ["%n kez","%n kez"],
    "Untitled event" : "Adlandırılmamış etkinlik",
    "Untitled task" : "Adlandırılmamış görev",
    "Please ask your administrator to enable the Tasks App." : "Lütfen Görevler Uygulamasını etkinleştirmesi için BT yöneticinizle görüşün.",
    "Prev" : "Önceki",
    "Next" : "Sonraki",
    "Prev year" : "Önceki yıl",
    "Next year" : "Sonraki yıl",
    "Year" : "Yıl",
    "W" : "W",
    "%n more" : "%n diğer",
    "No events to display" : "Görüntülenebilecek bir etkinlik yok",
    "_+%n more_::_+%n more_" : ["+%n diğer","+%n diğer"],
    "No events" : "Henüz bir etkinlik yok",
    "Create a new event or change the visible time-range" : "Yeni bir etkinlik ekleyin ya da görüntülenen zaman aralığını değiştirin",
    "It might have been deleted, or there was a typo in a link" : "Silinmiş olabilir ya da bir bağlantıda bir yazım hatası var",
    "It might have been deleted, or there was a typo in the link" : "Silinmiş olabilir ya da bağlantıda bir yazım hatası var",
    "Meeting room" : "Toplantı odası",
    "Lecture hall" : "Konferans salonu",
    "Seminar room" : "Seminer odası",
    "Other" : "Diğer",
    "When shared show" : "Paylaşıldığında görüntülenecek",
    "When shared show full event" : "Paylaşıldığında tüm etkinlik ayrıntıları görüntülensin",
    "When shared show only busy" : "Paylaşıldığında yalnızca meşgul olarak görüntülensin",
    "When shared hide this event" : "Paylaşıldığında bu etkinlik gizlensin",
    "The visibility of this event in shared calendars." : "Bu etkinliğin paylaşılmış takvimlerdeki görünümü.",
    "Add a location" : "Bir konum ekleyin",
    "Add a description" : "Bir açıklama ekleyin",
    "Status" : "Durum",
    "Confirmed" : "Kabul edildi",
    "Canceled" : "İptal edildi",
    "Confirmation about the overall status of the event." : "Etkinliğin genel kabul edilme durumu.",
    "Show as" : "Şu şekilde görüntülensin",
    "Take this event into account when calculating free-busy information." : "Serbest, meşgul zamanlar hesaplanırken bu etkinlik hesaba katılsın.",
    "Categories" : "Kategoriler",
    "Categories help you to structure and organize your events." : "Kategorileri kullanarak etkinliklerinizi düzenleyebilirsiniz.",
    "Search or add categories" : "Kategori ara ya da ekle",
    "Add this as a new category" : "Bunu yeni bir kategori olarak ekle",
    "Custom color" : "Özel renk",
    "Special color of this event. Overrides the calendar-color." : "Özel etkinlik rengi, takvim renginin yerine kullanılır.",
    "Chat room for event" : "Etkinliğin sohbet odası",
    "Imported {filename}" : "{filename} içe aktarıldı",
    "Meditation" : "Meditasyon",
    "Relaxing" : "Rahatlama",
    "Relax" : "Rahat",
    "Break" : "Kırık",
    "Commute" : "İşe gidiş/geliş",
    "Commuting" : "İşe gidip/gelme",
    "Shuttle" : "Mekik",
    "Invoice" : "Fatura",
    "Finance" : "Finans",
    "Bank" : "Banka",
    "Money" : "Para",
    "Wedding" : "Düğün",
    "Dog" : "Köpek",
    "Concert" : "Konser",
    "Festival" : "Festival",
    "Theater" : "Tiyatro",
    "Theatre" : "Tiyatro",
    "Presentation" : "Sunum",
    "Talk" : "Görüşme",
    "Speech" : "Konuşma",
    "Deadline" : "Bitiş tarihi",
    "Submission" : "Teslim",
    "Reporting" : "Rapor",
    "Camping" : "Kampçılık",
    "Camp" : "Kamp",
    "Election" : "Seçim",
    "Voting" : "Oylama",
    "Vote" : "Oy",
    "Barbecue" : "Mangal",
    "Barbeque" : "Mangal",
    "Garden" : "Bahçe",
    "Farm" : "Çiftlik",
    "Movie" : "Film",
    "Cinema" : "Sinema",
    "Graduation" : "Mezuniyet",
    "Brainstorm" : "Beyin Fırtınası",
    "Review" : "Gözden geçirme",
    "Audit" : "Denetim",
    "Inspection" : "İnceleme",
    "Proofreading" : "Düzeltme",
    "Baseball" : "Beyzbol",
    "Meet" : "Toplan",
    "Planning" : "Planlama",
    "Pointing" : "İşaret etme",
    "Retrospective" : "Geçmişi değerlendirme",
    "Office" : "Ofis",
    "Contributor week" : "Katılımcı haftası",
    "Mail" : "Posta",
    "Soccer" : "Futbol",
    "Football" : "Amerikan futbolu",
    "Gaming" : "Oyun",
    "Drive" : "Sürüş",
    "Driving" : "Sürüş",
    "Bicycle" : "Bisiklet",
    "Cycle" : "Bisiklet",
    "Cycling" : "Bisiklet",
    "Biking" : "Bisiklete ninme",
    "Bike" : "Bisiklet",
    "Podcast" : "Podcast",
    "Basketball" : "Basketbol",
    "Fishing" : "Balık tutma",
    "Hiking" : "Doğa yürüyüşü",
    "Hike" : "Yürüyüş",
    "Art" : "Sanat",
    "Exhibition" : "Sergi",
    "Museum" : "Müze",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Walk" : "Yürüyüş",
    "Studying" : "Ders Çalışma",
    "Doctor" : "Doktor",
    "Health" : "Sağlık",
    "Dentist" : "Dişçi",
    "Hospital" : "Hastane",
    "Interview" : "Röportaj",
    "Training" : "Antrenman",
    "Practice" : "Uygulama",
    "Sports" : "Spor",
    "Exercise" : "Egzersiz",
    "Work out" : "Spor çalışması",
    "Working out" : "Saha çalışması",
    "Gym" : "Gym",
    "Barber" : "Berber",
    "Haircut" : "Saç kesimi",
    "Hairdresser" : "Kuaför",
    "Exam" : "Sınav",
    "Written test" : "Yazılı sınav",
    "Oral test" : "Sözlü sınav",
    "Working" : "İş",
    "New Years Eve" : "Yılbaşı gecesi",
    "NYE" : "Yılbaşı",
    "Fireworks" : "Havai Fişek",
    "Running" : "Koşu",
    "Go for a run" : "Koşuya git",
    "Marathon" : "Maraton",
    "Video-conference" : "Görüntülü toplu görüşme",
    "Conference-call" : "Konferans çağrısı",
    "Video-call" : "Görüntülü çağrı",
    "Video-chat" : "Görüntülü sohbet",
    "Video-meeting" : "Görüntülü toplantı",
    "Call" : "Çağrı",
    "Calling" : "Çağrı",
    "Christmas" : "Noel",
    "Conference" : "Konferans",
    "Pizza" : "Pizza",
    "Travelling" : "Gezi",
    "Trip" : "Yolculuk",
    "Journey" : "Yolculuk",
    "Collaborate" : "İşbirliği",
    "Pair" : "Eşleştir",
    "Lecture" : "Ders",
    "Seminar" : "Seminer",
    "Teaching" : "Ders",
    "Photograph" : "Fotoğraf",
    "Party" : "Parti",
    "Celebration" : "Kutlama",
    "Celebrate" : "Kutlama",
    "Birthday" : "Doğum günü",
    "Shopping" : "Alışveriş",
    "Groceries" : "Market",
    "Skate" : "Kayak",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Şarap tadımı",
    "Golf" : "Golf",
    "Dinner" : "Akşam yemeği",
    "Lunch" : "Öğle yemeği",
    "Appointment not found" : "Randevu bulunamadı",
    "User not found" : "Kullanıcı bulunamadı"
},
"nplurals=2; plural=(n > 1);");
