OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s publikigis la kalendaron „%s“",
    "Hello," : "Saluton,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Ni volis sciigi vin, ke %s publikigis la kalendaron „%s“.",
    "Open »%s«" : "Malfermi „%s“",
    "Cheers!" : "Ĝis!",
    "Confirm" : "Konfirmi",
    "Date:" : "Dato:",
    "Where:" : "Kie:",
    "Calendar" : "Kalendaro",
    "A Calendar app for Nextcloud" : "Aplikaĵo pri kalendaro por Nextcloud",
    "New event" : "Nova okazaĵo",
    "Today" : "Hodiaŭ",
    "Day" : "Tago",
    "Week" : "Semajno",
    "Month" : "Monato",
    "Preview" : "Antaŭvidi",
    "Copy link" : "Kopii ligilon",
    "Edit" : "Modifi",
    "Delete" : "Forigi",
    "Copy private link" : "Kopii privatan ligilon",
    "Export" : "Eksporti",
    "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
    "Calendar link could not be copied to clipboard." : "Kalendara ligilo ne eblis esti kopiita al tondujo",
    "Share link" : "Kunhavigi ligilon",
    "Delete share link" : "Forigi kunhavo-ligilon",
    "Share with users or groups" : "Kunhavigi kun uzantoj aŭ grupoj",
    "No users or groups" : "Neniu uzanto aŭ grupo",
    "can edit" : "povas redakti",
    "New calendar" : "Nova kalendaro",
    "Name" : "Nomo",
    "Deleted" : "Forigita",
    "Restore" : "Restaŭri",
    "Delete permanently" : "Forigi por ĉiam",
    "Filename" : "Dosiernomo",
    "Cancel" : "Nuligi",
    "Automatic" : "Aŭtomata",
    "List view" : "Lista vido",
    "Actions" : "Agoj",
    "Show week numbers" : "Montri numerojn de semajno",
    "Location" : "Loko",
    "Description" : "Priskribo",
    "to" : "al",
    "Add" : "Aldoni",
    "Monday" : "lundo",
    "Tuesday" : "mardo",
    "Wednesday" : "merkredo",
    "Thursday" : "ĵaŭdo",
    "Friday" : "vendredo",
    "Saturday" : "sabato",
    "Sunday" : "dimanĉo",
    "Save" : "Konservi",
    "Update" : "Ĝisdatigi",
    "Your email address" : "Via retpoŝta adreso",
    "Email" : "Retpoŝto",
    "Available" : "Disponeblaj",
    "Busy" : "Okupita",
    "Unknown" : "Nekonata",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "Tentative" : "Nekonfirmita",
    "Send email" : "Sendi retpoŝtmesaĝon",
    "All day" : "Tuttage",
    "Repeat" : "Ripeti",
    "never" : "neniam",
    "after" : "post",
    "More" : "Pli",
    "Global" : "Monda",
    "Personal" : "Persona",
    "[Today]" : "[Hodiaŭ]",
    "[Tomorrow]" : "[Morgaŭ]",
    "[Yesterday]" : "[Hieraŭ]",
    "Details" : "Detaloj",
    "Attendees" : "Ĉeestontoj",
    "Resources" : "Rimedoj",
    "Close" : "Fermi",
    "Anniversary" : "Datreveno",
    "Week {number} of {year}" : "Semajno {number} en {year}",
    "Daily" : "Ĉiutage",
    "Weekly" : "Ĉiusemajne",
    "Untitled event" : "Sentitola okazaĵo",
    "Next" : "Sekva",
    "Other" : "Alia",
    "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
    "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
    "When shared hide this event" : "Kiam kunhavigita, kaŝi tiun okazaĵon",
    "Status" : "Stato",
    "Confirmed" : "Konfirmita",
    "Canceled" : "Nuligita",
    "Categories" : "Kategorioj",
    "Add this as a new category" : "Aldoni tion kiel novan kategorion",
    "Talk" : "Paroli",
    "Mail" : "Retpoŝtilo",
    "Birthday" : "Naskiĝotago",
    "User not found" : "Netrovita uzanto"
},
"nplurals=2; plural=(n != 1);");
