OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Sesja użytkownika nieoczekiwanie wygasła",
    "Provided email-address is not valid" : "Podany adres e-mail jest nieprawidłowy",
    "%s has published the calendar »%s«" : "%s opublikował kalendarz »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Nieoczekiwany błąd podczas wysyłania wiadomości e-mail. Skontaktuj się z administratorem.",
    "Successfully sent email to %1$s" : "Pomyślnie wysłano wiadomość e-mail do %1$s",
    "Hello," : "Witaj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chcieliśmy poinformować, że %s opublikował kalendarz %s.",
    "Open »%s«" : "Otwórz »%s«",
    "Cheers!" : "Zdrówko!",
    "Upcoming events" : "Nadchodzące wydarzenia",
    "Appointments" : "Spotkania",
    "Schedule appointment \"%s\"" : "Umówione spotkanie \"%s\"",
    "Schedule an appointment" : "Umów się na spotkanie",
    "Prepare for %s" : "Przygotuj się na %s",
    "Follow up for %s" : "Obserwuj %s",
    "Dear %s, please confirm your booking" : "Drogi %s, proszę o potwierdzenie rezerwacji",
    "Confirm" : "Potwierdź",
    "This confirmation link expires in %s hours." : "Ten link potwierdzający wygaśnie za %s godzin.",
    "Date:" : "Data:",
    "Where:" : "Gdzie:",
    "Calendar" : "Kalendarz",
    "A Calendar app for Nextcloud" : "Aplikacja Kalendarz dla Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aplikacja Kalendarz to interfejs użytkownika CalDAV dla serwera Nextcloud. Z łatwością synchronizuj wydarzenia z różnych urządzeń z Nextcloud i edytuj je online.\n\n* 🚀 **Integracja z innymi aplikacjami Nextcloud!** Obecnie Kontakty - więcej w przyszłości.\n* 🌐 **Wsparcie WebCal!** Chcesz widzieć mecze swojej ulubionej drużyny w swoim kalendarzu? Nie ma problemu!\n* 🙋 **Uczestnicy!** Zapraszaj ludzi na swoje wydarzenia\n* ⌚️ **Wolny/Zajęty!** Zobacz, kiedy Twoi uczestnicy są dostępni\n* ⏰ **Przypomnienia!** Otrzymuj alarmy o wydarzeniach w przeglądarce i e-mailem\n* 🔍 **Szukaj!** Łatwo znajdź swoje wydarzenia\n* ☑️ **Zadania!** Zobacz zadania z terminem bezpośrednio w kalendarzu\n* 🙈 **Nie wymyślamy na nowo koła!** Na podstawie wspaniałej [biblioteki c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) i [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Poprzedni dzień",
    "Previous week" : "Poprzedni tydzień",
    "Previous month" : "Poprzedni miesiąc",
    "Next day" : "Następny dzień",
    "Next week" : "Następny tydzień",
    "Next month" : "Następny miesiąc",
    "New event" : "Nowe zdarzenie",
    "Today" : "Dzisiaj",
    "Day" : "Dzień",
    "Week" : "Tydzień",
    "Month" : "Miesiąc",
    "List" : "Lista",
    "Preview" : "Podgląd",
    "Copy link" : "Kopiuj link",
    "Edit" : "Edytuj",
    "Delete" : "Usuń",
    "Appointment link was copied to clipboard" : "Link do spotkania został skopiowany do schowka",
    "Appointment link could not be copied to clipboard" : "Nie udało się skopiować linku do spotkania do schowka",
    "Add new" : "Dodaj nowe",
    "Untitled calendar" : "Kalendarz bez tytułu",
    "Edit name" : "Edytuj nazwę",
    "Saving name …" : "Zapisywanie nazwy…",
    "Edit color" : "Edytuj kolor",
    "Saving color …" : "Zapisywanie koloru…",
    "Copy private link" : "Kopiuj link prywatny",
    "Export" : "Eksportuj",
    "Unshare from me" : "Nie udostępniaj mi",
    "Disable calendar \"{calendar}\"" : "Wyłącz kalendarz \"{calendar}\"",
    "Disable untitled calendar" : "Wyłącz kalendarz bez tytułu",
    "Enable calendar \"{calendar}\"" : "Włącz kalendarz \"{calendar}\"",
    "Enable untitled calendar" : "Włącz kalendarz bez tytułu",
    "An error occurred, unable to change visibility of the calendar." : "Wystąpił błąd, nie można zmienić widoczności kalendarza.",
    "An error occurred, unable to delete the calendar." : "Wystąpił błąd, nie można usunąć kalendarza.",
    "Calendar link copied to clipboard." : "Link do kalendarza skopiowany do schowka.",
    "Calendar link could not be copied to clipboard." : "Nie można skopiować linku kalendarza do schowka.",
    "An error occurred, unable to rename the calendar." : "Wystąpił błąd, nie można zmienić nazwy kalendarza.",
    "An error occurred, unable to change the calendar's color." : "Wystąpił błąd, nie można zmienić koloru kalendarza.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Zatrzymywanie udostępnienia kalendarza za {countdown} sekundę","Zatrzymywanie udostępnienia kalendarza za {countdown} sekundy","Zatrzymywanie udostępnienia kalendarza za {countdown} sekund","Zatrzymywanie udostępnienia kalendarza za {countdown} sekund"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Usuwanie kalendarza za {countdown} sekundę","Usuwanie kalendarza za {countdown} sekundy","Usuwanie kalendarza za {countdown} sekund","Usuwanie kalendarza za {countdown} sekund"],
    "Share link" : "Udostępnij link",
    "Publish calendar" : "Opublikuj kalendarz",
    "Publishing calendar" : "Publikowanie kalendarza",
    "Copy public link" : "Kopiuj link publiczny",
    "Send link to calendar via email" : "Wyślij e-mailem link do kalendarza",
    "Enter one address" : "Wpisz jeden z adresów",
    "Sending email …" : "Wysyłanie e-maila…",
    "Copy subscription link" : "Kopiuj link do subskrypcji",
    "Copying link …" : "Kopiowanie linku…",
    "Copied link" : "Skopiowano link",
    "Could not copy link" : "Nie można skopiować linku",
    "Copy embedding code" : "Kopiuj kod osadzania",
    "Copying code …" : "Kopiowanie kodu…",
    "Copied code" : "Skopiowano kod",
    "Could not copy code" : "Nie można skopiować kodu",
    "Delete share link" : "Usuń link udostępnienia",
    "Deleting share link …" : "Usuwanie linku udostępnienia…",
    "An error occurred, unable to publish calendar." : "Wystąpił błąd, nie można opublikować kalendarza.",
    "An error occurred, unable to send email." : "Wystąpił błąd, nie można wysłać wiadomości e-mail.",
    "Embed code copied to clipboard." : "Kod do wstawienia został skopiowany do schowka.",
    "Embed code could not be copied to clipboard." : "Nie można skopiować do schowka kodu do wstawienia.",
    "Unpublishing calendar failed" : "Nie można cofnąć publikacji kalendarza",
    "Share with users or groups" : "Udostępnij użytkownikom lub grupom",
    "No users or groups" : "Brak użytkowników lub grup",
    "can edit" : "może edytować",
    "Unshare with {displayName}" : "Zatrzymaj udostępnianie z {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Wystąpił błąd, nie można zmienić cofnięcia udostępnienia kalendarza.",
    "An error occurred, unable to change the permission of the share." : "Wystąpił błąd, nie można zmienić uprawnień do udostępnienia.",
    "New calendar" : "Nowy kalendarz",
    "Name for new calendar" : "Nazwa nowego kalendarza",
    "Creating calendar …" : "Tworzenie kalendarza…",
    "New calendar with task list" : "Nowy kalendarz z listą zadań",
    "New subscription from link (read-only)" : "Nowa subskrypcja z linku (tylko do odczytu)",
    "Creating subscription …" : "Tworzenie subskrypcji…",
    "An error occurred, unable to create the calendar." : "Wystąpił błąd, nie można utworzyć kalendarza.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Wprowadź poprawny link (zaczynający się od http://, https://, webcal://, lub webcals://)",
    "Trash bin" : "Kosz",
    "Loading deleted items." : "Wczytuję usunięte pozycje.",
    "You do not have any deleted items." : "Nie masz żadnych usuniętych pozycji.",
    "Name" : "Nazwa",
    "Deleted" : "Usunięto",
    "Restore" : "Przywróć",
    "Delete permanently" : "Usuń trwale",
    "Empty trash bin" : "Opróżnij kosz",
    "Untitled item" : "Pozycja bez tytułu",
    "Unknown calendar" : "Kalendarz nieznany",
    "Could not load deleted calendars and objects" : "Nie udało się wczytać usuniętych kalendarzy i obiektów",
    "Could not restore calendar or event" : "Nie udało się przywrócić kalendarza lub wydarzenia",
    "Do you really want to empty the trash bin?" : "Czy na pewno chcesz opróżnić kosz?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Pozycje w koszu są usuwane po {numDays} dniu","Pozycje w koszu są usuwane po {numDays} dniach","Pozycje w koszu są usuwane po {numDays} dniach","Pozycje w koszu są usuwane po {numDays} dniach"],
    "Could not update calendar order." : "Nie można zaktualizować kolejności kalendarza.",
    "Import calendars" : "Importuj kalendarze",
    "Please select a calendar to import into …" : "Wybierz kalendarz do zaimportowania do…",
    "Filename" : "Nazwa pliku",
    "Calendar to import into" : "Kalendarz do zaimportowania",
    "Cancel" : "Anuluj",
    "_Import calendar_::_Import calendars_" : ["Importuj kalendarz","Importuj kalendarze","Importuj kalendarze","Importuj kalendarze"],
    "{filename} could not be parsed" : "Nie można przeanalizować {filename}",
    "No valid files found, aborting import" : "Nie znaleziono prawidłowych plików, przerywanie importu",
    "Import partially failed. Imported {accepted} out of {total}." : "Import częściowo nieudany. Zaimportowano {accepted} z {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Pomyślnie zaimportowano %n wydarzenie","Pomyślnie zaimportowano %n wydarzenia","Pomyślnie zaimportowano %n wydarzeń","Pomyślnie zaimportowano %n wydarzeń"],
    "Automatic" : "Automatycznie",
    "Automatic ({detected})" : "Automatycznie ({detected})",
    "New setting was not saved successfully." : "Nowe ustawienie nie zostało pomyślnie zapisane.",
    "Shortcut overview" : "Przegląd skrótu",
    "or" : "lub",
    "Navigation" : "Nawigacja",
    "Previous period" : "Poprzedni okres",
    "Next period" : "Następny okres",
    "Views" : "Widoki",
    "Day view" : "Widok dnia",
    "Week view" : "Widok tygodnia",
    "Month view" : "Widok miesiąca",
    "List view" : "Widok listy",
    "Actions" : "Akcje",
    "Create event" : "Utwórz wydarzenie",
    "Show shortcuts" : "Pokaż skróty",
    "Editor" : "Edytor",
    "Close editor" : "Zamknij edytor",
    "Save edited event" : "Zapisz edytowane wydarzenie",
    "Delete edited event" : "Usuń edytowane wydarzenie",
    "Duplicate event" : "Zduplikowane wydarzenie",
    "Enable birthday calendar" : "Włącz kalendarz urodzinowy",
    "Show tasks in calendar" : "Pokaż zadania w kalendarzu",
    "Enable simplified editor" : "Włącz uproszczony edytor",
    "Limit visible events per view" : "Ogranicz widoczne wydarzenia na widok",
    "Show weekends" : "Pokaż weekendy",
    "Show week numbers" : "Pokaż numery tygodni",
    "Time increments" : "Przyrosty czasu",
    "Default reminder" : "Przypomnienie domyślne",
    "Copy primary CalDAV address" : "Kopiuj główny adres CalDAV",
    "Copy iOS/macOS CalDAV address" : "Kopiuj adres CalDAV dla iOS/macOS",
    "Personal availability settings" : "Osobiste ustawienia dostępności",
    "Show keyboard shortcuts" : "Pokaż skróty klawiaturowe",
    "Calendar settings" : "Ustawienia Kalendarza",
    "No reminder" : "Bez przypomnienia",
    "CalDAV link copied to clipboard." : "Link CalDAV skopiowany do schowka.",
    "CalDAV link could not be copied to clipboard." : "Nie można skopiować linku CalDAV do schowka.",
    "Appointment was created successfully" : "Spotkanie zostało pomyślnie utworzone",
    "Appointment was updated successfully" : "Spotkanie zostało pomyślnie zaktualizowane",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minuty","{duration} minut","{duration} minut"],
    "0 minutes" : "0 minut",
    "_{duration} hour_::_{duration} hours_" : ["{duration} godzina","{duration} godziny","{duration} godzin","{duration} godzin"],
    "_{duration} day_::_{duration} days_" : ["{duration} dzień","{duration} dni","{duration} dni","{duration} dni"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} tydzień","{duration} tygodnie","{duration} tygodni","{duration} tygodni"],
    "_{duration} month_::_{duration} months_" : ["{duration} miesiąc","{duration} miesiące","{duration} miesięcy","{duration} miesięcy"],
    "_{duration} year_::_{duration} years_" : ["{duration} rok","{duration} lata","{duration} lat","{duration} lat"],
    "To configure appointments, add your email address in personal settings." : "Aby skonfigurować spotkania, dodaj swój adres e-mail w ustawieniach osobistych.",
    "Public – shown on the profile page" : "Publiczny – wyświetlane na stronie profilu",
    "Private – only accessible via secret link" : "Prywatny – dostępne tylko przez tajny link",
    "Location" : "Lokalizacja",
    "Description" : "Opis",
    "Visibility" : "Widoczne",
    "Duration" : "Czas trwania",
    "Increments" : "Zwiększ",
    "Additional calendars to check for conflicts" : "Dodatkowe kalendarze do sprawdzania konfliktów",
    "Pick time ranges where appointments are allowed" : "Wybierz przedziały czasowe, w których dozwolone są spotkania",
    "to" : "do",
    "Delete slot" : "Usuń przedział czasowy",
    "No times set" : "Nie ustawiono czasu",
    "Add" : "Dodaj",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Sunday" : "Niedziela",
    "Add time before and after the event" : "Dodaj czas przed i po wydarzeniu",
    "Before the event" : "Przed wydarzeniem",
    "After the event" : "Po wydarzeniu",
    "Planning restrictions" : "Ograniczenia planowania",
    "Minimum time before next available slot" : "Minimalny czas przed następnym dostępnym terminem",
    "Max slots per day" : "Maksymalna liczba terminów na dzień",
    "Limit how far in the future appointments can be booked" : "Ogranicz, jak daleko w przyszłości można rezerwować spotkania",
    "Create appointment" : "Utwórz spotkanie",
    "Edit appointment" : "Edytuj spotkanie",
    "Save" : "Zapisz",
    "Update" : "Aktualizuj",
    "Please confirm your reservation" : "Proszę o potwierdzenie rezerwacji",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Wysłaliśmy Tobie wiadomość e-mail ze szczegółami. Potwierdź wizytę, korzystając z linku w e-mailu. Możesz teraz zamknąć tę stronę.",
    "Your name" : "Twoja nazwa",
    "Your email address" : "Twój adres e-mail",
    "Please share anything that will help prepare for our meeting" : "Udostępnij coś, co pomoże przygotować się do spotkania",
    "Could not book the appointment. Please try again later or contact the organizer." : "Nie udało się zarezerwować spotkania. Spróbuj ponownie później lub skontaktuj się z organizatorem.",
    "Book the appointment" : "Zarezerwuj spotkanie",
    "Reminder" : "Przypomnienie",
    "before at" : "przed",
    "Notification" : "Powiadomienie",
    "Email" : "E-mail",
    "Audio notification" : "Powiadomienie audio",
    "Other notification" : "Inne powiadomienie",
    "Relative to event" : "W odniesieniu do zdarzenia",
    "On date" : "O czasie",
    "Edit time" : "Edytuj czas",
    "Save time" : "Zapisz czas",
    "Remove reminder" : "Usuń przypomnienie",
    "on" : "o",
    "at" : "o",
    "+ Add reminder" : "+ Dodaj przypomnienie",
    "Add reminder" : "Dodaj przypomnienie",
    "_second_::_seconds_" : ["sekunda","sekundy","sekund","sekundy"],
    "_minute_::_minutes_" : ["minuta","minuty","minut","minuty"],
    "_hour_::_hours_" : ["godzina","godziny","godzin","godziny"],
    "_day_::_days_" : ["dzień","dni","dni","dni"],
    "_week_::_weeks_" : ["tydzień","tygodnie","tygodni","tygodnie"],
    "Invitation accepted" : "Zaproszenie przyjęte",
    "Available" : "Dostępny",
    "Suggested" : "Zasugerował",
    "Participation marked as tentative" : "Uczestnictwo oznaczone jako niepewne",
    "Accepted {organizerName}'s invitation" : "Zaakceptowano zaproszenie od {organizerName}",
    "Not available" : "Niedostępny",
    "Invitation declined" : "Zaproszenie odrzucone",
    "Declined {organizerName}'s invitation" : "Odrzucono zaproszenie od {organizerName}",
    "Invitation is delegated" : "Zaproszenie jest oddelegowane",
    "Checking availability" : "Sprawdzanie dostępności",
    "Invitation sent" : "Zaproszenie wysłane",
    "Has not responded to {organizerName}'s invitation yet" : "Nie odpowiedział jeszcze na zaproszenie od {organizerName}",
    "Availability of attendees, resources and rooms" : "Dostępność uczestników, zasobów i pokoi",
    "{organizer} (organizer)" : "{organizer} (organizator)",
    "Free" : "Wolny",
    "Busy (tentative)" : "Zajęty (wstępnie)",
    "Busy" : "Zajęty",
    "Out of office" : "Biuro nie funkcjonuje",
    "Unknown" : "Nieznany",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "Tentative" : "Niepewne",
    "The invitation has been accepted successfully." : "Zaproszenie zostało pomyślnie przyjęte.",
    "Failed to accept the invitation." : "Nie udało się zaakceptować zaproszenia.",
    "The invitation has been declined successfully." : "Zaproszenie zostało pomyślnie odrzucone.",
    "Failed to decline the invitation." : "Nie udało się odrzucić zaproszenia.",
    "Your participation has been marked as tentative." : "Twoje uczestniczenie zostało oznaczone jako niepewne.",
    "Failed to set the participation status to tentative." : "Nie udało się ustawić statusu uczestnictwa na niepewne.",
    "Create Talk room for this event" : "Utwórz pokój w Talku dla tego wydarzenia",
    "Show busy times" : "Pokaż zajęte czasy",
    "No attendees yet" : "Brak uczestników",
    "Successfully appended link to talk room to description." : "Pomyślnie dołączono do opisu link do pokoju rozmów.",
    "Error creating Talk room" : "Błąd podczas tworzenia pokoju w Talku",
    "Send email" : "Wyślij e-mail",
    "Chairperson" : "Przewodniczący",
    "Required participant" : "Wymagany uczestnik",
    "Optional participant" : "Opcjonalny uczestnik",
    "Non-participant" : "Nieuczestniczący",
    "Remove attendee" : "Usuń uczestnika",
    "Search for emails, users or contacts" : "Szukaj e-maili, użytkowników lub kontaktów",
    "No match found" : "Nie znaleziono pasujących",
    "(organizer)" : "(organizator)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Aby wysyłać zaproszenia i otrzymywać odpowiedzi, [linkopen]dodaj swój adres e-mail w ustawieniach osobistych[linkclose].",
    "Remove color" : "Usuń kolor",
    "Event title" : "Tytuł wydarzenia",
    "All day" : "Cały dzień",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nie można zmodyfikować ustawienia całodziennego dla wydarzeń, które są częścią zestawu cyklicznego.",
    "from {startDate}" : "od {startDate}",
    "from {startDate} at {startTime}" : "od {startDate} o {startTime}",
    "to {endDate}" : "do {endDate}",
    "to {endDate} at {endTime}" : "do {endDate} o {endTime}",
    "Repeat" : "Powtarzaj",
    "End repeat" : "Zakończ powtarzanie",
    "Select to end repeat" : "Wybierz, aby zakończyć powtarzanie",
    "never" : "nigdy",
    "on date" : "o czasie",
    "after" : "po",
    "_time_::_times_" : ["raz","razy","razy","razy"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "To wydarzenie stanowi wyjątek powtarzalności zestawu cyklicznego. Nie można do niego dodać reguły powtarzalności.",
    "first" : "pierwszy",
    "third" : "trzeci",
    "fourth" : "czwarty",
    "fifth" : "piąty",
    "second to last" : "przedostatni",
    "last" : "ostatni",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Zmiany w regule powtarzalności będą miały zastosowanie tylko do tego i wszystkich przyszłych wydarzeń.",
    "Repeat every" : "Powtórz każdy",
    "By day of the month" : "Według dnia miesiąca",
    "On the" : "Na",
    "_month_::_months_" : ["miesiąc","miesiące","miesięcy","miesiące"],
    "_year_::_years_" : ["rok","lata","lat","lata"],
    "weekday" : "dzień powszedni",
    "weekend day" : "dzień weekendu",
    "No recurrence" : "Brak powtarzalności",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Definicja tego wydarzenia nie jest w pełni obsługiwana przez Nextcloud. W przypadku edycji opcji cyklicznej niektóre powtórzenia mogą zostać utracone.",
    "Suggestions" : "Propozycje",
    "No rooms or resources yet" : "Nie ma jeszcze pokoi ani zasobów",
    "Add resource" : "Dodaj zasób",
    "Has a projector" : "Ma projektor",
    "Has a whiteboard" : "Posiada białą tablicę",
    "Wheelchair accessible" : "Dostęp dla wózków inwalidzkich",
    "Remove resource" : "Usuń zasób",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} miejsce","{seatingCapacity} miejsca","{seatingCapacity} miejsc","{seatingCapacity} miejsc"],
    "Projector" : "Projektor",
    "Whiteboard" : "Biała tablica",
    "Search for resources or rooms" : "Szukaj zasoby lub pokoje",
    "available" : "dostępny",
    "unavailable" : "niedostępny",
    "Room type" : "Rodzaj pokoju",
    "Any" : "Dowolny",
    "Minimum seating capacity" : "Minimalna ilość miejsc",
    "More" : "Więcej",
    "Update this occurrence" : "Zaktualizuj to wydarzenie",
    "Update this and all future" : "Zaktualizuj to i wszystkie przyszłe",
    "Public calendar does not exist" : "Kalendarz publiczny nie istnieje",
    "Maybe the share was deleted or has expired?" : "Może udostępnienie zostało usunięte lub wygasło?",
    "Please select a time zone:" : "Wybierz strefę czasową:",
    "Pick a time" : "Wybierz czas",
    "Pick a date" : "Wybierz datę",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "w dniu {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} o {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} o {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "w dniu {formattedDate} o {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} o {formattedTime}",
    "Please enter a valid date" : "Podaj prawidłową datę",
    "Please enter a valid date and time" : "Podaj prawidłową datę i godzinę",
    "Type to search time zone" : "Wpisz, aby wyszukać strefę czasową",
    "Global" : "Globalnie",
    "Select date" : "Wybierz datę",
    "Select slot" : "Wybierz przedział czasowy",
    "No slots available" : "Brak dostępnych terminów",
    "The slot for your appointment has been confirmed" : "Termin Twojego spotkania został potwierdzony",
    "Appointment Details:" : "Szczegóły spotkania:",
    "Time:" : "Czas:",
    "Booked for:" : "Zarezerwowane dla:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Dziękujemy. Twoje spotkanie od {startDate} do {endDate} zostało potwierdzone.",
    "Book another appointment:" : "Umów się na kolejne spotkanie:",
    "See all available slots" : "Zobacz wszystkie dostępne wolne terminy",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Termin na spotkanie od {startDate} do {endDate} nie jest już dostępny.",
    "Please book a different slot:" : "Zarezerwuj inny termin:",
    "Book an appointment with {name}" : "Umów się na spotkanie z {name}",
    "No public appointments found for {name}" : "Nie znaleziono publicznych spotkań dla {name}",
    "Personal" : "Osobiste",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatyczne wykrywanie strefy czasowej określiło Twoją strefę czasową jako UTC.\nNajprawdopodobniej wynika to ze środków bezpieczeństwa przeglądarki internetowej.\nUstaw strefę czasową ręcznie w ustawieniach kalendarza.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Skonfigurowana strefa czasowa ({timezoneId}) nie została znaleziona. Powrót do UTC.\nZmień strefę czasową w ustawieniach i zgłoś ten problem.",
    "No more events today" : "Nie ma więcej wydarzeń na dzisiaj",
    "No upcoming events" : "Brak nadchodzących wydarzeń",
    "Create a new event" : "Utwórz nowe wydarzenie",
    "[Today]" : "[Dzisiaj]",
    "[Tomorrow]" : "[Jutro]",
    "[Yesterday]" : "[Wczoraj]",
    "[Last] dddd" : "[Ostatni] dddd",
    "Event does not exist" : "Wydarzenie nie istnieje",
    "Duplicate" : "Zduplikuj",
    "Delete this occurrence" : "Usuń to wydarzenie",
    "Delete this and all future" : "Usuń to i wszystkie przyszłe",
    "Details" : "Szczegóły",
    "Attendees" : "Uczestnicy",
    "Resources" : "Zasoby",
    "Close" : "Zamknij",
    "Show more details" : "Pokaż więcej szczegółów",
    "Subscribe to {name}" : "Subskrybuj dla {name}",
    "Export {name}" : "Eksportuj {nazwa}",
    "Anniversary" : "Rocznica",
    "Appointment" : "Spotkanie",
    "Business" : "Biznes",
    "Education" : "Edukacja",
    "Holiday" : "Święto",
    "Meeting" : "Zebranie",
    "Miscellaneous" : "Różne",
    "Non-working hours" : "Godziny wolne od pracy",
    "Not in office" : "Poza biurem",
    "Phone call" : "Zadzwonić",
    "Sick day" : "Dzień chorobowy",
    "Special occasion" : "Specjalna okazja",
    "Travel" : "Podróż",
    "Vacation" : "Urlop",
    "Midnight on the day the event starts" : "O północy rozpocznie się wydarzenie",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dzień przed wydarzeniem o {formattedHourMinute}","%n dni przed wydarzeniem o {formattedHourMinute}","%n dni przed wydarzeniem o {formattedHourMinute}","%n dni przed wydarzeniem o {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tydzień przed wydarzeniem o {formattedHourMinute}","%n tygodnie przed wydarzeniem o {formattedHourMinute}","%n tygodni przed wydarzeniem o {formattedHourMinute}","%n tygodni przed wydarzeniem o {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "w dniu wydarzenia o {formattedHourMinute}",
    "at the event's start" : "na początku wydarzenia",
    "at the event's end" : "na koniec wydarzenia",
    "{time} before the event starts" : "{time} przed rozpoczęciem wydarzenia",
    "{time} before the event ends" : "{time} przed końcem wydarzenia",
    "{time} after the event starts" : "{time} po rozpoczęciu wydarzenia",
    "{time} after the event ends" : "{time} po zakończeniu wydarzenia",
    "on {time}" : "o {time}",
    "on {time} ({timezoneId})" : "o {time} ({timezoneId})",
    "Week {number} of {year}" : "Tydzień {number} w {year}",
    "Does not repeat" : "Nie powtarza się",
    "Daily" : "Codziennie",
    "Weekly" : "Co tydzień",
    "Monthly" : "Co miesiąc",
    "Yearly" : "Co rok",
    "_Every %n day_::_Every %n days_" : ["Co %n dzień","Co %n dni","Co %n dni","Co %n dni"],
    "_Every %n week_::_Every %n weeks_" : ["Co %n tydzień","Co %n tygodnie","Co %n tygodni","Co %n tygodnie"],
    "_Every %n month_::_Every %n months_" : ["Co %n miesiąc","Co %n miesiące","Co %n miesięcy","Co %n miesiące"],
    "_Every %n year_::_Every %n years_" : ["Co %n rok","Co %n lata","Co %n lat","Co %n lata"],
    "_on {weekday}_::_on {weekdays}_" : ["w {weekdays}","w {weekdays}","w {weekdays}","w {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["w dzień {dayOfMonthList}","w dni {dayOfMonthList}","w dni {dayOfMonthList}","w dni {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "w dniu {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "za {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "za {monthNames} w dniu {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n raz","%n razy","%n razy","%n razy"],
    "Untitled event" : "Wydarzenie bez tytułu",
    "Untitled task" : "Zadanie bez tytułu",
    "Please ask your administrator to enable the Tasks App." : "Poproś administratora o włączenie aplikacji Zadania.",
    "Prev" : "Poprzedni",
    "Next" : "Następny",
    "Prev year" : "Poprzedni rok",
    "Next year" : "Następny rok",
    "Year" : "Rok",
    "W" : "T",
    "%n more" : "%n więcej",
    "No events to display" : "Brak wydarzeń do wyświetlenia",
    "_+%n more_::_+%n more_" : ["+%n więcej","+%n więcej","+%n więcej","+%n więcej"],
    "No events" : "Brak wydarzeń",
    "Create a new event or change the visible time-range" : "Utwórz nowe wydarzenie lub zmień widoczny zakres czasu",
    "It might have been deleted, or there was a typo in a link" : "Mogło zostać usunięte lub w linku była literówka",
    "It might have been deleted, or there was a typo in the link" : "Mogło zostać usunięte lub w linku była literówka",
    "Meeting room" : "Pokój spotkań",
    "Lecture hall" : "Sala wykładowa",
    "Seminar room" : "Pokój seminaryjny",
    "Other" : "Inny",
    "When shared show" : "Po udostępnieniu pokaż",
    "When shared show full event" : "Gdy udostępniony pokaż pełne wydarzenie",
    "When shared show only busy" : "Gdy udostępniony pokaż tylko zajęty",
    "When shared hide this event" : "Gdy udostępniony ukryj to wydarzenie",
    "The visibility of this event in shared calendars." : "Widoczność tego wydarzenia w udostępnianych kalendarzach.",
    "Add a location" : "Dodaj lokalizację",
    "Add a description" : "Dodaj opis",
    "Status" : "Status",
    "Confirmed" : "Potwierdzone",
    "Canceled" : "Anulowane",
    "Confirmation about the overall status of the event." : "Potwierdzenie ogólnego statusu wydarzenia.",
    "Show as" : "Pokaż jako",
    "Take this event into account when calculating free-busy information." : "Weź to wydarzenie pod kontem sprawdzenia informacji o wolnym czasie.",
    "Categories" : "Kategorie",
    "Categories help you to structure and organize your events." : "Kategorie pomagają uporządkować i organizować wydarzenia.",
    "Search or add categories" : "Wyszukaj lub dodaj kategorie",
    "Add this as a new category" : "Dodaj to jako nową kategorię",
    "Custom color" : "Kolor niestandardowy",
    "Special color of this event. Overrides the calendar-color." : "Specjalny kolor tego wydarzenia. Zastępuje kolor kalendarza.",
    "Chat room for event" : "Pokój rozmów dla wydarzenia",
    "Imported {filename}" : "Zaimportowano {filename}",
    "Meditation" : "Medytacja",
    "Relaxing" : "Odprężenie",
    "Relax" : "Relaks",
    "Break" : "Przerwa",
    "Commute" : "Dojazd",
    "Commuting" : "Dojeżdżanie",
    "Shuttle" : "Transport",
    "Invoice" : "Faktura",
    "Finance" : "Finanse",
    "Bank" : "Bank",
    "Money" : "Pieniądze",
    "Wedding" : "Ślub",
    "Dog" : "Pies",
    "Concert" : "Koncert",
    "Festival" : "Festiwal",
    "Theater" : "Teatr",
    "Theatre" : "Kino",
    "Presentation" : "Prezentacja",
    "Talk" : "Rozmowa",
    "Speech" : "Przemówienie",
    "Deadline" : "Ostateczny termin",
    "Submission" : "Przedłożona praca",
    "Reporting" : "Sprawozdanie",
    "Camping" : "Kemping",
    "Camp" : "Obóz",
    "Election" : "Wybory",
    "Voting" : "Głosowanie",
    "Vote" : "Wyniki głosowania",
    "Barbecue" : "Grill",
    "Barbeque" : "Przyjęcie",
    "Garden" : "Ogród",
    "Farm" : "Gospodarstwo rolne",
    "Movie" : "Film",
    "Cinema" : "Kino",
    "Graduation" : "Ukończenie szkoły",
    "Brainstorm" : "Burza mózgów",
    "Review" : "Przegląd",
    "Audit" : "Audyt",
    "Inspection" : "Kontrola",
    "Proofreading" : "Korekta",
    "Baseball" : "Baseball",
    "Meet" : "Spotkanie",
    "Planning" : "Planowanie",
    "Pointing" : "Wskazywanie",
    "Retrospective" : "Z mocą wsteczną",
    "Office" : "Biuro",
    "Contributor week" : "Tydzień współpracownika",
    "Mail" : "Poczta",
    "Soccer" : "Piłka nożna",
    "Football" : "Futbol",
    "Gaming" : "Hazard",
    "Drive" : "Przejażdżka",
    "Driving" : "Podróż",
    "Bicycle" : "Rower",
    "Cycle" : "Kolarzówka",
    "Cycling" : "Rower",
    "Biking" : "Jazda rowerem",
    "Bike" : "Rower",
    "Podcast" : "Pogawędka",
    "Basketball" : "Koszykówka",
    "Fishing" : "Wędkowanie",
    "Hiking" : "Wędrówka",
    "Hike" : "Wycieczka",
    "Art" : "Sztuka",
    "Exhibition" : "Wystawa",
    "Museum" : "Muzeum",
    "Pilates" : "Pilates",
    "Park" : "Park",
    "Walk" : "Spacer",
    "Studying" : "Studia",
    "Doctor" : "Lekarz",
    "Health" : "Zdrowie",
    "Dentist" : "Dentysta",
    "Hospital" : "Szpital",
    "Interview" : "Wywiad",
    "Training" : "Trening",
    "Practice" : "Praktyka",
    "Sports" : "Sport",
    "Exercise" : "Ćwiczenia",
    "Work out" : "Odrabianie",
    "Working out" : "Wypracowanie",
    "Gym" : "Siłownia",
    "Barber" : "Fryzjer",
    "Haircut" : "Strzyżenie",
    "Hairdresser" : "Fryzjer",
    "Exam" : "Egzamin",
    "Written test" : "Test pisemny",
    "Oral test" : "Test ustny",
    "Working" : "Praca",
    "New Years Eve" : "Sylwester",
    "NYE" : "Nowy Rok",
    "Fireworks" : "Fajerwerki",
    "Running" : "Bieganie",
    "Go for a run" : "Iść pobiegać",
    "Marathon" : "Maraton",
    "Video-conference" : "Konferencja wideo",
    "Conference-call" : "Połączenie konferencyjne",
    "Video-call" : "Połączenie wideo",
    "Video-chat" : "Rozmowa wideo",
    "Video-meeting" : "Spotkanie wideo",
    "Call" : "Połącz",
    "Calling" : "Zadzwonić",
    "Christmas" : "Boże Narodzenie",
    "Conference" : "Konferencja",
    "Pizza" : "Pizza",
    "Travelling" : "Wyjazd",
    "Trip" : "Wycieczka",
    "Journey" : "Podróż",
    "Collaborate" : "Współpraca",
    "Pair" : "Para",
    "Lecture" : "Wykład",
    "Seminar" : "Seminarium",
    "Teaching" : "Nauka",
    "Photograph" : "Fotografowanie",
    "Party" : "Przyjęcie",
    "Celebration" : "Uroczystość",
    "Celebrate" : "Świętować",
    "Birthday" : "Urodziny",
    "Shopping" : "Zakupy",
    "Groceries" : "Zakupy spożywcze",
    "Skate" : "Łyżwy",
    "Skateboard" : "Deskorolka",
    "Wine tasting" : "Degustacja wina",
    "Golf" : "Golf",
    "Dinner" : "Obiad",
    "Lunch" : "Lunch",
    "Appointment not found" : "Nie znaleziono spotkania",
    "User not found" : "Nie znaleziono użytkownika"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
