OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Сеанс работы пользователя неожиданно завершён",
    "Provided email-address is not valid" : "Указанный адрес электронной почты недействителен",
    "%s has published the calendar »%s«" : "%s опубликовал календарь «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Неожиданная ошибка отправки электронной почты. Сообщите об этом  администратору.",
    "Successfully sent email to %1$s" : "Письмо успешно отправлено по адресу %1$s",
    "Hello," : "Здравствуйте,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Хотим сообщить, что %s опубликовал(а) календарь «%s».",
    "Open »%s«" : "Открыть «%s»",
    "Cheers!" : "Удачи!",
    "Upcoming events" : "Приближающиеся события",
    "Appointments" : "Мероприятия",
    "Schedule appointment \"%s\"" : "Запланировать встречу «%s»",
    "Schedule an appointment" : "Запланировать встречу",
    "Prepare for %s" : "Подготовиться к %s",
    "Follow up for %s" : "Последующие действия для %s",
    "Dear %s, please confirm your booking" : "Уважаемый %s, подтвердите своё бронирование",
    "Confirm" : "Подтвердить",
    "This confirmation link expires in %s hours." : "Срок действия этой ссылки для подтверждения истекает через %s часов.",
    "Date:" : "Дата:",
    "Where:" : "Место:",
    "Calendar" : "Календарь",
    "A Calendar app for Nextcloud" : "Приложение Календарь для Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Приложение «Календарь» обеспечивает работу с календарями с использованием протокола CalDAV. Сервер Nextcloud позволяет синхронизировать  календарей между различными устройствами, а это приложение служит для работы из браузера. \n\n*🚀 **Интеграция с другими приложениями Nextcloud** В настоящее время поддерживается интеграция с приложением Контакты, готовится интеграция с другими приложениями;\n* 🌐 **Поддержка протокола WebCal** Возможно настроить синхронизацию и показ дней игр своей любимой команды в календаре;\n* 🙋 **Отправка приглашений участникам** Пригласите участников на свои мероприятия;\n* ⌚️ **Поддержка статусов занятого и свободного времени** позволяет назначать встречи в удобное время\n* ⏰ **Напоминания** Получение уведомлений в браузере и по электронной почте\n* 🔍 **Поиск** позволяет находить нужные события \n* ☑️  **Задачи** просмотр задач с датой выполнения прямо в календаре\n* 🙈 **Мы не изобретаем колесо** Приложение основано на отличных библиотеках [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) и [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Предыдущий день",
    "Previous week" : "Предыдущая неделя",
    "Previous month" : "Предыдущий месяц",
    "Next day" : "Следующий день",
    "Next week" : "Следующая неделя",
    "Next month" : "Следующий месяц",
    "New event" : "Создать событие",
    "Today" : "Сегодня",
    "Day" : "День",
    "Week" : "Неделя",
    "Month" : "Месяц",
    "List" : "Список",
    "Preview" : "Предварительный просмотр",
    "Copy link" : "Копировать ссылку",
    "Edit" : "Редактировать",
    "Delete" : "Удалить",
    "Appointment link was copied to clipboard" : "Ссылка на эту встречу скопирована в буфер обмена",
    "Appointment link could not be copied to clipboard" : "Не удалось скопировать в буфер обмена ссылку на эту встречу",
    "Add new" : "Добавить новое",
    "Untitled calendar" : "Календарь без названия",
    "Edit name" : "Изменить название",
    "Saving name …" : "Сохранение названия…",
    "Edit color" : "Изменить цвет",
    "Saving color …" : "Сохранение цвета…",
    "Copy private link" : "Скопировать закрытую ссылку",
    "Export" : "Экспорт",
    "Unshare from me" : "Отписаться",
    "Disable calendar \"{calendar}\"" : "Отключить календарь \"{calendar}\"",
    "Disable untitled calendar" : "Отключить безымянный календарь",
    "Enable calendar \"{calendar}\"" : "Включить календарь \"{calendar}\"",
    "Enable untitled calendar" : "Включить безымянный календарь",
    "An error occurred, unable to change visibility of the calendar." : "Произошла ошибка, не удалось изменить видимость календаря.",
    "An error occurred, unable to delete the calendar." : "Произошла ошибка, не удалось удалить календарь.",
    "Calendar link copied to clipboard." : "Ссылка на календарь скопирована в буфер обмена.",
    "Calendar link could not be copied to clipboard." : "Не удалось скопировать ссылку на календарь в буфер обмена.",
    "An error occurred, unable to rename the calendar." : "Не удалось переименовать календарь.",
    "An error occurred, unable to change the calendar's color." : "Не удалось изменить цвет календаря.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Закрытие общего доступа к календарю через {countdown} секунду","Закрытие общего доступа к календарю через {countdown} секунды","Закрытие общего доступа к календарю через {countdown} секунд","Закрытие общего доступа к календарю через {countdown} секунд"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календарь будет удалён через {countdown} секунду","Календарь будет удалён через {countdown} секунды","Календарь будет удалён через {countdown} секунд","Календарь будет удалён через {countdown} секунды"],
    "Share link" : "Поделиться ссылкой",
    "Publish calendar" : "Опубликовать календарь",
    "Publishing calendar" : "Публикация календаря",
    "Copy public link" : "Скопировать общедоступную ссылку",
    "Send link to calendar via email" : "Отправить ссылку на календарь по электронной почте",
    "Enter one address" : "Введите один адрес",
    "Sending email …" : "Отправка сообщения…",
    "Copy subscription link" : "Скопировать ссылку на подписку",
    "Copying link …" : "Копирование ссылки…",
    "Copied link" : "Ссылка скопирована",
    "Could not copy link" : "Не удалось скопировать ссылку",
    "Copy embedding code" : "Скопировать код встраивания",
    "Copying code …" : "Копирование кода…",
    "Copied code" : "Код скопирован",
    "Could not copy code" : "Не удалось скопировать код",
    "Delete share link" : "Удалить ссылку",
    "Deleting share link …" : "Удаление ссылки доступа…",
    "An error occurred, unable to publish calendar." : "Произошла ошибка, не удалось опубликовать календарь.",
    "An error occurred, unable to send email." : "Произошла ошибка, не удалось отправить email.",
    "Embed code copied to clipboard." : "Код встравивания скопирован в буфер обмена.",
    "Embed code could not be copied to clipboard." : "Код встравивания не может быть скопирован в буфер обмена.",
    "Unpublishing calendar failed" : "Не удалось закрыть публичный доступ к календарю",
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "No users or groups" : "Пользователи или группы отсутствуют",
    "can edit" : "может ред.",
    "Unshare with {displayName}" : "Отменить общий доступ для {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Произошла ошибка, не удалось закрыть доступ к календарю.",
    "An error occurred, unable to change the permission of the share." : "Произошла ошибка, не удалось изменить разрешения для общего ресурса.",
    "New calendar" : "Новый календарь",
    "Name for new calendar" : "Имя для нового календаря",
    "Creating calendar …" : "Создание календаря…",
    "New calendar with task list" : "Создать календарь со списком задач",
    "New subscription from link (read-only)" : "Создать подписку по ссылке (только чтение)",
    "Creating subscription …" : "Создание подписки…",
    "An error occurred, unable to create the calendar." : "Не удалось создать календарь.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Введите верный URL: адрес должен начинаться с http://, https://, webcal:// или webcals://",
    "Trash bin" : "Корзина",
    "Name" : "Название",
    "Deleted" : "Удалено",
    "Restore" : "Восстановить",
    "Delete permanently" : "Удалить безвозвратно",
    "Empty trash bin" : "Очистить корзину",
    "Untitled item" : "Объект без названия",
    "Unknown calendar" : "Неизвестный календарь",
    "Could not load deleted calendars and objects" : "Не удалось загрузить удалённые календари и объекты",
    "Could not restore calendar or event" : "Не удалось восстановить календарь или событие",
    "Do you really want to empty the trash bin?" : "Вы действительно хотите очистить корзину ?",
    "Could not update calendar order." : "Не удалось обновить порядок календарей.",
    "Import calendars" : "Импортировать календари",
    "Please select a calendar to import into …" : "Выберите календарь для импорта…",
    "Filename" : "Имя файла",
    "Calendar to import into" : "Календарь для импорта",
    "Cancel" : "Отмена",
    "_Import calendar_::_Import calendars_" : ["Импорт календаря","Импорт календарей","Импорт календарей","Импорт календарей"],
    "{filename} could not be parsed" : "Не удалось проанализировать файл {filename}",
    "No valid files found, aborting import" : "Не найдено файлов верного типа, импорт отменён",
    "Import partially failed. Imported {accepted} out of {total}." : "Импорт завершен частично. Импортировано {accepted} из {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Событие импортировано","Импортировано %n события","Импортировано %n событий","Импортировано %n событий"],
    "Automatic" : "Автоматически",
    "Automatic ({detected})" : "Автоматически ({detected})",
    "New setting was not saved successfully." : "Не удалось сохранить параметры.",
    "Shortcut overview" : "Обзор ссылок",
    "or" : "или",
    "Navigation" : "Навигация",
    "Previous period" : "Предыдущий период",
    "Next period" : "Следующий период",
    "Views" : "Просмотров",
    "Day view" : "Просмотров за день",
    "Week view" : "Просмотров за неделю",
    "Month view" : "Просмотров за месяц",
    "List view" : "Вид списком",
    "Actions" : "Действия",
    "Create event" : "Создать событие",
    "Show shortcuts" : "Показать горячие клавиши",
    "Editor" : "Редактор",
    "Close editor" : "Закрыть редактор",
    "Save edited event" : "Сохранить изменённое событие",
    "Delete edited event" : "Удалить изменённое событие",
    "Duplicate event" : "Дублировать событие",
    "Enable birthday calendar" : "Включить календарь дней рождения",
    "Show tasks in calendar" : "Показывать задачи в календаре",
    "Enable simplified editor" : "Использовать упрощённый редактор",
    "Limit visible events per view" : "Ограничить количество выводимых событий",
    "Show weekends" : "Показывать выходные",
    "Show week numbers" : "Показывать номера недель",
    "Time increments" : "Шаг изменения времени",
    "Default reminder" : "Напоминание по умолчанию",
    "Copy primary CalDAV address" : "Скопировать основной адрес CalDAV",
    "Copy iOS/macOS CalDAV address" : "Скопировать адрес CalDAV для iOS/macOS",
    "Personal availability settings" : "Личные настройки доступности",
    "Show keyboard shortcuts" : "Показать горячие клавиши клавиатуры",
    "No reminder" : "Не напоминать",
    "CalDAV link copied to clipboard." : "Ссылка CalDAV скопирована в буфер обмена.",
    "CalDAV link could not be copied to clipboard." : "Не удалось скопировать ссылку CalDAV в буфер обмена.",
    "Appointment was created successfully" : "Встреча была создана успешно",
    "Appointment was updated successfully" : "Встреча была успешно обновлена",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} минута","{duration} минуты","{duration} минут","{duration} минут"],
    "0 minutes" : "0 минут",
    "_{duration} hour_::_{duration} hours_" : ["{duration} час","{duration} часа","{duration} часов","{duration} часов"],
    "_{duration} day_::_{duration} days_" : ["{duration} день ","{duration} дня","{duration} дней","{duration} дней"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} неделя","{duration} недели","{duration} недель","{duration} недель"],
    "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяца","{duration} месяцев","{duration} месяцев"],
    "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} года","{duration} лет","{duration} лет"],
    "To configure appointments, add your email address in personal settings." : "Для конфигурации встреч, добавьте свой адрес электронной почты в личных настройках.",
    "Public – shown on the profile page" : "Публичный - отображается на странице профиля",
    "Private – only accessible via secret link" : "Приватный - доступен только по секретной ссылке",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Visibility" : "Видимость",
    "Duration" : "Продолжительность",
    "Increments" : "Повышения",
    "Additional calendars to check for conflicts" : "Дополнительные календари для проверки на наличие конфликтов",
    "Pick time ranges where appointments are allowed" : "Выберите диапазон времени, когда разрешено назначать встречи",
    "to" : "к",
    "Delete slot" : "Удалить слот",
    "No times set" : "Время не установлено",
    "Add" : "Добавить",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Sunday" : "Воскресенье",
    "Add time before and after the event" : "Добавить время до и после мероприятия",
    "Before the event" : "До начала мероприятия",
    "After the event" : "После мероприятия",
    "Planning restrictions" : "Ограничения при планировании",
    "Minimum time before next available slot" : "Минимальное время до следующего доступного слота",
    "Max slots per day" : "Максимум слотов в день",
    "Limit how far in the future appointments can be booked" : "Лимит на то, как далеко в будущем можно записываться на встречу",
    "Create appointment" : "Создать мероприятие",
    "Edit appointment" : "Редактировать встречу",
    "Save" : "Сохранить",
    "Update" : "Обновить",
    "Please confirm your reservation" : "Пожалуйста, подтвердите бронирование",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Мы отправили вам электронное письмо с подробной информацией. Пожалуйста, подтвердите свою встречу, используя ссылку в письме. Теперь вы можете закрыть эту страницу.",
    "Your name" : "Ваше имя",
    "Your email address" : "Ваш адрес электронной почты",
    "Please share anything that will help prepare for our meeting" : "Пожалуйста, поделитесь с нами тем, что поможет подготовиться к нашей встрече",
    "Could not book the appointment. Please try again later or contact the organizer." : "Не удалось забронировать встречу. Пожалуйста, повторите попытку позже или свяжитесь с организатором.",
    "Book the appointment" : "Записаться на встречу",
    "Reminder" : "Напоминание",
    "before at" : "ранее в",
    "Notification" : "Уведомление",
    "Email" : "Эл. почта",
    "Audio notification" : "Звуковое уведомление",
    "Other notification" : "Другое уведомление",
    "Relative to event" : "Относительно события",
    "On date" : "В указанную дату",
    "Edit time" : "Редактировать время",
    "Save time" : "Сохранить время",
    "Remove reminder" : "Удалить напоминание",
    "on" : "в",
    "at" : "в",
    "+ Add reminder" : "+ Создать напоминание",
    "Add reminder" : "Добавить напоминание",
    "_second_::_seconds_" : ["секунда","секунды","секунд","секунды"],
    "_minute_::_minutes_" : ["минута","минуты","минут","минуты"],
    "_hour_::_hours_" : ["час","часа","часов","часы"],
    "_day_::_days_" : ["день","дня","дней","дни"],
    "_week_::_weeks_" : ["неделя","недель","недель","недели"],
    "Invitation accepted" : "Приглашение принято",
    "Available" : "Доступный",
    "Suggested" : "Предложенный",
    "Participation marked as tentative" : "Участие обозначено как «под вопросом»",
    "Accepted {organizerName}'s invitation" : "Принято приглашение от {organizerName}",
    "Not available" : "Не доступен",
    "Invitation declined" : "Приглашение отклонено",
    "Declined {organizerName}'s invitation" : "Отклонено приглашение от {organizerName}",
    "Invitation is delegated" : "Приглашение делегировано",
    "Checking availability" : "Проверка доступности",
    "Invitation sent" : "Приглашение отправлено",
    "Has not responded to {organizerName}'s invitation yet" : "Ответ на приглашение от {organizerName} ещё не отправлен",
    "Availability of attendees, resources and rooms" : "Доступность участников, ресурсов и комнат",
    "{organizer} (organizer)" : "{organizer} (организатор)",
    "Free" : "Свободен",
    "Busy (tentative)" : "Занят (под вопросом)",
    "Busy" : "Занят",
    "Out of office" : "Вне офиса",
    "Unknown" : "Неизвестно",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Tentative" : "Под вопросом",
    "The invitation has been accepted successfully." : "Приглашение принято.",
    "Failed to accept the invitation." : "Не удалось принять приглашение.",
    "The invitation has been declined successfully." : "Приглашение отклонено.",
    "Failed to decline the invitation." : "Не удалось отклонить приглашение.",
    "Your participation has been marked as tentative." : "Выше участие было обозначено как «под вопросом».",
    "Failed to set the participation status to tentative." : "Не удалось обозначить свое участие как «под вопросом».",
    "Create Talk room for this event" : "Создать комнату этого события в приложении «Talk»",
    "Show busy times" : "Показать занятое время",
    "No attendees yet" : "Ещё нет участников",
    "Successfully appended link to talk room to description." : "Ссылка на комнату приложения Talk добавлена в описание.",
    "Error creating Talk room" : "Не удалось создать комнату в приложении Talk.",
    "Send email" : "Отправить сообщение",
    "Chairperson" : "Председатель",
    "Required participant" : "Обязательный участник",
    "Optional participant" : "Необязательный участник",
    "Non-participant" : "Не участвует",
    "Remove attendee" : "Удалить участника",
    "Search for emails, users or contacts" : "Поиск по адресам эл. почты, пользователям и контактам",
    "No match found" : "Соответствий не найдено",
    "(organizer)" : "(организатор)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Чтобы отправлять приглашения и обрабатывать ответы, [linkopen]добавьте свой адрес электронной почты в личные настройки[linkclose].",
    "Remove color" : "Убрать отметку цветом",
    "Event title" : "Название события",
    "All day" : "Весь день",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Изменение параметра «весь день» для повторяющегося события не поддерживается.",
    "from {startDate}" : "с {startDate}",
    "from {startDate} at {startTime}" : "с {startDate} {startTime}",
    "to {endDate}" : "по {endDate}",
    "to {endDate} at {endTime}" : "по {endDate} {endTime}",
    "Repeat" : "Повтор",
    "End repeat" : "Прекратить повтор",
    "Select to end repeat" : "Выбрать до последнего повторения",
    "never" : "никогда",
    "on date" : "в указанную дату",
    "after" : "после",
    "_time_::_times_" : ["раз","раз","раз","раз"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Невозможно задать правила повторения этого события, так как оно является исключением из правил повтора исходного события.",
    "first" : "первый",
    "third" : "третий",
    "fourth" : "четвёртый",
    "fifth" : "пятый",
    "second to last" : "предпоследний",
    "last" : "последний",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Изменение правила повторения повлияет только на это и все будущие повторения события.",
    "Repeat every" : "Повторять каждые",
    "By day of the month" : "В указанные дни месяца",
    "On the" : "По",
    "_month_::_months_" : ["месяц","месяца","месяцев","месяца"],
    "_year_::_years_" : ["год","года","лет","года"],
    "weekday" : "рабочий день",
    "weekend day" : "выходной день",
    "No recurrence" : "Нет повторения",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Заданные правила повторения этого события не полностью поддерживается Nextcloud. При изменении правил, некоторые повторения могут быть потеряны.",
    "Suggestions" : "Предложения",
    "No rooms or resources yet" : "Комнаты или ресурсы пока не назначены",
    "Add resource" : "Добавить ресурс",
    "Has a projector" : "Есть проектор",
    "Has a whiteboard" : "Имеет доску для записей",
    "Wheelchair accessible" : "Доступно для кресла-коляски",
    "Remove resource" : "Удалить ресурс",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} место","{seatingCapacity} места","{seatingCapacity} мест","{seatingCapacity} мест"],
    "Projector" : "Проектор",
    "Whiteboard" : "Доска",
    "Search for resources or rooms" : "Поиск ресурсов или помещений",
    "available" : "доступный",
    "unavailable" : "недоступен",
    "Room type" : "Тип комнаты",
    "Any" : "Любой",
    "Minimum seating capacity" : "Минимальная вместимость",
    "More" : "Больше",
    "Update this occurrence" : "Обновить это повторение",
    "Update this and all future" : "Обновить это и все будущие повторния",
    "Public calendar does not exist" : "Общедоступный календарь не существует",
    "Maybe the share was deleted or has expired?" : "Возможно общий ресурс был удалён или истёк срок действия доступа.",
    "Please select a time zone:" : "Выберите часовой пояс:",
    "Pick a time" : "Выберите время",
    "Pick a date" : "Выберите дату",
    "from {formattedDate}" : "с {formattedDate}",
    "to {formattedDate}" : "по {formattedDate}",
    "on {formattedDate}" : " {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "с {formattedDate} в {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} в {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} в {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} в {formattedTime}",
    "Please enter a valid date" : "Введите верную дату",
    "Please enter a valid date and time" : "Введите верную дату и время",
    "Type to search time zone" : "Начните вводить название часового поиска",
    "Global" : "Общие",
    "Select date" : "Выбрать дату",
    "Select slot" : "Выбрать слот",
    "No slots available" : "Нет свободных мест",
    "The slot for your appointment has been confirmed" : "Время вашей встречи было подтверждено",
    "Appointment Details:" : "Детали встречи:",
    "Time:" : "Время:",
    "Booked for:" : "Забронировано для:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Спасибо. Ваше бронирование с {startDate} по {endDate} подтверждено.",
    "Book another appointment:" : "Записаться на другую встречу:",
    "See all available slots" : "Посмотреть все доступные слоты",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Слот для вашей встречи с {startDate} по {endDate} больше не доступен.",
    "Please book a different slot:" : "Пожалуйста, забронируйте другое время:",
    "Book an appointment with {name}" : "Записаться на встречу к {name}",
    "No public appointments found for {name}" : "Не найдено ни одной публичной встречи для {name}",
    "Personal" : "Личный",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматическое определение часового пояса определило ваш часовой пояс как UTC. Скорее всего, это результат мер безопасности вашего веб-браузера. Пожалуйста, установите часовой пояс вручную в настройках календаря.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Настроенный вами часовой пояс ({timezoneId}) не найден. Возвращение к UTC. Пожалуйста, измените свой часовой пояс в настройках и сообщите об этой проблеме.",
    "No more events today" : "На сегодня больше нет событий",
    "No upcoming events" : "Приближающиеся события отсуствуют",
    "Create a new event" : "Создать событие",
    "[Today]" : "[Сегодня]",
    "[Tomorrow]" : "[Завтра]",
    "[Yesterday]" : "[Вчера]",
    "[Last] dddd" : "[Last] dddd",
    "Event does not exist" : "Событие не существует",
    "Duplicate" : "Дублировать",
    "Delete this occurrence" : "Удалить это повторение",
    "Delete this and all future" : "Удалить это и все будущие повторения",
    "Details" : "Подробности",
    "Attendees" : "Участники",
    "Resources" : "Ресурсы",
    "Close" : "Закрыть",
    "Show more details" : "Подробные сведения",
    "Subscribe to {name}" : "Подписаться на {name}",
    "Export {name}" : "Экспортировать {name}",
    "Anniversary" : "Годовщина",
    "Appointment" : "Встреча",
    "Business" : "Работа",
    "Education" : "Образование",
    "Holiday" : "Отпуск",
    "Meeting" : "Встреча",
    "Miscellaneous" : "Разное",
    "Non-working hours" : "Не рабочие часы",
    "Not in office" : "Не в офисе",
    "Phone call" : "Телефонный звонок",
    "Sick day" : "Больничный",
    "Special occasion" : "Особый случай",
    "Travel" : "Путешествие",
    "Vacation" : "Отпуск",
    "Midnight on the day the event starts" : "Полночь в день начала мероприятия",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n день до мероприятия в {formattedHourMinute}","%n дня до мероприятия в {formattedHourMinute}","%n дней до мероприятия в {formattedHourMinute}","%nдней до мероприятия в {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n неделя до мероприятия в {formattedHourMinute}","%n недели до мероприятия в {formattedHourMinute}","%n недель до мероприятия в {formattedHourMinute}","%n недель до мероприятия в {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "в день мероприятия в {formattedHourMinute}",
    "at the event's start" : "во время начала события",
    "at the event's end" : "во время окончания события",
    "{time} before the event starts" : "{time} до времени начала события",
    "{time} before the event ends" : "{time} до времени окончания события",
    "{time} after the event starts" : "{time} после времени начала события",
    "{time} after the event ends" : "{time} до времени окончания события",
    "on {time}" : "в {time}",
    "on {time} ({timezoneId})" : "в {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} неделя {year} года",
    "Does not repeat" : "Не повторять",
    "Daily" : "Ежедневно",
    "Weekly" : "Еженедельно",
    "Monthly" : "Ежемесячно",
    "Yearly" : "Ежегодно",
    "_Every %n day_::_Every %n days_" : ["Каждый %n день","Каждые %n дня","Каждые %n дней","Каждые %n дня"],
    "_Every %n week_::_Every %n weeks_" : ["Каждую %n неделю","Каждые %n недели","Каждые %n недель","Каждые %n недели"],
    "_Every %n month_::_Every %n months_" : ["Каждый %n месяц","Каждые %n месяца","Каждый %n месяцев","Каждые %n месяца"],
    "_Every %n year_::_Every %n years_" : ["Каждый %n год","Каждые %n года","Каждые %n лет","Каждые %n года"],
    "_on {weekday}_::_on {weekdays}_" : ["по {weekday}","по {weekday}","по {weekday}","по {weekday}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : [" {dayOfMonthList}"," {dayOfMonthList}"," {dayOfMonthList}"," {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "по {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "по {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "в {monthNames} по {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n раз","%n раза","%n раз","%n раза"],
    "Untitled event" : "Событие без названия",
    "Untitled task" : "Задача без названия",
    "Please ask your administrator to enable the Tasks App." : "Попросите администратора сервера активировать приложение «Задачи».",
    "Prev" : "Назад",
    "Next" : "Вперёд",
    "Prev year" : "Пред. год",
    "Next year" : "Следующий год",
    "Year" : "Год",
    "W" : "Н",
    "%n more" : "и ещё %n",
    "No events to display" : "Отсутствуют события для показа",
    "_+%n more_::_+%n more_" : ["+ ещё %n","+ ещё %n","+ ещё %n","+ ещё %n"],
    "No events" : "Нет ни одного события",
    "Create a new event or change the visible time-range" : "Создать событие или изменить интервал видимости",
    "It might have been deleted, or there was a typo in a link" : "Возможно, оно было удалено или вы выполнили переход по неверной ссылке",
    "It might have been deleted, or there was a typo in the link" : "Возможно, оно было удалено или вы выполнили переход по неверной ссылке",
    "Meeting room" : "Комната для переговоров",
    "Lecture hall" : "Лекционный зал",
    "Seminar room" : "Комната для семинаров",
    "Other" : "Другое",
    "When shared show" : "Показывать при публикации",
    "When shared show full event" : "Показывать подробно при публикации",
    "When shared show only busy" : "Показывать только занятость при публикации",
    "When shared hide this event" : "Скрыть это событие при публикации",
    "The visibility of this event in shared calendars." : "Видимость этого события в опубликованных календарях. ",
    "Add a location" : "Добавить местоположение",
    "Add a description" : "Добавить описание",
    "Status" : "Состояние",
    "Confirmed" : "Подтверждено",
    "Canceled" : "Отменена",
    "Confirmation about the overall status of the event." : "Подтверждение об общем статусе события.",
    "Show as" : "Показать как",
    "Take this event into account when calculating free-busy information." : "Учитывать это событие при учёте свободного времени.",
    "Categories" : "Категории",
    "Categories help you to structure and organize your events." : "Категории позволяют структурировать и упорядочивать свои события.",
    "Search or add categories" : "Поиск и добавление категорий",
    "Add this as a new category" : "Добавить как новую категорию",
    "Custom color" : "Свой цвет",
    "Special color of this event. Overrides the calendar-color." : "Задать свой цвет события, отличающийся от цвета календаря",
    "Chat room for event" : "Комната в приложении Talk для этого события",
    "Imported {filename}" : "Файл {filename} импортирован",
    "Meditation" : "Медитация",
    "Relaxing" : "Расслабляющий",
    "Relax" : "Расслабление",
    "Break" : "Перерыв",
    "Commute" : "Поездка",
    "Commuting" : "Перемещения",
    "Shuttle" : "Шаттл",
    "Invoice" : "Счет-фактура",
    "Finance" : "Финансы",
    "Bank" : "Банк",
    "Money" : "Деньги",
    "Wedding" : "Свадьба",
    "Dog" : "Собака",
    "Concert" : "Концерт",
    "Festival" : "Фестиваль",
    "Theater" : "Театр",
    "Theatre" : "Театр",
    "Presentation" : "Презентация",
    "Talk" : "Говорить ",
    "Speech" : "Речь",
    "Deadline" : "Крайний срок",
    "Submission" : "Представление",
    "Reporting" : "Сообщать",
    "Camping" : "Поход",
    "Camp" : "Лагерь",
    "Election" : "Выборы",
    "Voting" : "Голосование",
    "Vote" : "Голосовать",
    "Barbecue" : "Барбекю",
    "Barbeque" : "Барбекю",
    "Garden" : "Сад",
    "Farm" : "Ферма",
    "Movie" : "Фильм",
    "Cinema" : "Кинотеатр",
    "Graduation" : "получение учёной степени",
    "Brainstorm" : "Мозговой штурм",
    "Review" : "Обзор",
    "Audit" : "Аудит",
    "Inspection" : "Осмотр",
    "Proofreading" : "Корректирование",
    "Baseball" : "Бейсбол",
    "Meet" : "Встреча",
    "Planning" : "Планирование",
    "Pointing" : "Указание",
    "Retrospective" : "Ректроспектива",
    "Office" : "Офис",
    "Contributor week" : "Неделя участия",
    "Mail" : "Почта",
    "Soccer" : "Футбол",
    "Football" : "Американский футбол",
    "Gaming" : "Видео игры",
    "Drive" : "Езда",
    "Driving" : "Вождение",
    "Bicycle" : "Езда на велосипеде",
    "Cycle" : "Велосипед",
    "Cycling" : "Езда на велосипеде",
    "Biking" : "Езда на мотоцикле",
    "Bike" : "Bike",
    "Podcast" : "Подкаст",
    "Basketball" : "Баскетбол",
    "Fishing" : "Рыбалка",
    "Hiking" : "Пеший туризм",
    "Hike" : "Поход",
    "Art" : "Искусство",
    "Exhibition" : "Выстовка",
    "Museum" : "Музей",
    "Pilates" : "Пилатес",
    "Park" : "Парк",
    "Walk" : "Прогулка",
    "Studying" : "Учёба",
    "Doctor" : "Врач",
    "Health" : "Здоровье",
    "Dentist" : "Стоматология",
    "Hospital" : "Больница",
    "Interview" : "Собеседование",
    "Training" : "Тренировка",
    "Practice" : "Практика",
    "Sports" : "Спорт",
    "Exercise" : "Занятия",
    "Work out" : "Тренировка",
    "Working out" : "Тренироваться",
    "Gym" : "Тренажёрный зал",
    "Barber" : "Парикмахер",
    "Haircut" : "Стрижка",
    "Hairdresser" : "Парикмахер",
    "Exam" : "Экзамен",
    "Written test" : "Письменный тест",
    "Oral test" : "Устный тест",
    "Working" : "Работа",
    "New Years Eve" : "Сочельник",
    "NYE" : "Новый год",
    "Fireworks" : "Фейерверк",
    "Running" : "Пробежка",
    "Go for a run" : "Пробежаться",
    "Marathon" : "Марафон",
    "Video-conference" : "Видеоконференция",
    "Conference-call" : "Конференция по телефону",
    "Video-call" : "Видеозвонок",
    "Video-chat" : "Видеочат",
    "Video-meeting" : "Видеовстреча",
    "Call" : "Звонок",
    "Calling" : "Позвонить",
    "Christmas" : "Рождество",
    "Conference" : "Конференция",
    "Pizza" : "Пицца",
    "Travelling" : "Путешествие",
    "Trip" : "Поездка",
    "Journey" : "Поездка",
    "Collaborate" : "Совместная работа",
    "Pair" : "Пара",
    "Lecture" : "Лекция",
    "Seminar" : "Семинар",
    "Teaching" : "Обучение",
    "Photograph" : "Фотограф",
    "Party" : "Вечеринка",
    "Celebration" : "Празднование",
    "Celebrate" : "Празднование",
    "Birthday" : "День рождения",
    "Shopping" : "Покупки",
    "Groceries" : "Бакалея",
    "Skate" : "Роликовые коньки",
    "Skateboard" : "Скейтборд",
    "Wine tasting" : "Дегустация вина",
    "Golf" : "Гольф",
    "Dinner" : "Ужин",
    "Lunch" : "Обед",
    "Appointment not found" : "Встреча не найдена",
    "User not found" : "Пользователь не найден"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
