OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "A sessão do utilizador expirou inexplicavelmente",
    "Provided email-address is not valid" : "O endereço de e-mail que inseriu não é válido",
    "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Ocorreu um erro inesperado ao enviar o email. Por favor contacte o seu administrador",
    "Successfully sent email to %1$s" : "A mensagem enviada com sucesso para %1$s ",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informa-lo que %s publicou o calendário »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "Parabéns!",
    "Upcoming events" : "Próximos eventos",
    "Appointments" : "Reuniões",
    "Schedule appointment \"%s\"" : "Marcar reunião \"%s\"",
    "Schedule an appointment" : "Marcar uma reunião",
    "Prepare for %s" : "Prepare-se para %s",
    "Dear %s, please confirm your booking" : "Caro %s, por favor confirme o seu agendamento",
    "Confirm" : "Confirmar",
    "This confirmation link expires in %s hours." : "Esta ligação de confirmação expira em %s horas.",
    "Date:" : "Data:",
    "Where:" : "Local:",
    "Calendar" : "Calendário",
    "A Calendar app for Nextcloud" : "Uma aplicação de calendário para o Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "A aplicação Calendário é uma interface de utilizador para o servidor CalDAV da Nextcloud. Sincronize facilmente eventos de vários dispositivos com o seu Nextcloud e edite-os online..\n\n* 🚀 **Integração com outras aplicações Nextcloud!** Atualmente a de Contactos - mas mais estão para chegar.\n* 🌐 **Suporte para WebCal!** Quer ver os dias de jogo da sua equipa favorita no seu calendário? Não há problema!\n* 🙋 **Participantes!** Convide pessoas para os seus eventos\n* ⌚️ **Livre/Ocupado!** Veja quando os seus participantes estão disponíveis para se encontrarem\n* ⏰ **Lembretes!** Receba alarmes para eventos dentro do seu navegador e via e-mail\n* 🔍 Pesquisar! Encontre os seus eventos à vontade\n* ☑️ Tarefas! Ver tarefas com uma data de vencimento diretamente no calendário\n* 🙈 **Não estamos a reinventar a roda!** Baseado na grande [biblioteca c-dav](https://github.com/nextcloud/cdav-library), e nas [ical.js](https://github.com/mozilla-comm/ical.js) e [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Dia anterior",
    "Previous week" : "Semana anterior",
    "Previous month" : "Mês anterior",
    "Next day" : "Dia seguinte",
    "Next week" : "Próxima semana",
    "Next month" : "Próximo mês",
    "New event" : "Novo evento",
    "Today" : "Hoje",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "List" : "Lista",
    "Preview" : "Pré-visualizar",
    "Copy link" : "Copiar hiperligação",
    "Edit" : "Editar",
    "Delete" : "Eliminar",
    "Appointment link was copied to clipboard" : "Hiperligação da reunião copiada para a área de transferência",
    "Appointment link could not be copied to clipboard" : "Não é possível copiar a hiperligação da reunião para a área de transferência",
    "Add new" : "Adicionar nova",
    "Untitled calendar" : "Calendário sem titulo",
    "Edit name" : "Editar nome",
    "Saving name …" : "A guardar o nome...",
    "Edit color" : "Editar a cor",
    "Saving color …" : "A guardar a côr...",
    "Copy private link" : "Copiar link privado",
    "Export" : "Exportar",
    "Unshare from me" : "Cancelar partilha",
    "Disable calendar \"{calendar}\"" : "Desativar calendário \"{calendar}\"",
    "Disable untitled calendar" : "Desativar calendário sem título",
    "Enable calendar \"{calendar}\"" : "Ativar calendário \"{calendar}\"",
    "Enable untitled calendar" : "Ativar calendário sem título",
    "An error occurred, unable to change visibility of the calendar." : "Ocorreu um erro, incapaz de alterar a visibilidade do calendário.",
    "An error occurred, unable to delete the calendar." : "Ocorreu um erro que impede que o calendário seja apagado",
    "Calendar link copied to clipboard." : "Hiperligação do calendário copiado para a área de transferência.",
    "Calendar link could not be copied to clipboard." : "Link do calendário não pôde se copiado para a área de transferência.",
    "An error occurred, unable to rename the calendar." : "Ocorreu um erro que impede que o nome do calendário seja alterado",
    "An error occurred, unable to change the calendar's color." : "Ocorreu um erro que impede que a cor do calendário seja alterada",
    "Share link" : "Partilhar hiperligação",
    "Publish calendar" : "Publicar calendário",
    "Publishing calendar" : "A publicar o calendário",
    "Copy public link" : "Copiar ligação publica",
    "Send link to calendar via email" : "Enviar ligação por correio electrónico",
    "Enter one address" : "Introduza um endereço",
    "Sending email …" : "A enviar o email …",
    "Copy subscription link" : "Copiar ligação da subscrição",
    "Copying link …" : "Copiar ligação …",
    "Copied link" : "Ligação copiada",
    "Could not copy link" : "Não foi possível copiar a ligação",
    "Copy embedding code" : "Copiar código embebido",
    "Copying code …" : "A copiar código...",
    "Copied code" : "Código copiado",
    "Could not copy code" : "Não foi possível copiar o código",
    "Delete share link" : "Apagar hiperligação de partilha",
    "Deleting share link …" : "A apagar hiperligação de partilha",
    "An error occurred, unable to publish calendar." : "Ocorreu um erro, não foi possível publicar o calendário.",
    "An error occurred, unable to send email." : "Ocorreu um erro, não foi possível enviar o email.",
    "Embed code copied to clipboard." : "Código de incorporação copiado para a área de transferência.",
    "Embed code could not be copied to clipboard." : "Não é possível copiar o código de incorporação",
    "Unpublishing calendar failed" : "Erro ao remover a publicação do calendário",
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "No users or groups" : "Sem utilizadores ou grupos",
    "can edit" : "pode editar",
    "Unshare with {displayName}" : "Cancelar partilha com {displayName}",
    "New calendar" : "Novo calendário",
    "Name for new calendar" : "Nome para o novo calendário",
    "Creating calendar …" : "A criar o calendário …",
    "New calendar with task list" : "Novo calendário com lista de tarefas",
    "An error occurred, unable to create the calendar." : "Ocorreu um erro que impede que o calendário seja criado",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Por favor introduza uma ligação válida (começada por http://, https://, webcal://, ou webcals://)",
    "Trash bin" : "Reciclagem",
    "Name" : "Nome",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar permanentemente",
    "Empty trash bin" : "Esvaziar a reciclagem",
    "Unknown calendar" : "Calendário desconhecido",
    "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos apagados ",
    "Could not restore calendar or event" : "Não foi possível restaurar o calendário ou evento ",
    "Do you really want to empty the trash bin?" : "Tem a certeza que pretende esvaziar a reciclagem?",
    "Could not update calendar order." : "Não foi possível atualizar a ordenação do calendário.",
    "Import calendars" : "Importar calendários",
    "Filename" : "Nome do ficheiro",
    "Calendar to import into" : "Calendário para o qual importar",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendário","Importar calendários","Importar calendários"],
    "{filename} could not be parsed" : "{filename} não pôde ser processado",
    "No valid files found, aborting import" : "A importação foi cancelada pois não foram encontrados ficheiros válidos",
    "Import partially failed. Imported {accepted} out of {total}." : "A importação falhou parcialmente. Importados {accepted} de um total de {total}.",
    "Automatic" : "Automático",
    "New setting was not saved successfully." : "Erro a gravar a nova configuração.",
    "Shortcut overview" : "Visão geral de atalhos",
    "or" : "ou",
    "Navigation" : "Navegação",
    "Previous period" : "Período anterior",
    "Next period" : "Próximo período",
    "Views" : "Vistas",
    "Day view" : "Vista diária",
    "Week view" : "Vista semanal",
    "Month view" : "Vista mensal",
    "List view" : "Vista em lista",
    "Actions" : "Ações",
    "Create event" : "Criar evento",
    "Show shortcuts" : "Mostrar atalhos de teclado",
    "Editor" : "Editor",
    "Close editor" : "Fechar editor",
    "Save edited event" : "Gravar evento editado",
    "Delete edited event" : "Apagar evento editado",
    "Duplicate event" : "Duplicar evento",
    "Enable birthday calendar" : "Ativar calendário de aniversários",
    "Show tasks in calendar" : "Mostrar tarefas no calendário",
    "Enable simplified editor" : "Ativar editor simplificado",
    "Limit visible events per view" : "Limitar eventos visíveis por visualização",
    "Show weekends" : "Mostrar fins-de-semana",
    "Show week numbers" : "Mostrar o número das semanas",
    "Time increments" : "Incrementos de tempo",
    "Default reminder" : "Lembrete padrão",
    "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
    "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
    "Personal availability settings" : "Configurações de disponibilidade pessoal",
    "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
    "Calendar settings" : "Configurações do calendário",
    "No reminder" : "Nenhum lembrete",
    "CalDAV link copied to clipboard." : "Ligação CalDAV copiada para a área de transferência.",
    "CalDAV link could not be copied to clipboard." : "Não foi possível copiar a ligação CalDAV para a área de transferência.",
    "Appointment was created successfully" : "Reunião criada com sucesso",
    "Appointment was updated successfully" : "Reunião atualizada com sucesso",
    "0 minutes" : "0 minutos",
    "To configure appointments, add your email address in personal settings." : "Para configurar reuniões, adicione seu o endereço de e-mail nas configurações pessoais.",
    "Public – shown on the profile page" : "Público - mostrado na página de perfil",
    "Private – only accessible via secret link" : "Privado - acessível apenas por ligação secreta",
    "Location" : "Localização:",
    "Description" : "Descrição",
    "Visibility" : "Visibilidade",
    "Duration" : "Duração",
    "Increments" : "Incrementos",
    "Additional calendars to check for conflicts" : "Calendários adicionais para verificar conflitos",
    "Pick time ranges where appointments are allowed" : "Escolha os intervalos de tempo onde as reuniões são permitidas",
    "to" : "Para",
    "No times set" : "Nenhum horário definido",
    "Add" : "Adicionar",
    "Monday" : "Segunda",
    "Tuesday" : "Terça",
    "Wednesday" : "Quarta",
    "Thursday" : "Quinta",
    "Friday" : "Sexta",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Add time before and after the event" : "Adicionar um tempo antes e depois do evento",
    "Before the event" : "Antes do evento",
    "After the event" : "Depois do evento",
    "Planning restrictions" : "Restrições de planeamento",
    "Create appointment" : "Criar reunião",
    "Edit appointment" : "Editar reunião",
    "Save" : "Guardar",
    "Update" : "Atualizar",
    "Please confirm your reservation" : "Por favor confirme a sua reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Enviamos-lhe um e-mail com os detalhes. Por favor confirme a sua reunião utilizando a ligação do e-mail. Pode fechar esta página.",
    "Your name" : "O seu nome",
    "Your email address" : "O seu endereço de email",
    "Please share anything that will help prepare for our meeting" : "Por favor partilhe qualquer coisa que ajude na preparação da nossa reunião",
    "Could not book the appointment. Please try again later or contact the organizer." : "Não foi possível agendar a reunião. Tente novamente mais tarde ou entre em contacto com o organizador.",
    "Book the appointment" : "Agendar a reunião",
    "Reminder" : "Lembrete",
    "Notification" : "Notificação",
    "Email" : "E-mail",
    "Audio notification" : "Notificação de áudio",
    "Other notification" : "Outras notificações",
    "Relative to event" : "Relativo ao evento",
    "On date" : "Na data",
    "Edit time" : "Editar horário",
    "Save time" : "Gravar horário",
    "Remove reminder" : "Apagar lembrete",
    "+ Add reminder" : "+ Adicionar lembrete",
    "Add reminder" : "Adicionar lembrete ",
    "_second_::_seconds_" : ["segundo","segundos","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos","minutos"],
    "_hour_::_hours_" : ["hora","horas","horas"],
    "_day_::_days_" : ["dia","dias","dias"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "Invitation accepted" : "Convite aceite",
    "Available" : "Disponível",
    "Suggested" : "Sugerido",
    "Accepted {organizerName}'s invitation" : "Aceite convite de {organizerName}",
    "Not available" : "Indisponível",
    "Checking availability" : "A verificar disponibilidade",
    "Busy" : "Ocupado",
    "Unknown" : "Desconhecido",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Tentative" : "Tentativa",
    "Send email" : "Enviar e-mail",
    "All day" : "Todo o dia",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "depois",
    "first" : "primeiro",
    "third" : "terceiro",
    "fourth" : "quarto",
    "fifth" : "quinto",
    "second to last" : "do segundo ao último",
    "last" : "ultimo",
    "Repeat every" : "Repetir a cada",
    "By day of the month" : "Por dia do mês",
    "On the" : "No",
    "_month_::_months_" : ["mês","meses","meses"],
    "_year_::_years_" : ["ano","anos","anos"],
    "weekday" : "dia da semana",
    "weekend day" : "dia do fim-de-semana",
    "available" : "disponível",
    "More" : "Mais",
    "Pick a date" : "Escolha uma data",
    "Global" : "Global",
    "Personal" : "Pessoal",
    "Details" : "Detalhes",
    "Attendees" : "Participantes",
    "Resources" : "Recursos",
    "Close" : "Fechar",
    "Anniversary" : "Aniversário",
    "Miscellaneous" : "Diversos",
    "Week {number} of {year}" : "Semana {number} do {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Next" : "Seguinte",
    "Other" : "Outro",
    "When shared show full event" : "Quando partilhado, mostrar evento completo",
    "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
    "When shared hide this event" : "Quando partilhado, ocultar este evento",
    "Status" : "Estado",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelado",
    "Categories" : "Categorias",
    "Commuting" : "Em trânsito",
    "Presentation" : "Apresentação",
    "Talk" : "Falar",
    "Review" : "Rever",
    "Office" : "Escritório",
    "Mail" : "Correio",
    "Driving" : "Conduzir",
    "Biking" : "Andar de bicicleta",
    "Health" : "Saúde",
    "New Years Eve" : "Véspera de Ano Novo",
    "Fireworks" : "Fogo de artifício",
    "Running" : "Correr",
    "Marathon" : "Maratona",
    "Christmas" : "Natal",
    "Trip" : "Viagem",
    "Lecture" : "Leitura",
    "Seminar" : "Seminário",
    "Photograph" : "Fotografia",
    "Party" : "Festa",
    "Birthday" : "Aniversário",
    "Shopping" : "Compras",
    "Groceries" : "Mercearias",
    "Skate" : "Skate",
    "Skateboard" : "Skate",
    "Wine tasting" : "Degustação de vinho",
    "Golf" : "Golfe",
    "Dinner" : "Jantar",
    "Lunch" : "Almoço",
    "User not found" : "Utilizador não encontrado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
