OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "사용자 세션이 예기치 않게 만료되었습니다.",
    "Provided email-address is not valid" : "지정한 파일이 사진이 아님",
    "%s has published the calendar »%s«" : "%s 님이 달력 \"%s\"을(를) 공개했습니다",
    "Unexpected error sending email. Please contact your administrator." : "재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
    "Successfully sent email to %1$s" : "%1$s에게 이메일을 성공적으로 발송했습니다",
    "Hello," : "안녕하세요,",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s 님이 달력 \"%s\"을(를) 공개했음을 알려 드립니다.",
    "Open »%s«" : "%s 열기",
    "Cheers!" : "감사합니다!",
    "Upcoming events" : "곧 있을 일정",
    "Appointments" : "일정들",
    "Confirm" : "확인",
    "Date:" : "날짜:",
    "Where:" : "장소:",
    "Calendar" : "달력",
    "A Calendar app for Nextcloud" : "Nextcloud 달력 앱",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "캘린더 앱은 Nextcloud의 CalDAV 서버용 사용자 인터페이스입니다. 다양한 장치의 일정을 Nextcloud와 쉽게 동기화하고 온라인으로 편집하세요. \n* 🚀 ** 다른 Nextcloud 앱과 통합! ** 현재 연락처 - 추가 예정 \n* 🌐 ** WebCal 지원! ** 캘린더에서 좋아하는 팀의 경기 일정을 보고 싶으세요? 문제 없어요! \n* 🙋 ** 모여라! ** 내 일정에 사람들 초대합니다\n* ⌚️ ** 한가함 / 바쁨! ** 언제 미팅이 가능할지 확인할 수 있습니다\n* ⏰ ** 알림! ** 브라우저나 이메일로 일정에 대한 알람을 받을 수 있습니다 \n* 🔍 검색! 쉽게 일정 찾기\n* ☑️ 작업! 마감일이있는 작업을 캘린더에서 바로 확인할 수 있습니다 \n* 🙈 ** 우리는 바퀴를 새로 만들지 않습니다! ** 위대한  [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js] (https : // github.com/mozilla-comm/ical.js) 그리고 [fullcalendar] (https://github.com/fullcalendar/fullcalendar) 라이브러리를 기반으로 합니다.",
    "Previous day" : "이전날",
    "Previous week" : "이전주",
    "Previous month" : "이전달",
    "Next day" : "다음날",
    "Next week" : "다음주",
    "Next month" : "다음달",
    "New event" : "새 일정",
    "Today" : "오늘",
    "Day" : "일",
    "Week" : "주",
    "Month" : "달",
    "List" : "목록",
    "Preview" : "미리 보기",
    "Copy link" : "링크 복사",
    "Edit" : "수정",
    "Delete" : "삭제",
    "Add new" : "새로 추가",
    "Untitled calendar" : "제목없는 달력",
    "Edit name" : "이름 편집",
    "Saving name …" : "이름 저장 중...",
    "Edit color" : "색 편집",
    "Saving color …" : "색깔 저장 중...",
    "Copy private link" : "개인 링크 주소 복사",
    "Export" : "내보내기",
    "Unshare from me" : "나의 공유 해제",
    "An error occurred, unable to change visibility of the calendar." : "오류가 발생하여 달력의 공개 설정을 변경할 수 없습니다.",
    "An error occurred, unable to delete the calendar." : "오류가 발생하여 달력을 삭제할 수 없습니다.",
    "Calendar link copied to clipboard." : "달력의 링크를 클립보드에 복사되었습니다.",
    "Calendar link could not be copied to clipboard." : "달력의 링크를 클립보드에 저장할 수 없습니다.",
    "An error occurred, unable to rename the calendar." : "오류가 발생하여 달력의 이름을 변경할 수 없습니다.",
    "An error occurred, unable to change the calendar's color." : "오류가 발생하여 달력의 색깔을 변경할 수 없습니다.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}초 후 달력 공유 해제"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown}초 후 달력 삭제"],
    "Share link" : "링크 공유",
    "Publish calendar" : "달력 공개",
    "Publishing calendar" : "달력 공개 중",
    "Copy public link" : "공개 링크 복사",
    "Send link to calendar via email" : "이메일로 달력 링크 보내기",
    "Enter one address" : "주소 입력",
    "Sending email …" : "이메일로 보내는중 …",
    "Copy subscription link" : "구독 링크 복사",
    "Copying link …" : "링크 복사중 …",
    "Copied link" : "링크 복사됨",
    "Could not copy link" : "링크를 복사할 수 없음",
    "Copy embedding code" : "삽입 코드 복사",
    "Copying code …" : "코드 복사중 …",
    "Copied code" : "코드 복사됨",
    "Could not copy code" : "코드를 복사할 수 없음",
    "Delete share link" : "공유 링크 삭제",
    "Deleting share link …" : "공유링크 삭제 …",
    "An error occurred, unable to publish calendar." : "오류 발생, 달력을 공개할 수 없음",
    "An error occurred, unable to send email." : "오류 발생, 이메일로 보낼 수 없음",
    "Embed code copied to clipboard." : "삽입 코드가 클립보드에 복사됨",
    "Embed code could not be copied to clipboard." : "삽입 코드를 클립보드에 복사할 수 없음",
    "Unpublishing calendar failed" : "달력 공개 중단 실패",
    "Share with users or groups" : "사용자 및 그룹과 공유",
    "No users or groups" : "사용자나 그룹 없음",
    "can edit" : "편집 가능",
    "Unshare with {displayName}" : "{displayName}과 공유 중단",
    "An error occurred, unable to change the unshare the calendar." : "오류가 발생하여 달력의 공개 중단을 변경할 수 없습니다.",
    "An error occurred, unable to change the permission of the share." : "오류가 발생하여 공유 권한을 변경할 수 없습니다.",
    "New calendar" : "새 달력",
    "Creating calendar …" : "달력 생성중 …",
    "New calendar with task list" : "작업 목록이 포함된 새 달력",
    "New subscription from link (read-only)" : "링크를 통해 새로 구독하기 (읽기 전용)",
    "Creating subscription …" : "구독 생성 ...",
    "An error occurred, unable to create the calendar." : "오류가 발생하여 달력을 만들 수 없습니다.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "올바른 링크를 입력해 주십시오 (http://, https://, wdbcal://, 혹은 webcals:// 로 시작합니다.)",
    "Trash bin" : "휴지통",
    "Name" : "이름",
    "Deleted" : "삭제됨",
    "Restore" : "복원",
    "Delete permanently" : "영구히 삭제",
    "Empty trash bin" : "휴지통 비우기",
    "Could not load deleted calendars and objects" : "삭제된 달력과 요소들을 불러올 수 없음",
    "Could not restore calendar or event" : "달력과 일정을 복구할 수 없음",
    "Do you really want to empty the trash bin?" : "휴지통을 정말 비웁니까?",
    "Could not update calendar order." : "달력 순서를 갱신할 수 없습니다.",
    "Import calendars" : "달력 가져오기",
    "Please select a calendar to import into …" : "다음으로 가져올 달력을 선택해 주십시오 ...",
    "Filename" : "파일 이름",
    "Calendar to import into" : "다음으로 가져올 달력",
    "Cancel" : "취소",
    "_Import calendar_::_Import calendars_" : ["달력 가져오기"],
    "{filename} could not be parsed" : "{filename} 분석할 수 없음",
    "No valid files found, aborting import" : "올바른 파일을 발견할 수 없음, 가져오기 취소",
    "Import partially failed. Imported {accepted} out of {total}." : "가져오기가 부분적으로 실패했습니다. {total} 중 {accepted} 가져옴.",
    "Automatic" : "자동",
    "Automatic ({detected})" : "자동 ({detected})",
    "New setting was not saved successfully." : "새로운 설정이 저장되지 않았습니다.",
    "or" : "또는",
    "Previous period" : "이전 기간",
    "Next period" : "다음 기간",
    "Views" : "보기",
    "Day view" : "일간",
    "Week view" : "주간",
    "Month view" : "월간",
    "List view" : "목록 보기",
    "Actions" : "동작",
    "Create event" : "일정 만들기",
    "Show shortcuts" : "단축키 표시",
    "Enable birthday calendar" : "생일 달력 활성화",
    "Show tasks in calendar" : "달력에 작업 보이기",
    "Enable simplified editor" : "간편한 편집기 활성화",
    "Show weekends" : "공휴일 보기",
    "Show week numbers" : "주 번호 보이기",
    "Time increments" : "시간 단위",
    "Default reminder" : "기본 알림",
    "Copy primary CalDAV address" : "주 CalDAV 주소 복사하기",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV 주소 복사하기",
    "Personal availability settings" : "개인 별 가능한 시간대 설정",
    "Show keyboard shortcuts" : "키보드 단축키 표시",
    "No reminder" : "알림 없음",
    "CalDAV link copied to clipboard." : "CalDAV 링크를 클립보드에 복사했습니다.",
    "CalDAV link could not be copied to clipboard." : "CalDAV 링크를 클립보드에 복사할 수 없습니다.",
    "Location" : "위치",
    "Description" : "설명",
    "Visibility" : "표시 여부",
    "Duration" : "길이",
    "to" : "받는 사람",
    "Delete slot" : "시간대 삭제",
    "Add" : "추가",
    "Monday" : "월요일",
    "Tuesday" : "화요일",
    "Wednesday" : "수요일",
    "Thursday" : "목요일",
    "Friday" : "금요일",
    "Saturday" : "토요일",
    "Sunday" : "일요일",
    "Save" : "저장",
    "Update" : "업데이트",
    "Your email address" : "내 이메일 주소",
    "Reminder" : "알림",
    "before at" : "다음 이전에: ",
    "Notification" : "알림",
    "Email" : "이메일",
    "Audio notification" : "소리 알림",
    "Other notification" : "다른 알림",
    "Relative to event" : "일정과 관련된",
    "On date" : "날짜",
    "Edit time" : "시간 편집",
    "Save time" : "시간 저장",
    "Remove reminder" : "알림 삭제",
    "on" : "다음 시간/위치에: ",
    "at" : "다음 시간/위치에: ",
    "+ Add reminder" : "+ 알림 생성",
    "Add reminder" : "알림 추가",
    "_second_::_seconds_" : ["초"],
    "_minute_::_minutes_" : ["분"],
    "_hour_::_hours_" : ["시"],
    "_day_::_days_" : ["일"],
    "_week_::_weeks_" : ["주"],
    "Available" : "사용 가능",
    "Not available" : "사용할 수 없음",
    "Free" : "바쁘지 않음",
    "Busy (tentative)" : "바쁨 (잠정적으로)",
    "Busy" : "바쁨",
    "Out of office" : "자리에 없음",
    "Unknown" : "알 수 없음",
    "Accept" : "수락",
    "Decline" : "거절",
    "Tentative" : "예정됨",
    "Create Talk room for this event" : "이 일정에 대한 대화방 만들기",
    "Show busy times" : "바쁜 시간 보이기",
    "No attendees yet" : "아직 참석자가 없습니다",
    "Error creating Talk room" : "대화방 생성 오류",
    "Send email" : "이메일 보내기",
    "Chairperson" : "회장",
    "Required participant" : "필수 참여자",
    "Optional participant" : "추가 참여자",
    "Non-participant" : "미참여자",
    "Remove attendee" : "참석자 삭제",
    "Search for emails, users or contacts" : "이메일, 사용자 혹은 연락처 검색",
    "No match found" : "일치하는 항목 없음",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "초대장을 보내거나 답장을 관리하려면, [linkopen] 개인 설정에서 이메일 주소를 추가하십시오[linkclose].",
    "Remove color" : "색깔 삭제",
    "Event title" : "일정 제목",
    "All day" : "하루 종일",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "반복하는 이 일정의 \"하루 종일\" 여부를 수정할 수 없습니다.",
    "from {startDate}" : "{startDate} 부터",
    "from {startDate} at {startTime}" : "{startDate} {startTime} 부터",
    "to {endDate}" : "{endDate} 까지",
    "to {endDate} at {endTime}" : "{endDate} {endTime} 까지",
    "Repeat" : "반복",
    "End repeat" : "반복 종료",
    "never" : "없음",
    "after" : "이후",
    "_time_::_times_" : ["회"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "이 일정은 특정 반복 일정의 예외로 지정되어 있습니다. 이 일정에 다른 반복 규칙을 지정할 수 없습니다.",
    "first" : "첫번째",
    "third" : "세번째",
    "fourth" : "네번째",
    "fifth" : "다섯번째",
    "second to last" : "끝에서 두번째",
    "last" : "마지막",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "반복 규칙은 이번 및 그 이후의 일정에만 적용됩니다.",
    "Repeat every" : "반복 주기",
    "_month_::_months_" : ["개월"],
    "_year_::_years_" : ["년"],
    "weekday" : "주중",
    "weekend day" : "주말",
    "No recurrence" : "반복 없음",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud에서 이 일정의 반복 설정 방식을 완전히 지원하지 않습니다. 반복 설정을 편집할 경우, 현재의 반복 설정이 사라질 수 있습니다.",
    "No rooms or resources yet" : "방 혹은 비품 없음",
    "Has a projector" : "프로젝터 있음",
    "Has a whiteboard" : "화이트보드 있음",
    "Wheelchair accessible" : "휠체어 사용 가능",
    "Remove resource" : "비품 삭제",
    "Projector" : "프로젝터",
    "Whiteboard" : "화이트보드",
    "Search for resources or rooms" : "비품 혹은 방 검색",
    "available" : "사용 가능",
    "unavailable" : "사용 불가",
    "Room type" : "방 종류",
    "Minimum seating capacity" : "최소 좌석 수",
    "More" : "더 보기",
    "Update this occurrence" : "이 일정 업데이트",
    "Update this and all future" : "이후 모든 일정 업데이트",
    "Public calendar does not exist" : "공용 달력이 존재하지 않음",
    "Maybe the share was deleted or has expired?" : "공유가 삭제되었거나 만료되었을 수 있습니다.",
    "Please select a time zone:" : "시간대를 선택하십시오:",
    "Pick a time" : "시간 선택",
    "Pick a date" : "날짜 선택",
    "from {formattedDate}" : "{formattedDate} 부터",
    "to {formattedDate}" : "{formattedDate} 까지",
    "on {formattedDate}" : "{formattedDate}에",
    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 부터",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 까지",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 에",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "올바른 날짜를 입력하십시오",
    "Please enter a valid date and time" : "올바른 날짜와 시간을 입력하십시오",
    "Type to search time zone" : "시간대를 찾기 위해 입력하세요.",
    "Global" : "국제",
    "Time:" : "시간:",
    "Personal" : "개인",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "자동으로 감지된 귀하의 시간대가 UTC입니다.\n이 웹 브라우저의 보안 설정이 원인일 수 있습니다.\n달력 설정에서 수동으로 시간대를 설정해 주십시오.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "설정된 시간대 ({timezoneId}) 을(를) 찾을 수 없습니다. UTC로 설정됩니다.\n설정에서 시간대를 변경하고 이 문제를 보고해 주십시오.",
    "No more events today" : "오늘 더 이상 일정이 없음",
    "No upcoming events" : "다가오는 일정 없음",
    "Create a new event" : "새 일정 만들기",
    "[Today]" : "[오늘]",
    "[Tomorrow]" : "[내일]",
    "[Yesterday]" : "[어제]",
    "Event does not exist" : "일정이 존재하지 않음",
    "Delete this occurrence" : "이 일정 삭제",
    "Delete this and all future" : "이후 모든 일정 삭제",
    "Details" : "자세한 정보",
    "Attendees" : "참석자",
    "Resources" : "자원",
    "Close" : "닫기",
    "Show more details" : "더 자세히 보기",
    "Subscribe to {name}" : "{name} 구독",
    "Anniversary" : "기념일",
    "Appointment" : "일정",
    "Business" : "사업",
    "Education" : "교육",
    "Holiday" : "휴일",
    "Meeting" : "회의",
    "Non-working hours" : "비번인 시간",
    "Not in office" : "자리에 없음",
    "Phone call" : "전화 연락",
    "Sick day" : "병가",
    "Travel" : "여행",
    "Vacation" : "휴가",
    "Midnight on the day the event starts" : "자정에 일정이 시작됨",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["{formattedHourMinute}에 진행되는 일정의 %n일 전"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : [" {formattedHourMinute}에 진행되는 일정의 %n주 전 "],
    "on the day of the event at {formattedHourMinute}" : "{formattedHourMinute}에 진행되는 일정 당일",
    "at the event's start" : "일정의 시작에",
    "at the event's end" : "일정의 끝에",
    "{time} before the event starts" : "일정 시작 {time} 전",
    "{time} before the event ends" : "일정 종료 {time} 전",
    "{time} after the event starts" : "일정 시작 {time} 후",
    "{time} after the event ends" : "일정 종료 {time} 후",
    "on {time}" : "{time}에",
    "on {time} ({timezoneId})" : "{time} ({timezoneId})에",
    "Week {number} of {year}" : "{year}년 제 {number}주",
    "Does not repeat" : "반복하지 않음",
    "Daily" : "매일",
    "Weekly" : "매주",
    "Monthly" : "매달",
    "Yearly" : "매년",
    "_Every %n day_::_Every %n days_" : ["%n 일 마다"],
    "_Every %n week_::_Every %n weeks_" : ["%n 주 마다"],
    "_Every %n month_::_Every %n months_" : ["%n 개월 마다"],
    "_Every %n year_::_Every %n years_" : ["%n 년 마다"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekdays}"],
    "until {untilDate}" : "{untilDate} 까지",
    "Untitled event" : "제목없는 일정",
    "Untitled task" : "제목없는 작업",
    "Please ask your administrator to enable the Tasks App." : "관리자에게 Tasks 앱 활성화를 요청하십시오",
    "Prev" : "이전",
    "Next" : "다음",
    "Prev year" : "이전 년도",
    "Next year" : "다음 년도",
    "Year" : "년",
    "%n more" : "%n 더",
    "No events to display" : "표시할 일정 없음",
    "_+%n more_::_+%n more_" : ["+%n 더"],
    "No events" : "일정 없음",
    "Meeting room" : "회의실",
    "Lecture hall" : "강의실",
    "Seminar room" : "세미나실",
    "Other" : "기타",
    "When shared show full event" : "전체 일정 공유",
    "When shared show only busy" : "바쁨/한가함만 공유",
    "When shared hide this event" : "일정 공유하지 않음",
    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부",
    "Add a location" : "위치 추가",
    "Add a description" : "설명 추가",
    "Status" : "상태",
    "Confirmed" : "확인됨",
    "Canceled" : "취소됨",
    "Confirmation about the overall status of the event." : "일정의 전반적 상태에 대해 자세히 확인",
    "Show as" : "다음으로 표시: ",
    "Categories" : "분류",
    "Categories help you to structure and organize your events." : "카테고리는 일정을 만들고 조직할 때 도움이 됩니다.",
    "Search or add categories" : "카테고리를 찾거나 추가하기",
    "Add this as a new category" : "새 카테고리로 추가",
    "Special color of this event. Overrides the calendar-color." : "이 일정만의 색깔. 달력 색깔을 무시함.",
    "Chat room for event" : "일정에 대한 대화방",
    "Imported {filename}" : "{filename} 가져옴",
    "Meditation" : "명상",
    "Relaxing" : "휴식하기",
    "Relax" : "휴식",
    "Break" : "쉼",
    "Commuting" : "이동 중",
    "Shuttle" : "왕복",
    "Presentation" : "프레젠테이션",
    "Talk" : "토크",
    "Camping" : "캠핑하기",
    "Camp" : "캠핑",
    "Movie" : "영화",
    "Cinema" : "영화",
    "Graduation" : "졸업",
    "Review" : "리뷰",
    "Baseball" : "야구",
    "Meet" : "회의",
    "Office" : "사무실",
    "Mail" : "메일",
    "Soccer" : "축구",
    "Football" : "축구",
    "Gaming" : "게임",
    "Drive" : "드라이브",
    "Driving" : "운전",
    "Bicycle" : "자전거",
    "Cycle" : "사이클",
    "Biking" : "오토바이 타기",
    "Bike" : "오토바이",
    "Podcast" : "팟캐스트",
    "Basketball" : "농구",
    "Fishing" : "낚시",
    "Hiking" : "등산하기",
    "Hike" : "등산",
    "Exhibition" : "전시회",
    "Museum" : "박물관",
    "Pilates" : "필라테스",
    "Park" : "공원",
    "Studying" : "공부",
    "Doctor" : "의사",
    "Health" : "건강",
    "Dentist" : "치과",
    "Hospital" : "병원",
    "Interview" : "면접",
    "Training" : "훈련",
    "Practice" : "연습",
    "Sports" : "스포츠",
    "Exercise" : "운동",
    "Work out" : "운동",
    "Working out" : "운동하기",
    "Gym" : "체육관",
    "Barber" : "이발소",
    "Haircut" : "이발",
    "Exam" : "시험",
    "Written test" : "필기 시험",
    "Working" : "일",
    "Fireworks" : "불꽃놀이",
    "Running" : "달리기",
    "Go for a run" : "달리기",
    "Marathon" : "마라톤",
    "Video-conference" : "화상회의",
    "Video-call" : "영상 통화",
    "Video-chat" : "영상채팅",
    "Video-meeting" : "영상회의",
    "Call" : "전화",
    "Calling" : "전화하기",
    "Christmas" : "크리스마스",
    "Conference" : "회의",
    "Pizza" : "피자",
    "Travelling" : "여행가기",
    "Journey" : "탐험",
    "Collaborate" : "협업",
    "Lecture" : "강의",
    "Seminar" : "세미나",
    "Party" : "파티",
    "Celebration" : "축하",
    "Celebrate" : "축하하기",
    "Birthday" : "생일",
    "Shopping" : "쇼핑",
    "Skate" : "스케이트",
    "Skateboard" : "스케이트보드",
    "Golf" : "골프",
    "Dinner" : "저녁",
    "Lunch" : "점심",
    "User not found" : "사용자를 찾을 수 없음"
},
"nplurals=1; plural=0;");
